# 标识符

> 原文：<https://www.javatpoint.com/c-identifiers>

C 标识符代表 C 程序中的名称，例如变量、函数、数组、结构、联合、标签等。标识符可以由字母组成，如大写字母、小写字母、下划线、数字，但起始字母应该是字母或下划线。如果外部链接中没有使用该标识符，则它被称为内部标识符。如果标识符在外部链接中使用，则它被称为外部标识符。

我们可以说，标识符是以字母字符或下划线开头的字母数字字符的集合，用于表示各种编程元素，如变量、函数、数组、结构、联合、标签等。有 52 个字母字符(大写和小写)、下划线字符和 10 个数字(0-9)表示标识符。代表标识符的字母数字字符共有 63 个。

## 构造 C 标识符的规则

*   标识符的第一个字符应该是字母或下划线，其后可以是任何字符、数字或下划线。
*   它不应该以任何数字开头。
*   在标识符中，大写字母和小写字母是不同的。因此，我们可以说标识符区分大小写。
*   标识符中不能指定逗号或空格。
*   关键字不能表示为标识符。
*   标识符的长度不应超过 31 个字符。
*   标识符应该以有意义、简短和易于阅读的方式书写。

**有效标识符示例**

```

total, sum, average, _m _, sum_1, etc.

```

**无效标识符示例**

```

2sum (starts with a numerical digit)
int (reserved word)
char (reserved word)
m+n (special character, i.e., '+')

```

## 标识符的类型

*   内部标识符
*   外部标识符

**内部标识符**

如果外部链接中没有使用该标识符，则称其为内部标识符。内部标识符可以是局部变量。

**外部标识符**

如果该标识符用于外部链接，则称为外部标识符。外部标识符可以是函数名、全局变量。

## 关键字和标识符的区别

| 关键字 | 标识符 |
| 关键字是一个预定义的单词。 | 标识符是用户定义的单词 |
| 必须用小写字母写。 | 它可以用小写字母和大写字母书写。 |
| 它的含义是在 c 编译器中预先定义的。 | 它的含义在 c 编译器中没有定义。 |
| 它是字母字符的组合。 | 它是字母数字字符的组合。 |
| 它不包含下划线字符。 | 它可以包含下划线字符。 |

**我们通过一个例子来了解一下。**

```

int main()
{
    int a=10;
    int A=20;
    printf("Value of a is : %d",a);
    printf("\nValue of A is :%d",A);
    return 0;
}

```

**输出**

```
Value of a is : 10
Value of A is :20  

```

上面的输出显示变量“A”和“A”的值是不同的。因此，我们得出结论，标识符区分大小写。

* * *