# 什么是文字？

> 原文：<https://www.javatpoint.com/literals-in-c>

文字是分配给常量变量的常量值。我们可以说文字代表不可修改的固定值。它也包含内存，但没有引用作为变量。例如，const int = 10 是一个常量整数表达式，其中 10 是整数。

## 文字的类型

**在 [C 编程](https://www.javatpoint.com/c-programming-language-tutorial)中存在四种类型的文字:**

*   **整数文字**
*   **浮动文字**
*   **字符文字**
*   **字符串文字**

### 整数文字

它是一个数字文字，只表示整型值。它既不代表分数部分也不代表指数部分。

### 可以通过以下三种方式指定:

### 十进制数(以 10 为基数)

它通过表示 0 到 9 之间的数字来定义。比如 45、67 等。

### 八进制数(以 8 为基数)

它被定义为一个数字，其中 0 后跟数字，如 0，1，2，3，4，5，6，7。例如 012、034、055 等。

### 十六进制数(以 16 为基数)

它被定义为一个数字，其中 0x 或 0X 后跟十六进制数字(即从 0 到 9 的数字，字母字符从(a-z)或(A-Z))。

**一个整数文字由以下两个符号限定符后缀:**

**L 或 l:** 它是一个大小限定符，指定整数类型的大小为 long。

**U 或 u:** 它是一个符号限定符，表示整数的类型为无符号。无符号限定符只包含正值。

#### 注意:不考虑限定词的顺序，即 lu 和 ul 都是相同的。

**我们来看一个简单的整数字面量的例子。**

```

#include <stdio.h>
int main()
{
    const int a=23;  // constant integer literal
    printf("Integer literal : %d", a);
    return 0;
}

```

**输出**

```
Integer literal : 23

```

### 浮动文字

它是一个只包含浮点值或实数的文字。这些实数包含整数部分、实数部分、指数部分和小数部分等部分的数量。浮点文字必须以十进制或指数形式指定。让我们简单了解一下这些形式。

### 十进制形式

十进制形式必须包含小数点和/或指数部分。如果它不包含这两个，那么编译器将抛出一个错误。十进制记数法的前缀可以是“+”或“-”符号，表示正数和负数。

**十进制形式的浮点文字的例子有:**

```

1.2, +9.0, -4.5

```

**我们来看一个十进制形式的浮点字面量的简单例子。**

```

#include <stdio.h>
int main()
{
    const float a=4.5; // constant float literal
    const float b=5.6; // constant float literal
    float sum;
    sum=a+b;
    printf("%f", sum);
    return 0;
}

```

**输出**

```
10.100000

```

### 指数形式

当我们想要表示一个数量级很大的数字时，指数形式很有用。它包含尾数和指数两部分。例如，数字是 2340000000000，可以用指数形式表示为 2.34e12。

**指数形式的浮点文字的语法**

```

[+/-] <Mantissa> <e/E> [+/-] <Exponent>

```

指数记数法中的实数示例有:

```

+1e23, -9e2, +2e-25

```

**创建指数符号的规则**

**以下是用指数表示法创建浮点文字的规则:**

*   在指数表示法中，尾数可以用十进制或小数形式指定。
*   指数可以写成大写和小写，即 e 和 e
*   我们可以在尾数和指数之前使用两个符号，即正和负。
*   不允许有空格

### 字符文字

字符文字包含单引号内的单个字符。如果给变量分配了多个字符，那么我们需要创建一个字符数组。如果我们试图在一个变量中存储多个字符，那么就会产生一个**多字符字符常量**的警告。让我们通过一个例子来观察这个场景。

```

#include <stdio.h>
int main()
{
    const char c='ak';
    printf("%c",c);
    return 0;
}

```

在上面的代码中，我们在单引号中使用了两个字符，即“ak”。因此，该语句将生成如下所示的警告。

**警告生成:**

```

main.c:6:18: warning: multi-character character constant
      [-Wmultichar]
    const char c='ak';
main.c:6:18: warning: implicit conversion from 'int' to 'char'
      changes value from 24939 to 107 [-Wconstant-conversion]
    const char c='ak';
               ~ ^~~~
2 warnings generated.
? ./main

```

**字符文字的表示**

**字符文字可以通过以下方式表示:**

*   它可以通过在单引号中指定一个字符来表示。例如‘a’、‘b’等。
*   我们可以在单引号中指定转义序列字符来表示字符文本。例如，' \n '，' \a '，' \b '。
*   我们也可以用整数形式的 ASCII 来表示字符文字。例如，65 的 ascii 值是“A”。
*   八进制和十六进制符号可以用作转义序列来表示字符文本。例如，' \023 '，' \0x12 '。

### 字符串文字

字符串表示双引号内的多个字符。它包含一个额外的字符，即' \0 '(空字符)，自动插入。这个空字符指定字符串的结尾。我们可以使用“+”符号来连接两个字符串。

例如，

String1= "javatpoint";

String2 = " family

为了连接以上两个字符串，我们使用‘+’运算符，如下语句所示:

“javatpoint”+“family”= javatpoint family

#### 注意:如果我们表示一个字符，即“b”，那么这个字符将占用一个字节，因为它是一个字符文字。而且，如果我们用双引号" b "来表示字符，那么它将占用更多的字节，因为它是一个字符串。

* * *