# C 中的静态

> 原文：<https://www.javatpoint.com/static-in-c>

Static 是 C 编程语言中使用的一个关键字。它可以用于变量和函数，也就是说，我们可以声明一个静态变量和静态函数。一个普通的变量被限制在它被定义的范围内，而静态变量的范围在整个程序中。

### Static 关键字可用于以下情况:

*   **静态全局变量**
    当一个全局变量用 Static 关键字声明时，那么它就被称为静态全局变量。它在程序的顶部声明，并且它的可见性贯穿整个程序。
*   **静态函数**
    当一个函数用静态关键字声明时称为静态函数。它的生命周期贯穿整个程序。
*   **静态局部变量**
    当一个局部变量用 Static 关键字声明时，那么它就被称为静态局部变量。静态局部变量的内存在整个程序中是有效的，但是变量的可见性范围与自动局部变量相同。然而，当函数在第一次函数调用期间修改静态局部变量时，这个修改后的值也可用于下一次函数调用。
*   **静态成员变量**
    当成员变量在一个类中用 Static 关键字声明时，那么它就被称为静态成员变量。一个类的所有实例都可以访问它们，而不是特定的实例。
*   **静态方法**
    用 Static 关键字声明的类的成员函数称为静态方法。一个类的所有实例都可以访问它，而不是特定的实例。

**我们通过一个例子来了解一下。**

```

#include <stdio.h>
int main()
{
 printf("%d",func());
printf("\n%d",func());
 return 0;
}
int func()
{ 
    int count=0; // variable initialization
    count++; // incrementing counter variable

   return count; }

```

在上面的代码中，调用了 func()函数。在 func()中，计数变量被更新。一旦函数完成执行，count 变量的内存将被移除。如果我们不想从内存中移除计数，那么我们需要使用 count 变量作为静态变量。如果我们将变量声明为静态的，那么即使函数完成执行，变量也不会从内存中移除。

**输出**

```
1                                                                                                                               
1

```

### 静态变量

静态变量是在各种函数调用中保持其值的变量。

**语法**

静态变量的语法如下:

```

static data_type variable_name; 

```

**我们来看一个静态变量的简单例子。**

```

#include <stdio.h>
int main()
{
   printf("%d",func());
   printf("\n%d",func());

    return 0;
}
int func()
{
    static int count=0;
    count++;
    return count;
}

```

在上面的代码中，我们已经将 count 变量声明为静态的。调用 func()时，count 的值更新为 1，在下一次函数调用期间，count 变量的值变为 2。因此，我们可以说静态变量的值在函数调用中保持不变。

**输出**

```
1                                                                                                                             
2        

```

### 静态函数

我们知道，非静态函数在默认情况下是全局的，这意味着函数也可以在文件之外访问，但是如果我们将函数声明为静态的，那么它会限制函数的范围。静态函数只能在文件中访问。

**静态函数看起来像:**

```

static void func()
{
    printf("Hello javaTpoint");
}

```

### 静态变量和全局变量之间的差异

全局变量是在函数外部声明的变量。这些全局变量存在于[程序](https://www.javatpoint.com/cpp-programs)的开始，其范围一直保持到程序结束。它也可以在程序外访问。

静态变量仅限于定义它们的源文件，即它们不能被其他源文件访问。

静态变量和全局变量都有静态初始化。这里，静态初始化意味着，如果我们不为变量赋值，那么默认情况下，将为变量赋值 0。

### 静态局部变量和静态全局变量的区别

**静态全局变量**

如果变量在函数外部用静态关键字声明，那么它就被称为静态全局变量。它可以在整个程序中访问。

**静态局部变量**

带有静态关键字的变量在函数内部声明，称为静态局部变量。静态局部变量的范围将与自动局部变量相同，但是它的内存将在整个程序执行过程中可用。当函数在一次函数调用期间修改静态局部变量的值时，即使在下一次函数调用期间，它也将保持不变。

### 静态变量的属性

**以下是静态变量的属性:**

*   静态变量的内存是在静态变量中分配的。
*   它的内存在整个程序中是可用的，但是范围将保持与自动局部变量相同。它的
*   值将在各种函数调用中保持不变。
*   如果我们没有给变量赋值，那么默认值将是 0。
*   全局静态变量不能在程序外部访问，而全局变量可以被其他源文件访问。

* * *