# C 语言中的条件运算符

> 原文：<https://www.javatpoint.com/conditional-operator-in-c>

条件运算符也称为**三元运算符**。条件语句是依赖于表达式输出的决策语句。它由两个符号表示，即“？”和“:”。

由于条件运算符作用于三个操作数，因此也称为三元运算符。

条件运算符的行为类似于“ [if-else](https://www.javatpoint.com/c-if-else) ”语句，因为“if-else”语句也是一个决策语句。

### 条件运算符的语法

```

Expression1? expression2: expression3;

```

**上述语法的图示如下所示:**

![Conditional Operator in C](img/e50398d3c3e47a159364a22dbe312b43.png)

**以上语法的含义。**

*   在上面的语法中，表达式 1 是一个布尔条件，可以是真值也可以是假值。
*   如果表达式 1 得到真值，那么表达式 2 将执行。
*   只有当表达式 2 返回非零值时，它才被认为是真的。
*   如果表达式 1 返回假值，那么表达式 3 将执行。
*   表达式 3 只有在返回值为零时才被认为是假的。

**我们通过一个例子来理解三元或条件运算符。**

```

#include <stdio.h>
int main()
{
    int age;  // variable declaration
    printf("Enter your age");
    scanf("%d",&age);   // taking user input for age variable
    (age>=18)? (printf("eligible for voting")) : (printf("not eligible for voting"));  // conditional operator
    return 0;
}

```

在上面的代码中，我们将输入作为用户的“年龄”。在接受输入后，我们已经使用条件运算符应用了该条件。在这种情况下，我们正在检查用户的年龄。如果用户年龄大于或等于 18 岁，则陈述 1 将执行，即(printf("有资格投票"))否则，陈述 2 将执行，即(printf("无资格投票"))。

**我们来观察一下上面程序的输出。**

如果我们提供 18 岁以下用户的年龄，那么输出将是:

![Conditional Operator in C](img/9f10b957d5a6fe3108f38466a33b2edc.png)

如果我们提供 18 岁以上的用户年龄，那么输出将是:

![Conditional Operator in C](img/b8924e9eed8eba2ffc17195c1762c866.png)

从上面两个输出中我们可以观察到，如果条件为真，那么语句 1 被执行；否则，语句 2 将被执行。

到目前为止，我们已经观察到条件运算符如何检查条件并基于条件执行语句。现在，我们将了解如何使用条件运算符为变量赋值。

**我们通过一个例子来理解这个场景。**

```

#include <stdio.h>
int main()
{
   int a=5,b;  // variable declaration
   b=((a==5)?(3):(2)); // conditional operator
   printf("The value of 'b' variable is : %d",b);
    return 0;
}

```

在上面的代码中，我们已经声明了两个变量，即‘a’和‘b’，并为‘a’变量赋值 5。在声明之后，我们使用条件运算符为“b”变量赋值。如果“a”的值等于 5，则“b”被赋值为 3，否则为 2。

**输出**

![Conditional Operator in C](img/0337d8c2f6911a62659647f35a9458ce.png)

上面的输出显示“b”变量的值是 3，因为“a”变量的值等于 5。

正如我们所知，条件运算符和 if-else 的行为是相似的，但它们有一些区别。让我们看看他们的区别。

*   条件运算符是单个编程语句，而“if-else”语句是一个编程块，其中语句位于括号下面。
*   条件运算符也可用于给变量赋值，而“if-else”语句不能用于赋值。
*   当语句是多个时，它对于执行语句是没有用的，而当执行多个语句时，if-else 语句被证明是更合适的。
*   嵌套的三元运算符更复杂，不容易调试，而嵌套的“if-else”语句易于读取和维护。

* * *