# 转换语句

> 原文：<https://www.javatpoint.com/c-switch>

C 语言中的 switch 语句是 if-else-if 梯形语句的替代语句，它允许我们对一个名为 switch variable 的变量的不同可能值执行多个操作。在这里，我们可以为单个变量的不同值定义多种情况下的各种语句。

[c 语言](https://www.javatpoint.com/c-programming-language-tutorial)中 switch 语句的语法如下:

```
switch(expression){  
case value1:  
 //code to be executed;  
 break;  //optional
case value2:  
 //code to be executed;  
 break;  //optional
......  

default:   
 code to be executed if all cases are not matched;  
}  

```

* * *

### C 语言中开关语句的规则

1)*开关表达式*必须是整数或字符类型。

2)*大小写值*必须是整数或字符常量。

3)*案例值*只能在 switch 语句内部使用。

4)开关情况下的*断线声明*不是必须的。它是可选的。如果在案例中没有找到 break 语句，所有案例都将在匹配的案例之后执行。它被称为*跌落通过*状态的 C 开关语句。

让我们试着通过例子来理解它。我们假设有以下变量。

```
int x,y,z;
char a,b;
float f;

```

| 有效开关 | 无效开关 | 有效案例 | 无效案例 |
| 开关(x) | 开关(f) | 案例 3； | 案例 2.5； |
| 开关(x>y) | 开关(x+2.5) | 案例“a”； | 案例十； |
| 开关(a+b-2) |  | 案例 1+2； | 病例 x+2； |
| 开关(func(x，y)) |  | 大小写' x ' > ' y | 案例 1、2、3； |

* * *

#### C 语言中开关语句的流程图

![flow of switch statement in c](img/d88369a3be936e513e43c5a2777463cd.png)

## 开关状态语句的功能

首先，计算 switch 语句中指定的整数表达式。然后将该值与不同情况下给出的常数值一一匹配。如果找到匹配，则执行该案例中指定的所有语句以及该案例之后出现的所有案例，包括默认语句。没有两种情况可以有相似的值。如果匹配的事例包含一个 break 语句，那么在此之后出现的所有事例都将被跳过，并且控制从开关中出来。否则，将执行匹配案例之后的所有案例。

让我们看一个简单的 c 语言 switch 语句的例子。

```
#include int main(){  
int number=0;   
printf("enter a number:");  
scanf("%d",&number);  
switch(number){  
case 10:  
printf("number is equals to 10");  
break;  
case 50:  
printf("number is equal to 50");  
break;  
case 100:  
printf("number is equal to 100");  
break;  
default:  
printf("number is not equal to 10, 50 or 100");  
}  
return 0;
} 
```

**输出**

```
enter a number:4
number is not equal to 10, 50 or 100

```

```
enter a number:50
number is equal to 50

```

* * *

### 开关案例示例 2

```
#include <stdio.h>
int main()
{
	int x = 10, y = 5; 
	switch(x>y && x+y>0)
	{
		case 1: 
		printf("hi");
		break; 
		case 0: 
		printf("bye");
		break;
		default: 
		printf(" Hello bye ");
	} 

}

```

**输出**

```
hi	

```

#### 开关语句失败

在 C 语言中，switch 语句是通过的；这意味着如果在 switch case 中不使用 break 语句，匹配 case 之后的所有 case 都将被执行。

让我们通过下面给出的例子来理解 switch 语句的失败状态。

```
#include int main(){  
int number=0;  

printf("enter a number:");
scanf("%d",&number);

switch(number){
case 10:
printf("number is equal to 10\n");
case 50:
printf("number is equal to 50\n");
case 100:
printf("number is equal to 100\n");
default:
printf("number is not equal to 10, 50 or 100");
}
return 0;
} 
```

**输出**

```
enter a number:10
number is equal to 10
number is equal to 50
number is equal to 100
number is not equal to 10, 50 or 100

```

**输出**

```
enter a number:50
number is equal to 50
number is equal to 100
number is not equal to 10, 50 or 100

```

### 嵌套开关事例语句

我们可以在 switch 语句中使用任意多的 switch 语句。这种类型的语句称为嵌套开关语句。考虑下面的例子。

```
#include <stdio.h>
int main () {

   int i = 10;
   int j = 20;

   switch(i) {

      case 10: 
         printf("the value of i evaluated in outer switch: %d\n",i);
      case 20:
         switch(j) {
            case 20:
               printf("The value of j evaluated in nested switch: %d\n",j);
         }
   }

   printf("Exact value of i is : %d\n", i );
   printf("Exact value of j is : %d\n", j );

   return 0;
}

```

**输出**

```
the value of i evaluated in outer switch: 10
The value of j evaluated in nested switch: 20
Exact value of i is : 10
Exact value of j is : 20 

```

* * *