# if-else vs switch

> 原文：<https://www.javatpoint.com/if-else-vs-switch>

### 什么是 if-else 语句？

C 程序设计中的 if-else 语句是一个条件语句，它根据条件是真还是假来执行一组不同的语句。只有当指定条件为真时，才会执行“if”块，如果指定条件为假，则会执行 else 块。

**if-else 语句的语法如下:**

```

if(expression)
{
    // statements;
}
else
{
   // statements;
}

```

### 什么是 switch 语句？

一个[开关语句](https://www.javatpoint.com/c-switch)是在 [C 编程](https://www.javatpoint.com/c-programming-language-tutorial)中使用的一个条件语句，用于检查一个变量的值，并将其与所有情况进行比较。如果该值与任何情况匹配，则执行其相应的语句。每个案例都有一些名称或编号，称为标识符。用户输入的值将与所有案例进行比较，直到找到案例。如果用户输入的值与任何情况都不匹配，那么将执行默认语句。

**switch 语句的语法如下:**

```

switch(expression)
{
  case constant 1:
  // statements;
  break;
  case constant 2:
  // statements;
  break;
  case constant n:
  // statements;
  break;
 default:
// statements;
}

```

### 相似性 b/w if-else 和 switch

if-else 和 switch 都是决策语句。这里，决策语句意味着表达式的输出将决定执行哪些语句。

### 不带 if-else 和 switch 语句的差异

【if-else 和 switch 语句的区别如下:

![if-else vs switch](img/16a07b6505b41cefd844c7371afe11a7.png)

*   **定义**

**如果-否则**

根据“if-else”语句中的表达式结果，将执行语句块。如果条件为真，则执行“If”块，否则执行“else”块。

**切换语句**

switch 语句包含多个案例或选项。用户将决定要执行的案例。

*   **表达式**

**If-else**

它可以包含单个表达式，也可以包含用于多个选择的多个表达式。在这种情况下，表达式的计算基于值或条件的范围。它检查等式和逻辑表达式。

**开关**

它只包含一个表达式，这个表达式要么是一个整数对象，要么是一个字符串对象。它只检查等式表达式。

*   **评估**

**If-else**

if-else 语句可以计算几乎所有类型的数据，如整数、浮点、字符、指针或布尔值。

**开关**

switch 语句可以计算整数或字符。

*   **执行顺序**

**If-else**

在“if-else”语句的情况下，将根据条件执行“if”块或“else”块。

**开关**

在‘switch’语句的情况下，将执行一个接一个的情况，直到找不到 **break** 关键字，或者执行默认语句。

*   **默认执行**

**If-else**

如果“If”语句中的条件不为真，则默认情况下，将执行 else block 语句。

**开关**

如果在**开关**语句中指定的表达式与任何一种情况都不匹配，那么将执行默认语句(如果已定义)。

*   **值**

**If-else**

值基于“if”语句中指定的条件。该值将决定是执行“if”还是“else”块。

**开关**

在这种情况下，价值由用户决定。根据用户的选择，案例将被执行。

*   **使用**

**If-else**

它评估条件为真或假。

**开关**

一个**开关**语句将变量的值与多个情况进行比较。如果该值与任何一个案例匹配，那么将执行与该案例相关联的语句块。

*   **编辑**

**If-else**

在' if-else '语句中编辑并不容易，就好像我们删除了' else '语句，那么它就会造成大破坏。

**开关**

与“if-else”语句相比，在**开关**语句中编辑更容易。如果我们从开关中移除任何案例，那么它不会中断其他案例的执行。因此，我们可以说**开关**语句很容易修改和维护。

*   **速度**

**If-else**

如果有多个选择，那么“if-else”语句的执行速度就会很慢。

**开关**

switch 语句中的 case 常量在编译时创建一个跳转表。这个跳转表根据表达式的值选择执行路径。如果我们有一个多项选择，那么 switch 语句的执行将比“if-else”语句的等效逻辑快得多。

**我们用表格的形式总结一下上面的区别。**

|  | 如果-否则 | 转换 |
| **定义** | 根据“if”语句中的条件，执行“if”和“else”块。 | 用户将决定执行哪个语句。 |
| **表达式** | 它包含逻辑表达式或等式表达式。 | 它包含单个表达式，可以是字符或整数变量。 |
| **评估** | 它计算所有类型的数据，如整数、浮点、字符或布尔值。 | 它要么计算整数，要么计算字符。 |
| **执行顺序** | 首先，检查条件。如果条件为真，则执行“如果”块，否则执行“否则”块 | 它一个接一个地执行，直到找不到 break 关键字，或者执行默认语句。 |
| **默认执行** | 如果条件不为真，那么默认情况下，将执行 else 块。 | 如果该值与任何情况都不匹配，那么默认情况下，将执行 default 语句。 |
| **编辑** | 在“if-else”语句中编辑并不容易。 | switch 语句中的案例易于维护和修改。因此，我们可以说，删除或编辑任何案件都不会中断其他案件的执行。 |
| **速度** | 如果通过“if-else”实现了多个选择，那么执行速度会很慢。 | 如果我们有多个选择，那么 switch 语句是最好的选择，因为执行速度将远远高于 if-else。 |

* * *