# C 语言中的值调用和引用调用

> 原文：<https://www.javatpoint.com/call-by-value-and-call-by-reference-in-c>

用 C 语言将数据传入函数有两种方法，即*按值调用*和*按引用调用*。

![call by value and call by reference in c](img/f95ed31c3190837ce384bb103398539c.png)

让我们逐个理解 c 语言中的按值调用和按引用调用。

* * *

## 按值调用

*   在按值调用方法中，实际参数的值被复制到形式参数中。换句话说，我们可以说变量的值用在了 value by 方法的函数调用中。
*   在按值调用方法中，我们不能通过形式参数修改实际参数的值。
*   在按值调用中，由于实际参数的值被复制到形式参数中，因此为实际参数和形式参数分配了不同的内存。
*   实际参数是函数调用中使用的参数，而形式参数是函数定义中使用的参数。

让我们通过下面给出的例子来理解 c 语言中按值调用的概念:

```
#include void change(int num) {  
    printf("Before adding value inside function num=%d \n",num);  
    num=num+100;  
    printf("After adding value inside function num=%d \n", num);  
}  
int main() {  
    int x=100;  
    printf("Before function call x=%d \n", x);  
    change(x);//passing value in function  
    printf("After function call x=%d \n", x);  
return 0;
} 
```

#### 输出

```
Before function call x=100
Before adding value inside function num=100
After adding value inside function num=200
After function call x=100

```

* * *

#### 按值调用示例:交换两个变量的值

```
#include <stdio.h>
void swap(int , int); //prototype of the function 
int main()
{
    int a = 10;
    int b = 20; 
    printf("Before swapping the values in main a = %d, b = %d\n",a,b); // printing the value of a and b in main
    swap(a,b);
    printf("After swapping values in main a = %d, b = %d\n",a,b); // The value of actual parameters do not change by changing the formal parameters in call by value, a = 10, b = 20
}
void swap (int a, int b)
{
    int temp; 
    temp = a;
    a=b;
    b=temp;
    printf("After swapping values in function a = %d, b = %d\n",a,b); // Formal parameters, a = 20, b = 10 
}

```

#### 输出

```
Before swapping the values in main a = 10, b = 20
After swapping values in function a = 20, b = 10
After swapping values in main a = 10, b = 20  

```

## C 语言中的引用调用

*   在引用调用中，变量的地址作为实际参数传递到函数调用中。
*   由于传递了实际参数的地址，因此可以通过更改形式参数来修改实际参数的值。
*   在引用调用中，形式参数和实际参数的内存分配是相似的。函数中的所有操作都是对存储在实际参数地址的值执行的，修改后的值存储在相同的地址。

考虑以下引用调用的示例。

```
#include void change(int *num) {  
    printf("Before adding value inside function num=%d \n",*num);  
    (*num) += 100;  
    printf("After adding value inside function num=%d \n", *num);  
}    
int main() {  
    int x=100;  
    printf("Before function call x=%d \n", x);  
    change(&x);//passing reference in function  
    printf("After function call x=%d \n", x);  
return 0;
} 
```

#### 输出

```
Before function call x=100
Before adding value inside function num=100
After adding value inside function num=200
After function call x=200

```

#### 引用调用示例:交换两个变量的值

```
#include <stdio.h>
void swap(int *, int *); //prototype of the function 
int main()
{
    int a = 10;
    int b = 20; 
    printf("Before swapping the values in main a = %d, b = %d\n",a,b); // printing the value of a and b in main
    swap(&a,&b);
    printf("After swapping values in main a = %d, b = %d\n",a,b); // The values of actual parameters do change in call by reference, a = 10, b = 20
}
void swap (int *a, int *b)
{
    int temp; 
    temp = *a;
    *a=*b;
    *b=temp;
    printf("After swapping values in function a = %d, b = %d\n",*a,*b); // Formal parameters, a = 20, b = 10 
}

```

#### 输出

```
Before swapping the values in main a = 10, b = 20
After swapping values in function a = 20, b = 10
After swapping values in main a = 20, b = 10  

```

* * *

## c 语言中按值调用和按引用调用的区别

| 号码 | 按值调用 | 引用调用 |
| one | 该值的副本被传递到函数中 | 值的地址被传递到函数中 |
| Two | 在函数内部所做的更改仅限于函数。实际参数的值不会因为形式参数的改变而改变。 | 在函数内部进行的更改也会在函数外部进行验证。实际参数的值通过改变形式参数而改变。 |
| three | 实际参数和形式参数是在不同的内存位置创建的 | 实际参数和形式参数是在同一个内存位置创建的 |