# C 语言中的递归

> 原文：<https://www.javatpoint.com/recursion-in-c>

递归是当一个函数调用自己的一个副本来处理一个较小的问题时产生的过程。任何调用自身的函数称为递归函数，这样的函数调用称为递归调用。递归涉及多个递归调用。然而，强加递归的终止条件是很重要的。递归代码比迭代代码短，但是很难理解。

递归不能应用于所有的问题，但是对于可以用相似子任务定义的任务更有用。例如，递归可以应用于排序、搜索和遍历问题。

一般来说，迭代解决方案比递归更有效，因为函数调用总是开销很大。任何可以递归解决的问题，也可以迭代解决。然而，有些问题最适合用递归来解决，例如汉诺塔、斐波那契数列、阶乘求法等。

在下面的例子中，递归被用来计算一个数的阶乘。

```
#include <stdio.h>
int fact (int);
int main()
{
    int n,f;
    printf("Enter the number whose factorial you want to calculate?");
    scanf("%d",&n);
    f = fact(n);
    printf("factorial = %d",f);
}
int fact(int n)
{
    if (n==0)
    {
        return 0;
    }
    else if ( n == 1)
    {
        return 1;
    }
    else 
    {
        return n*fact(n-1);
    }
}

```

#### 输出

```
Enter the number whose factorial you want to calculate?5
factorial = 120 

```

我们可以通过下图来理解上述程序的递归方法调用:

![c recursion program](img/e5cdcb38c50feebe8a136ce89fa0f0cd.png)

## 递归函数

递归函数通过将任务分成子任务来执行任务。函数中定义了一个终止条件，由某个特定的子任务来满足。此后，递归停止，最终结果从函数返回。

函数不重复出现的情况称为基本情况，而函数不断调用自身来执行子任务的情况称为递归情况。所有递归函数都可以用这种格式编写。

下面给出了编写任何递归函数的伪代码。

```
if (test_for_base)
{
	return some_value;
}
else if (test_for_another_base)
{
	return some_another_value;
}
else
{
	// Statements;
	recursive call;
}

```

## C 语言中递归的例子

让我们看一个例子来找到斐波那契数列的第 n 项。

```
#include<stdio.h>
int fibonacci(int);
void main ()
{
    int n,f;
    printf("Enter the value of n?");
    scanf("%d",&n);
    f = fibonacci(n);
    printf("%d",f);
}
int fibonacci (int n)
{
    if (n==0)
    {
    return 0;
    }
    else if (n == 1)
    {
        return 1; 
    }
    else
    {
        return fibonacci(n-1)+fibonacci(n-2);
    }
}

```

#### 输出

```
Enter the value of n?12 
144 

```

## 递归方法的内存分配

每次递归调用都会在内存中创建该方法的新副本。一旦方法返回了一些数据，副本就会从内存中移除。由于函数内部声明的所有变量和其他东西都存储在堆栈中，因此每次递归调用时都会维护一个单独的堆栈。一旦从相应的函数返回值，堆栈就会被破坏。递归在解析和跟踪每次递归调用的值时涉及到如此多的复杂性。因此，我们需要维护堆栈并跟踪堆栈中定义的变量值。

让我们考虑下面的例子来理解递归函数的内存分配。

```
	int display (int n)
	{
		if(n == 0)
			return 0; // terminating condition
		else 
		{
			printf("%d",n);
			return display(n-1); // recursive call
		}
	}

```

**解释**

让我们检查 n = 4 的递归函数。首先，维护所有堆栈，打印相应的 n 值，直到 n 变为 0。一旦达到终止条件，通过将 0 返回到调用堆栈，堆栈会被逐个销毁。有关递归函数堆栈跟踪的更多信息，请参考下图。

![stack trace for recursive function](img/8c527793756ea198fc22f0bf3fb7645e.png)