# C 语言中的存储类

> 原文：<https://www.javatpoint.com/storage-classes-in-c>

C 语言中的存储类用于确定变量的生存期、可见性、内存位置和初始值。C 语言中有四种类型的存储类

*   自动的
*   外部
*   静态
*   注册

| 存储类 | 堆栈 | 缺省值 | 范围 | 一生 |
| 汽车 | 随机存取存储 | 垃圾价值 | 当地的 | 功能内 |
| 走读生 | 随机存取存储 | 零 | 全球的 | 直到主程序结束，可能在程序中的任何地方声明 |
| 静电 | 随机存取存储 | 零 | 当地的 | 直到主程序结束，保留多个函数调用之间的值 |
| 注册 | 注册 | 垃圾价值 | 当地的 | 在职能范围内 |

## 自动的

*   自动变量在运行时自动分配内存。
*   自动变量的可见性仅限于定义它们的块。
<ll>The scope of the automatic variables is limited to the block in which they are defined.</ll>

*   默认情况下，自动变量被初始化为垃圾。
*   分配给自动变量的内存在退出块时被释放。
*   用于定义自动变量的关键字是 auto。
*   默认情况下，C 语言中的每个局部变量都是自动的。

#### 例 1

```
#include <stdio.h>
int main()
{
int a; //auto
char b;
float c; 
printf("%d %c %f",a,b,c); // printing initial default value of automatic variables a, b, and c. 
return 0;
}

```

**输出:**

```
garbage garbage garbage 

```

#### 例 2

```
#include <stdio.h>
int main()
{
int a = 10,i; 
printf("%d ",++a);
{
int a = 20; 
for (i=0;i<3;i++)
{
printf("%d ",a); // 20 will be printed 3 times since it is the local value of a
}
}
printf("%d ",a); // 11 will be printed since the scope of a = 20 is ended. 
}

```

**输出:**

```
  11 20 20 20 11

```

## 静态

*   定义为静态说明符的变量可以在多个函数调用之间保存它们的值。
*   静态局部变量仅对定义它们的函数或块可见。
*   同一个静态变量可以声明多次，但只能赋值一次。
*   静态积分变量的默认初始值为 0，否则为空。
*   静态全局变量的可见性仅限于它所声明的文件。
*   用于定义静态变量的关键字是 static。

#### 例 1

```
#include<stdio.h>
static char c;
static int i;
static float f; 
static char s[100];
void main ()
{
printf("%d %d %f %s",c,i,f); // the initial default value of c, i, and f will be printed. 
}

```

**输出:**

```
0 0 0.000000 (null)

```

#### 例 2

```
#include void sum()
{
static int a = 10;
static int b = 24; 
printf("%d %d \n",a,b);
a++; 
b++;
}
void main()
{
int i;
for(i = 0; i< 3; i++)
{
sum(); // The static variables holds their value between multiple function calls.  
}
} 
```

**输出:**

```
10 24 
11 25 
12 26 

```

## 注册

*   定义为寄存器的变量根据中央处理器中剩余内存的大小将内存分配到中央处理器寄存器中。
*   我们不能取消引用寄存器变量，也就是说，我们不能对寄存器变量使用&运算符。
*   寄存器变量的访问时间比自动变量快。
*   寄存器局部变量的初始默认值为 0。
*   register 关键字用于应该存储在 CPU 寄存器中的变量。然而，它是编译器吗？s 选择是否；变量可以存储在寄存器中。
*   我们可以将指针存储到寄存器中，即寄存器可以存储变量的地址。
*   静态变量不能存储在寄存器中，因为我们不能对同一个变量使用多个存储说明符。

#### 例 1

```
#include <stdio.h>
int main()
{
register int a; // variable a is allocated memory in the CPU register. The initial default value of a is 0\. 
printf("%d",a);
}

```

**输出:**

```
0

```

#### 例 2

```
#include <stdio.h>
int main()
{
register int a = 0; 
printf("%u",&a); // This will give a compile time error since we can not access the address of a register variable. 
}

```

**输出:**

```
main.c:5:5: error: address of register variable ?a? requested
printf("%u",&a);
^~~~~~

```

## 外部

*   外部存储类用于告诉编译器，定义为 extern 的变量是用程序中其他地方的外部链接声明的。
*   声明为 extern 的变量没有分配任何内存。它只是声明，旨在指定变量在程序的其他地方声明。
*   外部整数类型的默认初始值为 0，否则为 null。
*   我们只能全局初始化外部变量，也就是说，我们不能在任何块或方法中初始化外部变量。
*   外部变量可以声明多次，但只能初始化一次。
*   如果一个变量被声明为外部变量，那么编译器会在程序的某个地方搜索要初始化的那个变量，这个变量可能是外部的，也可能是静态的。如果不是，那么编译器将显示一个错误。

#### 例 1

```
#include <stdio.h>
int main()
{
extern int a; 
printf("%d",a);
}

```

**输出**

```
main.c:(.text+0x6): undefined reference to `a'
collect2: error: ld returned 1 exit status

```

#### 例 2

```
#include int a; 
int main()
{
extern int a; // variable a is defined globally, the memory will not be allocated to a
printf("%d",a);
} 
```

**输出**

```
0

```

#### 例 3

```
#include int a; 
int main()
{
extern int a = 0; // this will show a compiler error since we can not use extern and initializer at same time 
printf("%d",a);
} 
```

**输出**

```
compile time error 
main.c: In function ?main?:
main.c:5:16: error: ?a? has both ?extern? and initializer
extern int a = 0;

```

#### 例 4

```
#include int main()
{
extern int a; // Compiler will search here for a variable a defined and initialized somewhere in the pogram or not. 
printf("%d",a);
}
int a = 20; 
```

**输出**

```
20

```

#### 例 5

```
extern int a;
int a = 10; 
#include int main()
{
printf("%d",a);
}
int a = 20; // compiler will show an error at this line 
```

**输出**

```
compile time error 

```