# C 数组

> 原文：<https://www.javatpoint.com/c-array>

数组被定义为存储在连续内存位置的相似类型数据项的集合。数组是 C 编程语言中的派生数据类型，可以存储 int、char、double、float 等数据的基元类型。它还能够存储派生数据类型的集合，如指针、结构等。数组是最简单的数据结构，其中每个数据元素都可以通过使用其索引号来随机访问。

如果你必须存储相似的元素，c 数组是有益的。例如，如果我们想存储一个学生在 6 个科目中的分数，那么我们不需要为不同科目中的分数定义不同的变量。取而代之的是，我们可以定义一个数组，将每个主题中的标记存储在连续的存储位置。

通过使用数组，我们可以很容易地访问元素。访问数组的元素只需要几行代码。

### 数组的性质

该数组包含以下属性。

*   数组的每个元素都是相同的数据类型，并且具有相同的大小，即 int = 4 字节。
*   阵列的元素存储在连续的存储位置，其中第一个元素存储在最小的存储位置。
*   数组的元素可以被随机访问，因为我们可以用给定的基地址和数据元素的大小来计算数组中每个元素的地址。

### C 数组的优势

**1)代码优化**:访问数据的代码更少。

**2)遍历**的简易性:通过使用 for 循环，我们可以很容易地检索数组的元素。

**3)易于排序**:对数组的元素进行排序，我们只需要几行代码。

**4)随机访问**:我们可以使用数组随机访问任意元素。

### C 数组的缺点

**1)固定大小**:无论是什么大小，我们在声明数组的时候定义的，都不能超过限制。因此，它不会像我们稍后将学习的 LinkedList 那样动态地增长大小。

## C 数组的声明

我们可以用以下方式用 c 语言声明一个数组。

```
data_type array_name[array_size];

```

现在，让我们看看声明数组的例子。

```
int marks[5];

```

这里 int 是*数据类型*，marks 是*数组名*，5 是*数组大小*。

## C 数组的初始化

初始化数组最简单的方法是使用每个元素的索引。我们可以使用索引初始化数组的每个元素。考虑下面的例子。

```
marks[0]=80;//initialization of array
marks[1]=60;
marks[2]=70;
marks[3]=85;
marks[4]=75;

```

![initialization of array in c language](img/662b4cd92922b009c5594fceacb67ae6.png)

### c 数组示例

```
#include<stdio.h>
int main(){    
int i=0;  
int marks[5];//declaration of array     
marks[0]=80;//initialization of array  
marks[1]=60;  
marks[2]=70;  
marks[3]=85;  
marks[4]=75;  
//traversal of array  
for(i=0;i<5;i++){    
printf("%d \n",marks[i]);  
}//end of for loop   
return 0;
}  

```

**输出**

```
80
60
70
85
75

```

## c 数组:带初始化的声明

我们可以在声明时初始化 c 数组。让我们看看代码。

```
int marks[5]={20,30,40,50,60};

```

在这种情况下，**没有定义尺寸**的要求。所以也可以写成下面的代码。

```
int marks[]={20,30,40,50,60};

```

让我们看看用 C 语言声明和初始化数组的 C 程序。

```
#include int main(){    
int i=0;  
int marks[5]={20,30,40,50,60};//declaration and initialization of array  
 //traversal of array  
for(i=0;i<5;i++){    
printf("%d \n",marks[i]);  
}  
return 0;
} 
```

**输出**

```
20
30
40
50
60

```

## 数组示例:对数组进行排序

在下面的程序中，我们使用冒泡排序法对数组进行升序排序。

```
#include<stdio.h>  
void main ()  
{  
    int i, j,temp;   
    int a[10] = { 10, 9, 7, 101, 23, 44, 12, 78, 34, 23};   
    for(i = 0; i<10; i++)  
    {  
        for(j = i+1; j<10; j++)  
        {  
            if(a[j] > a[i])  
            {  
                temp = a[i];  
                a[i] = a[j];  
                a[j] = temp;   
            }   
        }   
    }   
    printf("Printing Sorted Element List ...\n");  
    for(i = 0; i<10; i++)  
    {  
        printf("%d\n",a[i]);  
    }  
}   

```

## 程序打印数组中最大和第二大的元素。

```
#include<stdio.h>
void main ()
{
    int arr[100],i,n,largest,sec_largest;
    printf("Enter the size of the array?");
    scanf("%d",&n);
    printf("Enter the elements of the array?");
    for(i = 0; i<n; i++)
    {
        scanf("%d",&arr[i]);
    }
    largest = arr[0];
    sec_largest = arr[1];
    for(i=0;i<n;i++)
    {
        if(arr[i]>largest)
        {
            sec_largest = largest;
            largest = arr[i];
        }
        else if (arr[i]>sec_largest && arr[i]!=largest)
        {
            sec_largest=arr[i];
        }
    }
    printf("largest = %d, second largest = %d",largest,sec_largest);

}

```

* * *