# 在 C 语言中将数组传递给函数

> 原文：<https://www.javatpoint.com/passing-array-to-function-in-c>

在 C 语言中，有各种各样的一般问题，需要向一个函数传递多个相同类型的变量。例如，考虑一个按升序对 10 个元素进行排序的函数。这样的函数需要传递 10 个数字作为主函数的实际参数。这里，我们可以声明并初始化一个数组，然后将它传递给函数，而不是声明 10 个不同的数字，然后再传递给函数。这将解决所有的复杂性，因为函数现在可以处理任意数量的值。

我们知道 array_name 包含第一个元素的地址。这里，我们必须注意到，我们只需要在函数中传递数组的名称，该函数旨在接受一个数组。定义为形式参数的数组将自动引用由定义为实际参数的数组名称指定的数组。

考虑以下语法将数组传递给函数。

```
functionname(arrayname);//passing array

```

### 方法来声明接收数组作为参数的函数

有 3 种方法来声明函数，该函数旨在接收数组作为参数。

**第一种方式:**

```
return_type function(type arrayname[])

```

声明空白下标符号[]是广泛使用的技术。

**第二路:**

```
return_type function(type arrayname[SIZE])

```

或者，我们可以用下标符号[]定义大小。

**第三路:**

```
return_type function(type *arrayname)

```

您也可以使用指针的概念。在指针一章中，我们将了解它。

### c 语言将数组传递给函数示例

```
#include<stdio.h>
int minarray(int arr[],int size){  
int min=arr[0];  
int i=0;  
for(i=1;i<size;i++){  
if(min>arr[i]){  
min=arr[i];  
}  
}//end of for  
return min;  
}//end of function  

int main(){    
int i=0,min=0;  
int numbers[]={4,5,7,3,8,9};//declaration of array  

min=minarray(numbers,6);//passing array with size  
printf("minimum number is %d \n",min);  
return 0;
}  

```

**输出**

```
minimum number is 3

```

## 函数对数组进行排序

```
#include<stdio.h> 
void Bubble_Sort(int[]);
void main ()  
{  
    int arr[10] = { 10, 9, 7, 101, 23, 44, 12, 78, 34, 23};   
    Bubble_Sort(arr);  
}  
void Bubble_Sort(int a[]) //array a[] points to arr. 
{
int i, j,temp;   
    for(i = 0; i<10; i++)  
    {  
        for(j = i+1; j<10; j++)  
        {  
            if(a[j] < a[i])  
            {  
                temp = a[i];  
                a[i] = a[j];  
                a[j] = temp;   
            }   
        }   
    }   
    printf("Printing Sorted Element List ...\n");  
    for(i = 0; i<10; i++)  
    {  
        printf("%d\n",a[i]);  
    }
}

```

**输出**

```
Printing Sorted Element List ...
7  
9  
10  
12  
23 
23  
34  
44  
78  
101  

```

## 从函数返回数组

我们知道，一个函数不能返回多个值。然而，如果我们试图将 return 语句写成 return a、b、c；为了返回三个值(a，b，c)，函数将返回最后提到的值，在我们的例子中是 c。在一些问题中，我们可能需要从一个函数中返回多个值。在这种情况下，从函数返回一个数组。

返回数组类似于将数组传递给函数。从函数返回数组的名称。要使函数返回数组，请使用以下语法。

```
int * Function_name() {
//some statements; 
return array_type;
}

```

为了存储函数返回的数组，我们可以定义一个指向该数组的指针。我们可以通过增加指针来遍历数组，因为指针最初指向数组的基址。考虑以下示例，该示例包含一个返回排序数组的函数。

```
#include<stdio.h> 
int* Bubble_Sort(int[]);
void main ()  
{  
    int arr[10] = { 10, 9, 7, 101, 23, 44, 12, 78, 34, 23};   
    int *p = Bubble_Sort(arr), i;
    printf("printing sorted elements ...\n");
    for(i=0;i<10;i++)
    {
        printf("%d\n",*(p+i));
    }
}  
int* Bubble_Sort(int a[]) //array a[] points to arr. 
{
int i, j,temp;   
    for(i = 0; i<10; i++)  
    {  
        for(j = i+1; j<10; j++)  
        {  
            if(a[j] < a[i])  
            {  
                temp = a[i];  
                a[i] = a[j];  
                a[j] = temp;   
            }   
        }   
    }   
    return a;
}

```

**输出**

```
Printing Sorted Element List ...
7  
9   
10  
12  
23 
23  
34  
44  
78  
101  

```

* * *