# C 语言中的指针算法

> 原文：<https://www.javatpoint.com/pointer-arithmetic-in-c>

我们可以对指针进行算术运算，如加法、减法等。然而，我们知道指针包含地址，如果另一个操作数是整数类型，那么对指针执行的算术运算的结果也将是指针。在指针对指针减法中，结果将是一个整数值。在 C 语言中，可以对指针进行以下算术运算:

*   增量
*   减量
*   添加
*   减法
*   比较

* * *

## 递增 C 中的指针

如果我们将指针增加 1，指针将指向紧接的下一个位置。这与一般的算术有些不同，因为指针的值会随着指针所指向的数据类型的大小而增加。

我们可以通过在指针上使用增量操作来遍历数组，指针将一直指向数组的每个元素，对其执行一些操作，并在循环中更新自身。

增加指针的规则如下:

```

new_address= current_address + i * size_of(data type)

```

其中 I 是指针增加的数量。

### 32 位

对于 32 位 int 变量，它将增加 2 个字节。

### 64 位

对于 64 位 int 变量，它将增加 4 个字节。

让我们看看在 64 位架构上递增指针变量的例子。

```

#include int main(){
int number=50;      
int *p;//pointer to int    
p=&number;//stores the address of number variable      
printf("Address of p variable is %u \n",p);      
p=p+1;      
printf("After increment: Address of p variable is %u \n",p); // in our case, p will get incremented by 4 bytes.    
return 0;
} 
```

**输出**

```
Address of p variable is 3214864300 
After increment: Address of p variable is 3214864304 

```

### 使用指针遍历数组

```

#include<stdio.h>
void main ()
{
	int arr[5] = {1, 2, 3, 4, 5};
	int *p = arr;
	int i;
	printf("printing array elements...\n");
	for(i = 0; i< 5; i++)
	{
		printf("%d  ",*(p+i));
	}
}

```

**输出**

```
printing array elements...
1  2  3  4  5

```

## C 语言中指针的递减

像增量一样，我们可以减少一个指针变量。如果我们减少一个指针，它将开始指向前一个位置。指针递减公式如下:

```

new_address= current_address - i * size_of(data type)

```

### 32 位

对于 32 位 int 变量，它将减少 2 个字节。

### 64 位

对于 64 位 int 变量，它将减少 4 个字节。

让我们看看 64 位操作系统上指针变量递减的例子。

```

#include void main(){          
int number=50;      
int *p;//pointer to int    
p=&number;//stores the address of number variable      
printf("Address of p variable is %u \n",p);      
p=p-1;     
printf("After decrement: Address of p variable is %u \n",p); // P will now point to the immidiate previous location.       
} 
```

**输出**

```
Address of p variable is 3214864300 
After decrement: Address of p variable is 3214864296 

```

## 指针加法

我们可以给指针变量添加一个值。指针的增值公式如下:

```

new_address= current_address + (number * size_of(data type))

```

### 32 位

对于 32 位 int 变量，它将添加 2 *数字。

### 64 位

对于 64 位 int 变量，它将添加 4 *数字。

让我们看看在 64 位架构上给指针变量增加值的例子。

```

#include int main(){
int number=50;      
int *p;//pointer to int    
p=&number;//stores the address of number variable      
printf("Address of p variable is %u \n",p);      
p=p+3;   //adding 3 to pointer variable  
printf("After adding 3: Address of p variable is %u \n",p);     
return 0;
} 
```

**输出**

```
Address of p variable is 3214864300 
After adding 3: Address of p variable is 3214864312

```

如你所见，p 的地址是 3214864300。但用 p 变量加 3 后，就是 3214864312，即 4*3=12 增量。因为我们使用的是 64 位架构，所以它的增量是 12。但是如果我们使用 32 位架构，它只会增加到 6，即 2*3=6。因为在 32 位操作系统中，整数值占用 2 字节内存。

## 指针减法

像指针加法一样，我们可以从指针变量中减去一个值。从指针中减去任何数字都会得到一个地址。从指针变量中减去值的公式如下:

```

new_address= current_address - (number * size_of(data type))

```

### 32 位

对于 32 位 int 变量，它将减去 2 *数。

### 64 位

对于 64 位 int 变量，它将减去 4 *数。

让我们看看在 64 位架构上从指针变量中减去值的例子。

```

#include int main(){
int number=50;      
int *p;//pointer to int    
p=&number;//stores the address of number variable      
printf("Address of p variable is %u \n",p);      
p=p-3; //subtracting 3 from pointer variable  
printf("After subtracting 3: Address of p variable is %u \n",p);      
return 0;
} 
```

**输出**

```
Address of p variable is 3214864300 
After subtracting 3: Address of p variable is 3214864288

```

您可以看到，从指针变量中减去 3 后，它比前一个地址值少了 12 (4*3)。

然而，我们也可以从另一个地址(指针)中减去一个地址，而不是减去一个数字。这将产生一个数字。这将不是一个简单的算术运算，但它将遵循以下规则。

如果两个指针属于同一类型，

```

Address2 - Address1 = (Subtraction of two addresses)/size of data type which pointer points

```

考虑下面的例子，从一个指针减去另一个指针。

```

#include<stdio.h>
void main ()
{
	int i = 100; 
	int *p = &i;
	int *temp;
	temp = p; 
	p = p + 3;
	printf("Pointer Subtraction: %d - %d = %d",p, temp, p-temp);
}

```

**输出**

```
Pointer Subtraction: 1030585080 - 1030585068 = 3

```

## 带有指针的非法算术

有各种操作不能在指针上执行。由于指针存储地址，因此我们必须忽略可能导致非法地址的操作，例如加法和乘法。下面列出了这些操作的列表。

*   地址+地址=非法
*   地址*地址=非法
*   地址% Address =非法
*   地址/地址=非法
*   地址& Address =非法
*   地址^地址=非法
*   地址|地址=非法
*   ~地址=非法

## 指向 C 语言中函数的指针

正如我们在上一章中讨论的，指针可以指向 c 语言中的函数。但是，指针变量的声明必须与函数相同。考虑下面的例子，制作一个指向函数的指针。

```

#include<stdio.h>
int addition ();
int main ()
{
	int result; 
	int (*ptr)();
	ptr = &addition;
	result = (*ptr)();
	printf("The sum is %d",result);
}
int addition()
{
	int a, b; 
	printf("Enter two numbers?");
	scanf("%d %d",&a,&b);
	return a+b;
}

```

**输出**

```
Enter two numbers?10 15 
The sum is 25  

```

## 指向 C 语言中函数数组的指针

要理解函数数组的概念，我们必须理解函数数组。基本上，函数的数组是包含函数地址的数组。换句话说，指向函数数组的指针就是指向包含函数指针的数组的指针。考虑下面的例子。

```

#include<stdio.h>
int show();
int showadd(int);
int (*arr[3])();
int (*(*ptr)[3])();

int main ()
{
    int result1;
	arr[0] = show;
	arr[1] = showadd;
	ptr = &arr;
	result1 = (**ptr)();
	printf("printing the value returned by show : %d",result1);
	(*(*ptr+1))(result1);
}
int show()
{
	int a = 65;
	return a++;
}
int showadd(int b)
{
    printf("\nAdding 90 to the value returned by show: %d",b+90);
}

```

**输出**

```
printing the value returned by show : 65 
Adding 90 to the value returned by show: 155

```

* * *