# 什么是空指针？

> 原文：<https://www.javatpoint.com/null-pointer-in-c>

空指针是不指向任何内存位置的指针。它存储段的基址。空指针基本上存储空值，而 void 是指针的类型。

空指针是在 **stddef** 头文件中定义的特殊保留值。这里，空表示指针指向第 0 个<sup>存储单元。</sup>

如果我们没有任何要分配给指针的地址，那么它被称为空指针。当一个空值被赋给指针时，它被认为是一个**空指针**。

## 空指针的应用

**以下是空指针的应用:**

*   当指针没有指向有效的内存地址时，它用于初始化指针变量。
*   它用于在取消指针引用之前对指针执行错误处理。
*   它作为函数参数传递，当我们不想传递实际的内存地址时，它将从函数返回。

## 空指针示例

int *ptr=(int *)0：
浮点*ptr=(浮点*)0；
char * ptr =(char *)0；
双*ptr=(双*)0；
char * ptr = ' \ 0 '；
int * ptr = null；

**我们来看看需要使用空指针的情况。**

*   **当我们没有给指针变量分配任何内存地址时。**

```

#include <stdio.h>
int main()
{
    int *ptr;
   printf("Address: %d", ptr); // printing the value of ptr.
   printf("Value: %d", *ptr); // dereferencing the illegal pointer
   return 0;
}

```

在上面的代码中，我们声明了指针变量*ptr，但是它不包含任何变量的地址。未初始化的指针变量的解引用将显示编译时错误，因为它没有指向任何变量。根据堆栈内存概念，函数的局部变量存储在堆栈中，如果变量不包含任何值，则显示垃圾值。上述程序显示了一些不可预测的结果，并导致程序崩溃。因此，我们可以说，在程序中保留未初始化的指针会对计算机造成严重的危害。

**如何避免上述情况？**

我们可以通过使用空指针来避免上述情况。空指针是指向第 0<sup>个内存位置的指针，这是一个保留内存，不能被取消引用。</sup>

```

#include <stdio.h>
int main()
{
    int *ptr=NULL;
    if(ptr!=NULL)
    {
        printf("value of ptr is : %d",*ptr);
    }
    else
    {
        printf("Invalid pointer");
    }
  return 0;
}

```

在上面的代码中，我们创建了一个指针 ***ptr** ，并为该指针分配了一个 **NULL** 值，这意味着它不指向任何变量。在创建一个指针变量之后，我们添加一个条件，在这个条件下我们检查指针的值是否为空。

*   **当我们使用 malloc()函数时。**

```

#include <stdio.h>
int main()
{
    int *ptr;
    ptr=(int*)malloc(4*sizeof(int));
    if(ptr==NULL)
    {
        printf("Memory is not allocated");
    }
    else
    {
        printf("Memory is allocated");
    }
    return 0;
}

```

在上面的代码中，我们使用了库函数，即 **malloc()** 。我们知道，malloc()函数分配内存；如果 malloc()函数不能分配内存，则返回**空**指针。因此，有必要添加检查指针值是否为空的条件，如果指针值不为空意味着分配了**内存**。

![Null Pointer in C](img/da70fe555d9f924640e425b66f7473a1.png)

#### 注意:当我们不知道内存的确切地址时，给指针赋一个空值总是一个很好的做法。

* * *