# 函数指针

> 原文：<https://www.javatpoint.com/c-function-pointer>

我们知道，我们可以创建任何数据类型的指针，如 int、char、float，我们也可以创建指向函数的指针。函数的代码总是驻留在内存中，这意味着函数有一些地址。我们可以通过使用函数指针来获取内存的地址。

让我们看一个简单的例子。

```
#include <stdio.h>
int main()
{
    printf("Address of main() function is %p",main);
    return 0;
}

```

上面的代码打印了 **main()** 函数的地址。

**输出**

![C Function Pointer](img/787b3e0adec6b914e6000719d719e8d2.png)

在上面的输出中，我们观察到 main()函数有一些地址。因此，我们得出结论，每个函数都有一些地址。

### 函数指针的声明

到目前为止，我们已经看到函数有地址，所以我们可以创建包含这些地址的指针，从而可以指向它们。

**函数指针的语法**

```
return type (*ptr_name)(type1, type2…);

```

例如:

```
int (*ip) (int);

```

在上面的声明中，*ip 是指向一个函数的指针，该函数返回一个 int 值并接受一个整数值作为参数。

```
float (*fp) (float);

```

在上面的声明中， ***fp** 是一个指针，指向一个返回浮点值并接受浮点值作为参数的函数。

我们可以观察到，函数的声明类似于函数指针的声明，只是指针前面有一个**' ***。因此，在上面的声明中，fp 被声明为函数而不是指针。

到目前为止，我们已经学会了如何声明函数指针。我们的下一步是将函数的地址分配给函数指针。

```
float (*fp) (int , int);    // Declaration of a function pointer.
float func( int , int );    // Declaration of  function.
fp = func;                     // Assigning address of func to the fp pointer.

```

在上面的声明中，**‘FP’**指针包含**‘func’**函数的地址。

#### 注意:在将函数的地址分配给函数指针之前，需要声明函数。

### 通过函数指针调用函数

我们已经知道如何以通常的方式调用函数。现在，我们将看到如何使用函数指针调用函数。

假设我们声明如下函数:

```
float func(int , int);      // Declaration of a function.

```

用通常的方法调用上面的函数如下:

```
result = func(a , b);     // Calling a function using usual ways.

```

使用函数指针调用函数如下所示:

```
result = (*fp)( a , b);    // Calling a function using function pointer.

```

或者

```
result = fp(a , b);         // Calling a function using function pointer, and indirection             operator can be removed.

```

通过函数名或函数指针调用函数的效果是一样的。如果我们使用函数指针，我们可以省略间接操作符，就像在第二种情况下一样。尽管如此，我们使用间接操作符，因为它向用户表明我们使用的是函数指针。

**我们通过一个例子来理解函数指针。**

```
#include <stdio.h>
int add(int,int);
int main()
{
   int a,b;
   int (*ip)(int,int);
   int result;
   printf("Enter the values of a and b : ");
   scanf("%d %d",&a,&b);
   ip=add;
   result=(*ip)(a,b);
   printf("Value after addition is : %d",result);
    return 0;
}
int add(int a,int b)
{
    int c=a+b;
    return c;
}

```

**输出**

![C Function Pointer](img/b09a717ba416b77da36d48c15972c190.png)

### 将函数的地址作为参数传递给其他函数

我们可以将函数的地址作为参数传递给其他函数，就像我们将其他参数发送给函数一样。

**我们通过一个例子来了解一下。**

```
include <stdio.h>
void func1(void (*ptr)());
void func2();
int main()
{
    func1(func2);
     return 0;
}
void func1(void (*ptr)())
{
    printf("Function1 is called");
    (*ptr)();
}
void func2()
{
    printf("\nFunction2 is called");
}

```

在上面的代码中，我们创建了两个函数，即 func1()和 func2()。func1()函数包含函数指针作为参数。在 main()方法中，调用 func1()方法，我们在其中传递 func2 的地址。调用 func1()函数时，“ptr”包含“func2”的地址。在 func1()函数中，我们通过取消指针“ptr”的引用来调用 func2()函数，因为它包含 func2 的地址。

**输出**

![C Function Pointer](img/94e8eafffefa30088c8e498423cd514b.png)

### 函数指针数组

函数指针用于那些我们事先不知道将调用哪个函数的应用程序。在函数指针数组中，数组取不同函数的地址，根据索引号调用合适的函数。

让我们通过一个例子来理解。

```
#include <stdio.h>
float add(float,int);
float sub(float,int);
float mul(float,int);
float div(float,int);
int main()
{
    float x;              // variable declaration.
    int y;
    float (*fp[4]) (float,int);        // function pointer declaration.
    fp[0]=add;              // assigning addresses to the elements of an array of a function   pointer.
    fp[1]=sub;
    fp[2]=mul;
    fp[3]=div;
    printf("Enter the values of x and y :");
    scanf("%f %d",&x,&y);
  float r=(*fp[0]) (x,y);        // Calling add() function.
    printf("\nSum of two values is : %f",r);
     r=(*fp[1]) (x,y);             // Calling sub() function.
    printf("\nDifference of two values is : %f",r);
      r=(*fp[2]) (x,y);            // Calliung sub() function.
    printf("\nMultiplication of two values is : %f",r);
     r=(*fp[3]) (x,y);           // Calling div() function.
    printf("\nDivision of two values is : %f",r);
    return 0;
}

float add(float x,int y)
{
    float a=x+y;
    return a;
}
float sub(float x,int y)
{
    float a=x-y;
    return a;
}
float mul(float x,int y)
{
    float a=x*y;
    return a;
}
float div(float x,int y)
{
    float a=x/y;
    return a;
}

```

在上面的代码中，我们创建了一个包含四个函数地址的函数指针数组。在函数指针数组中存储函数地址后，我们使用函数指针调用函数。

**输出**

![C Function Pointer](img/7993de51b45315c2caaf79f773c104a2.png)

* * *