# 函数指针作为 C 语言中的参数

> 原文：<https://www.javatpoint.com/function-pointer-as-argument-in-c>

到目前为止，我们已经看到，在 C 编程中，我们可以将变量作为参数传递给函数。我们不能将函数作为参数传递给另一个函数。但是我们可以通过使用函数指针将函数的引用作为参数传递。这个过程被称为引用调用，因为函数参数是作为保存参数地址的指针传递的。如果函数使用指针进行了任何更改，那么它也将反映所传递变量地址的更改。

因此，C 编程允许您创建指向该函数的指针，该指针可以进一步作为参数传递给该函数。我们可以如下创建一个函数指针:

```

(type) (*pointer_name)(parameter);

```

在上面的语法中，**类型**是函数返回的变量类型， ***pointer_name** 是函数指针，**参数**是传递给函数的参数列表。

**我们来考虑一个例子:**

```

float (*add)(); // this is a legal declaration for the function pointer
float *add(); // this is an illegal declaration for the function pointer

```

函数指针也可以指向另一个函数，或者我们可以说它保存了另一个函数的地址。

```

float add (int a, int b);  // function declaration
float (*a)(int, int);  // declaration of a pointer to a function
a=add; // assigning address of add() to 'a' pointer

```

在上面的例子中，我们已经声明了一个名为“ **add** 的函数。我们还声明了返回浮点型值的函数指针(*a)，它包含两个整数类型的参数。现在，我们可以将 **add()** 函数的地址分配给‘a’指针，因为两者具有相同的返回类型(浮点)和相同类型的参数。

现在，“a”是指向 add()函数的指针。我们可以通过使用指针，即“a”来调用 add()函数。让我们看看如何做到这一点:

```

a(2, 3);

```

上面的语句使用指针“a”调用 add()函数，在“a”中传递了两个参数，即 2 和 3。

**我们来看一个简单的例子，如何将函数指针作为参数传递。**

```

void display(void (*p)())
{
    for(int i=1;i<=5;i++)
    {
        p(i);
    }
}
void print_numbers(int num)
{
    cout<<num;
}
int main()
{
    void (*p)(int);     // void function pointer declaration
    printf("The values are :");
  display(print_numbers);
    return 0;
}

```

**在上面的代码中，**

*   我们定义了两个名为“display()”和 print_numbers()的函数。
*   在 main()方法中，我们声明了一个名为(*p)的函数指针，并调用 display()函数，在该函数中我们传递 print_numbers()函数。
*   当控制转到 display()函数时，指针*p 包含 print_numbers()函数的地址。这意味着我们可以使用函数指针*p 调用 print_numbers()函数。
*   在 display()函数的定义中，我们定义了一个‘for’循环，在 for 循环内部，我们使用语句 p(i)调用 print_numbers()函数。这里，p(i)意味着每次迭代 I 时都会调用 print_numbers()函数，并且会打印“I”的值。

**输出**

![Function pointer as argument in C](img/28ae88923f80a34a5a98e47df37df08a.png)

**现在，我们将在 Quicksort 函数“qsort”中传递函数指针作为参数。它使用对数组进行排序的算法。**

```

#include <stdio.h>
#include <stdlib.h>

#include<string.h>
int compare(const int *p, const int *q);
int (*f)(const void *a, const void *b);
int main()
{
    int a[]={4,7,6,1,3,2};
    int num=sizeof(a)/sizeof(int);
    f=&compare;
    qsort(a, num, sizeof(int), (*f));
    for(int i=0;i<num;i++)
    {
        printf("%d ,",a[i]);
    }

}

int compare(const int *p, const int *q)
{
     if (*p == *q)
        return 0;
    else if (*p < *q)
        return -1;
    else
        return 1;
}

```

**在上面的代码中，**

*   我们定义了一个整数类型的数组。创建数组后，我们使用 size of()运算符计算了数组的大小，并将该大小存储在 **num** 中
*   我们定义了一个 compare()函数，它比较数组中的所有元素，并按升序排列它们。
*   我们还声明了函数指针，即(*f)，并使用语句 f=&compare 将 compare()函数的地址存储在(*f)中。
*   我们调用 qsort()函数，传递数组、数组大小、元素大小和比较函数。比较函数，即 compare()将比较数组元素，直到数组中的元素按升序排序。

**输出**

![Function pointer as argument in C](img/1fd5e8cfb5082fd38e3f0d00a7f314d1.png)

* * *