# 结构

> 原文：<https://www.javatpoint.com/structure-in-c>

## 为什么要用结构？

在 C 语言中，有些情况下我们需要存储一个实体的多个属性。一个实体没有必要只有一种类型的所有信息。它可以具有不同数据类型的不同属性。例如，一个实体**学生**可能有它的名字(字符串)、卷号(int)、标记(float)。为了存储关于实体学生的此类信息，我们有以下方法:

*   构建单独的数组来存储名称、卷号和标记。
*   使用特殊的数据结构来存储不同数据类型的集合。

让我们详细看看第一种方法。

```
#include<stdio.h>
void main ()
{
  char names[2][10],dummy; // 2-dimensioanal character array names is used to store the names of the students 
  int roll_numbers[2],i;
  float marks[2];
  for (i=0;i<3;i++)
  {

    printf("Enter the name, roll number, and marks of the student %d",i+1);
    scanf("%s %d %f",&names[i],&roll_numbers[i],&marks[i]);
    scanf("%c",&dummy); // enter will be stored into dummy character at each iteration
  }
  printf("Printing the Student details ...\n");
  for (i=0;i<3;i++)
  {
    printf("%s %d %f\n",names[i],roll_numbers[i],marks[i]);
  }
}

```

**输出**

```
Enter the name, roll number, and marks of the student 1Arun 90 91        
Enter the name, roll number, and marks of the student 2Varun 91 56      
Enter the name, roll number, and marks of the student 3Sham 89 69

Printing the Student details...
Arun 90 91.000000                                                                      
Varun 91 56.000000  
Sham 89 69.000000

```

上述程序可以满足我们存储实体学生信息的要求。然而，程序非常复杂，并且复杂性随着输入量的增加而增加。每个数组的元素都是连续存储的，但不是所有数组都连续存储在内存中。c 为您提供了一种额外的、更简单的方法，您可以在其中使用一种特殊的数据结构，即结构，在这种结构中，您可以对关于实体的不同数据类型的所有信息进行分组。

## 什么是结构

结构是用户定义的数据类型，它使我们能够存储不同数据类型的集合。结构的每个元素都称为成员。结构 ca；模拟类和模板的使用，因为它可以存储各种信息

使用**、struct** 关键字来定义结构。让我们看看用 c 语言定义结构的语法。

```
struct structure_name 
{
    data_type member1;
    data_type member2;
    .
    .
    data_type memeberN;
};

```

让我们看看在 c 语言中为实体雇员定义结构的例子。

```
struct employee
{   int id;
    char name[20];
    float salary;
};

```

下图显示了上例中定义的结构雇员的内存分配。

![c structure memory allocation](img/238c242e90c6603fad9e8f0f99e26e64.png)

这里， **struct** 是关键字；**员工**是结构的名称； **id** 、**名称**、**薪资**为结构的成员或字段。让我们通过下面给出的图表来理解它:

![c structure](img/7d6d5ec3709dba53e2974b0ab02816f7.png)

## 声明结构变量

我们可以为该结构声明一个变量，这样我们就可以很容易地访问该结构的成员。有两种方法可以声明结构变量:

1.  main()函数中的 By struct 关键字
2.  通过在定义结构时声明一个变量。

**第一路:**

让我们看看用 struct 关键字声明结构变量的例子。它应该在主函数中声明。

```
struct employee
{   int id;
    char name[50];
    float salary;
};

```

现在在 main()函数中编写给定的代码。

```
struct employee e1, e2;

```

变量 e1 和 e2 可用于访问存储在结构中的值。这里，e1 和 e2 可以和 [C++](https://www.javatpoint.com/cpp-tutorial) 和 [Java](https://www.javatpoint.com/java-tutorial) 中的对象一样处理。

**第二路:**

让我们看看在定义结构时声明变量的另一种方法。

```
struct employee
{   int id;
    char name[50];
    float salary;
}e1,e2;

```

### 哪种方法好

如果变量的数量不固定，使用第一种方法。它为您提供了多次声明结构变量的灵活性。

如果变量的数量是固定的，使用第二种方法。它保存您的代码以在 main()函数中声明一个变量。

## 访问结构的成员

有两种方法可以访问结构成员:

1.  由。(成员或点运算符)
2.  By ->(结构指针运算符)

让我们看看通过访问 *p1* 变量的 *id* 成员的代码。(成员)操作员。

```
p1.id

```

### 结构示例

让我们看一个简单的 C 语言结构的例子。

```
#include #include <string.h>struct employee    
{   int id;    
    char name[50];    
}e1;  //declaring e1 variable for structure  
int main( )  
{  
   //store first employee information  
   e1.id=101;  
   strcpy(e1.name, "Sonoo Jaiswal");//copying string into char array  
   //printing first employee information  
   printf( "employee 1 id : %d\n", e1.id);  
   printf( "employee 1 name : %s\n", e1.name);  
return 0;
}</string.h> 
```

**输出:**

```
employee 1 id : 101
employee 1 name : Sonoo Jaiswal

```

我们再来看看 [C 语言](https://www.javatpoint.com/c-programming-language-tutorial)中存储很多员工信息的结构示例。

```
#include #include <string.h>struct employee    
{   int id;    
    char name[50];    
    float salary;    
}e1,e2;  //declaring e1 and e2 variables for structure  
int main( )  
{  
   //store first employee information  
   e1.id=101;  
   strcpy(e1.name, "Sonoo Jaiswal");//copying string into char array  
   e1.salary=56000;  

  //store second employee information  
   e2.id=102;  
   strcpy(e2.name, "James Bond");  
   e2.salary=126000;  

   //printing first employee information  
   printf( "employee 1 id : %d\n", e1.id);  
   printf( "employee 1 name : %s\n", e1.name);  
   printf( "employee 1 salary : %f\n", e1.salary);  

   //printing second employee information  
   printf( "employee 2 id : %d\n", e2.id);  
   printf( "employee 2 name : %s\n", e2.name);  
   printf( "employee 2 salary : %f\n", e2.salary);  
   return 0;  
}</string.h> 
```

**输出:**

```
employee 1 id : 101
employee 1 name : Sonoo Jaiswal
employee 1 salary : 56000.000000
employee 2 id : 102
employee 2 name : James Bond
employee 2 salary : 126000.000000

```

* * *