# C 语言中的 typedef

> 原文：<https://www.javatpoint.com/typedef-in-c>

**typedef** 是一个在 C 程序中使用的关键字，为 [C 程序](https://www.javatpoint.com/c-programs)中已经存在的变量提供一些有意义的名称。它的行为类似于我们为命令定义的别名。简而言之，我们可以说这个关键字用于重新定义一个已经存在的变量的名称。

### typedef 的语法

```

typedef <existing_name> <alias_name>

```

在上面的语法中，' **existing_name'** 是一个已经存在的变量的名称，而'**别名'**是给现有变量的另一个名称。

例如，假设我们想要创建一个类型为**的无符号 int** 的变量，那么如果我们想要声明多个这种类型的变量，那么这就变成了一个繁琐的任务。为了克服这个问题，我们使用了**一个 typedef** 关键字。

```

typedef unsigned int unit;

```

在上面的陈述中，我们已经通过使用**一个 typedef** 关键字声明了无符号 int 类型的**单位**变量。

现在，我们可以通过编写以下语句来创建类型为**无符号 int** 的变量:

```

unit a, b; 

```

不写了:

```

unsigned int a, b;

```

到目前为止，我们已经观察到 **typedef** 关键字通过为已经存在的变量提供一个替代名称，提供了一个很好的快捷方式。当我们处理长数据类型，尤其是结构声明时，这个关键字很有用。

**我们通过一个简单的例子来理解。**

```

#include <stdio.h>
int main()
{
typedef unsigned int unit;
unit i,j;
i=10;
j=20;
printf("Value of i is :%d",i);
printf("\nValue of j is :%d",j);
return 0;
}

```

**输出**

```
Value of i is :10 
Value of j is :20 

```

### 将 typedef 用于结构

**考虑下面的结构声明:**

```

struct student
{
char name[20];
int age;
};
struct student s1; 

```

在上面的结构声明中，我们通过编写以下语句创建了**学生**类型的变量:

```

struct student s1;

```

上面的语句显示了一个变量的创建，即 s1，但是语句相当大。为了避免这样的大语句，我们使用 **typedef** 关键字来创建类型为**学生**的变量。

```

struct student
{
char name[20];
int age;
};
typedef struct student stud;
stud s1, s2; 

```

在上面的陈述中，我们已经声明了 student 类型的变量 **stud** 。现在，我们可以在程序中使用 **stud** 变量来创建类型为 **struct student** 的变量。

**上述 typedef 可以写成:**

```

typedef struct student
{
char name[20];
int age; 
} stud;
stud s1,s2;

```

从上面的声明中，我们得出结论: **typedef** 关键字减少了代码的长度和数据类型的复杂性。这也有助于理解程序。

**让我们来看另一个例子，在这个例子中，我们定义了结构声明。**

```

#include <stdio.h>
typedef struct student
{
char name[20];
int age;
}stud;
int main()
{
stud s1;
printf("Enter the details of student s1: ");
printf("\nEnter the name of the student:");
scanf("%s",&s1.name);
printf("\nEnter the age of student:");
scanf("%d",&s1.age);
printf("\n Name of the student is : %s", s1.name);
printf("\n Age of the student is : %d", s1.age);
return 0;
}

```

**输出**

```
Enter the details of student s1: 
Enter the name of the student: Peter 
Enter the age of student: 28 
Name of the student is : Peter 
Age of the student is : 28 

```

### 将 typedef 与指针一起使用

我们也可以借助 typedef 为指针变量提供另一个名称或别名。

例如，我们通常声明一个指针，如下所示:

```

int* ptr;

```

我们可以重命名上面的指针变量，如下所示:

```

typedef int* ptr;

```

在上面的语句中，我们已经声明了类型为 **int*** 的变量。现在，我们可以通过简单地使用“**ptr”**变量来创建类型为 **int*** 的变量，如下语句所示:

```

ptr p1, p2 ;

```

在上面的陈述中， **p1** 和 **p2** 是类型为“**ptr”**的变量。

* * *