# C 语言中的嵌套结构

> 原文：<https://www.javatpoint.com/nested-structure-in-c>

c 语言为我们提供了将一个结构嵌套在另一个结构中的功能，通过这个功能可以创建复杂的数据类型。例如，我们可能需要在结构中存储实体员工的地址。属性地址也可以有街道号码、城市、州和个人识别码等子部分。因此，为了存储员工的地址，我们需要将员工的地址存储到一个单独的结构中，并将结构地址嵌套到结构员工中。考虑以下程序。

```
#include<stdio.h>
struct address 
{
    char city[20];
    int pin;
    char phone[14];
};
struct employee
{
    char name[20];
    struct address add;
};
void main ()
{
    struct employee emp;
    printf("Enter employee information?\n");
    scanf("%s %s %d %s",emp.name,emp.add.city, &emp.add.pin, emp.add.phone);
    printf("Printing the employee information....\n");
    printf("name: %s\nCity: %s\nPincode: %d\nPhone: %s",emp.name,emp.add.city,emp.add.pin,emp.add.phone);
}

```

**输出**

```
Enter employee information?

Arun            

Delhi           

110001       

1234567890    

Printing the employee information....   

name: Arun      

City: Delhi  

Pincode: 110001

Phone: 1234567890

```

该结构可以通过以下方式嵌套。

1.  通过分离结构
2.  按嵌入式结构

### 1)分离结构

这里，我们创建了两个结构，但是从属结构应该在主结构内部作为成员使用。考虑下面的例子。

```
struct Date
{
   int dd;
   int mm;
   int yyyy; 
};
struct Employee
{   
   int id;
   char name[20];
   struct Date doj;
}emp1;

```

可以看到，doj(加入日期)是 date 类型的变量。在这里，doj 在 Employee 结构中用作成员。这样，我们可以在许多结构中使用日期结构。

### 2)嵌入式结构

嵌入式结构使我们能够在结构内部声明结构。因此，它需要较少的代码行，但不能用于多种数据结构。考虑下面的例子。

```
struct Employee
{   
   int id;
   char name[20];
   struct Date
    {
      int dd;
      int mm;
      int yyyy; 
    }doj;
}emp1;

```

## 访问嵌套结构

我们可以通过外部结构访问嵌套结构的成员。嵌套结构成员如下:

```
e1.doj.dd
e1.doj.mm
e1.doj.yyyy

```

## 嵌套结构示例

让我们看一个简单的 C 语言嵌套结构的例子。

```
#include #include <string.h>struct Employee
{   
   int id;
   char name[20];
   struct Date
    {
      int dd;
      int mm;
      int yyyy; 
    }doj;
}e1;
int main( )
{
   //storing employee information
   e1.id=101;
   strcpy(e1.name, "Sonoo Jaiswal");//copying string into char array
   e1.doj.dd=10;
   e1.doj.mm=11;
   e1.doj.yyyy=2014;

   //printing first employee information
   printf( "employee id : %d\n", e1.id);
   printf( "employee name : %s\n", e1.name);
   printf( "employee date of joining (dd/mm/yyyy) : %d/%d/%d\n", e1.doj.dd,e1.doj.mm,e1.doj.yyyy);
   return 0;
}</string.h> 
```

**输出:**

```
employee id : 101
employee name : Sonoo Jaiswal
employee date of joining (dd/mm/yyyy) : 10/11/2014

```

## 将结构传递给函数

就像其他变量一样，结构也可以传递给函数。我们可以将结构成员传递给函数，或者立即传递结构变量。考虑以下示例，将结构变量 employee 传递给函数 display()，该函数用于显示雇员的详细信息。

```
#include<stdio.h>
struct address 
{
    char city[20];
    int pin;
    char phone[14];
};
struct employee
{
    char name[20];
    struct address add;
};
void display(struct employee);
void main ()
{
    struct employee emp;
    printf("Enter employee information?\n");
    scanf("%s %s %d %s",emp.name,emp.add.city, &emp.add.pin, emp.add.phone);
    display(emp);
}
void display(struct employee emp)
{
  printf("Printing the details....\n");
  printf("%s %s %d %s",emp.name,emp.add.city,emp.add.pin,emp.add.phone);
}

```

* * *