# 工会

> 原文：<https://www.javatpoint.com/c-union>

**Union** 可以定义为用户自定义的数据类型，是同一内存位置不同数据类型的不同变量的集合。联合也可以定义为许多成员，但是在特定时间点只有一个成员可以包含一个值。

Union 是用户定义的数据类型，但与结构不同，它们共享相同的内存位置。

**我们通过一个例子来理解这一点。**

```

struct abc
{
   int a;
   char b; 
} 

```

上面的代码是用户定义的结构，由两个成员组成，即类型 **int** 的‘a’和类型**字符**的‘b’。当我们检查‘a’和‘b’的地址时，我们发现它们的地址不同。因此，我们得出结论，结构中的成员不共享相同的内存位置。

当我们定义 union 时，我们发现 union 的定义方式与结构的定义方式相同，但不同之处在于 union 关键字用于定义 union 数据类型，而 struct 关键字用于定义结构。联合包含数据成员，即“a”和“b”，当我们检查两个变量的地址时，我们发现两者具有相同的地址。这意味着工会成员共享相同的内存位置。

**我们来看看内存分配的图示。**

下图显示了该结构的图示。该结构有两个成员；即一个是整数类型，另一个是字符类型。因为 1 个块等于 1 个字节；因此，“a”变量将被分配 4 个内存块，而“b”变量将被分配 1 个内存块。

下图显示了工会成员的图示。这两个变量共享相同的内存位置，并且具有相同的初始地址。

在联盟中，成员将共享内存位置。如果我们试图对任何一个成员进行更改，那么它也会反映给其他成员。让我们通过一个例子来理解这个概念。

```

union abc
{
   int a;
char b; 
}var;
int main()
{
  var.a = 66;
  printf("\n a = %d", var.a);
  printf("\n b = %d", var.b);
} 

```

在上面的代码中，union 有两个成员，即‘a’和‘b’。“var”是联合 abc 类型的变量。在 **main()** 方法中，我们将 66 分配给‘a’变量，因此 var.a 将在屏幕上打印 66。由于“a”和“B”共享内存位置，因此 **var.b** 将打印“**B**”(ascii 码为 66)。

### 决定联盟的规模

工会的规模是以工会最大成员的规模为基础的。

**我们通过一个例子来了解一下。**

```

union abc{
int a;
char b;
float c;
double d;
};
int main()
{
  printf("Size of union abc is %d", sizeof(union abc));
  return 0;
}

```

我们知道，int 的大小是 4 字节，char 的大小是 1 字节，float 的大小是 4 字节，double 的大小是 8 字节。由于双变量占据了所有四个变量中最大的内存，因此内存中将总共分配 8 个字节。因此，上述程序的输出将是 8 字节。

### 使用指针访问联合成员

我们可以使用(->)箭头操作符通过指针访问联合的成员。

**我们通过一个例子来了解一下。**

```

#include union abc
{
    int a;
    char b;
};
int main()
{
    union abc *ptr; // pointer variable declaration
    union abc var;
    var.a= 90;
    ptr = &var;
    printf("The value of a is : %d", ptr->a);
    return 0;
} 
```

在上面的代码中，我们创建了一个指针变量，即*ptr，它存储 var 变量的地址。现在，ptr 可以通过使用(->)运算符来访问变量“a”。因此，上述代码的输出将是 90。

### 为什么我们需要 C 工会？

考虑一个例子来理解对 C 工会的需求。让我们考虑一家有两种商品的商店:

*   书
*   衬衫

店主希望将上述两项的记录与相关信息一起保存。例如，书籍包括标题、作者、页数、价格，衬衫包括颜色、设计、尺寸和价格。“价格”属性在这两个项目中都很常见。商店所有者想要存储属性，然后他/她将如何存储记录。

最初，他们决定将记录存储在如下所示的结构中:

```

struct store
{
   double price;
   char *title;
   char *author;
   int number_pages;
   int color;
  int size;
  char *design;
}; 

```

上面的结构包含了店主想要储存的所有物品。上述结构是完全可用的，但价格是两个项目的共同财产，其余项目是单独的。价格、*标题、*作者和页码等属性属于书籍，而颜色、尺寸、*设计属于衬衫。

**我们来看看如何访问结构的成员**。

```

int main()
{
   struct store book;
   book.title = "C programming";
book.author = "Paulo Cohelo";  
book.number_pages = 190;
book.price = 205;
printf("Size is : %ld bytes", sizeof(book));
return 0;
} 

```

在上面的代码中，我们创建了一个类型为**的变量来存储**。我们已经给变量赋值，包括标题、作者、页数、价格，但是书本变量不包含尺寸、颜色和设计等属性。因此，这是对记忆的浪费。上述结构的大小为 44 字节。

如果我们使用工会，我们可以节省很多空间。

```

#include struct store
{
    double price;
    union
    {
        struct{
        char *title;
        char *author;
        int number_pages;
        } book;

        struct {
        int color;
        int size;
        char *design;
        } shirt;
    }item;
};
  int main()
{
    struct store s;
    s.item.book.title = "C programming"; 
    s.item.book.author = "John";
    s.item.book.number_pages = 189;
    printf("Size is %ld", sizeof(s));
    return 0;
} 
```

在上面的代码中，我们创建了一个类型为 store 的变量。由于我们在上面的代码中使用了并集，因此内存分配将考虑变量占用的最大内存。上述程序的输出是 32 字节。在结构的情况下，我们获得了 44 字节，而在联合的情况下，获得的大小是 44 字节。因此，44 字节比 32 字节大，节省了大量内存空间。

* * *