# C 语言中的文件处理

> 原文：<https://www.javatpoint.com/file-handling-in-c>

在编程中，我们可能需要多次生成一些特定的输入数据。有时候，仅仅在控制台上显示数据是不够的。要显示的数据可能非常大，在控制台上只能显示有限数量的数据，并且由于内存是易失性的，不可能一次又一次地恢复以编程方式生成的数据。但是，如果我们需要这样做，我们可以将其存储到本地文件系统中，该文件系统是易失性的，每次都可以访问。这里，就出现了用 c 语言进行文件处理的需求。

C 语言中的文件处理使我们能够通过 C 程序创建、更新、读取和删除存储在本地文件系统中的文件。可以对文件执行以下操作。

*   新文件的创建
*   打开现有文件
*   从文件中读取
*   正在写入文件
*   删除文件

* * *

## 文件处理功能

C 库中有很多打开、读取、写入、搜索和关闭文件的功能。文件功能列表如下:

| 号码 | 功能 | 描述 |
| one | fopen() | 打开新的或现有的文件 |
| Two | fprintf（） | 将数据写入文件 |
| three | fscanf（） | 从文件中读取数据 |
| four | fputc() | 将字符写入文件 |
| five | fgetc（） | 从文件中读取字符 |
| six | fclose() | 关闭文件 |
| seven | fseek（） | 将文件指针设置到给定位置 |
| eight | fputw() | 将整数写入文件 |
| nine | fgetw() | 从文件中读取整数 |
| Ten | ftell（） | 返回当前位置 |
| Eleven | 倒带() | 将文件指针设置到文件的开头 |

* * *

## 打开文件:fopen()

我们必须先打开文件，然后才能对其进行读取、写入或更新。fopen()函数用于打开文件。fopen()的语法如下。

```
FILE *fopen( const char * filename, const char * mode );

```

fopen()函数接受两个参数:

*   文件名(字符串)。如果文件存储在某个特定的位置，那么我们必须提到文件存储的路径。例如，文件名可以像**“c://some _ folder/some _ file . ext”**。
*   打开文件的模式。它是一个字符串。

我们可以在 fopen()函数中使用以下模式之一。

| 方式 | 描述 |
| r | 以读取模式打开文本文件 |
| w | 以写入模式打开文本文件 |
| a | 以追加模式打开文本文件 |
| r+ | 以读写模式打开文本文件 |
| w+ | 以读写模式打开文本文件 |
| a+ | 以读写模式打开文本文件 |
| 元素铷的符号 | 以读取模式打开二进制文件 |
| 世界银行 | 以写模式打开二进制文件 |
| 腹肌 | 以追加模式打开二进制文件 |
| rb+ | 以读写模式打开二进制文件 |
| wb+ | 以读写模式打开二进制文件 |
| ab+ | 以读写模式打开二进制文件 |

* * *

fopen 函数的工作方式如下。

*   首先，它搜索要打开的文件。
*   然后，它从磁盘加载文件并将其放入缓冲区。缓冲器用于为读取操作提供效率。
*   它设置一个指向文件第一个字符的字符指针。

考虑以下以写模式打开文件的示例。

```
#include<stdio.h>
void main( )
{
FILE *fp ;
char ch ;
fp = fopen("file_handle.c","r") ;
while ( 1 )
{
ch = fgetc ( fp ) ;
if ( ch == EOF )
break ;
printf("%c",ch) ;
}
fclose (fp ) ;
}

```

#### 输出

将打印文件的内容。

```
#include;
void main( )
{
FILE *fp; // file pointer
char ch; 
fp = fopen("file_handle.c","r");
while ( 1 )
{
ch = fgetc ( fp ); //Each character of the file is read and stored in the character file.  
if ( ch == EOF )
break;
printf("%c",ch);
}
fclose (fp );
} 
```

## 正在关闭文件:fclose()

函数的作用是:关闭一个文件。对文件执行所有操作后，必须将其关闭。fclose()函数的语法如下:

```
int fclose( FILE *fp );

```

* * *

## C fprintf()和 fscanf()

[C fprintf() and fscanf() example](fprintf-fscanf-in-c)  [C fputc() and fgetc() example](fputc-fgetc-in-c)  [C fputs() and fgets() example](fputs-fgets-in-c)  [C fseek() example](fseek-in-c)