# C 语言中的枚举

> 原文：<https://www.javatpoint.com/enum-in-c>

C 语言中的枚举也称为枚举类型。它是由整数值组成的用户定义的数据类型，并为这些值提供有意义的名称。C 语言中枚举的使用使得程序易于理解和维护。枚举是使用枚举关键字定义的。

下面是在 C 语言中定义枚举的方法:

```

enum flag{integer_const1, integer_const2,.....integter_constN};

```

在上面的声明中，我们将枚举定义为包含“N”个整数常量的标志。integer_const1 的默认值为 0，integer_const2 的默认值为 1，依此类推。我们还可以在声明时更改整数常量的默认值。

**例如:**

```

enum fruits{mango, apple, strawberry, papaya};

```

芒果的默认值是 0，苹果是 1，草莓是 2，木瓜是 3。如果我们想要更改这些默认值，那么我们可以按照下面给出的方式进行:

```

enum fruits{
mango=2,
apple=1,
strawberry=5,
papaya=7,
};

```

### 枚举类型声明

我们知道，在 C 语言中，我们需要声明一个预定义类型的变量，比如 int、float、char 等。同样，我们可以声明用户定义的数据类型的变量，例如 enum。让我们看看如何声明枚举类型的变量。

假设我们创建了如下所示的状态类型的枚举:

```

enum status{false,true};

```

现在，我们创建状态类型的变量:

```

enum status s; // creating a variable of the status type.

```

在上面的语句中，我们已经声明了类型状态的' s '变量。

要创建一个变量，上面两个语句可以写成:

```

enum status{false,true} s;

```

在这种情况下，默认值 false 将等于 0，值 true 将等于 1。

**让我们创建一个简单的枚举程序。**

```

#include <stdio.h>
 enum weekdays{Sunday=1, Monday, Tuesday, Wednesday, Thursday, Friday, Saturday};
 int main()
{
 enum weekdays w; // variable declaration of weekdays type
 w=Monday; // assigning value of Monday to w.
 printf("The value of w is %d",w);
    return 0;
}

```

在上面的代码中，我们创建了一个名为 weekdays 的枚举类型，它包含了所有七天的名称。我们为星期日分配了 1 个值，所有其他名称都将被赋予一个值，作为前一个值加 1。

**输出**

![Enum in C](img/d114932c8b520b416825b08b9856f8d6.png)

**让我们演示另一个例子，以更清楚地理解枚举。**

```

#include <stdio.h>
 enum months{jan=1, feb, march, april, may, june, july, august, september, october, november, december};
int main()
{
// printing the values of months
 for(int i=jan;i<=december;i++)
 {
 printf("%d, ",i);
 }
    return 0;
}

```

在上面的代码中，我们创建了一个名为 months 的枚举类型，它由所有月份的名称组成。我们分配了一个' 1 '值，所有其他月份都将被赋予一个与前一个 1 加 1 相同的值。在 main()方法中，我们定义了一个 for 循环，在这个循环中，我们在 jan 之前初始化‘I’变量，这个循环将迭代到 12 月。

**输出**

![Enum in C](img/20203bd6cddc7c73896e3a2fc94fd52c.png)

### 我们为什么使用枚举？

当我们希望变量只有一组值时，使用枚举。例如，我们创建一个方向变量。因为我们知道存在四个方向(北、南、东、西)，所以这个方向变量将有四个可能的值。但是变量一次只能保存一个值。如果我们试图为这个变量提供一些不同的值，那么它将抛出编译错误。

枚举也用在 switch case 语句中，我们在 switch 括号中传递枚举变量。它确保大小写块的值应该在枚举中定义。

**让我们看看如何在 switch case 语句中使用枚举。**

```

#include <stdio.h>
enum days{sunday=1, monday, tuesday, wednesday, thursday, friday, saturday};
int main()
{
   enum days d;
   d=monday;
   switch(d)
   {
       case sunday:
       printf("Today is sunday");
       break;
       case monday:
       printf("Today is monday");
       break;
       case tuesday:
       printf("Today is tuesday");
       break;
       case wednesday:
       printf("Today is wednesday");
       break;
       case thursday:
       printf("Today is thursday");
       break;
       case friday:
       printf("Today is friday");
       break;
       case saturday:
       printf("Today is saturday");
       break;
   }

    return 0;
}

```

**输出**

![Enum in C](img/cb9670a868c27fef5c9724f103e38795.png)

**一些与枚举相关的要点**

*   枚举类型中可用的枚举名称可以具有相同的值。让我们看看这个例子。

```

#include <stdio.h>

int main(void) {
  enum fruits{mango = 1, strawberry=0, apple=1};
    printf("The value of mango is %d", mango);
    printf("\nThe value of apple is %d", apple);
  return 0;
}

```

**输出**

![Enum in C](img/f003871710056f32b3992261e46584be.png)

*   如果我们不为枚举名称提供任何值，那么编译器将从 0 开始自动为枚举名称分配默认值。
*   我们还可以以任何顺序向枚举名称提供值，未分配的名称将获得与前一个 1 加 1 相同的默认值。
*   分配给枚举名称的值必须是整型常量，也就是说，它不应该是字符串、浮点等其他类型。
*   所有的枚举名称在它们的作用域中必须是唯一的，也就是说，如果我们定义了两个具有相同作用域的枚举，那么这两个枚举应该具有不同的枚举名称，否则编译器将抛出一个错误。

**我们通过一个例子来理解这个场景。**

```

#include <stdio.h>
enum status{success, fail};
enum boolen{fail,pass};
int main(void) {

    printf("The value of success is %d", success);
  return 0;
}

```

**输出**

![Enum in C](img/804198fcb2ef81966c1e80197d3a39d2.png)

*   在枚举中，我们可以定义一个没有名称的枚举数据类型。

```

#include <stdio.h>
enum {success, fail} status;
int main(void) {
status=success;
printf("The value of status is %d", status);
return 0;
    }

```

**输出**

![Enum in C](img/e4d41bc6eacd4210f4fd4a2c8bc3a7f7.png)

### C 语言中的枚举与宏

*   宏也可以用来定义名称常量，但是在枚举的情况下，所有的名称常量可以在一个语句中组合在一起。
    例如
    #定义传球 0；
    #定义成功 1；
    以上两个语句可以使用枚举类型写成一个语句。
    枚举状态{通过，成功}；
*   枚举类型遵循范围规则，而宏不遵循范围规则。
*   在枚举中，如果我们不为枚举名赋值，那么编译器将自动为枚举名赋值。但是，在宏的情况下，需要显式分配值。
*   C 语言中的枚举类型是整数，但是宏的类型可以是任何类型。

* * *