# C 语言中的函数调用是什么？

> 原文：<https://www.javatpoint.com/what-is-the-function-call-in-c>

在跳转到函数调用之前，我们需要了解 C 编程语言中的函数。函数是一组用于执行预定义操作并返回值的任务。一个大的程序可以被分成小的代码块，这些代码块有助于理解逻辑、调试和修改它。

![What is the function call in C](img/d55e3361fa5a2dfd3580a51f5f03b1af.png)

在 [C 编程语言](https://www.javatpoint.com/c-programming-language-tutorial)中，函数分为两部分:**内置的** /库函数和**自定义函数**。

## 库/内置函数

一个**库函数**是预定义的函数，它的任务也是在 C 头文件中定义的。因此，它不需要编写特定函数的代码；相反，只要需要，它就可以在程序中直接调用。例如:printf()，scanf()，getch()，等。，是 C 库中预定义的函数，这些函数的含义不能更改。

让我们编写一个程序，用 c 语言定义库函数。

**预定义的 c**

```

# include //  Contains the printf, scanf() built-in function
#include <conio.h>void main() 
{
printf( " Welcome to the JavaTpoint.com "); 
printf("\n It is the library or built-in function in C "); 
getch(); // built-in function
}</conio.h> 
```

**输出:**

```
Welcome to the JavaTpoint.com
It is the library function or built-in function in C

```

## 用户定义的函数

是 C 编程语言中的一个**自定义** [函数，根据程序员的要求执行一些具体的动作。用户定义的函数分为三种类型，如函数声明、函数定义和函数调用。](https://www.javatpoint.com/functions-in-c)

### 函数声明

函数声明定义了程序中函数的名称和返回类型。在使用函数之前，我们需要在程序中的 main()函数之外声明它。

**语法:**

```

return_data_type function_name ( data_type arguments) ;

```

函数声明示例:

```

int add ( int num1, int num2 );

```

在上例中， **int** 是函数名 **add** 函数的返回数据类型，包含两个整数参数 **num1** 和 **num2** 。再者，我们可以把上面的函数声明写如下:

```

int add (int, int);

```

### 函数定义

它定义了程序内部函数的实际主体，用于在 c 语言中执行它们的任务

**语法:**

```

return_data_type function_name (argument list ) {
// Statement to be executed in a function;
}

```

在上面的语法中，函数定义包含以下三个部分:

1.  **Return Data_Type:** 定义函数中某个值的返回数据类型。返回的数据类型可以是整数、浮点、字符等。
2.  **函数名:**定义包含一些参数的函数的实际名称。
3.  **参数/自变量:**是在程序的函数名内部传递的参数。参数可以是任何类型、顺序和参数数量。
4.  **函数体:**是执行函数中特定任务所要执行的语句的集合。

考虑一个示例来演示函数定义:

```

int min (int n1, int n2); // min() is the name of a function that contains n1 and n2 parameters
{
// declaration of the local variable.
int out;
if ( n1 > n2) 
out = n1; // return n1 when n1 is greater than n2.
else
out = n2; // return n2 when n2 is greater than n1.
return out;
}

```

### 函数调用:

函数调用是 C 编程语言的重要组成部分。每当需要调用函数时，都会在程序内部调用它。在程序的 main()函数中，只能通过名称来调用它。我们可以将参数传递给在 main()函数中调用的函数。

**语法:**

```

Add(a, b) // a and b are the parameters

```

让我们考虑一个用 C 编程语言调用函数的程序。

**Add.c**

```

#include int add(int a, int b); 
void main()
{

int sum;
int a, b;
printf(" Enter the first and second number \n");
scanf("%d %d", &a, &b);
sum = add(a, b); // call add() function
printf( "The sum of the two number is %d", sum);
}
int add(int n1, int n2) // pass n1 and n2 parameter
{
int c;
c = n1 + n2;
return c;
} 
```

**输出:**

```
Enter the first and second number
5
6
The sum of the two number is 11

```

### 按价值呼叫:

当一个实际参数的单个或多个值被复制到一个函数的形式参数中时，该方法被称为**按值调用**。因此，它不会使用形式参数改变函数的实际参数。

考虑一个程序来演示 C 编程中的值调用。

**Call_Value.c**

```

#include int main()
{
int x = 10, y = 20;
printf (" x = %d, y = %d from main before calling the function", x, y);
CallValue(x, y);
printf( "\n x = %d, y = %d from main after calling the function", x, y);
}
int CallValue( int x, int y)
{
x = x + 5;
y = y + 5;
printf (" \nx = %d, y = %d from modular function", x, y);
} 
```

**输出:**

```
x = 10, y = 20 from main before calling the function
x = 15, y = 25 from modular function
 x = 10, y = 20 from main after calling the function

```

### 参考呼叫:

在这个方法中，实际参数的地址被复制到函数调用的形式参数中；该方法被称为**引用调用**。如果我们对形式参数做一些改变，它会显示实际参数值的影响。

考虑一个程序来演示 C 编程中的引用调用。

**Call_Ref.c**

```

#include int main()
{
int x = 10, y = 20;
printf (" x = %d, y = %d from main before calling the function", x, y);
CallValue (&x, &y);
printf( "\n x = %d, y = %d from main after calling the function", x, y);
}
int CallRef( int *a, int *b)
{
*a = *a + 5;
*b = *b + 5;
printf (" \nx = %d, y = %d from modular function", *a, *b);
} 
```

**输出:**

```
x = 10, y = 20 from main before calling the function
x = 15, y = 25 from modular function
 x = 15, y = 25 from main after calling the function

```

* * *