# typedef 和 C 语言中定义的区别

> 原文：<https://www.javatpoint.com/typedef-vs-define-in-c>

在本主题中，我们将讨论 C 编程语言中 **typedef** 和**定义**的区别。

![typedef vs define in C](img/f2e00a5392da169a3d69fa9a2805fdc1.png)

## typedef(类型定义):

一个 [typedef](https://www.javatpoint.com/typedef-in-c) 是一个在 [C 编程](https://www.javatpoint.com/c-programming-language-tutorial)中使用的关键字，用于定义现有数据类型的新名称。但是它不能为预定义的数据类型提供新的数据类型。相反，它为已经存在的数据类型(int、char、float 等)提供了一个完整的名称。).它是在程序的 main()函数之外定义的。换句话说，typedef 用于在 C 编程中重新定义现有数据类型的名称。

**语法**

```

typedef data_type newName
or typedef <alias_name></alias_name> 
```

在上面的语法中， **existing _name** 定义了预定义的数据类型或变量名。“**别名**或**新名称**定义了 C 程序中现有数据类型或变量名的新名称。

**示例 1:** 考虑一个在 c 语言中使用 typedef 关键字的程序

**c 型**

```

#include typedef int Length; // typedef provide the int data type to a new name as Length 
int main()
{
Length num1, num2, sum; // here Length variable is treated as the int data type
printf(" Enter the first number:");
scanf(" %d", & num1);
printf(" Enter the second number:");
scanf(" %d", & num2);
sum = num1 + num2;
printf(" The sum of the two numbers is: %d", sum);
return 0;
} 
```

**输出:**

```
Enter the first number: 20
Enter the second number: 10
The sum of the two numbers is: 30

```

**示例 2:** 让我们考虑另一个在 c 的无符号字符中使用 typedef 的程序。

**program.c**

```

#include #include <conio.h>typedef unsigned char Bit;
int main()
{
Bit B1, B2;
B1 = 'D';
B2 = 'E';
printf( " Demonstrate the use of typedef Keyword ");
printf (" Print a single Byte: %c", B1);
printf (" Print a single Byte: %c", B2);
return 0;
}</conio.h> 
```

**输出:**

```
Demonstrate the use of typedef Keyword
Print a single Byte: D
Print a single Byte: E

```

### 结构中 typedef 关键字的使用

让我们考虑一个在 structure 中使用 typedef 关键字为结构提供新名称并初始化结构变量的程序，如下所示:

**结构 c**

```

#include #include <string.h>typedef struct Students {
   int roll_no;
   char name[50];
   char Subject[60];
   char teacher_name[80];
} Stud;

int main( ) {

   Stud S1;
   S1.roll_no = 30;
   strcpy( S1.name, "Lockie Ferguson");
   strcpy( S1.Subject, "Mathematics"); 
   strcpy( S1.teacher_name, "Jasmine");

   printf( "Student Roll No: %d\n", S1.roll_no);
   printf( "Student Name: %s\n", S1.name);
   printf( "Student Subject: %s\n", S1.Subject);
   printf( "Student Teacher Name: %s\n", S1.teacher_name);

   return 0;
}</string.h> 
```

**输出:**

```
Student Roll No: 30
Student name: Lockie Fergusion
Student Subject: Mathematics
Student Teacher Name: Jasmine

```

在上面的程序中，我们使用 typedef 关键字为结构数据类型定义一个新名称为**学生**，并使用它初始化变量。

## 规定

A [**#define**](https://www.javatpoint.com/c-preprocessor-define) 是用于表示各种数据的常量别名的预处理器。用于定义 C 中不同[数据类型的常量变量。它在主程序之外定义。](https://www.javatpoint.com/data-types-in-c)

**语法**

```

#define token value

```

在上面的语法中，#define 是一个预处理器，它将**标记**定义为常量变量名，该值代表标记值。在预处理器中初始化常量变量后，我们可以在程序中使用变量的值。

**示例 1:** 考虑一个在 c 语言中使用#define 预处理器的程序

**定义 c**

```

#include #include <conio.h>#define PI 3.14 // define the constant variable 
void main()
{
printf (" Display the PI Constant value using the #define is: %f", PI);
getch();
}</conio.h> 
```

**输出:**

```
Display the PI Constant value using the #define is: 3.14

```

**示例 2:** 考虑一个使用#define 预处理器获取 C 语言中圆的面积的程序。

**c 区**

```

# include #include <conio.h>#define PI 3.14 // define the constant variable 
void main()
{
int r, area;
printf (" Enter the radius of the circle: ");
scanf ("%d", &r);
area = PI * r * r;
printf (" The area of the circle is: %d", area);
getch();
}</conio.h> 
```

**输出:**

```
Enter the radius of the circle : 5
The area of the circle is: 78

```

在上面的程序中，我们使用 PI 作为连续变量，使用#define 预处理器。而当程序执行时，PI 值会自动在程序中调用。

**示例 3:** 考虑一个程序来演示 typedef 相对于数据类型的#define 的重要性。

**pgrm . c .**

```

#include #include <conio.h>typedef char* ptr;
#define PTR char
int main()
{
ptr x, y, z;
PTR p, q, r;
printf (" sizeof x : %d\n", sizeof(x) );
printf (" sizeof y : %d\n", sizeof(y) );
printf (" sizeof z : %d\n", sizeof(z) );
printf (" sizeof p : %d\n", sizeof(p) );
printf (" sizeof q : %d\n", sizeof(q) );
printf (" sizeof r : %d\n", sizeof(r) );
return 0;
}</conio.h> 
```

**输出:**

```
Sizeof x:8
Sizeof y:8
Sizeof z:8
Sizeof p:8
Sizeof q:1
Sizeof r:1

```

### typedef 和 C #定义之间的区别

以下是 typedef 和#define 的区别，如下所示:

| 塞内加尔 | Typedef(类型定义) | #定义 |
| 1. | Typedef 是 C 编程语言中的一个关键字。 | #define 是一个预处理器，用作 C 编程中使用的宏。 |
| 2. | 这是一个关键字，仅用于为现有数据类型提供替代名称。这个名字可以用来初始化程序中的变量。 | #define 用于定义值的别名。 |
| 3. | 编译器执行它。 | 预处理器执行它。 |
| 4. | 它使用分号来终止语句。 | 它不使用分号来终止语句。 |
| 5. | 它定义了新数据类型的实际定义。 | #define 只是用来复制粘贴它调用或使用的定义值。 |
| 6. | 它遵循作用域规则，该规则定义了如果一个新的数据类型在作用域中(在一个函数内部)，新的类型名称将只在该数据类型的作用域中可见。 | 当#define 预处理程序在程序中遇到时，它用定义的值替换所有出现的变量；在那之后，没有范围被跟随。 |
| 7. | 在 main()函数之外定义。 | 在 main()函数之外定义。 |

* * *