# 类型转换和类型铸造的区别

> 原文：<https://www.javatpoint.com/type-casting-vs-type-conversion>

两个术语**类型转换**和**类型转换**在程序中用于将一种数据类型转换为另一种数据类型。只有当数据类型相互兼容时，编译器才可能进行数据类型转换。让我们讨论任何编程语言中类型转换和类型转换的区别。

### 什么是类型铸造？

当程序员或用户在编写任何编程语言的程序代码时，将一种数据类型转换为另一种数据类型时，这种机制被称为**类型转换**。程序员手动使用它将一种数据类型转换成另一种数据类型。如果我们想将目标数据类型更改为另一种数据类型，则使用它。请记住，目标数据类型必须小于源数据类型。因此，它也被称为缩小转换。

![Difference Between Type Casting and Type Conversion](img/9ebf0b09d6176ccce21c573c6648892f.png)

**语法:**

```

Destination_datatype = (target_datatype) variable;
(data_type) it is known as casting operator

```

**Target_datatype:** 是我们要转换目的数据类型的数据类型。该变量定义了要在 target_data 类型中转换的值。让我们用一个例子来理解类型铸造的概念。

假设，我们要将 **float** 数据类型转换为 **int** 数据类型。这里，目标数据类型比源数据小，因为 **int** 的大小是 2 字节，而 **float** 数据类型的大小是 4 字节。当我们改变它时，浮点变量的值被截断并转换成整数变量。可以使用兼容和不兼容的数据类型进行转换。

```

float b = 3.0;
int a = (int) b; // converting a float value into integer

```

让我们通过一个 C 程序来理解类型转换。

**区域频率范围。c**

```

#include<stdio.h>
#include<conio.h>
void main()
{
	printf("\n Welcome to Javatpoint tutorials ");
	float x = 3.5, y = 4.5;  // the size of float variable is 4 byte.
	int area; // the size of the int variable is 2 bytes.
	area = (int) x * y; // after conversion the product converts into integer
	printf("\n Area of a Rectangle is : %d", area);
	printf("\n Here, we convert float data type into the Int data type");
	getch();
}

```

**输出:**

![Difference Between Type Casting and Type Conversion](img/52c5c699e384604a78611a4bcb29cb6d.png)

### 什么是类型转换？

如果一种数据类型在编译时自动转换为另一种数据类型，这就是所谓的类型转换。如果两种数据类型相互兼容，则由编译器执行转换。请记住，目标数据类型不应小于源类型。也称为数据类型的**加宽**转换。

![Difference Between Type Casting and Type Conversion](img/071882032d2a5f755cbe646b5c7fd820.png)

让我们用一个例子来理解类型转换。

假设，我们有一个 **int** 数据类型，并希望将其转换为一个 **float** 数据类型。这些是相互兼容的数据类型，因为它们的类型是数字，int 的大小是 2 字节，比 float 数据类型小。因此，编译器会自动转换数据类型，而不会丢失或截断值。

```

int a = 20;
Float b;	
b = a; // Now the value of variable b is 20.000   /* It defines the conversion of int data type to float data type without losing the information. */ 

```

在上面的示例中，int 数据类型被转换为 float，其大小大于 int，因此它扩展了源数据类型。

让我们通过一个 C 程序来理解类型转换。

```

#include<stdio.h>
#include<conio.h>
void main()
{
	printf("\n Welcome to Javatpoint tutorials ");
	int x = 3, y = 4;  // the size of int variable is 2 byte.
	float area; // the size of float variable is 4 bytes.
	area =  x * y; /* It is a type conversion that automatically converted by the compiler at the compile time of a program. */
	printf("\n Area of a Rectangle is : %f", area);
	printf("\n Here, we convert int data type to the float data type");
	getch();
}

```

**输出:**

![Difference Between Type Casting and Type Conversion](img/3ad90deea8c787c28d6a4e654dac3151.png)

### 类型转换和类型铸造的区别

| 附注 | 类型铸造 | 类型变换 |
| one | 类型转换是一种机制，在这种机制中，程序员使用 casting()运算符将一种数据类型转换为另一种数据类型。 | 类型转换允许编译器在程序或代码编译时将一种数据类型转换为另一种数据类型。 |
| Two | 它既可以用于兼容数据类型，也可以用于不兼容数据类型。 | 类型转换仅用于兼容的数据类型，因此不需要任何转换运算符。 |
| three | 它需要程序员手动将一种数据转换成另一种类型。 | 将一种数据类型转换为另一种数据类型不需要任何程序员干预，因为编译器会在程序运行时自动编译它。 |
| four | 程序员在设计程序时会用到它。 | 它在程序编译时使用或发生。 |
| five | 将一种数据类型转换为另一种数据类型时，目标数据类型必须小于源数据。 | 将一种数据类型转换为另一种数据类型时，目标类型应大于源数据类型。 |
| six | 它也被称为窄化转换，因为一个较大的数据类型会转换为一个较小的数据类型。 | 它也被称为扩展转换，因为一个较小的数据类型转换为一个较大的数据类型。 |
| seven | 它更加可靠和高效。 | 效率更低，可靠性更低。 |
| eight | 类型转换中可能会丢失数据或信息。 | 在类型转换中，从小型数据类型转换为大型数据类型时，数据不太可能丢失。 |
| eight | 

```
float b = 3.0;
int a = (int) b
```

 | 

```
int x = 5, y = 2, c;
float q = 12.5, p;
p = q/x;
```

 |

* * *