# C 中两个数的 LCM

> 原文：<https://www.javatpoint.com/lcm-of-two-numbers-in-c>

在本主题中，我们将讨论 LCM 以及如何在 [C 编程语言](https://www.javatpoint.com/c-programming-language-tutorial)中获得两个数字的 LCM。

![LCM of two numbers in C](img/4ceed595b67aa162f349d95298a5c49f.png)

**LCM** 是一个数学术语，代表 [**最小公倍数** (LCM)](https://www.javatpoint.com/least-common-multiple) 。它是最小的正数，可以被整数 n1 和 n2 整除，没有任何余数。LCM 也被称为**最低公倍数**。它被表示为 LCM (a，b)或 lcm (a，b)。例如，两个正数 72 和 120 的 LCM 是 360。

### LCM 算法

以下是两个数的 LCM 算法，如下所示:

**第一步:**初始化正整数变量 A 和 b

**第二步:**将 A & B 的公倍数存入 **max** 变量。

**步骤 3:** 验证最大值是否能被变量 A 和 b 整除。

**第四步:**如果 max 是可分的，显示 max 为两个数的 LCM。

**第五步:**否则，最大值增加，进入第三步。

**第 6 步:**停止程序。

### 使用 while 循环的两个数字的 LCM

让我们考虑一个例子，用 while 循环找到 C 中两个数的 LCM。

LCM . c .

```

#include #include <conio.h>void main()
{
	int num1, num2, max_div, flag = 1;
	// accept any two positive number from the user
	printf( " Enter any two positive numbers to get the LCM \n ");
	scanf(" %d %d", &num1, &num2);

	// max_div variable holds the max divisible number between num1 and num2.
	max_div = (num1 > num2) ? num1 : num2;

	while (flag) // (flag = 1)
	{
		if (max_div % num1 == 0 && max_div % num2 == 0)
		{
			printf( " The LCM of %d and %d is %d. ", num1, num2, max_div);
			break;
		}
		++max_div; // pre-increment max_div
	}
}</conio.h> 
```

**输出**

```
Enter any two positive numbers to get the LCM
 15
12
 The LCM of 15 and 12 is 60.

```

正如我们在上面的程序中看到的，我们已经传递了两个正数，15 和 12，存储在变量 num1 和 num2 中。其中 max_div 变量存储最大的可被变量 num1 和 num2 整除的数。但是，两个数的 LCM 不能小于 max_div。

在 while 循环的每次迭代中，max_div 检查 if 条件中可被 num1 和 num2 变量整除的数。

```

 if (max_div % num1 == 0 && max_div % num2 == 0)
{
}

```

如果上述条件不成立，max_div 递增 1，循环迭代继续，直到 If 语句为真。

### 使用 GCD 的两个数字的 LCM

让我们考虑一个程序，用 GCD 得到 C 中两个数的 LCM。

**Gcd.c**

```

#include #include <conio.h>int main()
{
	// declaration of the local variables
	int num1, num2, i, gcd, LCM;
	printf (" Enter any two positive numbers: \n ");
	scanf (" %d %d", &num1, &num2);

	/* use for loop to define the num1 & num2\. Where the num1 and num2 should be equal or less than i. */
	for ( i = 1; i <= num1 && i <= num2; ++i)
	{
		// check whether i id divisible by both positive number num1 and num2.
		if  (num1 % i ==0 && num2 % i == 0)
		gcd = i; // assign the divisible number i to gcd		
	}
	LCM = (num1 * num2) / gcd;

	printf( " The LCM of two numbers %d and %d is %d. ", num1, num2, LCM );
}</conio.h> 
```

**输出**

```
Enter any two positive numbers:
 30
20
 The LCM of two numbers 30 and 20 is 60.

```

### 用函数表示两个数的 LCM

让我们考虑一个程序，用函数得到 C 中两个数的 LCM。

**最大 c**

```

#include #include <conio.h>int get_lcm( int a, int b); // function declaration 

int main()
{
	int n1, n2, lcm; // declaration of variables
	printf (" \n Enter any two positive numbers to get the LCM of: \n ");
	scanf ("%d %d", &n1, &n2);
	lcm = get_lcm( n1, n2); // function calling
	printf ( " \n LCM of %d and %d is %d. ", n1, n2, lcm);
	return 0;
}

int get_lcm ( int n1, int n2) // function definition 
{
	/* static variabe is iniatialized only once for each function call */	
	static int max = 1;
	if ( max % n1  == 0 && max % n2 == 0)
	{
		return max;
	}
	else
	{
		max++;
		get_lcm( n1, n2);
		return max;
	}
}</conio.h> 
```

**输出**

```
 Enter any two positive numbers to get the LCM of:
 30
25
 LCM of 30 and 25 is 150.	

```

### 用递归函数求两个数的 LCM

让我们考虑一个程序，用递归函数得到 C 中两个数的 LCM。

LCM _ fun . c

```

#include #include <conio.h>// use Recursive function to return gcd of two numbers num1 and num2.
int gcd( int num1, int num2)
{
	if ( num1 == 0)  // if num1 is equal to 0, return num2

		{
		return num2;	
		}
	return gcd (num2 % num1, num1);
}

// lcm_fun () function returns the LCM of two numbers
int lcm_fun( int num1, int num2)
{	// divide the num1 by gcd() function and then multiply with num2.
	return ( num1 / gcd(num1, num2)) * num2;
}

int main()
{   // declaration and initialization of positive numbers
	int num1, num2;
	printf( "Enter any two positive numbers \n");
	scanf(" %d %d", &num1, &num2);

	printf ( " LCM of two numbers %d and %d is %d ", num1, num2, lcm_fun( num1, num2));
	return 0;
}</conio.h> 
```

**输出**

```
Enter any two positive numbers
26
20
 LCM of two numbers 26 and 20 is 260

```

* * *