# C 语言中的二进制到十进制数

> 原文：<https://www.javatpoint.com/binary-to-decimal-number-in-c>

本节将讨论二进制数到十进制数的转换。在进入概念之前，我们需要了解二进制数和十进制数。正如我们所知，计算机不理解人类书写或做的单词或数字。相反，它只理解 0 和 1。例如，当我们在计算机上键入一个单词或数字时，各种软件或编译器会帮助将这些数字或单词转换成二进制形式(0 和 1 位)。这样电脑机器就能很容易理解这些。

![Binary to Decimal Number in C](img/0e29ee767924d50240580d69d4c4195c.png)

## 二进制数

二进制数是代表计算机中存储的信息或数据的数字，由 0 和 1 位组合而成。它也被称为 2 进制数字系统，因为它有两个位，0 和 1。这些是二进制数(0 和 1) 1001、1010、1101、1111、1010101 等。

## 小数

十进制数是包含从 0 到 9 的 10 位数字的数字。它的基数是 10，因为它收集了 10 个数字(0、1、2、3、4、5、6、7、8、9)，并使用这 10 个数字表示或组成整数。

### 将二进制转换为十进制的算法

1.  取一个二进制数作为输入。
2.  将该数除以 10，并将余数存储到变量 rem 中。
3.  decimal _ num = decimal _ num+rem * base；
    最初，decimal_num 为 0，base 为 1，其中 rem 变量存储数字的余数。
4.  将原数的商除以 10。
5.  基数乘以 2。
6.  打印二进制数的十进制数。

### 使用 while 循环将二进制数转换为十进制数

让我们考虑使用 while 循环将二进制数(0 和 1)的组合转换为十进制数的 C 程序。

**program.c**

```
#include #include <conio.h>void main()
{
	// declaration of variables
	int num, binary_num, decimal_num = 0, base = 1, rem;
	printf (" Enter a binary number with the combination of 0s and 1s \n");
	scanf (" %d", &num); // accept the binary number (0s and 1s)

	binary_num = num; // assign the binary number to the binary_num variable

	while ( num > 0)
	{
		rem = num % 10; /* divide the binary number by 10 and store the remainder in rem variable. */
		decimal_num = decimal_num + rem * base;
		num = num / 10; // divide the number with quotient
		base = base * 2;
	}

	printf ( " The binary number is %d \t", binary_num); // print the binary number
	printf (" \n The decimal number is %d \t", decimal_num); // print the decimal 
	getch();
}</conio.h> 
```

**输出**

```
Enter a binary number with the combination of 0s and 1s
1101
 The binary number is 1101
 The decimal number is 13

```

**代码说明:**正如我们在上面的程序中看到的，它要求用户输入一个二进制数(0 和 1)将该数存储到变量 num 中。在每次迭代中，while 循环检查二进制数条件，并验证给定的数不应小于 0；否则，它将退出循环。

**下面是 while 循环的迭代，如下所示:**

**第一次迭代:**

rem = 1101 % 10 => 1

decimal _ num = 0+1 * 1 = > 1(decimal _ val = 0，rem = 1，base = 1)

num = 1101 / 10 => 110

基数= 1 * 2 => 2

**第二次迭代:**

rem = 110 % 10 => 0

decimal _ num = 1+0 * 2 = > 1(decimal _ val = 1，rem = 0，base = 2)

num = 110 / 10 => 11

基数= 2 * 2 => 4

**第三次迭代:**

rem = 11 % 10 => 1

decimal _ num = 1+1 * 4 = > 5(decimal _ val = 1，rem = 1，base = 4)

num = 11 / 10 => 1

基数= 4 * 2 => 8

**第 4 次迭代:**

rem = 1 % 10 => 1

decimal _ num = 5+1 * 8 = > 1(decimal _ val = 5，rem = 1，base = 8)

num = 1 / 10 => 0

基数= 8 * 2 => 16

### 使用 for 循环将二进制数转换为十进制数

让我们考虑一个用 C 语言编写的程序，使用 for 循环将二进制数(0 和 1)的组合转换成十进制数。

**十进制。c**

```
#include #include <conio.h>#include <math.h>// use math.h header file
void main()
{
	// declaration of local variables i, bin_num, decimal_num = 0, rem;
	int i, bin_num, decimal_num = 0, rem;
	printf (" Enter the binary number with the combination of 0s and 1s \n");
	scanf ("%d", &bin_num); // takes the binary number as the input

	printf( " \n The binary number is %d", bin_num); // print the binary number
	for (i = 0; bin_num != 0; ++i)
	{
		rem = bin_num % 10;
		bin_num = bin_num / 10;
		decimal_num = decimal_num + (rem) * ( pow (2, i));

	}
	// print the decimal number
	printf ("\n Conversion from binary to decimal number is %d", decimal_num);
	getch();
}</math.h></conio.h> 
```

**输出**

```
Enter the binary number with the combination of 0s and 1s
10010

 The binary number is 10010
 Conversion from binary to decimal number is 18 

```

### 使用函数将二进制数转换为十进制数

让我们考虑一个用 C 语言编写的程序，使用用户定义的函数将二进制数(0 和 1)的组合转换成十进制数。

**所以.c**

```
#include #include <conio.h>int binaryTodecimal(int bin_num);
int main()
{
	// declare the local variable
	int bin_num, dec_num;
	printf (" Enter the binary number (0s and 1s) \n");
	scanf ("%d", &bin_num);

	dec_num = binaryTodecimal (bin_num); // call the binaryTodecimal() function
	printf (" Conversion of the binary number to decimal number is %d", dec_num);
}

// use user defined function --- binaryTo decimal function
int binaryTodecimal( int bin_num)
{
	// declaration of variables
	int decimal_num = 0, temp = 0, rem;
	while (bin_num != 0)
	{
		rem = bin_num % 10;
		bin_num = bin_num / 10;
		decimal_num = decimal_num + rem * pow( 2, temp);
		temp++;
	}
	return decimal_num;
}</conio.h> 
```

**输出**

```
Enter the binary number (0s and 1s)
11001
 Conversion of the binary number to decimal number is 25

```

### 使用数组和函数将二进制数转换为十进制数

让我们考虑一个用 C 语言编写的程序，使用函数和数组将二进制数(0 和 1)的组合转换成十进制数。

**十进制 2.c**

```
#include #include <conio.h>int binaryTodecimal (char num[])
{
	int i, deci_num, mul = 0;
	for ( deci_num = 0, i = str_length(num) - 1; i >= 0; --i, ++mul)
	{
			deci_num = deci_num + (num[i] - 48) * (1 << mul);
	}

	return deci_num;
 }

 int str_length( char str[])
 {
 	int i = 0;
 	while (str[i] != '\0')
 		i++;
 	return i;	
 }

int main()
{
	char num[] = "1101";
	int deci_num;
	printf ("\n The binary number is %s", num);
	printf ("\n The decimal number of %s is %d", num, binaryTodecimal(num));
	return 0;
  }</conio.h> 
```

**输出**

```
The binary number is 1101
The decimal number of 1101 is 13

```

* * *