# C 语言中的 Getchar()函数

> 原文：<https://www.javatpoint.com/getchar-function-in-c>

在本节中，我们将学习 C 编程语言中的 getchar()函数。一个 **getchar()** 函数是一个**非标准的**函数，其含义已经在 **stdin.h** 头文件中定义，接受来自用户的单一输入。换句话说，是 C 库函数从 stdin 中获取单个字符(无符号字符)。但是 getchar()函数与 getc()函数类似，只是 [C 编程语言](https://www.javatpoint.com/c-programming-language-tutorial)的 getchar()和 getc()函数有一点区别。getchar()从标准输入中读取一个字符，而 getc()从任何输入流中读取一个字符。

![Getchar() function in C](img/fcf6dcbf63ace10669fb01a87fe709e8.png)

**语法**

```

int getchar (void);

```

它没有任何参数。但是，它将读取的字符作为 int 中的无符号字符返回，如果文件有错误，它将在文件末尾返回 **EOF** 。

现在我们编写几个 getchar()函数程序来接受 C 语言中的单个字符，并使用 putchar()函数打印它们。

### 使用 getchar()函数读取单个字符

让我们考虑一个使用 c 语言中的 getchar()函数获取单个。

**程序代码**

```

#include <stdio.h>
#include <conio.h>	
void main()
{
	char c;	
	printf ("\n Enter a character \n");
	c = getchar(); // get a single character
	printf(" You have passed ");
	putchar(c); // print a single character using putchar

	getch();
}

```

**输出**

```
Enter a character
A
 You have passed A

```

正如我们在上面的程序中看到的，它在运行时使用 getchar()函数从用户那里获取一个字符。获取字符后，它通过 putchar()函数打印字母。

### 使用 getchar()函数从用户处读取 n 个字符

让我们考虑一个使用 c 语言中的 getchar()函数读取 n 个字符的程序。

**Getchar.c**

```

#include <stdio.h>
#include <conio.h>
#include <ctype.h> 
int main()	
{
	char ch; 
	printf (" Enter a character ( If we want to exit press #) \n");
	while (ch != '#') /* accept the number till the user does not enter the # to exit from the loop. */
	{
		ch = getchar(); 
		printf (" \n We have entered the character : ");
		putchar (ch); // print a single character
		printf ("\n");
		}	
		return 0;
}

```

**输出**

```
Enter a character ( If we want to exit.. press #)
A

 We have entered the character: A
 We have entered the character:

B

 We have entered the character: B
 We have entered the character:
C

 We have entered the character: C
 We have entered the character:

```

正如我们在上面的输出中所看到的，while 循环不断地接受来自用户的字符，直到用户没有传递#字符。在这里，getchar()函数从标准输入中获取一个字符，并将它们分配给一个 ch 变量。而 putchar()函数打印读取的字符。

### 使用 scanf()函数读取单个字符

让我们考虑一个使用 c 语言中的 scanf()库函数读取字符的程序。

**Prog.c**

```

#include <stdio.h>
#include <conio.h>
int main()
{
	char ch;

	printf ("\n Enter the character \n");
	scanf ("%c", &ch); // get a single character, numeric or words
	printf( " You have entered %c",  ch);  /* It print a single character or first letter of the words. */

	return 0;
}

```

**输出**

```
Enter the character
A
 You have entered A

```

如我们所见，当我们执行上述程序时，它使用 scanf()库函数而不是 getchar()函数来获取单个字符或一组字符。但是有一个小小的区别；scanf()函数可以从用户处获取单个或一组字符，而 getchar()函数只能接受单个字符。

这里我们再次执行上面的程序，这一次，它显示了下面的结果。

```

Enter the character
Apple
 You have entered A

```

### 使用边做边循环读字符

让我们考虑一个使用 c 语言中的 do while 和 getchar()函数读取字符的程序。

**Dowhile1.c**

```

#include <stdio.h>
#include <ctype.h>
int main()
{
	int ch, i = 0;
	char str[150]; 
    printf (" Enter the characters from the keyboard (Press Enter button to stop).\n");
    // use do while loop to define the condition
    do
    {
    	ch = getchar(); // takes character, number, etc from the user
    	str[i] = ch; // store the ch into str[i]
    	i++; // increment loop by 1
	} while (ch != '\n');  // ch is not equal to '\n'
	printf("Entered characters are %s ", str); 
	return 0;
}

```

**输出**

```
Enter the characters from the keyboard (Press Enter button to stop).
Well b47gvb come
Entered characters are Well b47gvb come

```

在上述程序中，边做边循环连续接受字符，直到用户通过**回车**按钮退出循环。

* * *