# C 语言中的金字塔模式

> 原文：<https://www.javatpoint.com/pyramid-patterns-in-c>

本节将讨论 C 编程语言中数字、星星和字母的金字塔模式。所有金字塔图案都是多边形结构。面试官通常会要求这些模式来考察程序员的逻辑和思维能力。一旦理解了代码的逻辑，就可以用 C 语言和 [C++](https://www.javatpoint.com/cpp-tutorial) 、 [JAVA](https://www.javatpoint.com/java-tutorial) 、 [PYTHON](https://www.javatpoint.com/python-tutorial) 、 [PHP](https://www.javatpoint.com/php-tutorial) 等创建各种金字塔模式。[编程语言](https://www.javatpoint.com/programming-language)。

现在我们将使用[循环](https://www.javatpoint.com/c-loop)和 [if 语句](https://www.javatpoint.com/c-if-else)在 [C 编程语言](https://www.javatpoint.com/c-programming-language-tutorial)中创建金字塔的各种模式。

## 1.星形金字塔图案

### 打印半金字塔的程序

让我们考虑一个打印用于循环的半金字塔图案的例子。

**star.c**

```

#include <stdio.h>
#include <conio.h>
void main()
{
	int i, j, rows;
	printf (" Enter a number to define the rows: \n ");
	scanf("%d", &rows);
	printf("\n");
	for (i = 1; i <= rows; ++i) // outer loop
	{
		for (j = 1; j <= i; ++j) // inner loop
		{
			printf ("* "); // print the Star
		}
		printf ("\n"); 
	}
	getch();	
}

```

**输出**

![Pyramid Patterns in C](img/0f7ace0a9a24e092d94d608f9ce695e6.png)

### 打印倒半金字塔图案的程序

让我们考虑一个使用 for 循环打印倒半金字塔图案的示例。

**star.c**

```

#include <stdio.h>
#include <conio.h>
void main()
{
	int i, j, rows;
	printf (" Enter a number to define the rows: \n ");
	scanf("%d", &rows); 
	printf("\n");
	for (i = rows; i > 0; i--) // define the outer loop
	{
		for (j = i; j > 0; j--) // define the inner loop
		{
			printf ("* "); // print the Star
		}
		printf ("\n"); 
	}
	getch();	
}

```

**输出**

![Pyramid Patterns in C](img/97c9d0ab1c1b278b76c0f529b3b8a8b3.png)

### 打印倒右半金字塔的程序

让我们考虑一个使用 for 循环打印反向右半金字塔图案的示例。

**star.c**

```

#include <stdio.h>
#include <conio.h>
void main()
{
	int i, j, rows, k;
	printf (" Enter a number to define the rows: \n ");
	scanf("%d", &rows); 
	printf("\n");
	for (i = 1; i <= rows; i++) 
	{
		for (j = 1; j <= i; j++) 
		{
			printf(" "); 
		}
		for (k = i; k <= rows; k++)
		{
			printf("*"); // print the Star
		}
		printf ("\n"); 
	}
	getch();	
}

```

**输出**

![Pyramid Patterns in C](img/149f6a17808293ee3d26f460355bf7c7.png)

### 打印右半部金字塔的程序

让我们考虑一个例子来打印用于循环的右半金字塔图案。

**star.c**

```

#include <stdio.h>
#include <conio.h>
void main()
{

	int i, j, rows, k;
	printf (" Enter a number to define the rows: \n ");
	scanf("%d", &rows); 
	printf("\n");
	for (i = 1; i <= rows; i++) 
	{
		for (j = i; j < rows; j++)
		{
			printf(" "); 
		}
		for (k = 1; k <= i; k++)
		{
			printf("*"); // print the Star
		}
		printf ("\n"); 
	}
	getch();	
}

```

**输出**

![Pyramid Patterns in C](img/40c4cb8d813d1ac7abeeaf44b05f0c01.png)

### 程序打印完整的 180 度星金字塔

让我们考虑一个使用 for 循环以 180 度打印完整的星形金字塔的示例。

**star.c**

```

#include <stdio.h>
#include <conio.h>
void main()
{
	int num, i, j, m = 1; // declare local variables
	printf (" Enter the number to define the columns: \n");
	scanf ("%d", & num);
	for (i = 1; i <= num; i++)
	{
		for (j = 1; j <= i; j++)
		{
			printf( "* ");
		}
		printf("\n");
	}
	for (i = num-1; i >= 1; i--)
	{
		for (j = 1; j <= i; j++)
		{
			printf ("* ");
		}
		printf("\n");
	}
	getch();
}

```

**输出**

![Pyramid Patterns in C](img/628d9f4b44edd41ab999022ea03a41a1.png)

### 程序以相反的方向打印整个星金字塔

让我们考虑一个使用 for 循环以 180 度的相反方向打印完整的星形金字塔的示例。

**star.c**

```

#include <stdio.h>
#include <conio.h>
void main()
{
	// declare the local variables
	int i, j, rows, k;
	printf (" Enter a number to define the columns: \n ");
	scanf("%d", &rows); 
	printf("\n");
	for (i = 1; i <= rows; i++) 
	{
		for (j = i; j < rows; j++) 
		{
			printf(" "); 
		}
		for (k = 1; k <= i; k++)
		{
			printf("*"); // print the Star
		}
		printf ("\n"); 
	}
	for (i = 1; i <= rows; ++i) 
	{
		for (j = 2; j <= i; j++)
		{
			printf(" "); 
		}
		for (k = i; k <= rows; k++)
		{
			printf("*"); // print the Star
		}
		printf ("\n"); 
	}
	getch();	
}

```

**输出**

![Pyramid Patterns in C](img/375b4664b122f38ec3c61cb1e1ec8a27.png)

### 打印完整的恒星金字塔的程序

让我们考虑一个使用 for 循环打印完整的星形金字塔的例子。

**star.c**

```

#include <stdio.h>
#include <conio.h>
void main()
{

	int i, j, rows, k = 0;
	printf (" Enter a number to define the rows: \n");
	scanf ("%d", &rows); 

	for ( i =1; i <= rows; i++)
	{
		for ( j = 1; j <= rows - i; j++)
		{
			printf ("  "); 
		}
		// use for loop where k is less than equal to (2 * i -1)
		for ( k = 1; k <= ( 2 * i - 1); k++)
		{
			printf ("* "); // print the Star
		}
		printf ("\n");
	}
	getch();
}

```

**输出**

![Pyramid Patterns in C](img/cf7878f3bb32cedab420a5440fd7ed1c.png)

### 打印倒完整的星金字塔的程序

让我们考虑一个使用 for 循环打印完整的星形金字塔的例子。

**star.c**

```

#include <stdio.h>
#include <conio.h>
void main()
{
	// declare the local variables
	int i, j, rows, k, m = 1;
	printf (" Enter a number to define the rows: \n");
	scanf ("%d", &rows); 
	printf("\n");

	for ( i = rows; i >= 1; i--)
	{

		for ( j = 1; j <= m; j++)
		{
			printf ("  "); // print the space
		}

		for ( k = 1; k <= ( 2 * i - 1); k++)
		{
			printf ("* "); // print the Star
		}
		m++;
		printf ("\n");
	}
	getch();
}

```

**输出**

![Pyramid Patterns in C](img/78d6b139f7d3c54f653c8aa87226a8e2.png)

### 打印星形菱形图案的程序

让我们考虑一个打印用于循环的星形菱形图案的示例。

**star.c**

```

#include <stdio.h>
#include <conio.h>
void main()
{
	// declare the local variables
	int i, j, rows, k;
	printf (" Enter a number to define the rows: \n ");
	scanf("%d", &rows); 
	int space = rows-1, num=1;
	printf("\n");
	for (i = 1; i <= rows; i++) 
	{
		for (j = 1; j <= space; j++) 
		{
			printf("  "); / print the number
		}
		for ( k= 1; k <= num; k++)
		{
			printf(" *");
		}
		if(space > i)
		{
			space = space -1;
			num = num+2;
		}
		if(space <i)
		{
			space = space + 1;
			num = num -2;
		}
		printf("\n");
	}
	getch();	
}

```

**输出**

![Pyramid Patterns in C](img/c379937523436e7a3461e7073d6d5e09.png)

## 2.数字金字塔模式

### 打印数字的半金字塔的程序

让我们考虑一个打印用于循环的半金字塔图案的例子。

**star.c**

```

#include <stdio.h>
#include <conio.h>
void main()
{
	// declare the local variables
	int i, j, rows;
	printf (" Enter a number to define the rows: \n ");
	scanf("%d", &rows); 
	printf("\n");
	for (i = 1; i <= rows; ++i) 
	{
		for (j = 1; j <= i; ++j) 
		{
			printf ("%d ", j); 
		}
		printf ("\n"); 
	}
	getch();	
}

```

**输出**

![Pyramid Patterns in C](img/5e12c7344e8760d64ad185b628e67b89.png)

**例 2:**

让我们考虑一个例子来打印用于循环的数字的半金字塔模式。

**Star.c**

```

#include <stdio.h>
#include <conio.h>
void main()
{
	// declare the local variables
	int i, j, rows;
	printf (" Enter a number to define the rows: \n ");
	scanf("%d", &rows); 
	printf("\n");
	for (i = 1; i <= rows; ++i) 
	{
		for (j = 1; j <= i; ++j) 
		{
			printf ("%d ", i); // print the number
		}
		printf ("\n"); 
	}
	getch();	
}

```

**输出**

![Pyramid Patterns in C](img/6a6353aff4a9cf2241eb828fa825dbb6.png)

### 打印倒半金字塔图案的程序

让我们考虑一个使用 for 循环打印倒半金字塔图案的示例。

**star.c**

```

#include <stdio.h>
#include <conio.h>
void main()
{
	// declare the local variables
	int i, j, rows;
	printf (" Enter a number to define the rows: \n ");
	scanf("%d", &rows); 
	printf("\n");
	for (i = rows; i > 0; i--) // define the outer loop
	{
		for (j = i; j > 0; j--) // define the inner loop
		{
			printf ("%d ", j);
		}
		printf ("\n");
	}
	getch();	
}

```

**输出**

![Pyramid Patterns in C](img/baf01114454418b71ad07aa16175033f.png)

### 打印数字金字塔右半部的程序

让我们考虑一个例子来打印用于循环的数字的右半金字塔模式。

**star.c**

```

#include <stdio.h>
#include <conio.h>
void main()
{
	// declare the local variables
	int i, j, rows, k;
	printf (" Enter a number to define the rows: \n ");
	scanf("%d", &rows); 
	printf("\n");
	for (i = 1; i <= rows; i++) 
	{
		for (j = i; j < rows; j++) 
		{
			printf("  "); 
		}
		for (k = 1; k <= i; k++)
		{
			printf(" %d", k); 
		}
		printf ("\n"); 
	}
	getch();	
}

```

**输出**

![Pyramid Patterns in C](img/66eb355cd1df5a582cf6bd156effd273.png)

### 程序打印一个倒右半金字塔的数字

让我们考虑一个例子，打印一个反向右半金字塔模式的数字用于循环。

**star.c**

```

#include <stdio.h>
#include <conio.h>
void main()
{
      // declare the local variables
int i, j, rows, k;
printf (" Enter a number to define the rows: \n ");
scanf("%d", &rows); 
printf("\n");
for (i = 1; i <= rows; i++) 
{
        for (j = 1; j <= i; j++) 
             {
                 printf("  "); 
           }
        for (k = i; k <= rows; k++)
            {
               printf(" %d", k); 
           }
          printf ("\n"); 
 }
getch();	
}

```

**输出**

![Pyramid Patterns in C](img/4ded0b67b8b42afab9476e9584e6c911.png)

### 打印弗洛伊德三角形的程序

让我们考虑一个打印用于循环的弗洛伊德金字塔图案的例子。

**star.c**

```

#include <stdio.h>
#include <conio.h>
void main()
{
	// declare the local variables
	int i, j, rows, k = 1;
	printf (" Enter a number to define the rows: \n ");
	scanf("%d", &rows); 
	printf("\n");
	for (i = 1; i <= rows; i++) 
	{
		for (j = 1; j <= i; j++) 
		{
			printf("%d ", k); 
			k += 1;
		}
		printf("\n");
	}
	getch();	
}

```

**输出**

![Pyramid Patterns in C](img/a2ca94b6d44ae8f3380a1e1093d694d0.png)

### 打印菱形数字金字塔的程序

让我们考虑一个例子来打印用于循环的菱形金字塔。

**star.c**

```

#include <stdio.h>
#include <conio.h>
void main()
{
	// declare the local variables
	int i, j, rows, k;
	printf (" Enter a number to define the rows: \n ");
	scanf("%d", &rows);
	int space = rows-1, num=1;
	printf("\n");
	for (i = 1; i <= rows; i++)
	{
		for (j = 1; j <= space; j++) 
		{
			printf(" "); 
		}
		for ( k= 1; k <= num; k++)
		{
			printf("%d", k);
		}
		if(space > i)
		{
			space = space -1;
			num = num+2;
		}
		if(space <i)
		{
			space = space + 1;
			num = num -2;
		}
		printf("\n");
	}	
	getch();	
}

```

**输出**

![Pyramid Patterns in C](img/7bf9973753369b0e83cd9b72f350d43a.png)

### 程序打印完整的数字金字塔

让我们考虑一个使用 for 循环打印完整的数字金字塔的例子。

**star.c**

```

#include <stdio.h>
#include <conio.h>
void main()
{
	// declare the local variables
	int i, j, rows, k = 0;
	printf (" Enter a number to define the rows: \n");
	scanf ("%d", &rows); // take a number

	for ( i =1; i <= rows; i++)
	{
		// inner loop define j should be less than equal to rows- i
		for ( j = 1; j <= rows - i; j++)
		{
			printf ("  "); // print the space
		}
		// use for loop where k is less than equal to (2 * i -1)
		for ( k = 1; k <= ( 2 * i - 1); k++)
		{
			printf ("%d ",i); // print the number
		}
		printf ("\n");
	}
	getch();
}

```

**输出**

![Pyramid Patterns in C](img/7da877a86e4be93ef1423374baa9996a.png)

### 打印倒全金字塔数字的程序

让我们考虑一个使用 for 循环打印数字倒金字塔的例子。

**star.c**

```

#include <stdio.h>
#include <conio.h>
void main()
{
	// declare the local variables
	int i, j, rows, k, m = 1;
	printf (" Enter a number to define the rows: \n");
	scanf ("%d", &rows); // take a number
	printf("\n");
	// outer loop define the total rows and i should be greater than equal to 1
	for ( i = rows; i >= 1; i--)
	{
		// inner loop define j should be less than equal to m
		for ( j = 1; j <= m; j++)
		{
			printf ("  "); 
		}
		for ( k = 1; k <= ( 2 * i - 1); k++)
		{
			printf ("%d ", i); // print the number
		}
		m++;
		printf ("\n");
	}
	getch();
}

```

**输出**

![Pyramid Patterns in C](img/e5ad9d446e2d5234d41f35dbd7a3dfab.png)

### 打印帕斯卡三角形的程序

让我们考虑一个使用 for 循环打印帕斯卡三角形的例子。

**star.c**

```

#include <stdio.h>
#include <conio.h>
void main()
{
	// declare the local variables
	int i, j, rows, k, m;
	printf (" Enter a number to define the rows: \n");
	scanf ("%d", &rows); 
	printf("\n");
	// outer loop define the total rows and i should be less than equal to rows
	for ( i = 1; i <= rows; i++)
	{
		// inner loop define j should be less than equal to rows- i
		for ( j = 1; j <= rows-i; j++)
		{	
			printf (" "); 
		}
		// use for loop where k is less than equal to i
		for ( k = 1; k <= i; k++)
		{
			printf ("%d", k); // print the number
		}
		for (m = i-1; m >=1; m--)
		{
			printf("%d", m); // print the number
		}
		printf ("\n");
	}
	getch();
}

```

**输出**

![Pyramid Patterns in C](img/a07104534601b6807785787fa56342da.png)

### 组合两个半金字塔数字的程序

让我们考虑一个打印两个半金字塔数字的组合的例子..

**star.c**

```

#include <stdio.h>
#include <conio.h>
void main()
{
	// declare the local variables
	int i, j, rows, k;
	printf (" Enter a number to define the rows: \n");
	scanf ("%d", &rows); // take a number
	printf("\n");
	for ( i = 1; i <= rows; i++)
	{

		for ( j = 1; j <= rows; j++)
		{
			if( j <= i)
			printf ("%d", j); 
			else
			printf(" ");
		}
		for (j = rows; j >= 1; j--)
		{
			if(j <= i)
			printf ("%d", j);
			else
			printf(" ");
		}
		printf ("\n");
	}
	getch();
}

```

**输出**

![Pyramid Patterns in C](img/7848a26c5da4554dd6f27a9fef642eea.png)

## 3.字母金字塔图案

### 打印字母半金字塔的程序

让我们考虑一个打印用于循环的半金字塔图案的例子。

**star.c**

```

#include <stdio.h>
#include <conio.h>
void main()
{
	// declare the local variables
	int i, j, rows;
	printf (" Enter a number to define the rows: \n ");
	scanf("%d", &rows); 
	printf("\n");
	for (i = 1; i <= rows; ++i) // define the outer loop
	{
		for (j = 1; j <= i; ++j) // define the inner loop
		{
			printf ("%c ", 'A' + j - 1); // print the alphabets 
		}
		printf ("\n"); // jump to next line
	}
	getch();	
}

```

**输出**

![Pyramid Patterns in C](img/03a3ad8beceaa2498f379fd8e14981a7.png)

### 打印倒半金字塔字母的程序

让我们考虑一个打印用于循环的半金字塔图案的例子。

**star.c**

```

#include <stdio.h>
#include <conio.h>
void main()
{	
	// declare the local variables
	int i, j, rows, ch = 'A';
	printf (" Enter a number to define the rows: \n ");
	scanf("%d", &rows); 
	printf("\n");
	for (i = rows; i > 1; i--) 
	{
		for (j = 1; j < i; j++) 
		{
			printf ("%c ", ch); 
		}
		ch++;
		printf ("\n");
	}
	getch();
}

```

**输出**

![Pyramid Patterns in C](img/20e5ef52d9f090befa0f628ce82f76f2.png)

### 打印字母金字塔右半部分的程序

让我们考虑一个打印用于循环的半金字塔图案的例子。

**star.c**

```

#include <stdio.h>
#include <conio.h>
void main()
{
	// declare the local variables
	int i, j, rows, k, ch='A';
	printf (" Enter a number to define the rows: \n ");
	scanf("%d", &rows); 
	printf("\n");
	for (i = 1; i <= rows; i++) 
	{
		for (j = i; j < rows; j++) 
		{
			printf("  "); 
		}
		for (k = 1; k <= i; k++)
		{
			printf(" %c", ch);
		}
		ch++;
		printf ("\n"); 
	}
	getch();	
}

```

**输出**

![Pyramid Patterns in C](img/4b713cd7cdb2ea1373c2177455b41eb7.png)

### 打印倒半金字塔字母的程序

让我们考虑一个打印用于循环的半金字塔图案的例子。

**star.c**

```

#include <stdio.h>
#include <conio.h>
void main()
{

int i, j, rows, k;
printf (" Enter a number to define the rows: \n ");
scanf("%d", &rows); 
printf("\n");
for (i = 1; i <= rows; i++) 
{
        for (j = 1; j <= i; j++) 
             {
                 printf("  "); 
           }
        for (k = i; k <= rows; k++)
            {
               printf(" %c", 'A' + k);
           }
          printf ("\n"); 
 }
getch();	
}

```

**输出**

![Pyramid Patterns in C](img/421e36c10d662a1f62c1b09b83aec9bc.png)

### 程序打印完整的字母金字塔

让我们考虑一个使用 for 循环打印完整金字塔图案的示例。

**star.c**

```

#include <stdio.h>
#include <conio.h>
void main()
{

	int i, j, rows, k, ch = 'A';
	printf (" Enter a number to define the rows: \n");
	scanf ("%d", &rows); 

	for ( i =1; i <= rows; i++)
	{

		for ( j = 1; j <= rows - i; j++)
		{
			printf ("  "); 
		}
		// use for loop where k is less than equal to (2 * i -1)
		for ( k = 1; k <= ( 2 * i - 1); k++)
		{
			printf ("%c ", ch); 
		}
		ch++;
		printf ("\n");
	}
	getch();
}

```

**输出**

![Pyramid Patterns in C](img/46a0d10ea3ca4a3260d88f6361dd32e4.png)

### 打印字母倒金字塔的程序

让我们考虑一个使用 for 循环打印完整金字塔图案的示例。

**star.c**

```

#include <stdio.h>
#include <conio.h>
void main()
{	
	// declare the local variables
	int i, j, rows, k, m = 1;
	printf (" Enter a number to define the rows: \n");
	scanf ("%d", &rows); 
	printf("\n");

	for ( i = rows; i >= 1; i--)
	{
		for ( j = 1; j <= m; j++)
		{
			printf ("  "); 
		}
		// use for loop where k is less than equal to (2 * i -1)
		for ( k = 1; k <= ( 2 * i - 1); k++)
		{
			printf ("%c ", 'A' + k - 1); 
		}
		m++;
		printf ("\n");
	}
	getch();
}

```

**输出**

![Pyramid Patterns in C](img/a14c8feb2fc7b6b88eec344534124ec0.png)

### 打印菱形字母金字塔的程序

让我们考虑一个使用 for 循环打印完整金字塔图案的示例。

**star.c**

```

#include <stdio.h>
#include <conio.h>
void main()
{
	// declare the local variables
	int i, j, rows, k;
	printf (" Enter a number to define the rows: \n ");
	scanf("%d", &rows); 
	int space = rows-1, num=1;
	printf("\n");
	for (i = 1; i <= rows; i++) 
	{
		for (j = 1; j <= space; j++) 
		{
			printf(" ");		
                        }
		for ( k= 1; k <= num; k++)
		{
			printf("%c", 'A' + k - 1);
		}
		if(space > i)
		{
			space = space -1;
			num = num+2;
		}
		if(space <i)
		{
			space = space + 1;
			num = num -2;
		}
		printf("\n");
	}	
	getch();	
}

```

**输出**

![Pyramid Patterns in C](img/b627ae04e9397c9e1e6bfcc3f06b2472.png)

### 程序以 180 度打印完整的字母金字塔

让我们考虑一个使用 for 循环以 180 度打印完整金字塔图案的示例。

**star.c**

```

#include <stdio.h>
#include <conio.h>
void main()
{
	int num, i, j, m = 1; // declare local variables
	printf (" Enter the number to define the columns: \n");
	scanf ("%d", & num);
	for (i = 1; i <= num; i++)
	{
		for (j = 1; j <= i; j++)
		{
			printf( "%c", 'A' + j -1);
		}
		printf("\n");
	}
	for (i = num-1; i >= 1; i--)
	{
		for (j = 1; j <= i; j++)
		{
			printf ("%c", 'A' + j -1);
		}
		printf("\n");
	}
	getch();
}

```

**输出**

![Pyramid Patterns in C](img/207582c2a0ded30d11c00d5bb04828cb.png)

* * *