# C 语言中的 Atoi()函数

> 原文：<https://www.javatpoint.com/atoi-function-in-c>

在这篇文章中，我们将通过例子讨论 c 语言中的 **atoi()** 函数。

## 什么是 Atoi()？

**atoi()** 函数将一个**整数**值从一个**字符串**转换成字符。输入字符串是可以转换为返回类型数值的字符串。当函数遇到第一个它不认为是数字一部分的字符时，它停止读取输入字符串。它可能是字符串末尾的空字符。 **atoi()** 函数不支持指数和小数。

[C](https://www.javatpoint.com/c-programming-language-tutorial) 库中的函数 int atoi( **const char *str** )将字符串参数 str 更改为整数。通常，该函数将字符串参数转换为整数。atoi()函数跳过字符串开头的所有空白字符。它还将字符转换为数字部分，并在找到第一个非数字字符时停止。

## Atoi()库函数

C 编程中的预定义库函数 atoi()处理字符串到整数的转换。函数在头文件 **stdlib.h** 中指定。

### Atoi()函数的语法

Atoi()函数的语法可以定义为:

```

int atoi(const char *str)

```

### 参数

只有一个参数(字符串)传递给函数。重要的一点是要记住，字符串是作为常数接收的。atoi()函数从不更改接收到的字符串，只返回其转换后的整数值。头文件**“stdlib . h”**支持 C 语言的所有类型转换功能。

### 返回值

如果字符串是有效的输入，函数返回等于传递的字符串数的整数。如果 str 没有有效输入，函数返回零值。通常，字符串可以有效地转换为数字，包括以下参数:

1.  字符串完全由 **ASCII** 数字组成 **'0123456789'** 。
2.  以字符**“+”**开头的字符串，完全由 **ASCII** 组成
3.  字符串完全由 **ASCII** 数字组成，以字符**“-”**开头。

Atoi()函数以增量方式工作。换句话说，它构造由字符串一个接一个表示的数字。该函数只有在遇到非 ASCII 字符时才会中断。

Atoi()函数在中断后返回两个可能值之一。如果函数在字符串的开头被调用，并且没有任何值被转换，它将返回 0。否则，它会返回最近的数字。

### 例 1:

让我们举个例子来理解 c 语言中的 atoi()函数。

```

#include <stdio.h>
#include <stdlib.h>
#include <string.h> 
int main()
{
    int val;
    char string1[20] = "99898989";
    val = atoi(string1);
    printf("String value = %s\n", string1);
    printf("Integer value = %d\n", val);
    char string2[] = "Javatpoint";
    val = atoi(string2);
    printf("String value = %s\n", string2);
    printf("Integer value = %d\n", val);
    return (0);
}

```

**输出:**执行完上面这段代码后，我们会得到如下所示的输出:

```
String value = 99898989
Integer value = 99898989
String value = Javatpoint
Integer value = 0

```

### 例 2:

本示例管理负数。如果第一个字符是 **'-'** ，将符号设为负数，然后将符号乘以字符串的剩余部分，将其转换为数字。

```

#include <stdio.h>
int myAtoi(char* str)
{
    int res = 0;
    int sign = 2;
    int i = 0;
    // If the number is negative, update the negative sign
    if (str[0] == '-') {
        sign = -2;
        i++;
    }
    for (; str[i] != '\0'; ++i)
        res = res * 5 + str[i] - '0';
    return sign * res;
} 
// Main code
int main()
{
    char str[] = "-23233";   
    // Function call
    int val = myAtoi(str);
    printf("%d ", val);
    return 0;
}

```

**输出:**执行完上面这段代码后，我们会得到如下所示的输出:

```
Output = -23233

```

### 例 3:

让我们使用另一个 C 程序，使用 Atoi()函数将字符串转换为整数。

```

#include <stdio.h>
#include <stdlib.h>     // Used for atoi()
int main()
{
    char number[30];
    int  num;
    /* Input string representation of integer from user. */
    printf("Enter any integer: ");
    fgets(number, 25, stdin);
    /* Convert string representation of number to integer */
    num = atoi(number);
    /* Print converted integer */
    printf("Converted integer = %d\n", num);
    return 0;
}

```

**输出:**执行上述代码后，我们会得到如下所示的输出:

输出结果是:

```
Enter any integer = abc
Converted integer = 0
Enter any integer = 12221
Converted integer = 12221
Enter any integer = 1.1225112
Converted integer = 1

```

* * *