# C 语言中的结构指针

> 原文：<https://www.javatpoint.com/structure-pointer-in-c>

在本节中，我们将讨论 C 编程语言中的结构指针。在讨论概念之前，让我们先了解一下结构。**结构**是使用**结构**关键字分组在同一名称下的不同数据类型的集合。它也称为用户定义的数据类型，使程序员能够在结构中存储不同的数据类型记录。此外，结构内的数据元素集合被称为**成员**。

例如，假设我们想要创建包含姓名、年龄、身份证、城市等的个人记录。，并且这些记录不能在一维数组中分组。因此，我们使用结构来存储数据项的多个集合。

![Structure Pointer in C](img/a59d125986f13dd2ba53aa45aca92e01.png)

### 定义结构的语法

```

struct structure_name
{
char name[40];
int roll_no;
float percentage;
char sub[30];
};
struct structure_name  str;  // str is a variable of the structure_name

```

这里**结构名称**是使用**结构**关键字定义的结构的名称。在 structure_name 内部，它收集不同的数据类型(int、char、float)元素，称为**成员**。最后， **str，**是结构的变量。

### 演示结构并访问其成员的程序

在这个程序中，创建一个学生结构，并使用结构变量和点(。)运算符。

**结构 c**

```

#include <stdio.h>
#include <string.h>

// create the Structure of student to store multiples items
struct student
{
	char name[ 30];
	int roll_no;
	char state[100];
	int age;
};
struct student s1, s2; // declare s1 and s2 variables of student structure

int main()
{
	// records of the student s1
	strcpy (s1.name, "John");
	s1.roll_no = 1101;
	strcpy (s1.state, "Los Angeles");
	s1.age = 20;	

	// records of the student s2
	strcpy (s2.name, " Mark Douglas");
	s2.roll_no = 111;
	strcpy (s2.state, "California");
	s2.age = 18;

	// print the details of the student s1;
	printf (" Name of the student s1 is: %s\t ", s1.name);
    printf (" \n Roll No. of the student s1 is: %d\t ", s1.roll_no);
    printf (" \n The state of the student s1 is: %s\t ", s1.state);
    printf (" \n Age of the student s1 is: %d\t ", s1.age);

    	// print the details of the student s2;
	printf ("\n Name of the student s1 is: %s\t ", s2.name);
    printf (" \n Roll No. of the student s1 is: %d\t ", s2.roll_no);
    printf (" \n The state of the student s1 is: %s\t ", s2.state);
    printf (" \n Age of the student s1 is: %d\t ", s2.age);
    return 0;
}

```

**输出:**

```
Name of the student s1 is: John
Roll No. of the student s1 is: 1101
 state of the student s1 is: Los Angeles
Age of the student s1 is: 20
Name of the student s1 is:  Mark Douglas
Roll No. of the student s1 is: 111
 The state of the student s1 is: California
Age of the student s1 is: 18

```

**程序说明:**我们在上面的程序中可以看到，我们创建了一个名为 **student、**的结构，学生结构中包含了 name (char)、roll_no (int)、state (char)、age (int)等不同的成员。学生结构还定义了两个变量，如 **s1** 和 **s2** ，它们使用 main()函数中的点运算符访问结构成员。

### 结构指示器

**结构指针**指向存储结构的存储块的地址。就像一个指针告诉内存中任何数据类型(int、char、float)的另一个变量的地址。这里，我们使用一个结构指针，它通过将指针变量 **ptr** 指向结构变量来告诉内存中某个结构的地址。

### 声明结构指针

结构指针的声明类似于结构变量的声明。所以，我们可以在 main()函数的内部和外部声明结构指针和变量。要在 C 语言中声明指针变量，我们在变量名称前使用星号(*)。

```

struct structure_name *ptr;

```

定义结构指针后，我们需要初始化它，如代码所示:

### 结构指针的初始化

```

ptr = &structure_variable;

```

我们也可以在指针声明过程中直接初始化结构指针。

```

struct structure_name *ptr = &structure_variable;

```

我们可以看到，一个指针 **ptr** 指向结构的地址结构变量。

### 使用指针访问结构成员:

使用结构指针访问结构成员有两种方法:

1.  使用(*)星号或间接运算符和点(。)运算符。
2.  使用箭头(->)运算符或成员运算符。

### 使用结构指针和点运算符访问结构成员的程序

让我们考虑一个例子，创建一个 Subject 结构，并使用指向 c 语言中 Subject 变量地址的结构指针来访问它的成员

**指针 c**

```

#include <stdio.h>

// create a structure Subject using the struct keyword
struct Subject
{
	// declare the member of the Course structure
	char sub_name[30];
	int sub_id;
	char sub_duration[50];
	char sub_type[50];
};

int main()
{
	struct Subject sub; // declare the Subject variable
	struct Subject *ptr; // create a pointer variable (*ptr) 
	ptr = ⊂ /* ptr variable pointing to the address of the structure variable sub */

	strcpy (sub.sub_name, " Computer Science");
	sub.sub_id = 1201;
	strcpy (sub.sub_duration, "6 Months");
	strcpy (sub.sub_type, " Multiple Choice Question");

	// print the details of the Subject;
	printf (" Subject Name: %s\t ", (*ptr).sub_name);
            printf (" \n Subject Id: %d\t ", (*ptr).sub_id);
    	printf (" \n Duration of the Subject: %s\t ", (*ptr).sub_duration);
           printf (" \n Type of the Subject: %s\t ", (*ptr).sub_type);

	return 0;

}

```

**输出:**

```
Subject Name:  Computer Science
 Subject Id: 1201
 Duration of the Subject: 6 Months
 Type of the Subject:  Multiple Choice Question

```

在上面的程序中，我们创建了 **Subject** 结构，它包含不同的数据元素，如 sub_name (char)、sub_id (int)、sub_duration (char)和 sub_type (char)。在这种情况下，**子**是结构变量，ptr 是指向子变量地址的结构指针变量，就像 ptr = &子一样。这样，每个*ptr 都在访问主题结构成员的地址。

### 使用结构指针和箭头(->)操作符访问结构成员的程序

让我们考虑一个使用 c 语言中的指针和箭头(->)操作符访问结构成员的程序。

**指针 2.c**

```

#include <stdio.h>

// create Employee structure 
struct Employee
{
	// define the member of the structure
	char name[30];
	int id;
	int age;
	char gender[30];
	char city[40];
};

// define the variables of the Structure with pointers
struct Employee emp1, emp2, *ptr1, *ptr2;

int main()
{
	// store the address of the emp1 and emp2 structure variable
	ptr1 = &emp1;
	ptr2 = &emp2;

	printf (" Enter the name of the Employee (emp1): ");
	scanf (" %s", &ptr1->name);

	printf (" Enter the id of the Employee (emp1): ");
	scanf (" %d", &ptr1->id);
	printf (" Enter the age of the Employee (emp1): ");
	scanf (" %d", &ptr1->age);
	printf (" Enter the gender of the Employee (emp1): ");
	scanf (" %s", &ptr1->gender);
	printf (" Enter the city of the Employee (emp1): ");
	scanf (" %s", &ptr1->city);

	printf (" \n Second Employee: \n");
            printf (" Enter the name of the Employee (emp2): ");
	scanf (" %s", &ptr2->name);

	printf (" Enter the id of the Employee (emp2): ");
	scanf (" %d", &ptr2->id);
	printf (" Enter the age of the Employee (emp2): ");
	scanf (" %d", &ptr2->age);
	printf (" Enter the gender of the Employee (emp2): ");
	scanf (" %s", &ptr2->gender);
	printf (" Enter the city of the Employee (emp2): ");
	scanf (" %s", &ptr2->city);

	printf ("\n Display the Details of the Employee using Structure Pointer");
	printf ("\n Details of the Employee (emp1) \n");
	printf(" Name: %s\n", ptr1->name);
	printf(" Id: %d\n", ptr1->id);
	printf(" Age: %d\n", ptr1->age);
	printf(" Gender: %s\n", ptr1->gender);
	printf(" City: %s\n", ptr1->city);

	printf ("\n Details of the Employee (emp2) \n");
	printf(" Name: %s\n", ptr2->name);
	printf(" Id: %d\n", ptr2->id);
	printf(" Age: %d\n", ptr2->age);
	printf(" Gender: %s\n", ptr2->gender);
	printf(" City: %s\n", ptr2->city);
	return 0;
} 

```

**输出:**

```
Enter the name of the Employee (emp1): John
 Enter the id of the Employee (emp1): 1099
 Enter the age of the Employee (emp1): 28
 Enter the gender of the Employee (emp1): Male
 Enter the city of the Employee (emp1): California

 Second Employee:  
 Enter the name of the Employee (emp2): Maria
 Enter the id of the Employee (emp2): 1109
 Enter the age of the Employee (emp2): 23
 Enter the gender of the Employee (emp2): Female
 Enter the city of the Employee (emp2): Los Angeles

 Display the Details of the Employee using Structure Pointer
 Details of the Employee (emp1) 
 Name: John
 Id: 1099
 Age: 28
 Gender: Male
 City: California

 Details of the Employee (emp2) Name: Maria
 Id: 1109
 Age: 23
 Gender: Female
 City: Los Angeles

```

在上面的程序中，我们已经创建了一个包含两个结构变量 **emp1** 和 **emp2** 的**员工**结构，指针变量 ***ptr1** 和 ***ptr2** 。员工结构的成员是姓名、身份证、年龄、性别和城市。所有雇员结构成员都使用指针变量和箭头操作符从用户处逐个获取各自的值，这些操作符决定了它们在内存中的空间。

* * *