# 整数的范围

> 原文：<https://www.javatpoint.com/range-of-int-in-c>

在这篇文章中，我们将与程序一起讨论 C 语言中 int 的范围。

## Int 的范围

数据类型及其大小和范围在 C 编程中起着重要的作用。 [**sizeof()** 运算符](https://www.javatpoint.com/size-of-operator-in-c)给出了在特定形式的内存中存储一个值所需的字节数。然而，为了防止编程中的上溢和下溢错误，我们必须知道类型的范围。 [**C**](https://www.javatpoint.com/c-programming-language-tutorial) 为每个整数形式指定确切的最小存储大小。例如，短的至少需要两个字节，长的至少需要四个字节。编译器决定数据类型的大小和范围。因此，我们不应该在程序中硬编码大小和范围值。

### 在没有 C 库的情况下手动查找一系列数据类型

给定的公式定义了有符号类型的最小和最大范围:

*   **-(2N-1)至 2N-1 - 1** (其中 N 为 sizeof(类型)* 8(为整数类型使用的总位数))。

给定的公式定义了无符号类型的最小和最大范围:

*   **0 至(2N-1) + (2N-1 - 1)**

**示例:**

我们举个例子，在 C 编程中求整数的范围。

```

#include <stdio.h>
void printUnsignedRange(int bytes)
{
    int bits = 8 * bytes;   
    unsigned long long to = (1LLU << (bits - 1)) + ((1LL << (bits - 1)) - 1);;    
    printf(" 0 to %llu\n\n", to);
}
void printSignedRange(int bytes)
{
    int bits = 8 * bytes;   
    long long from  = -(1LL << (bits - 1));
    long long to    =  (1LL << (bits - 1)) - 1;
    printf(" %lld to %lld\n\n", from, to);
}
int main()
{
    /* print the range of integer type */
    printf("Range of int =");
    printSignedRange(sizeof(int));   
    printf("Range of unsigned int =");
    printUnsignedRange(sizeof(unsigned int)); 
    /* print the range of character type */
    printf("Range of char =");
    printSignedRange(sizeof(char));
    printf("Range of unsigned char =");
    printUnsignedRange(sizeof(unsigned char));
    /*print the range of long type */
    printf("Range of long =");
    printSignedRange(sizeof(long));  
    printf("Range of unsigned long =");
    printUnsignedRange(sizeof(unsigned long)); 
    /* print the range of short type */
    printf("Range of short =");
    printSignedRange(sizeof(short));
    printf("Range of unsigned short =");
    printUnsignedRange(sizeof(unsigned short));
    /* print the range of long long type */
    printf("Range of long long =");
    printSignedRange(sizeof(long long));  
    printf("Range of unsigned long long =");
    printUnsignedRange(sizeof(unsigned long long));
    return 0;
}

```

**输出:**执行完这段代码后，我们会得到如下所示的输出:

```
Range of int = -2147483648 to 2147483647
Range of unsigned int = 0 to 4294967295
Range of char = -128 to 127
Range of unsigned char = 0 to 255
Range of long = -9223372036854775808 to 9223372036854775807
Range of unsigned long = 0 to 18446744073709551615
Range of short = -32768 to 32767
Range of unsigned short = 0 to 65535
Range of long long = -9223372036854775808 to 9223372036854775807
Range of unsigned long long = 0 to 18446744073709551615

```

### 使用 C 库查找数据类型的范围

上面描述的获得任何形式的范围的方法很有趣，但不建议使用。通常建议使用预定义的 C 库的功能。

**Limits.h** 和 **float.h** 是 C 编程中定义最小和最大常量的两个头文件。 **limits.h** 指定整数类型和字符类型的常量。小尺寸和最大尺寸范围、总位数和许多其他。**浮点数。h** 定义浮点数。

**示例:**

现在，让我们举一个例子来理解如何使用 C 库找到整数的范围。

```

#include <stdio.h>
#include <limits.h>
#include <float.h>

int main()
{
    /* print the range of signed integer type */
    printf("Range of signed int %d to %d\n", INT_MIN, INT_MAX);
   /* print the range of unsigned integer type */
    printf("Range of unsigned int 0 to %u\n\n", UINT_MAX);
    /* print the range of signed char type */
    printf("Range of signed char %d to %d\n", SCHAR_MIN, SCHAR_MAX);
    /* print the range of unsigned char type */
    printf("Range of unsigned char 0 to %d\n\n", UCHAR_MAX);
    /* print the range of signed long integer type */
    printf("Range of signed long int %ld to %ld\n", LONG_MIN, LONG_MAX);
    /* print the range of unsigned long integer type */
    printf("Range of unsigned long int 0 to %lu\n\n", ULONG_MAX);
    /* print the range of signed short integer type */
    printf("Range of signed short int %d to %d\n", SHRT_MIN, SHRT_MAX);
    /* print the range of unsigned short integer type */
    printf("Range of unsigned short int 0 to %d\n\n", USHRT_MAX);
    /* print the range of float type */
    printf("Range of float %e to %e\n", FLT_MIN, FLT_MAX);
    /* print the range of double type */
    printf("Range of double %e to %e\n", DBL_MIN, DBL_MAX);
    /* print the range of long double type */
    printf("Range of long double %Le to %Le\n", LDBL_MIN, LDBL_MAX);
    return 0;
}

```

**输出:**执行完上面这段代码后，我们会得到如下所示的输出:

输出结果是:

```
Range of signed int -2147483648 to 2147483647
Range of unsigned int 0 to 4294967295
Range of signed char -128 to 127
Range of unsigned char 0 to 255
Range of signed long int -9223372036854775808 to 9223372036854775807
Range of unsigned long int 0 to 18446744073709551615
Range of signed short int -32768 to 32767
Range of unsigned short int 0 to 65535
Range of float 1.175494e-38 to 3.402823e+38
Range of double 2.225074e-308 to 1.797693e+308
Range of long double 3.362103e-4932 to 1.189731e+4932

```

**示例:**

写一个程序，读取一个整数类型，并对照给定的范围检查它属于哪里。

```

#include <stdio.h>
int main() {
	int x;
	printf("\nInput an integer: "); 
	scanf("%d", &x);
	if(x >=0 && x <= 25) 
	{
		printf("Range [0, 25]\n");
	} 
	else if(x >=26 && x <= 40) 
	{
		printf("Range (26,50]\n");
	} 
	else if(x >=41 && x <= 60) 
	{
		printf("Range (45,75]\n");
	} 
	else if(x >61 && x <= 80) {
		printf("Range (61,80]\n");
	} 
	else 
	{
	printf("Outside the range\n");
	}	
	return 0;
}

```

**输出:**执行完上面这段代码后，我们会得到如下所示的输出:

输出为:

```
Input an integer: 28
Range [26,50]

```

**示例:**

**sizeof()** 运算符用于确定整数形式或其他类型的大小。下面给出的程序显示了如何使用 **sizeof()** 运算符来确定系统中各种整数类型的大小。

```

#include <stdio.h> 
int main()
{
    printf("sizeof(short) = %d bytes\n",sizeof(short));
    printf("sizeof(int) = %d bytes\n",sizeof(int));
    printf("sizeof(unsigned int) = %d bytes\n",sizeof(unsigned int));
    printf("sizeof(long) = %d bytes\n",sizeof(long));
    return 0;
}

```

**输出:**执行完上面这段代码后，我们会得到如下所示的输出:

输出结果是:

```
sizeof(short) = 2 bytes
sizeof(int) = 4 bytes
sizeof(unsigned int) = 4 bytes
sizeof(long) = 8 bytes

```

* * *