# 什么是 C 中的双？

> 原文：<https://www.javatpoint.com/what-is-double-in-c>

在本主题中，我们将讨论 C 编程语言中的双数据类型。C 语言提供了四种主要的数据类型，如 **int、char、float** 和 **float** 。int 数据类型用于存储整数，char 数据类型用于存储字符类型，float 数据类型用于存储单精度的小数类型数据。

A **double** 是 C 语言中的一种数据类型，在计算机内存中存储高精度浮点数据或数字。它被称为双数据类型，因为与浮点数据类型相比，它可以容纳双倍大小的数据。双字节有 **8 字节**，大小等于 **64 位**。在双数据类型中，1 位用于符号表示，11 位用于指数，其余 52 位用于尾数。双倍的范围是 1.7E-308 到 1.7E+308。双精度数据可以用实数(1，10)、小数(0.1，11.002)和负数(-1，-0.00002)表示。小数点前后可以容纳大约 15 到 16 位数字。

比如 4.5672，2.45354，-5.22234，3.12345678901，0.15197e-7 等。

![What is double in C](img/91d2761f17ea5a76fccf733e9cc2fbe4.png)

### 双变量的声明和初始化

**双变量的声明:**要在 [C](https://www.javatpoint.com/c-programming-language-tutorial) 中声明双变量，需要指定数据类型和变量名。

```

double data1;

```

**双变量初始化:**要初始化一个变量，我们可以给变量名指定一个有效值。

```

Data1 = 3.2325467;

```

此外，我们可以在一行中声明和初始化变量名。

```

double data1 = 3.2325467;

```

### 使用 size of()函数获取数据类型大小的程序

让我们考虑一个用 C 编程语言打印所有数据类型大小的例子。

**Get_size.c**

```

#include #include <conio.h>void main()
{
// use sizeof() function to get the size of data type in c
printf (" The size of int data type is %d", sizeof(int));
printf (" The size of char data type is %d", sizeof(char));
printf (" The size of float data type is %f", sizeof(float));
printf (" The size of double data type is %f", sizeof(double));
getch()
}</conio.h> 
```

**输出:**

```
The size of int data type is 4
 The size of char data type is 1
 The size of float data type is 4
 The size of double data type is 8

```

在上面的程序中，我们使用 **sizeof** ()函数绕过 int、char、float 和 double 作为参数来获取整数、float、字符和 double 数据类型的大小。

### 使用双数据类型将英尺转换为米的程序

让我们考虑一个例子，将双数据数作为参数传递给一个函数，然后将英尺转换为米。

**Prog.c**

```

#include double feet_to_meter (double f); // declare a user defined function
int main()
{
double feet, cnvt; // declare a variable as the double data type
printf (" Enter the feet in double ");
scanf("%lf", &feet); 
cnvt = feet_to_meter(feet); // call feet_to_meter function
printf (" Converted feet to meter is: %lf", cnvt);
return 0;
}
// definition of the function
double feet_to_meter (double f)
{
return f / 3.28;
} 
```

**输出:**

```
Enter the feet in double 45.78
Converted feet to meter is: 13.957317

```

### 将整数数据转换为双数据类型的程序

让我们考虑一个例子，将一个整数转换成 c 语言中的双数据类型数。

**程序 2.c**

```

#include int main()
{
int sum = 17, count = 5;
double var;
var = (double) sum / count;
printf (" Convert an int value into double data type is: %lf \n", var);
} 
```

**输出:**

```
Convert an int value into double data type is: 3.400000

```

### 将摄氏温度转换为华氏温度的程序

让我们考虑一个把给定的摄氏温度转换成华氏温度的程序

**转换 c**

```

#include int main()
{
// declaration of double variable
double c_temp, f_temp;
printf(" Enter the temperature in Celsius: ");
scanf (" %lf", &c_temp); // accept the Celsius temperature 

f_temp  = ( c_temp * 1.8) + 32; // use conversion formula
printf (" The temperature in Fahrenheit is: %lf", f_temp);
return 0;
} 
```

**输出:**

```
Enter the temperature in Celsius: 56.8
 The temperature in Fahrenheit is: 134.240000

```

### 使用函数打印两个双数之和的程序

让我们考虑一个程序，用 c 语言中的一个函数得到两个双数之和。

**双 c**

```

#include double sum_num(double p, double q);
int main()
{
	// declaration of the double variables
	double x, y, res;

	printf (" Enter two double numbers ");
	scanf(" %lf %lf", &x, &y); // take two double variable from user
	res = sum_num(x, y); // call double function
	printf (" The result of two double number is: %lf", res);
	return 0;
}
double sum_num(double p, double q)
{
	return p + q; // return the sum of double values
} 
```

**输出:**

```
Enter two double numbers 34.798
43.567
The result of two double number is: 78.365000

```

### 浮点与双精度

**浮点数据类型:**浮点是一种单精度数据类型，保存一个 32 位浮点或十进制数，等于 4 个字节。它是预定义的数据类型或关键字，其含义和名称不能更改。浮点数据类型比双倍快，因为它的范围很小。它可以容纳大约 7 位数字。此外，浮点数据类型的范围是 1.5 x 10 <sup>-45</sup> 到 3.4 x 10 <sup>38</sup> 。

**双精度数据类型:**双精度数据类型保存 64 位浮点或十进制数，等于 8 字节。它也是一种预定义的数据类型，其含义和名称不能更改。与浮点数据类型相比，它速度较慢，因为它的大小很大。它可以容纳 15 到 17 个数字。双数据范围为 5.0×10<sup>-345</sup>至 1.7×10<sup>308</sup>。

### 结论:

双数据类型是双精度浮点数据。与浮点数据类型相比，它可以保存双倍大小的数据，因为 double 在计算机内存中占用 64 位，比浮点数据类型的 32 位大。它通常用于处理数字和尾数的大量计算，以获得精确的结果。许多程序员选择双数据类型，因为它为复数提供了精确的十进制相关结果。

* * *