# C 里面的主要是什么？

> 原文：<https://www.javatpoint.com/what-is-the-main-in-c>

在这个话题中，我们将主要讨论在 [C 语言中的编程语言](https://www.javatpoint.com/c-programming-language-tutorial)。main 是 C 语言中预先定义的关键字或函数。它是每个 C 程序的第一个函数，负责启动程序的执行和终止。这是一个特殊的函数，总是从“ **main** 开始执行代码，返回数据类型为“ **int** 或“ **void** ”。换句话说，main()函数是编程代码开始执行的入口点。

![What is the main in C](img/43ddd7b56a453910a53597878f5fa640.png)

## main()函数的重要点

1.  当程序员或用户执行他们的编程代码时，操作系统总是调用 main()函数。
2.  它负责程序的开始和结束。
3.  它是编程语言中普遍接受的关键词，不能改变其含义和名称。
4.  main()函数是 C 语言中用户定义的函数，这意味着我们可以根据程序的要求将参数传递给 main()函数。
5.  main()函数用于在运行时调用编程代码，而不是在程序编译时。
6.  main()函数后面是左括号和右括号。

### 句法

```

main()
{
// codes start from here
}

```

### 使用 main()函数打印语句的程序

让我们考虑一个不使用 c 语言中的 void 和 int main()函数来打印语句的程序。

**程序代码**

```

#include main()
{
printf ("Welcome to the JavaTpoint");
} 
```

**输出:**

```
Welcome to the JavaTpoint

```

### 使用 main()函数调用嵌套函数的程序

让我们考虑一个在 main()函数内部调用嵌套函数的程序。

**Main.c**

```

#include #include <conio.h>main()
{
printf (" It is a main() function ");
int fun2(); // jump to void fun1() function
printf ("\n Finally exit from the main() function. ");
}

void fun1()
{
printf (" It is a second function. ");
printf (" Exit from the void fun1() function. ");
}

int fun2()
{ 
void fun1(); // jump to the int fun1() function
printf (" It is a third function. ");
printf (" Exit from the int fun2() function. ");
return 0;
}</conio.h> 
```

**输出:**

```
It is a main() function
 Finally exit from the main() function.

```

## main()函数的类型

下面是 C 语言中使用的 main()函数的类型

1.  void main()
2.  int main()
3.  int main ( int argc、char **argv)
4.  int main(空)
5.  主空隙

### void main()函数

void 是引用没有返回值的空数据类型的关键字。换句话说，当我们不想向调用函数返回任何值时，使用 void 数据类型。此外，它与 main()函数一起使用，不返回任何内容，并且可以与 C 编程中的用户定义和预定义函数一起使用。

**语法**

```

void main()
{
// body of the code
}

```

### 演示 void main()函数的程序

让我们编写一个简单的程序来演示 void main()函数。

**void.c**

```

#include #include <conio.h>void main()
{
printf (" C is a programming language. ");
printf( " \n It is a void main() function in C. " );
}</conio.h> 
```

**输出:**

```
C is a programming language.
 It is a void main() function in C.

```

### int main()函数

**int** 是引用整数数据类型的关键字。与 main()函数一起使用的 int 数据类型，指示该函数应返回一个整数值。当我们使用 int main()函数时，必须写**返回 0；**语句末尾的 main()函数。返回 0；语句表示程序已成功执行，而任何其他语句表示程序未成功终止。

**语法**

```

int main()
{
// code to be executed
return 0;
}

```

### 程序使用 C 语言中的 int main()函数返回值

让我们用 C 语言编写一个使用 int main()函数返回值的程序。

**程序**

```

#include int main() 
{
printf (" Welcome to the JAVATPOINT ");
printf( " \n It is an int main() function to return a value. " );
return 0;
} 
```

**输出:**

```
Welcome to the JAVATPOINT
 It is an int main() function to return a value.

```

### 使用 int main()函数打印迭代数字的程序

让我们考虑一个使用 int main()函数显示 C 中数字迭代序列的例子。

**程序代码**

```

#include int main()
{
	static int num = 20;
	if ( --num)
		{
			printf (" %d ", num); // print the number
			main(20); 
		}
return 0;
} 
```

**输出:**

```
19  18  17  16  15  14  13  12  11  10  9  8  7  6  5  4  3  2  1

```

我们也可以使用 **EXIT_SUCCESS** 语句，这是返回 0 的替代语句。如果程序没有成功执行，我们可以在没有 return 1 语句的情况下使用 **EXIT_FAILURE** 。标准输入输出头文件( **stdio.h** )中定义了 return 语句，而标准库( **stdlib.h** )头文件中定义了 EXIT 语句。

### 在 int main()函数中使用 EXIT_SUCCESS 语句的程序

让我们用 C 语言编写一个程序，用 EXIT_SUCCESS 语句代替 return 语句。

**c 出口**

```

#include #include <stdlib.h>int main()
{
	printf (" Hello, Welcome to the World ");
	printf (" \n Use EXIT_SUCCESS on successful execution of the program ");
	EXIT_SUCCESS; // use EXIT_SUCCESS statement in replacement of the return 0;
}</stdlib.h> 
```

**输出:**

```
Hello, Welcome to the World
 Use EXIT_SUCCESS on successful execution of the program

```

#### 注意:return 语句不能与 void main()函数一起使用，因为它返回值。所以不能和 void main()函数一起使用。但是，我们可以将 EXIT 语句与 void main()函数一起使用。

### int main (int argc、char *argv)

可以使用命令行参数调用 main()函数。它是一个包含两个参数的函数，整数(int argc)和字符(char *argv)数据类型。 **argc** 参数代表参数计数， **argv** 代表参数值。

### int main(void)函数

int main(void)函数类似于返回整数值的 int main()函数。但是我们可以将多个参数传递给 int main()，而 int main(void)只能在没有任何参数的情况下调用。

### C 语言中使用 int main(void)函数的程序

让我们考虑一个用 C 语言演示 int main(void)函数的程序。

**prog_main.c**

```

#include int main (void) // It does not accept any parameter other than void
{
printf (" Welcome to the JAVATPOINT "); // print the statement
return 0;
} 
```

**输出:**

```
Welcome to the JAVATPOINT

```

### 无效主(无效)功能

void main (void)函数类似于不返回值的 void main()函数。但是，void main()函数可以接受多个参数，但它不返回值。它是一个空数据类型，而 void main(void)不接受任何参数，因为它有一个预定义的 main(void)函数。

### 程序使用 C 语言中的 void main(void)函数

让我们考虑一个用 C 语言演示 void main(void)函数的程序。

**主程序**

```

#include void main (void) 
{
printf (" Welcome to the JAVATPOINT "); // print the statement
} 
```

**输出:**

```
Welcome to the JAVATPOINT

```

* * *