# 胼胝体在 C

> 原文：<https://www.javatpoint.com/calloc-in-c>

本主题将讨论如何使用 C 编程语言中的 calloc()函数创建动态内存分配。在介绍这些概念之前，我们先来讨论一下 c 语言中的动态内存分配。动态内存是一种结构化编程过程，允许用户在程序运行时分配内存。使用动态内存分配，我们可以在程序执行过程中增加或减少内存。这样，就避免了计算机内存的浪费。一个内存分配分为两部分分别是 malloc()和 calloc()函数。

![Calloc in C](img/073d613fe0d5177c9a711d7def6bc534.png)

**calloc()函数**是一个预定义的库函数，代表**连续内存分配**。calloc()函数用于在内存中具有相同大小的程序运行时创建多个块。在 **stdlib.h** 头文件中定义了一个 calloc 函数。它有两个参数，块数和每个块的大小。当使用 calloc()函数分配动态内存时，它会返回第一个块的基址，每个块都用 0 初始化。如果没有创建内存，它将返回一个空指针。

例如，假设我们想使用 calloc()函数创建三个内存块，我们需要传递两个参数，一个块数(3)和每个块的大小(int、char、float 等)。)在字节中。这样，它会在计算机内存中创建三个大小相同的块。

**语法**

```

ptr = (cast_type *) calloc ( number_of_blocks, size_of_block);

```

在上面的语法中，calloc()函数有两个参数。第一个参数定义了块的**数量，第二个参数定义了内存中每个块**的**大小。块的大小和 cast_type 可以是 int、char、float 等。**

**返回**:将第一块的基址返回给 ptr 变量。

### 使用 calloc()函数检查动态内存分配的程序

让我们编写一个简单的程序来检查动态内存是否在 c 中分配。

**program.c**

```

#include #include <stdlib.h>int main()
{
int *ptr;
/* use calloc() function to define the no. of blocks and size of each blocks. */
ptr = calloc (4, sizeof(int)); // here 4 is the no. of block and int is the size of block
if (ptr != NULL)
{
printf (" Memory is created successfully \n");
}
else 
printf (" Memory is not created ");
return 0;
}</stdlib.h> 
```

**输出:**

```
Memory is created successfully

```

### 演示 calloc()函数使用的程序

让我们考虑使用 calloc()函数创建动态内存分配，并将数据存储到内存块中。

**程序 2.c**

```

#include #include <conio.h>#include <stdlib.h>void main()
{	
	int n, *ptr, *p, i, sum = 0;
	/* n = number of elements, *ptr = store base address of the dynamic memory, 
	*p store temporary address of the *ptr */ 
	printf (" Enter the number of elements: ");
	scanf (" %d", &n); // it takes number of elements 

	// use calloc syntax to create memory block of int data type 
	ptr = (int *) calloc (n, sizeof(int));
	p = ptr; // assign the address of ptr
	if (ptr == NULL) // it checks whether the memory is allocated 
	{
		printf (" Memory is not allocated. ");
		exit(0); // exit from the program
	}
	printf (" Enter %d numbers \n", n);
	for ( i = 1; i <= n; i++)
	{
		scanf ( "%d", ptr);
		sum = sum + *ptr;
		ptr++;
	}

	printf (" Elements are: ");
	for (i = 1;  i <= n; i++)
	{
		printf (" %d", *p);
	p++;
	}
	printf (" \n The addition of the elements is: %d ", sum);
	getch();
}</stdlib.h></conio.h> 
```

**输出:**

```
Enter the number of elements: 5
 Enter 5 numbers
1
2
3
4
5
 Elements are:  1 2 3 4 5
 The addition of the elements is: 15

```

### 使用 free()函数释放动态内存分配的程序

**free()函数:**free()函数用于释放由**卡洛克**()或**马洛克**()函数创建的动态内存。这些分配的内存无法释放到自己的内存中，它们将一直存在到程序结束。因此，释放可以重用的内存是我们的责任，因此我们显式地使用 free()函数来释放内存。

**语法**

```

free (ptr);

```

这里 free()是一个使用指针 ptr 变量释放分配内存的函数。

让我们考虑使用 calloc()函数创建动态内存分配，然后在 C 程序中使用 free()函数释放占用的空间。

**释放 c**

```

#include #include <conio.h>#include <stdlib.h>void main()
{	
	int n, *ptr, *p, i, sum = 0;
	printf (" Define the number of elements to be entered: ");
	scanf (" %d", &n); 

	// use calloc syntax to create memory block of int data type 
	ptr = (int *) calloc (n, sizeof(int));
	p = ptr; // store the base address in p
	if (ptr == NULL)
	{
		printf (" Out of memory ");
		exit(0);
	}
	printf (" Enter the elements \n", n);
	for ( i = 1; i <= n; i++)
	{
		scanf ( "%d", ptr);
		sum = sum + *ptr;
		ptr++;
	}

	printf (" Elements are: ");
	for (i = 1;  i <= n; i++)
	{
		printf (" %d", *p);
	p++;
	}
	printf (" \n The addition of the elements is: %d ", sum);
	free(ptr); /* Use free() function to release the dynamic memory allocation */ 
	getch();
}</stdlib.h></conio.h> 
```

**输出:**

```
Define the number of elements to be entered: 6
 Enter the elements
2
4
6
8
10
12
 Elements are:  2 4 6 8 10 12
 The addition of the elements is: 42

```

* * *