# C 语言中的静态函数

> 原文：<https://www.javatpoint.com/static-function-in-c>

在本主题中，我们将讨论 C 编程语言中的静态函数。默认情况下，每个函数都被声明为全局函数，可以在程序中的任何地方访问。**静态关键字**用在函数名称之前，使任何函数成为静态函数。C 语言中静态函数的范围仅限于它的目标文件或一个程序。这意味着静态函数仅对其程序文件可见，并限制其他文件或程序访问静态函数。

![Static function in C](img/639f20c36b1b90a9a0173e87e61e1b0b.png)

**语法**

```

<function data_type> static <function_ name> ( ){}
or
static int function_name ()
{
// define the statement to be executed
}

```

这里，我们在**函数名**前使用**静态**关键字来使给定的函数成为静态的。

### 静态函数的几个要点

1.  静态关键字可以用在函数名之前，使其成为静态的。
2.  然而，静态函数的范围仅在整个程序中。这意味着静态函数可以在同一个程序或文件中调用。
3.  如果我们试图从另一个文件访问静态函数，它会抛出一个错误。
4.  我们可以通过在程序的函数名前添加静态函数，将全局函数作为静态函数。

### 在另一个文件中调用全局函数的程序

在这个程序中，我们需要创建两个文件，文件 1.c 和文件 2.c。现在，我们在文件 1.c 内部创建一个全局函数，如下所示。

**文件 1.c**

```

int add(int x, int y) // this function is called to the file2.c
{
int sum; // declare the sum variable
sum = x + y; // store the sum of two number in sum
return sum;
}

```

在**文件 1.c** 文件中定义了全局函数之后，现在我们创建另一个文件 file2.c，然后在其中调用全局函数 add()。

**文件 2.c**

```

#include #include <stdlib.h>#include "file1.c"  // file1.c is use as a refernce file
int add(int x, int y); // define the global function
int main()
{
	int n1, n2, res; // define local variables
	printf (" Enter any two numbers: ");
	scanf ("%d %d", &n1, &n2); // accepts two numbers 

	res = add(n1, n2); // call global function from "file1.c"
	printf (" The sum of the two numbers is: %d", res);
	return 0;
}</stdlib.h> 
```

**输出**

```
Enter any two numbers: 5
20
 The sum of the two numbers is: 25

```

正如我们在上面的程序中看到的，我们创建了两个文件，file1.c 和 file2.c，在 file1.c 中，我们定义了一个全局函数 add()，在 file2.c 中调用，而在 file2.c 中，file1.c 将被视为包含全局函数定义的引用文件，并在 main()函数中调用，以返回两个整数的和。

### 程序调用另一个文件中的静态函数

让我们创建一个程序，通过在函数前添加 static 关键字，然后在 file2.c 中调用，将一个全局函数作为静态函数。

**文件 1.c**

```

static void add(void) // It is a static function
{
printf (" I am a static function"); 
}

```

现在我们创建另一个名为 file2.c 的文件，并调用静态函数来检查它的作用域。

**文件 2.c**

```

#include #include <stdlib.h>int main()
{
	printf(" I am a main() function.");
            myFun(); // call static function 
	return 0;
}</stdlib.h> 
```

**输出**

```
Undefined reference to myFun() function.

```

当我们编译上面的程序时，它抛出一个错误作为“对 myFun()的未定义引用”。因为静态函数 myFun()，它的对象文件只能访问，不允许其他函数访问静态函数。

### 在同一目标文件或函数中调用静态函数的程序

让我们创建一个程序来演示静态函数在 c 语言中的使用。

**文件 1.c**

```

#include #include <stdlib.h>// define the static function
static int mySqr( int num)
{
	return num * num; 
}

int main()
{
	int n1, res;
	printf (" Enter an integer number: ");
	scanf ("%d", &n1);
	res = mySqr(n1); // call static function
	printf(" The square of the %d is %d.", n1, res);
	return 0;
}</stdlib.h> 
```

**输出**

```
Enter an integer number: 25
The square of the 25 is 625

```

在上面的程序中，我们在同一个对象文件 **File1.c** 里面创建了一个静态函数。在 File1.c 中，main()函数调用静态函数 mySqr()返回给定数字的平方。静态函数工作正常，因为静态函数的范围只在它的目标文件或程序中。

### 程序在同一个文件中调用多个静态函数

让我们创建一个程序来创建多个静态函数，并在 main()函数内部调用。

**程序代码**

```

#include #include <stdlib.h>#include <math.h>// define the static function
static int mySqr( int num)
{
	return num * num; 
}

static void myfun2(void)
{
	printf ("\n I am inside the static function.");
}

static int myFun3(int num2)
{
	return sqrt(num2);
}
int main()
{
	int n1, res;
	printf (" Enter an integer number: ");
	scanf ("%d", &n1);
	res = mySqr(n1); // call static function
	printf(" The square of the %d is %d", n1, res);
	myfun2(); // call static function
	res = myFun3(n1);
	printf(" \n The square root of the %d is %d", n1, res);
	return 0;
}</math.h></stdlib.h> 
```

**输出**

```
Enter an integer number: 36
 The square of the 36 is 1296
 I am inside the static function.
 The square root of the 36 is 6

```

在上面的程序中，我们在同一个对象文件中创建了多个静态函数，每个静态函数都在 main()函数内部调用以返回值。

* * *