# C 语言中的孪生素数

> 原文：<https://www.javatpoint.com/twin-prime-numbers-in-c>

本主题将讨论孪生素数以及我们如何用 C 编程语言打印孪生素数。孪生素数是一对表示两个素数之差的素数，总是 **2** ，因此被称为**孪生素数。**简单来说，如果两个素数之差为 2，两者之间正好有一个复合数，那么这个数就叫做**孪生素数。**

![Twin Prime Numbers in C](img/5df68fce8bf0871fac470807ab428b1d.png)

例如，(59，61)和(71，73)是孪生素数对，这两个数的差是 61 - 59 = 2，73 - 71 = 2。

**孪生素数**的性质

1.  (2，3)不被认为是孪生素数，因为它们之间没有复合数，两个素数(2，3)的差也不等于 2。
2.  (3，5)是一对孪生素数，因为两个素数之差(5 - 3 = 2)是 2，因此(3，5)是孪生素数。
3.  (3，5)之外的每一个孪生数都是素数(6n - 1，6n + 1)的形式，其中 n 定义自然数。
4.  5 是唯一正负素数之差都为 5 的素数。所以，5 出现在两个素数对(3，5)和(5，7)中。
5.  如果我们加上两对孪生素数，孪生素数的结果将被 12 整除，除了(3，5)对孪生素数。

### 使用用户定义的函数打印从 2 到 n 的双素数的程序

用 [C 编程语言](https://www.javatpoint.com/c-programming-language-tutorial)创建一个程序，生成 2 到 n 之间的孪生素数。

**程序 1.c**

```

#include #include <conio.h>int main ()
{
	// declare variables
	int i, num, count = 0;
	printf (" Enter the last number: ");
	scanf (" %d", &num); // get the last number

	for (i = 2; i <= num; i++)
	{
		if (twinprime (i) && twinprime (i+2))
		{
			printf (" \n The twin prime number is: (%d, %d) ", i, i+2);
			count++; // counter increment by 1
		}
	}
	printf (" \n \n Total number of twin prime pairs: %d", count);
	return 0;
}
// function definition 
int twinprime( int n)
{
	int i = 2;
	// use for loop to find the twin prime
	for (i = 2; i <= n/2; i++)
	{
		// if n is completely divisible by 1 without leaving any remainder, it returns 0
		if (n%i == 0)
			return 0;
	}
	// otherwise it returns 1
	if (i > n / 2)
		return 1;
}</conio.h> 
```

**输出**

```
Enter the last number: 100
 The twin prime number is: (3, 5)
 The twin prime number is: (5, 7)
 The twin prime number is: (11, 13)
 The twin prime number is: (17, 19)
 The twin prime number is: (29, 31)
 The twin prime number is: (41, 43)
 The twin prime number is: (59, 61)
 The twin prime number is: (71, 73)
 Total number of twin prime pairs: 8

```

在上面的程序中，一个 for 循环迭代指定范围 2 到 100 之间的数字。之后，我们创建一个 twinprime()作为在 for 循环中调用的用户定义函数，以检查**‘I’**和**‘I+2’**索引的素数。如果条件满足，它会打印出一对孪生素数和孪生素数。

### 用厄拉多塞筛算法打印双素数的程序

厄拉多塞的**筛**是一种获得小于或等于给定数(n)的所有素数的列表的方法。它将质数迭代到 n 个连续的数，并检查第 I 个<sup>和第(i + 2)个数是否都是质数，然后打印质数；否则，它会移动到下一个数字来获得孪生素数。这里，(3，5)、(5，7)、(11，13)是厄拉多塞筛算法的例子。</sup>

让我们考虑一个使用厄拉多塞筛算法得到孪生素数的例子。

**程序 2.c**

```

#include #include <string.h>int main()
{
	// declare an integer variable
	int num;
	printf (" Enter the last number to get twin prime numbers: ");
	scanf (" %d", &num); 	
	// call twinprime() function
	twinprime( num); // pass num as an argument
	return 0;
}
void twinprime (int n)
{
	int j;
	/* here we create a unsigned char array 'prime[]' and initialize all its entries as true. */
	unsigned char prime[n + 1]; // declaration of the unsigned char prime[] array	
	memset (prime, 1, sizeof(prime));	
	// use for loop to iterate over a certain range
	for ( j = 2; (j * j) <= n; j++)
	{
		// if the condition of prime[j] remains true, it is a prime
		if (prime [j] == 1)
		{
			int i = 0;
			// update the multiples of j
			for (i = (j * 2); i <= n; i += j)	
				prime[i] = 0;
		}
	  } 	  
	  // now check for twin prime numbers and print the twin primes	  
	  for ( j = 2; j <= (n - 2); j++)
	  {
	  	if (prime[j] && prime[j + 2])
	  		printf (" \n The twin prime numbers: (%d, %d) ", j, j +2);	   	
	   } 
}</string.h> 
```

**输出**

```
Enter the last number to get twin prime numbers: 200
 The twin prime numbers: (3, 5)
 The twin prime numbers: (5, 7)
 The twin prime numbers: (11, 13)
 The twin prime numbers: (17, 19)
 The twin prime numbers: (29, 31)
 The twin prime numbers: (41, 43)
 The twin prime numbers: (59, 61)
 The twin prime numbers: (71, 73)
 The twin prime numbers: (101, 103)
 The twin prime numbers: (107, 109)
 The twin prime numbers: (137, 139)
 The twin prime numbers: (149, 151)
 The twin prime numbers: (179, 181)
 The twin prime numbers: (191, 193)
 The twin prime numbers: (197, 199)

```

### 检查给定数字是否是孪生素数的程序

让我们考虑一个例子，在 C 编程语言中，给定的数是否是孪生素数。

**程序 3.c**

```

#include #include <string.h>// function definition of the checktwin()
void checktwin(num1, num2)
{
	// declare integer variables
	int i;	
	// declare and initialize isprime
	unsigned char isprime = 1;	
	// use for loop to check the prime number for the first number 
	for ( i = 2; i <= (num1 / 2); i++ )
	{
		// if num1 is completely divisible by i, the if block is executed
		if (num1 % i == 0)
		{
			isprime = 0;
			break;
		}			
	}
	/* here isprime is called and abs() function get the absolute result of num1 and num2 */
	if (isprime && abs(num1 - num2) == 2)
	{
		// declare isprime2 as unsigned char and initialize as 1 that represents true.
		unsigned char isprime2 = 1;		
		// use for loop to check the second number is a prime number
		for ( i = 2; i <= num2 / 2; i++)
		{
			// it checks num2 is completely divisible by i and return 0
			if (num2 % i == 0)
			{
				// isprime2 initialize by 0
				isprime2 = 0;
				break;
			}
		}
		// check the isprime2 condition
		if (isprime2)
		{
			printf (" %d and %d are twin prime", num1, num2);
		}
		else
			printf (" %d and %d are not twin prime", num1, num2);	
	}
	else
		printf (" %d and %d are not twin prime number", num1, num2);
}
int main()
{
	int num1, num2;	
	printf (" Enter the first number: ");
	scanf ("%d", &num1); // get first number	
	printf (" Enter the second number: ");
	scanf (" %d", &num2); // get second number	
	checktwin(num1, num2); /* call the checktwin() function and pass num1 and num2 as parameters. */
	return 0;
}</string.h> 
```

**输出**

```
Enter the first number: 71
 Enter the second number: 73
 71 and 73 are twin prime

```

**第二次执行:**

```
Enter the first number: 15
 Enter the second number: 17
 15 and 17 are not twin prime

```

在上面的程序中，我们从用户那里取两个数字来检查给定的数字是否是孪生素数。这里我们取 5 和 7 为素数，函数返回 5 和 7 **为孪生素数。**同样，我们取数字 15 和 17，函数返回数字，**不是孪生素数。**

* * *