# 一个 C 程序的结构

> 原文：<https://www.javatpoint.com/structure-of-a-c-program>

C 程序的结构是指用 C 语言开始编程的具体结构。没有合适的结构，分析问题和解决方案就变得困难。这也给我们编写更复杂的程序提供了参考。

我们先来讨论一下 C 语言编程。

## c 程序设计

[C 语言](https://www.javatpoint.com/c-programming-language-tutorial)结合了一种**低级语言**和一种**高级语言**的力量。低级语言用于系统编程，而高级语言用于应用程序编程。因为这样的语言灵活易用。因此，C 语言是一种广泛使用的计算机语言。

它支持各种运算符、构造函数、数据结构和循环构造。C 编程的特性使得使用该语言进行系统编程、开发解释器、编译器、操作系统、图形、通用工具等成为可能。c 还用于编写其他应用程序，如**数据库、编译器、文字处理器、**和**电子表格**。

C 程序的基本特征如下:

**指针:**它允许通过程序中分配给它的名称来引用内存位置。

**内存分配:**在定义时，内存被分配给一个变量名，允许动态分配内存。这意味着程序本身可以请求操作系统释放内存，以便在执行时使用。

**递归:**当函数调用自身时，称为递归。

**位操作:**指对最低形式数据的操作。它也被称为位。计算机以二进制格式(0 和 1)存储信息。

让我们从指定 C 程序结构的重要性开始。

## C 程序结构的重要性

有时，当我们开始使用一种新的编程语言时，我们并不了解程序的基本结构。程序的各个部分通常会被打乱，遗漏错误的机会也会增加。语言的结构使我们对程序中各部分的顺序有了一个基本的概念。我们知道何时何地使用特定的**语句、变量、函数、花括号、括号**等。这也增加了我们对那种编程语言的兴趣。

因此，该结构帮助我们分析格式，以编写错误最少的程序。它提供了更好的清晰度和程序的概念。

在这里，我们将讨论 C 程序的**部分，一些带有解释的实际例子，编译和执行 C 程序的步骤**。

我们开始吧。

## C 程序的各部分

![Structure of a C program](img/499a74971e6d7e288790a85978c805cd.png)

C 程序的各部分如下所示:

1.  文件科
2.  预处理器部分
3.  定义部分
4.  全球宣言
5.  主要功能
6.  用户定义的函数

让我们详细讨论一下。

### 文件科

包括节目开头指定的语句，如节目的**名称、日期、描述、**和**标题**。它表示为:

```

//name of a program

```

或者

```

/*
Overview of the code
.
*/

```

这两种方法都作为程序中的文档部分工作。它提供了该计划的概述。里面写的任何东西都将被视为文档部分的一部分，不会干扰指定的代码。

### 预处理器部分

预处理器部分包含程序中使用的所有头文件。它通知系统将头文件链接到系统库。它由下式给出:

```

#include<stdio.h>
#include<conio.h>

```

**#include** 语句包含编译时作为函数一部分的特定文件。因此，包含的文件的内容与被编译的函数一起被编译。 **#include < stdio.h >** 由标准输入输出文件的内容组成，其中包含 stdin、stdout 和 stderr 的定义。每当函数中使用定义 stdin、stdout 和 stderr 时，都需要使用语句#include < stdio.h >。

有各种头文件可用于不同的目的。比如 **#包括<数学. h >。**用于程序中的数学函数。

### 定义部分

define 部分由使用 define 关键字声明的不同常量组成。它由下式给出:

```

#define a = 2

```

### 全球宣言

全局部分由程序中的所有全局声明组成。它由下式给出:

```

float num = 2.54;
 int a = 5;
char ch ='z';

```

上述全局变量的大小如下所示:

char = 1 字节

浮点= 4 字节

int = 4 字节

我们也可以在全局变量部分声明用户定义的函数。

### 主要功能

main()是计算机要执行的第一个功能。代码必须包含 main()。它就像 C 库中任何其他可用的函数一样。括号()用于将参数(如果有)传递给函数。

主要功能声明为:

```

main()

```

我们也可以将 int 或 main 与 main()一起使用。void main()指定程序将不返回任何值。int main()指定程序可以返回整数类型的数据。

```

int main()

```

或者

```

void main()

```

主函数进一步分为**局部声明、语句、**和**表达式。**

### 本地声明

在给定函数或块中声明的变量称为局部声明。

```

main()
{
int i = 2;
i++;
}

```

**报表**

语句指 **if，else，while，do，for** 等。用于主函数内的程序。

**表达式**

表达式是一种公式类型，其中操作数通过使用运算符相互链接。它由下式给出:

```

a - b;
a +b;

```

### 用户定义的函数

用户定义的功能指定了根据用户要求指定的功能。比如颜色()，求和()，除法()，等等。

程序(基本或高级)遵循上面列出的相同部分。

**返回功能**一般是一段代码的最后一段。但是，没有必要包括。当我们想要返回值时，就会用到它。当函数指定了 void 以外的返回类型时，return 函数返回一个值。

返回类型结束函数的执行。它进一步将控制返回给指定的调用函数。它由下式给出:

```

return;

```

或者

```

return expression ;

```

例如，

返回 0；

### 例子

让我们从一个简单的 C 语言程序开始。

**例 1:** 求用户给出的两个数之和

它由下式给出:

```

/* Sum of two numbers */
#include int main()
{
int a, b, sum;
printf("Enter two numbers to be added ");
    scanf("%d %d", &a, &b);
    // calculating sum
    sum = a + b;    
    printf("%d + %d = %d", a, b, sum);
    return 0;  // return the integer value in the sum
} 
```

**输出**

![Structure of a C program](img/65c85856154d139401b2ae7d518f49ba.png)

代码各部分的详细解释如下:

| /*两个数之和*/ | 这是评论区。其中描述的任何语句都不被视为代码。它是代码中描述部分的一部分。
评论行可选。它可以在单独的行中，也可以是可执行行的一部分。 |
| #包括<stdio.h></stdio.h> | 它是标准的输入输出头文件。它是预处理器部分的命令。 |
| int main() | main()是每个程序中执行的第一个函数。为了返回一个整数值，我们在 main()中使用了 int。 |
| {…
} | 大括号标记了函数的开始和结束。它在所有功能中都是强制性的。 |
| printf() | printf()在屏幕上打印文本。它是一个显示常量或变量数据的函数。这里，“输入两个要相加的数字”是传递给它的参数。 |
| scanf() | 它从标准输入流中读取数据，并将结果写入指定的参数。 |
| 总和= a + b | 指定的两个数字的相加将被传递给输出中的 sum 参数。 |
| 返回 0 | 一个程序也可以在没有返回 0 函数的情况下运行。它只是声明程序没有错误，可以成功退出。 |

**示例 2:** 通过接受用户的数字来绘制方框

它由下式给出:

```

/* a simple code to draw a box by accepting a number from the user */

#include // preprocessor section that contains header files
#include <conio.h>void main()  // main section
{
char num;  //local statements
puts(" Enter number of lines of a box (1 to 3) \n"); 
/* puts accepts, as parameter, a string constant, or a variable enclosed within the double quotes for display on the standard output*/

num = getchar(); // getchar() is also equal to getc(stdin) in C programming.
/* It accepts a parameter and allows the character to be read during the program execution. */
fflush(stdin); // clears the buffer
if(num=='1')  // beginning of if-else condition
{
puts("-----------");
puts("|         |");
puts("-----------");
}
else if(num=='2') /*if-else performs two different operations depending on the true or false condition of the expression.*/
{
puts("-----------");
puts("|         |");
puts("|         |");
puts("-----------");
}
else if(num=='3')
{
puts("-----------");
puts("|         |");
puts("|         |");
puts("|         |");
puts("-----------");
}
else
{
puts("Invalid input");
}
}</conio.h> 
```

我们已经保存了名为 boxexample.c 的文件。让我们在命令提示符的帮助下编译并执行代码。该文件是在记事本中创建的。

**输出**

![Structure of a C program](img/06d17a5b880905798cddfbb97160fcde.png)

本主题后面将解释从头开始创建、编译和执行代码的步骤。它将帮助我们在文本编辑器(这里是记事本)和 **cmd** (命令提示符)的帮助下编译任何类型的 C 代码。

我们可以统称该程序包括预处理器命令、变量、函数、语句、表达式和注释。

## C 程序的编译和执行

在这里，我们将讨论借助命令提示符编译和运行 C 程序的方法。

完整的程序执行步骤如下:

1.  创建程序
2.  编译程序
3.  运行或执行程序
4.  程序输出

### 创建程序

它指的是在任何文本编辑器中创建的代码。我们也可以在任何软件中编译和运行 C 代码，比如 Visual studio。

### 编译程序

If 指的是检查代码中错误的过程。计算机显示在我们指定的 C 代码中发现的所有错误(如果有的话)。我们可以做进一步的修改来纠正这些错误。

### 运行或执行程序

下一步是运行或执行部分。程序被组装和链接，没有任何错误。计算机执行不同的操作，如解码、算术逻辑单元操作来运行程序。

### 程序输出

它是程序的最后一部分，指定代码的输出作为结果产生。

但是，在哪里编写程序以及如何打开命令提示符来运行该程序。不要担心；完成所有这些步骤非常容易。让我们从编译和运行 C 程序的步骤开始。

## 编译和运行 C 程序的步骤

我们首先需要确保 gcc 编译器是否已经存在于我们的电脑上。如果没有安装，我们需要先安装 gcc 编译器。我们也可以尝试其他方法来运行一个 C 程序。但是在这里，我们使用了 gcc 编译器。

### 步骤:1 - gcc 编译器安装

我们可以通过链接直接安装最新的 gcc 编译器:[https://jmeubank.github.io/tdm-gcc/](https://jmeubank.github.io/tdm-gcc/)

在安装过程中完成所有步骤，直到该过程完成。

### 步骤 2:创建一个 C 程序

使用简单的文本编辑器创建一个 C 程序。在这里，我们使用了记事本。如下所示:

```

#include main()
{
    printf("Hello, Welcome to the C programming \n");
    return;
} 
```

现在，将文件保存在扩展名为()的任何目录中。c)。例如，我们已经在桌面上保存了名为“welcome.c”的文件。

### 步骤 3 -打开命令提示符

在我们的计算机上打开 cmd 或命令提示符。我们可以简单地在搜索或运行选项上键入 cmd。将出现命令提示符。

### 步骤 4 -重新检查 gcc 编译器

命令提示符打开后，输入“gcc -v”并按下回车。它将如下图所示:

![Structure of a C program](img/9e16b96d0eec95c7ce2ea733132ecfac.png)

它显示 gcc 已成功安装在我们的电脑上。

### 步骤 5 -转到源目录

我们现在需要在 cmd 上指定源目录。键入“光盘空间源目录”并按**进入**。此后，我们将文本编辑器文件保存在桌面上，因此我们将源目录指定为**桌面**。它由下式给出:

```

cd desktop

```

### 步骤 6:编译源代码

运行命令“以扩展名保存的文件的 gcc 空间全名(。c’)并按回车键，如下所示:

```

gcc welcome.c

```

如果我们的文件中有任何错误，它就会出现。否则，继续第 7 步。

### 步骤 7:编译源代码

可执行文件还没有命名，因为我们还没有告诉编译器执行任何这样的任务。因此，我们将首先通过运行命令‘gcc space-o space(可执行文件的名称)space(带有扩展名的原始文件的名称)’来命名可执行文件，然后按**进入**。它由下式给出:

```

gcc -o hello welcome.c

```

这里，我们将可执行文件命名为 hello。我们可以根据自己的方便来定义这个名字。

### 步骤 8 -运行程序

这是运行程序的最后一步。我们将只在命令提示符下运行程序。在这里，我们将键入没有任何扩展名的可执行文件的名称。可执行文件的名称将与步骤 7 中指定的名称相同。它由下式给出:

```

hello

```

按**进入**。输出将出现在命令提示符下，如下所示:

![Structure of a C program](img/b8f6b5168fe2106c7bd5421b08d21656.png)

同样，我们可以使用相同的步骤运行多个 C 程序，如上所述。

* * *