# C 语言中的 Malloc

> 原文：<https://www.javatpoint.com/malloc-in-c>

本节将讨论使用 C 编程语言中的 malloc 分配动态内存。malloc 是一个预定义的库函数，代表内存分配。malloc 用于在程序运行时分配指定大小的内存块。这意味着当用户/程序员不知道程序中需要多少内存空间时，它会在运行时创建一个动态内存分配。

因此，它在运行时输入内存大小(以字节为单位)，以保留一个连续的内存块，该内存块返回 void 类型的指针，该指针被转换为任何形式的指针。使用 malloc 创建的动态内存不会在执行时初始化内存，因此内存块包含一些默认的垃圾值。malloc 函数是在 stdlib.h 头文件中定义的。因此，在我们的程序中使用 malloc 函数时，我们需要使用 **< stdlib.h >** 头文件。

![Malloc in C](img/65c24867587ca37b30eb127e958b2659.png)

**语法**

```

ptr = ( cast_ type *) malloc (byte_size);

```

在上面的语法中，byte_size 是一个指定内存块大小(以字节为单位)的参数，它被传递给 malloc 函数以保留连续的内存。malloc()函数返回一个类型 void 指针，该指针可以转换为任何定义形式的指针。

### 检查内存的程序是使用 malloc 函数创建的

让我们考虑一个例子，检查内存是使用 C 编程语言中的 malloc 函数创建的。

**程序 1.c**

```

#include #include <stdlib.h>// use stdlib.h header file to malloc() function
int main ()
{
	int *pt; // declare a pointer of type int
	// use malloc() function to define the size of block in bytes
	pt = malloc (sizeof(int));

	// use if condition that defines ptr is not equal to null
	if (pt != NULL)
	{
		printf (" Memory is created using the malloc() function ");
	}
	else
	printf (" memory is not created ");
	return 0;	
}</stdlib.h> 
```

**输出**

```
Memory is created using the malloc() function

```

在上面的程序中，我们使用 malloc()函数创建了一个整数类型的动态内存，该函数返回一个指向基地址的整数指针。如果该语句检查 ptr 是否等于空指针，如果该语句为真，则意味着没有创建内存。否则通过 malloc()函数成功创建内存。

### 使用 malloc()函数创建动态内存的程序

让我们考虑一个例子，将大小作为用户的输入，然后在运行时使用 C 编程语言中的 malloc()函数输入数据。

**程序 2.c**

```

#include #include <stdlib.h>int main ()
{
	// declare the local variables
	int *ptr, size, i;

	printf (" Enter the allocated size of memory ");
	scanf (" %d", &size); // get the size of a memory	
	// use malloc() function to define the size of block in bytes
	ptr = malloc (size * sizeof(int));	
	// use if condition that defines ptr is not equal to null
	if (ptr != NULL)
	{
		// get an input from the user and print it
		printf (" Enter numbers from the user: ");		
		for ( i = 0; i < size; i++)
		{
			scanf (" %d", ptr + i); // stores the numbers from base address of memory
		}		
		printf (" Numbers are stores in contiguous memory: \n ");		
		for ( i = 0; i < size; i++)
		{
			printf (" \n The number is: %d", *(ptr + i)); // here *(ptr + i) is same as ptr[i]
		}
		printf (" \n Memory is created using the malloc() function ");
		return 0;
	}
	else
	printf (" memory is not created ");
	return 0;
}</stdlib.h> 
```

**输出**

```
Enter the allocated size of memory 10
 Enter numbers from the user: 25
40
20
13
56
78
67
24
10
7
 Numbers are stores in contiguous memory:
 The number is: 25
 The number is: 40
 The number is: 20
 The number is: 13
 The number is: 56
 The number is: 78
 The number is: 67
 The number is: 24
 The number is: 10
 The number is: 7
 Memory is created using the malloc() function

```

### 使用 free()函数释放内存空间

free()函数释放通过 malloc()函数创建的动态内存分配。动态内存无法释放已占用的内存本身，即使程序结束，现有空间仍然存在。因此，我们需要释放保留的内存，以便其他程序可以重用它。

**语法**

```

free (ptr);

```

在上面的语法中，我们在 free()函数中传递 ptr，该函数充当动态内存的引用或基址，指向内存块。

**程序 3.c**

```

#include #include <stdlib.h>void main()
{
	int num, i, sum = 0;
	int *ptr, *p;
	printf (" The number of elements to be entered: \n ");
	scanf (" %d", &num); // define the no. of element to be entered	
	// use malloc() function to define the size of memory block
	ptr = (int *) malloc (num);
	p = ptr; // store the base address of ptr in p	
	// validate the string is full or not
	if (ptr == NULL)
	{
		printf (" Memory is not allocated ");
		exit(0); // exit from program
	}
	else
	{
		printf (" Memory is created using the malloc() function ");
	}
	printf ("\n Enter the elements in allocated space: ");	
	for (i = 1; i <= num; i++)
	{
		scanf (" %d", ptr);
		sum = sum + *ptr;
		ptr++;
	}	
	// print the entered number
	printf (" Elements are: ");
	for (i = 1; i <= num; i++)
	{
		printf (" \n %d", *p);
		p++;
	}	
	printf (" \n The addition of stored elements is: %d ", sum);
	free (ptr); // use free() function to release the occupy space using malloc() function
	getch();	
}</stdlib.h> 
```

**输出**

```
The number of elements to be entered:
10
 Memory is created using the malloc() function
 Enter the elements in allocated space: 45
12
67
89
34
56
25
25
67
34
 Elements are:
 45
 12
 67
 89
 34
 56
 25
 25
 67
 34
 The addition of stored elements is: 454

```

* * *