# C 语言中递归的类型

> 原文：<https://www.javatpoint.com/types-of-recursion-in-c>

本节将讨论 C 编程语言中不同类型的递归。递归是一个函数调用自己 n 次的过程。如果一个程序允许用户递归调用同一个函数中的一个函数，那么这个过程被称为函数的递归调用。此外，递归函数可以在同一个程序中直接或间接调用自己。

**递归函数的语法**

```

void recursion ()
{
recursion(); // The recursive function calls itself inside the same function
}
int main ()
{
recursion (); // function call
}

```

在上面的语法中，main()函数只调用递归函数一次。之后，递归函数将自己调用到定义的条件，如果用户没有定义条件，它将无限次调用同一个函数。

![Types of Recursion in C](img/cf1a981da67b7f98580cca46ca3e8dd2.png)

### 不同类型的递归

以下是 C 编程语言中递归的类型，如下所示:

1.  直接递归
2.  间接递归
3.  尾部递归
4.  无尾部/头部递归
5.  线性递归
6.  树递归

### 直接递归

当一个函数在同一个函数中重复调用自己时，称为直接递归。

**直接递归的结构**

```

fun()
{
// write some code
fun();
// some code
}

```

在直接递归的上述结构中，外部 fun()函数递归调用内部 fun()函数，这种类型的递归称为直接递归。

让我们编写一个程序来演示 C 语言中的直接递归。

**程序 2.c**

```

#include int fibo_num (int i)
{
// if the num i is equal to 0, return 0;
if ( i == 0)
{
return 0;
}
if ( i == 1)
{
return 1;
}
return fibo_num (i - 1) + fibonacci (i -2);
}
int main ()
{
int i;
// use for loop to get the first 10 fibonacci series
for ( i = 0; i < 10; i++)
{
printf (" %d \t ", fibo_num (i));
}
return 0;
} 
```

**输出**

```
0	1	1	2	3	5	8	13	21	34 

```

### 间接递归

当一个函数被另一个函数以循环方式相互调用时，这个函数被称为间接递归函数。

**间接递归的结构**

```

fun1()
{
//  write some code 
fun2()
}
fun2()
{
// write some code
fun3()
// write some code
}
fun3()
{
// write some code
fun1()
}

```

在这个结构中，有四个函数，fun1()、fun2()、fun3()和 fun4()。fun1()函数执行时，会调用 fun2()来执行。然后 fun2()函数开始执行，调用 fun3()函数。这样，每个函数都通向另一个函数，使它们循环执行。这种方法叫做间接递归。

让我们编写一个程序来演示 C 语言中的间接递归。

**程序 3.c**

```

#include // declaration of the odd and even() function
void odd(); // Add 1 when the function is odd() 
void even(); // Subtract 1 when the function is even
int num = 1; // global variable 
void odd ()
{   
    // if statement check and execute the block till n is less than equal to 10
	if (num <= 10)
	{
		printf (" %d ", num + 1);  // print a number by adding 1
		num++; // increment by 1
		even(); // invoke the even function
	}
	return;
}
void even ()
{
	// if block check the condition that n is less than equal to 10
	if ( num <= 10)
	{
		printf (" %d ", num - 1); // print a number by subtracting 1 
		num++;
		odd(); // call the odd() function
	}
	return;
}
int main ()
{
	odd(); // main call the odd() function at once
	return 0;
} 
```

**输出**

```
2  1  4  3  6  5  8  7  10  9

```

### 尾部递归

如果递归函数本身进行递归调用，则该递归函数称为尾部递归，并且该递归调用是该函数执行的最后一条语句。之后，就没有函数或语句可以调用递归函数了。

让我们编写一个程序来演示 C 语言中的尾部递归。

**程序 4.c**

```

#include // function definition
void fun1( int num)
{
	// if block check the condition
	if (num == 0)
		return;
	else
		printf ("\n Number is: %d", num); // print the number
	return fun1 (num - 1);		// recursive call at the end in the fun() function 
}
int main ()
{
	fun1(7); // pass 7 as integer argument
	return 0;
} 
```

**输出**

```
Number is: 7
 Number is: 6
 Number is: 5
 Number is: 4
 Number is: 3
 Number is: 2
 Number is: 1

```

### 非尾/头递归

一个函数被称为非尾部或头部递归如果一个函数本身进行递归调用，递归调用将是函数中的第一条语句。这意味着在递归调用之前不应该调用任何语句或操作。此外，头递归在递归调用时不执行任何操作。相反，所有操作都在返回时完成。

让我们编写一个程序来演示 C 语言中的头尾递归。

**程序 5.c**

```

#include void head_fun (int num)
{
if ( num > 0 )
{
// Here the head_fun() is the first statement to be called
head_fun (num -1);
printf (" %d", num);
}
}
int main ()
{
int a = 5;
printf (" Use of Non-Tail/Head Recursive function \n");
head_fun (a); // function calling
return 0;
} 
```

**输出**

```
Use of Non-Tail/Head Recursive function
 1 2 3 4 5

```

### 线性递归

如果函数在每次运行时对自身进行一次调用，并且与问题的大小成正比地线性增长，则该函数称为线性递归。

让我们编写一个程序来演示 C 语言中的线性递归。

**程序 6.c**

```

#include #define NUM 7
int rec_num( int *arr, int n)
{
	if (n == 1)
	{
		return arr[0];
		}	
	return Max_num (rec_num (arr, n-1), arr[n-1]);	
}
// get the maximum number
int Max_num (int n, int m)
{
	if (n > m)
		return n;
	return m;
}
int main ()
{
	// declare and initialize an array
	int arr[NUM] = { 4, 8, 23, 19, 5, 35, 2};
	int max = rec_num(arr, NUM); // call function
	printf (" The maximum number is: %d\n", max); // print the largest number
} 
```

**输出**

```
The maximum number is: 35

```

### 树递归

一个函数被称为树递归，其中该函数在递归函数中对自己进行多次调用。

让我们编写一个程序来演示 C 语言中的树递归。

**程序 7.c**

```

#include // It is called multiple times inside the fibo_num function
int fibo_num (int num)
{
if (num <= 1)
	return num;
return fibo_num (num - 1 ) + fibo_num(num - 2);
}
void main()
{
int num = 7;
printf (" Use of Tree Recursion: \n");
// print the number
printf (" The Fibonacci number is: %d", fibo_num(7));
} 
```

**输出**

```
Use of Tree Recursion:
 The Fibonacci number is: 13

```

* * *