# C 语言中的一元算子

> 原文：<https://www.javatpoint.com/unary-operator-in-c>

在本节中，我们将讨论 C 编程语言中的一元运算符。**运算符**是用于对给定的数字或操作数执行数学和逻辑运算的特殊符号，并根据操作数之间传递的运算符返回结果。

一元运算符是用于对单个操作数进行运算以返回新值的运算符。换句话说，它是一个通过使用适当的一元运算符来更新操作数或表达式值的运算符。在一元运算符中，运算符从右到左的结合性具有相同的优先级。

![Unary Operator in C](img/14b6fe8aafe16b66c3cdea90ce40e594.png)

## 一元运算符的类型

下面是 C 编程语言中一元运算符的类型。

1.  一元减号(-)
2.  一元加号(+)
3.  增量(++)
4.  减量(-)
5.  逻辑否定(！)
6.  地址运算符(&)
7.  Sizeof()运算符

### 一元减号(-)

一元减号运算符用符号(-)表示。一元运算符用于将任何正值的符号更改为负值。这意味着它将正数变为负数，负数使用一元减运算符变为正数。

**语法**

```

int a = 2;
int b = -(a);

```

**例 1:**

```

#include #include <conio.h>int main ()
{
int a = 5; // positive value of a.
int b = -(a); // use unary minus operator to change the value

int n1 = 20;
int n2 = -30;

printf (" The value of a: %d \n", a);
printf (" The value of b: %d \n", b);

printf (" The value of -n1: %d \n", -n1);
printf (" The value of -n2: %d ", -n2);

return 0;
}</conio.h> 
```

**输出**

```
The value of a: 5
The value of b: -5
The value of -n1: -20 
The value of -n2: 30

```

### 一元加号(+)

一元加号运算符表示为“+”符号，它不会更改为操作数值。

**例 2:**

```

#include #include <conio.h>int main ()
{
int a = 10; // use unary plus operator
int b = (-10); // It does not change the operand value
printf (" The value of a: %d \n", a);
printf (" The value of b: %d \n", b);
return 0;	
}</conio.h> 
```

**输出**

```
The value of a: 10
The value of b: -10

```

### 一元增量运算符(++)

它是一元增量运算符，用“++”符号表示。“++”符号表示操作数的值增加 1。它可以有两种使用方式，作为后增量和前增量。

**预增量**:预增量运算符表示为(++a)，这意味着在对表达式使用操作数之前，变量‘a’的值会增加 1。

例如:

```

x = 10;
A = ++x;

```

x 的初始值是 10，使用预增量运算符(++x)将操作数值增加 1，然后将其赋给变量“A”。

**后增量**:(a++)符号代表后增量运算符，这意味着在将原始值赋给表达式或另一个变量后，“a”的值增加 1。

例如:

```

x = 10;
A = x++;

```

这里，x 变量的初始值是 10，并使用后增量运算符(x++)将“x”的增量值赋给变量“A”。

**例 3:**

```

#include #include <conio.h>int main ()
{
	int x, y, a, b; // declare local variable
	a = 10;
	x = ++a; // It shows pre increment operator

	printf (" Pre Increment Operator");
	// Here the value of x is increased by 1.
	printf (" \n The value of x is %d.", x);

	printf (" \n The value of a is %d.", a);

	b = 20;
	y = b++; // It shows the post increment operator
	printf (" \n\n Post Increment Operator");
	printf (" \n The value of y is %d.", y);
	// get updated value of b
	printf (" \n The value of b is %d.", b);

	return 0;
}</conio.h> 
```

**输出**

```
Pre Increment Operator
The value of x is 11.
The value of a is 11.

Post Increment Operator
The value of y is 20.
The value of b is 21.

```

### 一元递减运算符(-)

一元递减运算符与一元递增运算符相反。一元递减运算符由双减号(-)表示，用于根据递减类型将操作数值减少 1。一元递减运算符有两种类型:前递减运算符和后递减运算符。

**预减量**:预减量运算符表示为(- a)符号，表示在赋值给另一个变量或表达式之前，操作数值先减 1。

**语法**

```

int pre = --a;

```

**后递减**:后递减运算符表示为(a -)符号，表示赋值给另一个变量或表达式后，原值减 1。

**语法**

```

int post = a--;

```

**例 4:**

```

#include #include <conio.h>int main ()
{
	int x, y, a, b; // declare local variable
	a = 10;
	x = --a; // It shows pre decrement operator

	printf (" Pre Decrement Operator");
	// Here the value of x is decreased by 1.
	printf (" \n The value of x is %d.", x);

	printf (" \n The value of a is %d.", a);

	b = 20;
	y = b--; // It shows the post decrement operator
	printf (" \n\n Post Decrement Operator");
	printf (" \n The value of y is %d.", y);
	// get updated value of b
	printf (" \n The value of b is %d.", b);

	return 0;
}</conio.h> 
```

**输出**

```
Pre Decrement Operator
 The value of x is 9.
 The value of a is 9.

 Post Decrement Operator
 The value of y is 20.
 The value of b is 19.

```

### 一元大小()运算符

sizeof 是一个关键字，用于查找不同数据类型或操作数的大小，如 int、float、char、double 等。

**语法**

```

sizeof(data_variable);

```

**例 5:**

```

#include #include <conio.h>int main ()
{
// declaration of different types of data variables
int x;
float y;
char ch;
double z;

// use sizeof() operator and pass the different data type variable to get their size.
printf (" The size of the int (x) variable is: %d", sizeof(x));
printf (" \n The size of the float (y) variable is: %d", sizeof(y));
printf (" \n The size of the char (ch) variable is: %d", sizeof(ch));
printf (" \n The size of the double (z) variable is: %d", sizeof(z));
return 0;
}</conio.h> 
```

**输出**

```
The size of the int (x) variable is: 4
 The size of the float (y) variable is: 4
 The size of the char (ch) variable is: 1
 The size of the double (z) variable is: 8

```

### 逻辑非(！)操作员

逻辑非运算符用于反转给定的条件。例如，如果操作数为真，则逻辑非运算符(！)反转并返回 false 如果操作数为 false，则逻辑运算符返回 true。

**语法**

```

bool a = true;
bool b = !a; // It reverse the condition of variable b

```

**例 6:**

```

#include #include <stdbool.h>int main () 
{
// declare variables
bool a = true;
bool  b;
b = !a; // use logical operator to reverse the condition
printf (" The Boolean value of a is: %d", a);
printf (" \n The Boolean value of b is: %d", b);

bool c = 0;
bool d = !c;
printf (" \n The Boolean value of c is: %d", c);
printf (" \n The Boolean value of d is: %d", d);
return 0;
}</stdbool.h> 
```

**输出**

```
The Boolean value of a is: 1
 The Boolean value of b is: 0
 The Boolean value of c is: 0
 The Boolean value of d is: 1

```

### 操作员的地址(&)

运算符的一元地址表示为&符号，用于查找计算机内存中定义的变量的地址。

**语法**

```

int a = 5;
int b = &a; // variable b hold the address of variable a

```

**例 7:**

```

#include #include <conio.h>int main () 
{
// declare variables
int a = 10;
int b;

// use addressof (&) operator to assign the address
b = &a;
printf (" The value of variable a is: %d", a);
printf (" \n The address of variable b is: %d", b);
return 0;
}</conio.h> 
```

**输出**

```
The value of variable a is: 10
The address of variable b is: 6487704

```

* * *