# C 语言中的前增后增算子

> 原文：<https://www.javatpoint.com/pre-increment-and-post-increment-operator-in-c>

增量运算符是 C 编程语言的运算符，用于将给定变量的值增加 1。在将给定值赋给变量之前，增量运算符可以将给定值增加 1。另一方面，增量运算符可以在分配变量后将给定值增加 1。增量运算符表示为双加号(++)，这意味着值增加 1。

![Pre-increment and Post-increment Operator in C](img/9a2a40dda18055cb1718a5fe0337c592.png)

### 增量算子的性质

增量运算符有如下一些属性:

1.  增量运算符用于将变量的当前值增加 1。
2.  我们只能对变量使用这些运算符。
3.  它是由双加号(++)表示的运算符。

### 增量运算符有两种类型

1.  预增量运算符
2.  后递增运算符

### 预增量运算符

预增量运算符表示为双加号(++a)，附加在变量名称之前。预递增运算符用于在数学表达式中使用操作数之前将操作数的值递增 1。换句话说，变量的值首先递增，然后在表达式中使用更新的值。

**语法**

```

x = ++a;

```

在上面的语法中，变量“a”的值在表达式中使用之前先递增 1。

**示例 1:** 让我们创建一个简单的程序，在 C 编程语言中使用预增量运算符。

**程序 1.c**

```

#include #include <conio.h>int main ()
{
// declaration of the variables
int a = 7;
int b = 2

// print the value of the increment operator
printf (" Use the pre-increment operator " );
printf (" The value of a is %d ", a);
printf (" The value of b is %d ", b);
// use pre-increment operator
b = ++a;
printf (" After using the pre-increment operator ");
printf (" The value of a is %d ", a);
printf (" The value of b is %d ", b);
return 0;
}</conio.h> 
```

**输出**

```
Use the pre-increment operator
The value of a is 7
The value of b is 2
After using the pre-increment operator
The value of a is 8
The value of b is 10

```

**示例 2:** 让我们创建另一个程序，在数学表达式中使用预增量运算符。

**程序 2.c**

```

#include #include <conio.h>int main ()
{
	// declare integer variables
	int a, b, c, d, x;

	// initialization of the variables
	a = 5;
	b = 7;
	c = 12;
	d = 15;

	// use pre-increment operator in the mathematical expression
	x = ++a + ++b + ++c + ++d;
	printf ( " The value of x is: %d ", x);

	// print the updated value of a, b, c, and d
	printf (" \n The updated value of a = %d, b = %d, c = %d and d = %d ", a, b, c, d);
	return 0;	
}</conio.h> 
```

**输出**

```
The value of x is: 43
 The updated value of a = 6, b = 8, c = 13 and d = 16

```

### 后增量运算符

后增量是一个增量运算符，表示为双加号(a++)符号，后跟一个运算符“a”。在数学表达式中使用后，它将操作数的值增加 1。换句话说，变量的原始值首先在表达式中使用，然后后递增运算符将操作数值更新 1。

**语法**

```

x = a++;

```

在上面的语法中，操作数“a”的值被赋给变量 x，然后后递增运算符将“a”的值增加或更新 1。

**示例 1:** 让我们创建一个简单的程序，在 C 编程语言中使用后递增运算符。

**程序 1.c**

```

#include #include <conio.h>int main ()
{
// declaration of the variables
int a = 7;
int b = 0;

// print the value of the increment operator
printf (" Before using the post-increment operator " );
printf (" \n The value of a is %d ", a);
printf (" \n The value of b is %d ", b);
// use post increment operator
b = a++;
printf (" \n\n After using the post-increment operator ");
printf (" \n The value of a is %d ", a);
printf (" \n The value of b is %d ", b);
return 0;
}</conio.h> 
```

**输出**

```
Before using the post-increment operator
 The value of a is 7
 The value of b is 0

 After using the post-increment operator
 The value of a is 8
 The value of b is 7

```

**示例 2:** 让我们创建另一个程序，在数学表达式中使用后增量运算符。

**程序 2.c**

```

#include #include <conio.h>int main ()
{
	// declare integer variables
	int a, b, c, d, x;

	// initialization of the variables
	a = 5;
	b = 7;
	c = 12;
	d = 15;

	// use post-increment operator in the mathematical expression
	x = a++ + b++ + c++ + d++;
	printf ( " The value of x is: %d ", x);

	// print the updated value of a, b, c, and d
	printf (" \n The updated value of a = %d, b = %d, c = %d and d = %d ", a, b, c, d);
	return 0;

}</conio.h> 
```

**输出**

```
The value of x is: 39
 The updated value of a = 6, b = 8, c = 13 and d = 16

```

### 使用预增量和后增量运算符的程序

让我们创建一个简单的程序，在 C 编程语言中使用前增量和后增量运算符。

**程序 3.c**

```

#include #include <conio.h>int main ()
{
	int x, y, z, exp;

	printf (" Enter the value of x: ");
	scanf (" %d", &x);
	printf (" \n Enter the value of y: ");
	scanf (" %d", &y);
	printf (" \n Enter the value of z: ");
	scanf (" %d", &z);

	printf (" \n Before using the increment operator: ");
	printf (" \n The original value of x: %d", x);
	printf (" \n The original value of x: %d", y);
	printf (" \n The original value of x: %d", z);

	// use pre-increment and post-increment operator
	exp = x++ + ++x + ++y + y++ + ++z;
	printf (" \n\n After using the increment operator: ");
	printf (" \n The result of the expression is: %d", exp);
	printf (" \n The updated value of x: %d", x);
	printf (" \n The updated value of y: %d", y);
	printf (" \n The updated value of z: %d", z);
	return 0;

}</conio.h> 
```

**输出**

```
Enter the value of x: 7

 Enter the value of y: 12

 Enter the value of z: 15

 Before using the increment operator:
 The original value of x: 7
 The original value of x: 12
 The original value of x: 15

 After using the increment operator:
 The result of the expression is: 58
 The updated value of x: 9
 The updated value of y: 14
 The updated value of z: 16

```

* * *