# C 语言中的指针与数组

> 原文：<https://www.javatpoint.com/pointer-vs-array-in-c>

通常，在大多数情况下，用户假设指针和数组都是同一个东西。然而，事情并没有那么简单，因为如果我们深入研究两者，我们会发现一些明显的差异。因此，在本文中，我们将看到指针和数组是否真的相同。

### 数组的定义

数组通常用于存储性质相同的相同类型的数据项或值。虽然数组不能用来存储本质上不相同的数据项或值，但它也被认为是数组的一个显著缺点。

**语法:**

```

int mark[5] = {19, 10, 8, 17, 9};

```

### 指针的定义

除了数组，如果我们谈论指针，它们通常用于存储另一个变量的内存地址，而不是存储变量的实际值。但是，我们也可以使用指针通过指针算法来访问整个数组。此外，它甚至使访问数组的过程更快。

**语法:**

指针变量可以声明如下:

```

//Declaration in C++
type * name;

```

### 指针和数组的主要区别是什么？

除了我们在上面讨论的内容，关键的区别可以在实现指针和数组时找到。例如，当实现阵列时，分配固定大小的内存块。另一方面，在实现指针的地方，内存是动态分配的。因此，在指针和数组中分配内存可以被认为是关键的区别。然而，这并不是数组和指针之间的唯一区别，因为还存在其他一些区别，如下所示:

1.  数组通常存储相似数据类型的变量，变量的数据类型必须与数组的类型相匹配。然而，指针变量存储一个类型类似于指针变量类型的变量的地址。
2.  我们可以生成一个指针数组，即变量是指针变量的数组。另一方面，我们也可以创建一个指向数组的指针。
3.  一般来说，数组是静态的，这意味着一旦声明了数组的大小，就不能根据用户的要求调整它的大小。而另一方面，指针是动态的，这意味着分配的内存可以在以后的任何时间点调整大小。
4.  数组在编译时分配，而指针在运行时分配
5.  如果我们谈论数组的大小，它通常取决于存储在其中的变量的数量。而在指针变量的情况下，它只存储变量的地址。为了更清楚地理解它，您可以考虑下面给出的例子:
6.  “sizeof”运算符

如果我们使用“sizeof(array)”，它将返回存储在数组中的所有元素所使用的内存量。但是，如果我们将它用于指针，例如“sizeof(指针)”，它只返回指针变量本身使用的内存量。

### 对比图

让我们看一下快速比较图，以更简单的方式了解数组和指针之间的区别:

| 比较的基础 | 指针 | 排列 |
| 申报 | //在 c++ 中，键入* var _ name | //在 c++ 中，键入 var _ name[size]；//在 Java 中. type var-name[]；var_name =新类型[大小]； |
| 工作 | 它通常存储与指针变量的数据类型相同的另一个变量的地址。 | 数组通常存储相同数据类型的变量值。 |
| 产生 | 可以生成指向数组的指针。 | 可以生成指针数组。 |
| 仓库 | 指针是专门为存储变量地址而设计的。 | 普通数组存储变量值，指针数组存储变量地址。 |
| 容量 | 通常，数组可以存储与数组变量大小相同的元素数量。 | 指针变量一次只能存储一个变量的地址。 |

**结论**

在本文中，我们解释了数组和指针之间的主要区别。因此，读完这篇文章，我们希望你对指针和数组的困惑永远被清除。

* * *