# 限制 C 中的关键字

> 原文：<https://www.javatpoint.com/restrict-keyword-in-c>

在本文中，我们将学习什么是 C 语言中的 restrict 关键字，以及如何在 C 程序中使用它。然而，它最初是在 C99 版本的 C 语言中引入的。那么，让我们看看这个受限关键词到底是什么。

## 介绍

一般来说，restrict 关键字作为指针的一种量词，主要用于指针的减速。但是，这个关键字并没有给它添加任何类型的新功能或任何新特性，那么使用它背后的原因是什么。答案非常简单，因为程序员可以通知编译器使用这个关键字来优化可以优化的内容。

换句话说，我们可以说，每当“restrict”关键字与诸如 **ptr** 这样的指针一起使用时，它都会通知编译器 **ptr** 是访问它所指向的对象的唯一方式。但是，编译器不会添加和执行任何额外的检查。简而言之，应该没有其他指向该特定对象的指针。但是，如果任何用户以某种方式违反了这一条件，很有可能该用户会得到未定义的结果，或者他的程序可能会表现异常。

#### 注意:C++ 不支持 restrict 关键字，它只是 C 编程语言的一个关键字。

为了更详细地理解“restrict”关键字的使用，您可以考虑下面给出的例子，在这些例子中，我们以尽可能简单的方式使用了“restrict”关键字。

**例 1**

```

#include /* In this function we are adding the value of variable c to other variables a and y */
void function(int* a, int* b, int* restrict c) 
{
  *a += *c;  
/* Updating value of variable a by adding the value of variables a and c */
  *b += *c;  
/* Updating value of variable b by adding the value of variables b and c. Since c is restrict, compiler will not reload value at address c in its assembly code. Therefore generated assembly code will be optimized */
}
int main(void) 
{
  int a = 50 , b = 100 , c = 150 ;
  function(&a, &b, &c);
  printf("%d %d %d", a, b, c);
} 
```

**输出**

```
200 250 150

```

**例 2**

```

#include void my_function(int* x, int* y, int* restrict z) {
   *x += *z;
   *y += *z;
}
main(void) {
   int x = 10, y = 20, z = 30;
   my_function(&x, &y, &z);
   printf("%d %d %d", x, y, z);
} 
```

**输出**

```
40 50 30

```

**Q1。哪里可以使用 restrict 关键字？**

**A** 。指向指针

**语法:**

```

int* restrict p;

```

**Q2。如果给指针添加一个' restrict '关键字，编译器会怎么想？**

**A** 。它将假设由“p”指向的内存将仅由“p”唯一指向。

**Q3。编译器的优化有什么帮助？**

**A** 。一般来说，指针指向的数据也可以被任何其他指针修改。一般来说，对于您执行的每一条涉及读取指针的指令，您需要将指针中存储的值(指向的值)重新加载到 CPU 寄存器中。但是一旦你知道它只有一个指针，在某些情况下你可以跳过重新加载。

### 结论

在本文中，我们已经解释了 C 语言的 restrict 关键字，并且我们已经尝试让事情尽可能简单。此外，回答了一些与“restrict”关键字相关的常见基本问题。

* * *