# C 语言中的 exit()函数

> 原文：<https://www.javatpoint.com/exit-function-in-c>

**exit()函数**用于立即终止程序中的进程或函数调用。这意味着当 exit()函数出现在程序中时，属于该进程的任何打开的文件或函数都会立即关闭。exit()函数是 C 的标准库函数，在 **stdlib.h** 头文件中定义。因此，我们可以说它是强制终止当前程序并将控制权转移给操作系统以退出程序的函数。exit(0)函数确定程序在没有任何错误消息的情况下终止，然后 exit(1)函数确定程序强制终止执行过程。

![The exit() function in C](img/dacdf4ad9458e23976403f441a115e3b.png)

### exit()函数的要点

C 程序设计中退出函数的要点如下:

1.  在使用 exit()函数时，我们必须包含 stdlib.h 头文件。
2.  它用于在遇到 exit()函数时终止程序的正常执行。
3.  exit()函数按照注册的相反顺序调用注册的 atexit()函数。
4.  我们可以使用 exit()函数来刷新或清除所有打开的流数据，比如用未写入的缓冲数据进行读取或写入。
5.  它关闭了所有打开的与父函数或其他函数或文件链接的文件，并且可以删除由 tmpfile 函数创建的所有文件。
6.  如果用户多次调用 exit 函数或调用 exit 和 quick_exit 函数，程序的行为是未定义的。
7.  退出功能分为两个部分:退出(0)和退出(1)。

**exit()函数的语法**

```

void exit ( int status);

```

**退出()**功能没有返回类型。

**int status:** 表示返回到父进程的退出函数的状态值。

**示例 1:在 for 循环中使用 exit()函数的程序**

让我们创建一个程序来演示在 C 编程语言中正常终止进程的 exit (0)函数。

```

#include 
#include <stdlib.h>
int main () 
{
// declaration of the variables
int i, num;
printf ( " Enter the last number: ");
scanf ( " %d", &num);
for ( i = 1; i</stdlib.h>
```

**输出**

```
Enter the last number: 10

 Number is 1
 Number is 2
 Number is 3
 Number is 4
 Number is 5

```

### C 中有两种退出状态

以下是 C 编程语言中退出函数的类型，如下所示:

1.  退出 _ 成功
2.  退出失败

**EXIT _ SUCCESS**:EXIT _ SUCCESS 是 EXIT()函数类型，用 exit(0)语句表示。其中“0”表示程序成功终止，没有任何错误，或者在程序执行过程中出现编程失败。

**退出成功的语法**

```

exit (EXIT_SUCCESS);

```

**示例 1:演示 EXIT_SUCCESS 或 exit(0)功能用法的程序**

让我们创建一个简单的程序来演示退出(0)函数在 C 编程中的工作。

```

#include #include <stdlib.>int main ()
{
printf ( " Start the execution of the program.  \n");
printf (" Exit from the program. \n ");
// use exit (0) function to successfully execute the program
exit (0);
printf ( "Terminate the execution of the program.\n ");
return 0;
}</stdlib.> 
```

**输出**

```
Start the execution of the program.
Exit from the program. 

```

**示例 2:在 EXIT()函数中使用 EXIT_SUCCESS 宏的程序**

让我们创建一个 C 程序来验证这个角色是否存在。

```

#include #include <stdlib.h>int main () 
{
// declaration of the character type variable
char ch;
printf(" Enter the character: ");
scanf (" %c", &ch);

// use if statement to check the condition
if ( ch == 'Y')
{
	printf(" Great, you did it. ");
	exit(EXIT_SUCCESS); // use exit() function to terminate the execution of a program
}
else
{
	printf (" You entered wrong character!! ");
}
return 0;
}</stdlib.h> 
```

**输出**

```
Enter the character: Y
Great, you did it.

```

**EXIT _ FAILURE**:EXIT _ FAILURE 是 EXIT()函数异常执行并终止程序的宏。退出失败也表示为退出(1)功能。“1”是否表示异常终止程序并将控制权转移给操作系统。

**退出失败的语法**

```

exit (EXIT_FAILURE); 

```

**示例 1:让我们创建一个程序来使用 EXIT_FAILURE 或 exit(1)功能**

```

#include #include <stdlib.h>int main ()
{
int num1, num2;
printf (" Enter the num1: ");
scanf ("%d", &num1);

printf (" \n Enter the num2: ");
scanf ("%d", &num2);

if (num2 == 0)
{
printf (" \n Dividend cannot be zero. ");

// use EXIT_FAILURE
exit(1);
}

float num3 = (float)num1 / (float)num2;
printf (" %d / %d : %f", num1, num2, num3);

// use the EXIT_SUCCESS
exit(0);
}</stdlib.h> 
```

**输出**

```
Enter the num1: 20
Enter the num2: 6
20 / 6 : 3.333333

2nd Run
Enter the num1: 20
Enter the num2: 6
Dividend cannot be zero

```

**示例 2:让我们创建另一个程序，使用 EXIT_FAILURE 来终止 C 程序。**

```

#include #include <stdlib.h>int main ()
{

// declare the data type of a file	
FILE *fptr = fopen ( "javatpoint.txt", "r" );
// use if statement to check whether the fptr is null or not.
if ( fptr == NULL)
{
fprintf ( stderr, "Unable to open the defined file \n" );
exit ( EXIT_FAILURE); // use exit function to check termination
}
// use fclose function to close the file pointer
fclose (fptr); 
printf ( " Normal termination of the program. ");
return 0;
}</stdlib.h> 
```

**输出**

```
Unable to open the defined file.

```

* * *