# C 语言中的常量限定词

> 原文：<https://www.javatpoint.com/const-qualifier-in-c>

通常，const 限定符用于将变量声明为常量，这意味着一旦变量初始化，其值就不能改变。然而，使用常量有几个好处，比如如果我们有一个常量值，我们不希望程序的任何部分修改这个值。因此，我们可以使用 const 限定符将其声明为 const。但它像往常一样有一点扭曲，因为有时我们能够改变用 const 限定符声明的变量值。然而，这并不总是可能的，因为这取决于常量变量在内存中的存储位置。

**常量变量的语法**

```

const Data_Type Identifier = Value;

```

一般来说，const 限定符只给编译器一个指示，即限定对象的值不能改变。换句话说，我们可以说 const 表示不可修改(不能在运行时给对象赋值)。

![Const Qualifier in C](img/fd6929ebde7cb9e76b35320f125d0cb7.png)

然而，当我们使用 const 限定符将一个标识符声明为常量时，它取决于“常量变量”在过程控制块中的位置或存储位置的实现(或编译器)。因此，一些机器将常量和跳转表存储在文本部分，该部分只读取并包含所有其他可执行指令。

**规则**

很少有规则可以帮助我们决定何时在 C 程序中使用常量:

*   当我们不想在初始化后改变变量的值时，我们可以使用它。
*   在通过引用调用的情况下，当我们不想改变传递的变量值时。例如，

```

int Display ( const char *pcMessage)

```

*   我们也可以使用它，同时借助 c 语言中的指针映射输入输出寄存器。

**现在，让我们看一些例子，在这些例子中，我们将在程序中使用带有指针的 const 限定符:**

### 1.指向常数的指针

**语法**

```

const int *xData;
or
int const *xData;

```

正如您在上面的声明中看到的，“xData”指向一个常量整数变量。因此，我们不能使用指针(*xData)来更改所指向的整数变量的值，但是我们可以将指针更改为指向任何其他整数变量。所以现在有可能，指针可以指向任何其他变量，因为它通常存储在读写区(或读写内存)。因此，让我们看一个例子，说明我们如何借助下面给出的例子来实现它。

**例 1**

在本例中，我们将尝试使用指向常量(piIndex)的指针来更改整数变量的值。但是，如果用户试图使用*piData 更改变量(iIndexData1)的值，他将得到编译器错误。

**程序**

```

#include int main(void)
{
/*Integer variable*/
int iIndexData1 = 2;
/*pointer to const int*/
const int *piIndex = NULL;
/*Assign the address of iIndexData to a pointer to const,here integer variable qualify to const integer its called up qualification which is valid in c*/
piIndex = &iIndexData1;
*piIndex = 3; /*Try to change value constant object*/
printf("Data is %d",*piIndex);
return 0;
} 
```

**输出**

在函数“main”中:错误:分配了只读位置“*piIndex”

```
*piIndex = 3;

```

**例 2**

现在，我们将尝试改变这个例子中的指向变量。

**程序**

```

#include int main(void)
{
/*Integer variable1*/
int iIndexData1 = 2;
/*Integer variable2*/
int iIndexData2 = 4;
/*Assign address of iIndexData to pointer to const,
here integer variable qualify to const integer*/
const int* piIndex = &iIndexData1;
printf("*piIndex is %d\n",*piIndex);
/*It's invalid because pointer is constant*/
piIndex = &iIndexData2;
printf("*piIndex is %d\n",*piIndex);
return 0;
} 
```

**输出**

```
*piIndex is 2
*piIndex is 4

```

您可以看到上面给出的代码工作得非常完美，我们已经成功地更改了指向变量:

### 2.指向常数的常数指针:

**语法**

```

const int *const piData;

```

正如您在上面的声明中看到的，它描述了常量指针指向一个常量整数变量。这意味着我们不能改变指针指向的值，也不能将指针指向其他整数变量。

**例 1**

在这个例子中，我们将使用指向常数的常数指针的概念。

**程序**

```

#include int main(void)
{
//Integer variable1
int Data = 2;
//const pointer to const int
const int *const piData = &Data;
printf("*piData is %d\n",*piData);
return 0;
} 
```

**输出**

```
*piData is 2

```

如您所见，如果我们不尝试更改 piData 和*piData 的值，一切都很好。

**例 2**

在本例中，我们将尝试更改*piData 的值。但是，根据这个概念，我们会得到编译器错误，因为*piData 限定为常量。现在让我们看看会发生什么:

**程序**

```

#include int main(void)
{
//Integer variable
int Data = 2;
//const pointer to const int
const int *const piData = &Data;
//changing the value
*piData = 3;
printf("*piData is %d\n",*piData);
return 0; 
```

**输出**

```
Error: assignment of read-only location '*piData'

```

正如您在输出中看到的，我们无法更改“*pidata”的值。

**例 2**

这里我们将看到，我们可以将另一个整数变量指向指针。让我们看看会发生什么:

**程序**

```

#include int main(void)
{
/*Integer variable1*/
int Data1 = 2;
/*Integer variable2*/
int Data2 = 4;
const int* const piData = &Data1;
//Display data
printf("*piData is %d\n",*piData);
/*It's invalid because pointer is constant*/
piData = &Data2;
printf("*piData is %d\n",*piData);
return 0; 
```

**输出**

```
Error: assignment of read-only variable 'piData'

```

在上面给定的两个程序的输出中，您可以看到，在常量指针指向常量的情况下，我们不能更改常量值，也不能将常量指针指向另一个变量。

* * *