# C 中的序列点

> 原文：<https://www.javatpoint.com/sequence-points-in-c>

在本文中，我们将学习 C 编程语言中的序列点是什么。此外，为了更容易理解它们，我们还将讨论一些序列点的例子以及它们的实际实现。

## 介绍

一般来说，我们可以考虑序列点，因为它定义了计算机程序执行中的任何一点，在该点上，它保证或确保程序代码先前评估的所有副作用都已完成或成功执行。然而，这也确保了后续评估的任何改变或副作用都不会发生。换句话说，我们可以说，在命令式编程中，序列点定义了计算机程序执行中的任何一点，在该点上保证了先前评估的所有副作用都已经完成。此外，后续评估尚未发现副作用。“副作用”这个词很可能会让你感到困惑。然而，如果有，那么让我们看看到底什么是“副作用”。

**副作用**

术语“副作用”只不过是任何种类的函数或表达式所产生的副作用或变化，在这些函数或表达式中，事物的状态会发生变化。

为了更详细地理解序列点，可以考虑下面给出的例子:

**例 1**

```

#include int f1() { printf ("hi,there"); return 1;}
int f2() { printf ("hello, there"); return 1;}
int main() 
{ 
  int p = f1() + f2();  
  return 0; 
} 
```

上面给出的程序的输出是未定义的或非预测性的，因为上面程序的输出在不同的机器或编译器上会有所不同，因为这就像询问未定义的自动变量的值。上述程序未定义行为背后的主要原因是“+”运算符没有为其操作数定义任何标准的求值顺序。因此，我们无法预测哪个函数“f1”或“f2”将首先执行。但是，也有一些类似于“+”运算符的运算符，如“-”、“/”、“*”、按位 AND &和、按位 OR |，..等等。

**例 2**

```

#include int x = 20;
int f1() { x = x+10; return x;}
int f2() { x = x-5;  return x;}
int main()
{
  int p = f1() + f2();
  printf ("p = %d", p);
  return 0;
} 
```

上述程序的输出也是未定义的，因为即使是表达式的求值也会引起副作用。例如，在上面的程序中，p 的最终值是模糊的，因为它完全取决于表达式求值的顺序。因此，如果函数“f1()；”首先执行，p 的值是 55；否则 40。

### 序列点

这些是 C 语言中可用的一些基本序列点

1.  逻辑与和
2.  逻辑或||
3.  有条件吗？
4.  逗号，

**1。逻辑与& &**

在逻辑 AND &运算符的情况下，它的左操作数将首先被完整地执行，并且在继续之前它都是副作用。但是，如果左操作数的计算结果为 false，则执行过程将停止，另一个操作数将根本不执行。

**2。逻辑或||**

在逻辑 OR ||，它的左操作数必须首先被完全执行，并且它的所有副作用才能继续。但是，如果左操作数的计算结果为假(或非零)，则另一个操作数根本不会被执行。

**3。有条件？**

在条件运算符的情况下，将首先计算条件运算符的第一个操作数，并在继续之前完成其所有副作用。

**4。逗号，**

逗号操作符的左操作数必须首先被完全求值，并且在继续之前它的所有副作用都必须发生。但是，逗号运算符的两个操作数总是被求值。

#### 注意:函数调用中的逗号运算符不能保证求值的顺序。

* * *