# C 语言中的逻辑与运算符

> 原文：<https://www.javatpoint.com/logical-and-operator-in-c>

逻辑运算符通过连接两个或多个表达式或条件对给定的表达式执行逻辑运算。它可以用于各种关系表达式和条件表达式。该运算符基于布尔值对条件进行逻辑检查，如果条件为真，则返回 1。否则，它返回 0(假)。在 C 编程中，逻辑运算符分为三种类型，如逻辑 AND (&&)运算符、逻辑 or 运算符(||)和逻辑 NOT(！)运算符。在这里，我们学习逻辑与运算符及其在 C 编程语言中的各种示例。

![Logical AND Operator in C](img/1958b6fc5d7103a35237924af5d59743.png)

## 逻辑与运算符

逻辑“与”运算符表示为“&&”双&符号。它通过在表达式中组合来检查两个或多个操作数的条件，如果所有条件都为真，逻辑“与”运算符将返回布尔值“真”或“1”。否则返回 false 或 0。

#### 注意:如果两者的值都不为零，条件将保持为真。否则，逻辑“与”(&&)运算符返回 0(假)。

**语法**

```

(condition1 && condition2)

```

在上面的语法中有两个条件，条件 1 和条件 2，以及在双(&&)和符号之间。如果两个条件都为真，逻辑“与”运算符将返回布尔值 1 或真。否则，它返回 false。

### 逻辑与(&&)运算符的真值表

| A | B | a & B |
| one | one | one |
| one | Zero | Zero |
| Zero | one | Zero |
| Zero | Zero | Zero |

**例 1:用 C 语言演示逻辑与运算符的程序**

```

#include #include <conio.h>int main ()
{
	// declare variable
	int n = 20;

	// use Logical AND (&&) operator to check the condition
	printf (" %d \n", (n == 20 && n >= 8)); // condition is true, therefore it returns 1
	printf (" %d \n", (n >= 1 && n >= 20));
	printf (" %d \n", (n == 10 && n >= 0));
	printf (" %d \n", (n >= 20 && n <= 40));

	return 0;
}</conio.h> 
```

**输出**

```
1
1
0
1

```

**示例 2:使用逻辑“与”运算符**查找最大数的程序

```

#include #include <conio.h>int main ()
{
// declare integer type variable
int x, y, z;
printf (" Enter the first number: ");
scanf ("%d", &x);
printf (" Enter the second number: ");
scanf ("%d", &y);
printf (" Enter the third number: ");
scanf ("%d", &z);

// use logical AND operator to validate the condition
if ( x >= y && x >= z )
{
printf (" %d is the largest number of all. ", x);
}
else if ( y >= x && y >= z)
{
printf (" %d is the largest number of all. ", y);
}
else
{
	printf ( " %d is the largest number of all. ", z);
}
return 0;
}</conio.h> 
```

**输出**

```
Enter the first number: 20
Enter the second number: 10
Enter the third number: 50
50 is the largest number of all

```

**示例 3:使用逻辑与(& &)运算符检查用户是否为青少年的程序。**

```

#include #include <conio.h>int main ()
{
	// declare variable
	int age;

	printf (" Enter the age: ");
	scanf (" %d", &age); // get age

	// use logical AND operator to check more than one condition
	if ( age >= 13 && age <= 19) 
	{
		printf (" %d is a teenager age. ", age);
	}
	else
	{
		printf (" %d is not a teenager age. ", age);
	}

	return 0;
}</conio.h> 
```

**输出**

```
Enter the age: 17
17 is a teenager age.

2nd execution:
Enter the age: 10
10 is not a teenager age.

```

**示例 4:验证输入的数字是否在定义的范围内的程序。**

```

#include int main ()
{
	int num;
	printf (" Enter a number between 1 to 50: ");
	scanf (" %d", &num); //get the number

	// use logical AND operator to check condition
	if ( (num > 0 ) && (num <= 50))
	{
		printf (" The entered number is in the range 0 and 50\. ");
	}
	else if ( ( num > 50 ) && ( num <= 100))
	{
		printf (" The entered number is in the range 50 and 100\. ");
	}
	else
	{
		printf (" Please enter the number is in the defined range. ");
	}
	return 0;

 } 
```

**输出**

```
Enter a number between 1 to 50: 19
The entered number is in the range 0 and 50.

2nd Run 
Enter a number between 1 to 50:
51
The entered number is in the range 50 and 100.

3rd execution:
Enter a number between 1 to 50:
0
Please enter the number is in the defined range.

```

**示例 5:使用预定义的用户名和密码验证用户输入的用户名和密码是否正确的程序。**

```

#include #include <string.h>// use #define macro to define the values for UserName and Password
#define UserName "system"
#define Password "admin@123"

int main ()
{
// declare character type array
char un[50], pass[50];
// take UserName and Password from user
printf ( " Enter the username: " );
scanf (" %s", un);
printf ( " Enter the password: " );
scanf (" %s", pass);

// use if statement and Logical AND operator to validate the condition
if (strcmp (UserName, un) == 0 && strcmp (Password, pass) == 0)
{
printf (" \n The user's credentials are correct. ");
}
else
{
printf ( " \n The user's credentials are incorrect. ");
}
return 0;
}</string.h> 
```

**输出**

```
Enter the username: system
Enter the password: [email protected]

The user's credentials are correct.

2nd execution
Enter the username: system
Enter the password: [email protected]

The user's credentials are incorrect.

```

* * *