# C 语言中的近指针、远指针和巨指针

> 原文：<https://www.javatpoint.com/near-far-and-huge-pointers-in-c>

在本文中，我们学习了在 Ms-Dos 早期的 16 位英特尔架构中通常使用和实现的一些旧概念，但它们现在并不常用。尽管如此，这些概念非常重要，因为它们就像当前技术的构建模块。但是，根据内存模型和段，指针可以分为三种类型，如下所示:

*   近指针
*   远指针
*   巨大的指针

### 近指针

一般来说，我们可以考虑近点，因为它用于存储地址，最大大小只有 16 位。使用近指针，我们不能存储大于 16 位的地址。但是，我们可以存储 16 位限制内的所有其他较小的地址。你可能认为 16 位有点小，因为我们一次只能访问 64kb 的数据。因此，它被认为是近指针的主要缺点之一，这就是为什么它不再被普遍使用的原因。让我们看看其他一些重要的关键点，可以帮助我们理解近指针。

**语法**

语法如下-

```

<data type> near <pointer definition>

```

下面的语句为变量 s 声明了一个近指针

```

char near *string;

```

让我们看看一些重要的关键点，可以帮助我们理解附近的“**”指针。**

*   近指针不能访问数据段以外的内容，如图形视频存储器、文本视频存储器等。近指针的大小是两个字节。借助关键字 near，我们可以使任何指针成为一个 near 指针。
*   它是一个在内存 64Kb 数据段范围内工作的指针。
*   它不能访问给定数据段以外的地址。
*   通过使用算术运算符，可以在地址范围内递增或递减近指针。

**为了更详细地理解“近”指针，我们来看一个例子:**

**例**

```

#include int main()
      {
          int x=25;
          int near* ptr;
          ptr=&x;
          printf("%d",sizeof ptr);
          return 0;
      } 
```

**输出**

```
2

```

### 远指针

一般来说，远指针通常被认为是 32 位大小的指针。但是，它也可以从当前段访问存储在计算机内存之外的信息。尽管要使用这种类型的指针，我们通常需要分配扇区寄存器来存储当前段中的数据地址。此外，我们还需要分配另一个寄存器来存储当前段内的偏移量。

**语法**

语法如下:

```

<data type> far <pointer definition>

```

以下语句为变量 s 声明了一个远指针

```

char far *s;

```

让我们看看其他一些重要的关键点，它们可以帮助我们理解**远**指针。

*   当指针递增或递减时，只改变偏移部分。
*   这种类型的指针既存储偏移量，也存储指针所指向的段地址。
*   远指针地址的范围从 0 到 1MB。
*   它可以访问所有 16 个片段。

**例**

```

#include int main(){
   int number=50;
   int far *p;
   p=&number;
   printf("%d",sizeof number);
   return 0;
} 
```

**输出**

```
4

```

### 巨大的指针

像远指针一样，巨大的指针也有 32 位大小，但它甚至可以访问存储或位于段外的位。然而，远指针与巨指针非常相似，但它仍然比远指针有一些优势。例如，固定的远指针；因此，存储或定位它们的扇区部分不能以任何方式改变或修改。然而，巨大指针的情况并非如此，因为巨大指针具有允许它这样做的弹性。

让我们看看其他一些重要的关键点，它们可以帮助我们理解**“巨大”**指针。

*   可以指向内存中任何段的指针称为巨大指针。一个巨大的指针大小为 **4 字节或 32 位**，它可以访问内存中高达 64K 的大小。
*   巨大的指针可以递增，而不会受到分段循环的影响。

下面给出的例子显示了巨大指针的用法。

**示例:**

```

#include int main()
{
char huge * far *p;
printf("%d %d %d",sizeof(p),sizeof(*p),sizeof(**p));
return 0;
} 
```

**输出**

```
4 4 1

```

在给定的程序中，p 是巨大的指针，*p 是远指针，**p 是 char 类型的数据变量。

### 近指针、远指针和巨指针有什么区别？

通常，虚拟地址由选择器和偏移量组成。近指针没有显式选择器，而大指针有显式选择器。当我们对一个远指针执行指针运算时，选择器不会被修改，但是在一个巨大指针的情况下，它可以被修改。

#### 注意:这些都是非标准的关键字，也是特定于实现的，在现代平台中是不相关的。

* * *