# C 语言中的幻数

> 原文：<https://www.javatpoint.com/magic-number-in-c>

在本节中，我们将讨论 C 编程语言中的幻数及其各种示例。当一个数的所有给定位数的和与那个和的倒数相乘，等于原来的数，那么这个数就叫做幻数。

例如，假设我们有一个 1729 的数字，我们需要验证这个数字是否是一个幻数。所以，首先我们需要得到 19 (1 + 7 + 2 + 9 = 19)这个数的所有数字的和。将数字的和反相为 91，然后得到原始数字和的乘积，和的反相为 19 * 19 = 1729。所以，这是一个神奇的数字。

**C 中寻找幻数的步骤**

第一步:声明一个整型变量，从用户输入一个数字，存储在 n 中。

第二步:得到原数所有数字的总和，并存储到另一个变量 a 中。

第三步:反转变量 A 的个数，存入 b。

第四步:之后将变量 A 和 B 的值相乘，存入 c。

第五步:检查 C == N，那么这个数就是幻数。否则，这个数字不是一个神奇的数字。

**例 1:程序检查数字是否是 C** 中的幻数

让我们创建一个程序，从用户那里获取一个数字，并验证在 C 编程语言中输入的数字是否是一个神奇的数字。

```

#include #include <conio.h>int main ()
{
	// declare integer variables
	int n, temp, rev = 0, digit, sum_of_digits = 0;

	printf (" Enter a Number: \n");
	scanf (" %d", &n); // get the number

	temp = n; // assign the number to temp variable

	// use while loop to calculate the sum of digits
	while ( temp > 0)
	{
		// extract digit one by one and store into the sum_of_digits
		sum_of_digits = sum_of_digits + temp % 10; /* use modulus symbol to get the remainder of each iteration by temp % 10 */
		temp = temp / 10;
	}

	temp = sum_of_digits; // assign the sum_of_digits to temp variable
	printf (" \n The sum of the digits = %d", temp);

	// get the reverse sum of given digits
	while ( temp > 0)
	{
		rev = rev * 10 + temp % 10;
		temp = temp / 10;
	}

	printf (" \n The reverse of the digits = %d", rev);

	printf (" \n The product of %d * %d = %d", sum_of_digits, rev, rev * sum_of_digits);
	// use if else statement to check the magic number
	if ( rev * sum_of_digits == n)
	{
		printf (" \n %d is a Magic Number. ", n);
	}
	else
	{
		printf (" \n %d is not a Magic Number. ", n);
	}
	return 0;

}</conio.h> 
```

**当我们在 C 编译器中执行上述程序时，它在控制台屏幕中产生如下输出。**

```
Enter a number
1729
The sum of the digits = 19
The reverse of the digits = 91
The product of 19 * 91 = 1729 
1729 is a Magic Number.

```

在上面的程序中，我们从用户那里得到 1729，并将这个数字分配给 temp 变量。之后，使用 while 循环将原始数字(n)的总和逐个提取为 sum_of_digits，并将结果分配给 temp。再次使用循环来反转数字的总和并打印反转的数字。最后将原始数字(N)与返回相同结果的 sum_of_digits 和 rev 变量相乘，以显示一个幻数。

**例 2:使用自定义功能**检查数字是否为幻数的程序

让我们创建一个例子，从用户那里获取一个数字，并验证在 C 编程语言中输入的数字是否是一个神奇的数字。

```

/* program to check the magic number using the user-defined function in c programming. */
#include #include <conio.h>// create getReverse () function to get the reverse of the given number
int getReverse (int num)
{
	int revNum = 0;

	//use while loop to get the reverse of original nummber (n)
	while ( num > 0)
	{
		revNum = (revNum * 10) + (num % 10);
		num = num / 10;	
	 } 
	 printf (" \n The reverse of the number = %d", revNum);
	 return revNum;
}

// create getSum() function to get the sum of each digits of the given number
int getSum ( int num)
{
	int sum = 0; // initialize the sum variable with 0
	while ( num > 0)
	{
		sum = sum + ( num % 10);
		num = num / 10;
	}
	printf ( " \n The sum of the given number = %d", sum);
	return sum;
}

int main ()
{
	// declare variable
	int num, sum, revNum;
	printf (" Enter the number: ");
	scanf (" %d", &num);

	sum = getSum (num); // call getSum () function
	revNum = getReverse (sum); // callgetReverse () function and argument sum

	int result = sum * revNum;
	printf (" \n The product of %d and %d = %d ", sum, revNum, result);

	// use if else to check condition
	if (sum * revNum == num)
	{
		printf (" \n %d is a magic number. ", num);	
	}
	else
	{
		printf ( " \n %d is not a magic number. ", num);
	}
}</conio.h> 
```

**当我们在 C 编译器中执行上面的程序时，它会在你的电脑屏幕中产生下面的输出。**

```
Enter the number: 1729
The sum of the given number = 19
The reverse of the number = 91
The product of 19 and 91 = 1729
1729 is a Magic Number.

```

**2<sup>2</sup>执行:**

```
Enter the number: 5189
The sum of the given number = 23
The reverse of the number = 32
The product of 23 and 32 = 736
5189 is not a magic number.

```

在上面的程序中，我们从用户那里获取 5189，并创建两个用户定义的函数 getSum()和 getRevere()。其中 getSum()函数用于计算给定数字的和，getReverse()函数用于反转 getSum()函数的和。如果 getSum()和 getReverse()函数的乘积等于 num，那么这个数就是一个幻数。

**方法二:递归法检查 C** 中的幻数

如果数字的总和被递归计算到等于 1 的一位数，那么这个数字被称为幻数。否则这个数字不是一个神奇的数字

**例 1:用递归法求幻数的程序**

让我们创建一个程序来输入来自用户的整数数据，并在 C 编程语言中验证这个数字是否是一个幻数。

```

/* create a program to get the magic number by dividing the given number by 9\. */
#include #include <conio.h>int main ()
{
	// declare integer variable
	int num;
	printf ( " Enter the number: ");
	scanf (" %d", &num);

	// get the modulus of the input number by 9 to check magic number
	if ( num % 9 == 1)
	{
		printf ( " It is a Magic Number. ");
	}
	else
	{
		printf ( " it is not a Magic Number. ");
	}
	return 0;
}</conio.h> 
```

**当我们在 C 编译器中执行上述程序时，它在控制台屏幕中产生如下输出。**

```
Enter the number: 1789
It is a Magic Number.

```

**2<sup>2</sup>执行:**

```
Enter the number: 55057
It is not a Magic Number.

```

* * *