# C 语言中的通用链表

> 原文：<https://www.javatpoint.com/generic-linked-list-in-c>

链表是数据元素的线性集合，其顺序是由内存中的物理位置决定的，而不是由它们的物理顺序决定的。相反，每一个元素都是通往下一个元素的垫脚石。这是一个由节点组成的数据结构，节点代表一个序列。所以每个节点都包含数据和对序列中下一个节点最基本形式的引用(链接)。在迭代过程中，这种结构能够有效地插入和移除序列中任何位置的元素。更复杂的变体包括额外的链接，允许在任意位置更有效地插入和移除节点。

链表的一个缺点是访问时间是线性的，很难流水线化。不可能提供更快的访问，例如随机访问。与链表相比，数组具有更好的缓存局部性。

链表是最基本和最广泛使用的数据结构之一。它们可以用来合并各种其他流行的抽象数据类型，如列表、堆栈、队列、关联数组和 S 表达式；然而，不使用链表作为基础或底层数据结构而直接合并这些数据结构的情况并不少见。

与传统数组相比，链表的主要优点是列表元素可以很容易地插入或移除，而不需要重新分配或重组整个结构，因为数据项不需要连续存储在内存或磁盘上，而在运行时重组数组是一个成本更高的操作。链表允许在链表遍历过程中，通过在内存中保留被添加或删除的链接之前的链接，以恒定的操作次数在链表中的任意点添加和删除节点。然而，因为简单的链表不支持对数据的随机访问或有效的索引，所以许多基本操作，如获取列表的最后一个节点、定位包含给定数据的节点或定位新节点应该插入的位置，可能需要遍历大部分或所有列表元素。下面列出了使用链表的好处和缺点。

动态数组是一种数据结构，它以连续的方式分配内存中的所有元素，并跟踪当前的元素数量。如果超出了动态阵列的分配空间，将重新分配并(可能)复制该空间，这是一项昂贵的操作。与动态数组相比，使用链表有几个优点。在列表的特定点插入或删除元素是一个恒定时间的操作(除非我们已经索引了指向该节点的指针(在要移除的节点之前或插入点之前)。相比之下，在随机位置插入动态数组平均需要移动一半的元素，在最坏的情况下需要移动所有的元素。虽然可以通过将数组中的某个元素的槽标记为“空”来在恒定时间内“删除”该元素，但这会导致碎片，从而影响迭代性能。

根据指针的类型，链表的节点具有链表节点的指针方向。

## 链表的类型

链表有不同的类型，一些主要的链表类型有:

*   单链表
*   双向链表
*   循环链表
*   双循环链表

## 单链表

在单链表中，单链表的节点指向存储下一个节点的存储单元的地址。类似地，以这种方式，所有节点都存储它们各自的下一个节点的地址。除了最后一个节点，最后一个节点的指针中的地址为空，表示它是链表的最后一个节点。

**代码**

现在让我们看一个示例代码，创建一个单链表，在链表中添加元素，然后用 C 编程语言遍历单链表。

```

/* A sample C code to perform the following functions on Singly Linked list Insert, Delete, Display and Count Operations */
/* All Operations Example Program Using Functions in C*/
// stdio library is included to use the input output functionalities in the program
#include <stdio.h>
// the malloc library is included to dynamically allocate memory to the nodes of the Singly Linked list
#include <malloc.h>
#include <stdlib.h>
// a struct named node is defined that will represent the node of the Singly Linked list
// the struct object has two variables in it named value and next
struct node {
  // the value variable is of integer type and will be used to store the value associated with that particular node of the Singly Linked list
  int value;
  // the next variable is of struct node* type and will be used to store the address of the next node of the Singly Linked list
  struct node *next;
};
void insert();
void display();
void delete();
int count();
// the struct object named node is typedef with DATA_NODE for easier interpretation 
typedef struct node DATA_NODE;
// An object of the DATA_NODE (which is struct node) named head_node is created and initialized with 0 that acts as the head node of the Singly Linked list. 
DATA_NODE *head_node = 0;
// An object of the DATA_NODE (struct node) named first_node is created and initialized with 0, which acts as the first node of the Singly Linked list.
DATA_NODE *first_node = 0;
// An object of the DATA_NODE (which is struct node) named temp_node is created and initialized with 0 that will be used to store the node of the Singly Linked list temporarily.
DATA_NODE *temp_node = 0;
// An object of the DATA_NODE (which is struct node) named next_node,prev_node is created that will be used to temproray store the node of Singly Linked list.
DATA_NODE *prev_node;
DATA_NODE next_node;
// a variable named data of integer type is created to store the value associated with that particular node of the Singly Linked list 
int data;
// A function named insert is written to add a new node to the Singly Linked list 
void insert() {
  // Data to be associate with that particular node of the Singly Linked list is taken as input from the user
  printf("\nEnter Element for Insert Linked list : \n");
  // the data enetred by the user is stored in the data variable
  scanf("%d", &data);
  // a temporary node is created with the added new data by the user, and this new temporary node is allocated memory by using the malloc function 
  temp_node = (DATA_NODE *) malloc(sizeof (DATA_NODE));
  // now the data added by the user is associated with this particular new temproray node
  temp_node->value = data;
  // while inserting a new node to the Singly linked list, it is checked whether the first_node is zero or not,
  // if first_node is zero, that means there are no nodes present in the Singly Linked list at that time, so that
  // new node is added at the start of the Singly Linked list, which will act as the head of the Linked list
  // if the first_node is not zero, then the new node is added after that already existing node   
  // this if condition will check the value of first_node varible
  if (first_node == 0) {
    // if value of first_node varible is zero then it will become the head of the Singly Linked list
    first_node = temp_node;
  } else {
    // if the value is not zero, then the address of this new node will be added to the pointer of the already last existing node in the Singly Linked list
    head_node->next = temp_node;
  }
  // and the address that is stored in the newly added node is 0 representing it to be the last node of the Singly Linked list   
  temp_node->next = 0;
  head_node = temp_node;
  fflush(stdin);
}//end of the insert function
// A function named delete was written to delete a node from the Singly Linked list
void delete() {
  int countvalue = 0;
  int pos = 0;
  int i = 0;
  countvalue = count();
  temp_node = first_node;
  printf("\nDisplay Linked list : \n");
  // The position of the node that we want to delete from the Singly Linked list is taken as input from the user
  printf("\nEnter Position for Delete Element : \n");
  // The position of the node that we want to delete from the Singly Linked list entered by the user is stored in the pos variable
  scanf("%d", &pos);
  // Now, for deleting a node from the Singly Linked list, first we need to traverse to that position and then delete that node from the Singly Linked list  
  // By deleting, we mean to add the pointer of the previous node to the next node of the node whose position is entered by the user.
  if (pos > 0 && pos <= countvalue) {    
    // this is the case when the user wants to delete the head node of the Singly Linked list
    if (pos == 1) {
      temp_node = temp_node -> next;
      first_node = temp_node;
      // Once the node is deleted a message is displayed to the user
      printf("\nDeleted Successfully \n\n");
    } else {
      while (temp_node != 0) {
        if (i == (pos - 1)) {
          prev_node->next = temp_node->next;
          if(i == (countvalue - 1))
          {
			  head_node = prev_node;
		  }
          // Once the node is deleted a message is displayed to the user
          printf("\nDeleted Successfully \n\n");
          break;
        } else {
          i++;
          prev_node = temp_node;
          temp_node = temp_node -> next;
        }
      }
    }
    // if the position that is entered by the user is out of the range of the length of the  Singly Linked list then an error message saying Invalid position is displayed
  } else
    printf("\nInvalid Position \n\n");
}// end of delete function
// A function named display is written to print the data in the nodes of the Singly Linked list 
void display() {
  //an integer variable named count is initialized with zero that will keep the total count of the number of nodes in the Singly Linked list 
  int count = 0;
  // the temp_node variable is initialized with the first_node variable, which is the first node of the Singly Linked list
  temp_node = first_node;
  printf("\nDisplay Linked list : \n");
  // The Singly Linked list is traversed untill the last element of the Singly Linked list is encountered
  while (temp_node != 0) {
    // while traversing the Singly Linked list the data present in the each node of the Singly Linked list is printed
    printf("# %d # ", temp_node->value);    
    // the count variable is incremented after traversing each node of the Singly Linked list 
    count++;
    temp_node = temp_node -> next;
  }  
  // after traversing each node of the Singly Linked list, the total count of the number of nodes in the Singly Linked list is printed
  printf("\nNo Of Items In Linked list : %d\n", count);
}// end of display function
// A function named count is written to count the total number of nodes in the Singly Linked list
int count() {  
  //an integer variable named count is initialized with zero that will keep the total count of the number of nodes in the Singly Linked list 
  int count = 0;
  // the temp_node variable is initialized with the first_node variable, which is the first node of the Singly Linked list
  temp_node = first_node;
  // The Singly Linked list is traversed until the last element of the Singly Linked list is encountered
  while (temp_node != 0) {
    // the count varible is incremented after traversing each node of the Singly Linked list
    count++;
    temp_node = temp_node -> next;
  }
  // after traversing each node of the Singly Linked list, the total count of the number of nodes in the Singly Linked list is printed
  printf("\nNo Of Items In Linked list : %d\n", count);
  return count;
}// end of count function
// main function is written to call all the functionalities functions of the Singly Linked list written above
int main() {
  char ch;
            // Do-while loop
            // Do part for performing actions
            do
            // Menu is displayed
            // Users enter 'y' to continue 'n' if
            // entered by user , the program terminates
            {
                  // Menu
                  // Display messages
                  printf("Please Choose one of the Operations::\n");
                  printf("1\. To Insert Data in the Singly Linked list.\n");
                  printf("2\. To Delete Data from the Singly Linked list.\n");
                  printf("3\. To Display Data present in the Singly Linked list.\n");
                  printf("4\. To Display the count of nodes in the Singly Linked list.\n");
                  printf("\n");
                  int choice;
                  scanf("%d",&choice);
                  // Switch case
                  switch (choice) {
                  // Case 1
                  case 1:
                        insert();
                        // Display message
                        printf("Data Added Sucessfully.\n");
                        // Break statement to terminate a case
                        break;
                  // Case 2
                  case 2:
                        // Display message
                        delete();
                        // Break statement to terminate a case
                        break;
                  // Case 3
                  case 3:
                        // Display message
                        display();
                        // Break statement to terminate a case
                        break;
                  // Case 2
                  case 4 :
                        // Display message
                        count();
                        // Break statement to terminate a case
                        break;
                  default:
                        // Print statement
                        printf("Please enter a valid option from the menu to proceed further.\n \n");
                        // Break statement
                        break;
                  }
                  printf("\nType [N or n] to terminate the program.\nType [Y or y] to continue the program.\n");
                  scanf(" %c",&ch);                  
            } while (!(ch == 'N' || ch == 'n'));
  return 0;
}// end of main function

```

**输出:**

上面的代码给出了以下输出:

```
Please Choose one of the Operations::
1\. To Insert Data in the Singly Linked list.
2\. To Delete Data from the Singly Linked list.
3\. To Display Data present in the Singly Linked list.
4\. To Display the count of nodes in the Singly Linked list.
1
Enter Element for Insert Linked list: 
2
Data Added Successfully.
Type [N or n] to terminate the program.
Type [Y or y] to continue the program.
y
Please Choose one of the Operations::
1\. To Insert Data in the Singly Linked list.
2\. To Delete Data from the Singly Linked list.
3\. To Display Data present in the Singly Linked list.
4\. To Display the count of nodes in the Singly Linked list.
1
Enter Element for Insert Linked list: 
3
Data Added Successfully.
Type [N or n] to terminate the program.
Type [Y or y] to continue the program.
y
Please Choose one of the Operations::
1\. To Insert Data in the Singly Linked list.
2\. To Delete Data from the Singly Linked list.
3\. To Display Data present in the Singly Linked list.
4\. To Display the count of nodes in the Singly Linked list.
1
Enter Element for Insert Linked list: 
6
Data Added Successfully.
Type [N or n] to terminate the program.
Type [Y or y] to continue the program.
y
Please Choose one of the Operations::
1\. To Insert Data in the Singly Linked list.
2\. To Delete Data from the Singly Linked list.
3\. To Display Data present in the Singly Linked list.
4\. To Display the count of nodes in the Singly Linked list.
1
Enter Element for Insert Linked list: 
89
Data Added Successfully.
Type [N or n] to terminate the program.
Type [Y or y] to continue the program.
y
Please Choose one of the Operations::
1\. To Insert Data in the Singly Linked list.
2\. To Delete Data from the Singly Linked list.
3\. To Display Data present in the Singly Linked list.
4\. To Display the count of nodes in the Singly Linked list.
1
Enter Element for Insert Linked list: 
56
Data Added Successfully.
Type [N or n] to terminate the program.
Type [Y or y] to continue the program.
y
Please Choose one of the Operations::
1\. To Insert Data in the Singly Linked list.
2\. To Delete Data from the Singly Linked list.
3\. To Display Data present in the Singly Linked list.
4\. To Display the count of nodes in the Singly Linked list.
1
Enter Element for Insert Linked list: 
31
Data Added Successfully.
Type [N or n] to terminate the program.
Type [Y or y] to continue the program.
y
Please Choose one of the Operations::
1\. To Insert Data in the Singly Linked list.
2\. To Delete Data from the Singly Linked list.
3\. To Display Data present in the Singly Linked list.
4\. To Display the count of nodes in the Singly Linked list.
1 
Enter Element for Insert Linked list: 
78
Data Added Successfully.
Type [N or n] to terminate the program.
Type [Y or y] to continue the program.
y
Please Choose one of the Operations::
1\. To Insert Data in the Singly Linked list.
2\. To Delete Data from the Singly Linked list.
3\. To Display Data present in the Singly Linked list.
4\. To Display the count of nodes in the Singly Linked list.
3
Display Linked list: 
# 2 # # 3 # # 6 # # 89 # # 56 # # 31 # # 78 # 
No Of Items In Linked list: 7
Type [N or n] to terminate the program.
Type [Y or y] to continue the program.
y
Please Choose one of the Operations::
1\. To Insert Data in the Singly Linked list.
2\. To Delete Data from the Singly Linked list.
3\. To Display Data present in the Singly Linked list.
4\. To Display the count of nodes in the Singly Linked list.
2
No of Items In Linked list: 7
Display Linked list: 
Enter Position for Delete Element: 
4
Deleted Successfully 
Type [N or n] to terminate the program.
Type [Y or y] to continue the program.
y
Please Choose one of the Operations::
1\. To Insert Data in the Singly Linked list.
2\. To Delete Data from the Singly Linked list.
3\. To Display Data present in the Singly Linked list.
4\. To Display the count of nodes in the Singly Linked list.
3
Display Linked list: 
# 2 # # 3 # # 6 # # 56 # # 31 # # 78 # 
No Of Items In Linked list: 6
Type [N or n] to terminate the program.
Type [Y or y] to continue the program.
y
Please Choose one of the Operations::
1\. To Insert Data in the Singly Linked list.
2\. To Delete Data from the Singly Linked list.
3\. To Display Data present in the Singly Linked list.
4\. To Display the count of nodes in the Singly Linked list.
4
No of Items in Linked list: 6
Type [N or n] to terminate the program.
Type [Y or y] to continue the program.
n  

```

在上面的代码中，我们为链表的不同功能创建了不同的函数，比如向链表插入一个新节点，显示链表所有节点中存在的数据，删除链表中特定位置存在的特定节点，以及计算链表中节点的总数。

在向单链表插入新节点时，检查第一个节点是否为零，

*   如果第一个节点为零，则此时单链表中没有节点，因此在单链表的开始处添加一个新节点，该节点将作为链表的头。
*   如果第一个节点不为零，则添加新节点。之后，链表中已经存在最后一个节点。要从链表中删除一个节点，首先，我们需要从用户那里获取该节点的索引。一旦我们有了那个节点的位置，下一步就是遍历那个节点，在到达那个节点之后，我们想要删除的节点的前一个节点持有这个节点的地址，所以我们需要把它改变成那个位置的下一个节点。为了打印所有节点中存在的数据，我们需要遍历整个列表，从头(第一个)节点开始，一直到最后一个节点，遍历每个节点时，显示该节点中存在的数据。打印链表中节点的总数也遵循类似的方法。

* * *