# C 中的平方根

> 原文：<https://www.javatpoint.com/square-root-in-c>

本节将讨论在 C 编程语言中使用 sqrt()函数寻找给定数字的平方根。在数学中，一个数的平方根正好是该数平方的倒数。它的意思是当同一个数乘以它自己，返回一个数的平方。而单个数乘以它本身就叫做一个数的平方根。例如，假设我们想要得到的任何数字的平方都是 3，数字 3 本身乘以 3 * 3，返回平方 9。同样的数字 3 叫做数字 9 的平方根。同样，我们有一个数字 81，这个数字的平方根是 9 (9 * 9 = 81)。

![Square Root in C](img/fd51b7b3e603d80903e4bcf661647b88.png)

在 C 语言编程中，sqrt()函数是一个预定义的库函数，用于计算一个数的平方根。sqrt()函数在 math.h 头文件中定义。所以，我们需要在 c 语言中使用 sqrt()函数的同时编写<math.h>头文件，而且，不用 sqrt 函数就可以求出给定数的平方根。</math.h>

**sqrt()函数的语法**

```

double sqrt( double arg);

```

在上面的语法中，sqrt()函数将单个参数作为 double 来返回其在 double 数据类型中的平方根。

**arg:** 是 sqrt()函数的双数据类型参数。

**返回值:**sqrt 函数以定义的双数据类型返回给定数字的平方根。

#### 注意:我们可以通过显式地将给定的数据类型转换为另一种数据类型来找到 int、float、double 或 long double 数据类型号的平方根。

**求平方根的算法**

1.  声明一个整数变量，如 num。
2.  使用 sqrt()函数将 num 变量作为参数传递，以找到平方根。
3.  打印结果。
4.  退出或终止程序。

### 示例 1:使用 sqrt()函数获取一个数的平方根的程序

让我们考虑一个例子，使用 c 语言中的 sqrt()函数计算给定数字的平方根。

```

#include #include <conio.h>#include <math.h>int main ()
{
	// declaration of the int, float and double variables
	int x, res;
	float y, res1;
	double z, res2;

	x = 289;
	// use the sqrt() function to return integer values 
	res = sqrt(x); 
	printf (" The square root of %d is: %d", x, res);

	// square root of float variable
	y = 12.25;
	// use the sqrt() function to return float values 
	res1 = sqrt(y); 
	printf (" \n The square root of %.2f is: %.2f", y, res1);

           // square root of double variable
	z = 144.00;
	// use the sqrt() function to return double values 
	res2 = sqrt(z); 
	printf (" \n The square root of %.2lf is: %.2lf", z, res2);

	return 0;	
}</math.h></conio.h> 
```

**输出:**

```
The square root of 289 is: 17
The square root of 12.25 is: 3.50
The square root of 144.00 is: 12.00

```

### 示例 2:从用户处获取一个数字并得到平方根的程序

让我们考虑一个例子，通过接收用户的输入来打印一个数字的平方根，然后使用 c 语言中的 sqrt()函数。

```

#include #include <conio.h>#include <math.h>int main ()
{
	// declare an integer variable
	int x;
	double res;
	printf (" Enter any number to get the square root: ");
	scanf (" %d", &x);
	// use the sqrt() function to return integer values 
	res = sqrt(x); 
	printf (" \n The square root of %d is: %.2lf", x, res);

	return 0;	
}</math.h></conio.h> 
```

**输出:**

```
Enter any number to get the square root: 625
The square root of 625 is: 25.00 

```

### 示例 3:使用用户定义函数求平方根的程序

让我们创建一个程序，使用 C 编程语言中的用户定义函数来获取给定数字的平方根。

```

#include #include <conio.h>#include <math.h>// function declaration
double getSqr (int num);

int main ()
{
	// declare an integer variable
	int x;
	double res;
	printf (" Enter any number to get the square root: ");
	scanf (" %d", &x);

	res = getSqr(x); // call the function
	printf (" \n The square root of %d is: %.2lf", x, res);

	return 0;	
}

// function definition
double getSqr ( int num)
{
	double getRes;
	// use sqrt() function to print the square root
	getRes = sqrt (num);
	return getRes;
}</math.h></conio.h> 
```

**输出:**

```
Enter any number to get the square root: 87
The square root of 87 is: 9.33

```

### power()函数

power()是 math.h 头文件的预定义函数，用于计算给定数字的幂。

**pow()函数的语法**

```

int pow( arg, 0.5);

```

pow()函数有两个参数:第一个参数定义了一个变量来获取给定数字的幂或平方根，0.5 是一个默认参数，等于或 1 / 2 = 0.5。

### 示例 4:使用幂()函数计算一个数的平方根的程序

让我们考虑一个例子，用 c 语言中的 power()函数打印一个数的平方根。

```

#include #include <conio.h>#include <math.h>int main ()
{
	// declare an integer variable
	int x;
	double res;
	printf (" Enter any number to get the square root: ");
	scanf (" %d", &x);
	// use the pow() function to return the square root  
	res = pow(x, 0.5); //it takes two argument: input variable and 0.5 is default value
	printf (" \n The square root of %d is: %.2lf", x, res);

	return 0;	
}</math.h></conio.h> 
```

**输出:**

```
Enter any number to get the square root: 1225
The square root of 1225 is: 35.00

```

在上面的程序中，我们从用户那里获取变量 x 的整数值是 1225，并将 x 作为参数传递给 pow()函数，以返回给定数字的幂或平方根。

### 示例 5:不使用 sqrt()函数获取一个数的平方根的程序

让我们考虑一个例子，在不使用 c 语言中预先定义的 sqrt()函数的情况下，打印一个数字的平方根。

```

/* Display the square root of a number without using the sqrt() function in C. */
#include #include <conio.h>int main()
{
	// declaration of the variables
	int num;
	float sqrt, temp;

	printf (" Enter a number to get the square root: ");
	scanf (" %d", &num);

	// divide the given number by 2 and store into sqrt
	sqrt = num / 2;
	temp = 0;

	// use while loop to continuously checks the sqrt is not equal to the temp
	while (sqrt != temp) // Initially temp is 0 and sqrt = num
	{
		temp = sqrt; // assign sqrt to temp

		sqrt = ( num / temp + temp) / 2;
	 } 

	 printf (" \n The square root of %d is %f", num, sqrt);
	 return 0;
}</conio.h> 
```

**输出:**

```
Enter a number to get the square root: 2
The square root of 2 is 1.414214

```

在上面的程序中，我们从用户输入一个数字，我们找到平方根。因此，首先，我们将给定的数字除以 2，并将其存储在 sqrt 变量中。之后，我们用 0 初始化 temp。然后使用不断迭代并检查 sqrt 不等于 temp 的 while 循环，每次迭代时，它都将 sqrt 值赋给 temp，sqrt 通过求解逻辑(num/temp + temp) /2 得到一个新值；然后打印出 2 的平方根是 1.414214。

* * *