# C 语言中的 isgraph()函数

> 原文：<https://www.javatpoint.com/isgraph-function-in-c>

本主题将讨论 C 编程语言中的 isgraph()函数。C 程序设计中的 isgraph()函数用于检查一个字符是否是图形字符。

图形字符是用于在屏幕上显示或打印字符的图形表示字符。这意味着图形字符打印传递的字符时不显示空白、换行符和新的制表符，如(')、' \n '、' \t '，这不被认为是 isgraph()字符。

![isgraph() function in C](img/3a0f604f6c946e7304cee5665291db79.png)

isgraph()函数在 ctype.h 头文件中声明。如果传递的字符是图形字符，isgraph()函数将返回非零值。如果给定的字符不是图形或可打印字符，该函数将返回一个零值。

例如，假设我们向 isgraph 函数输入字符' u '，6，/然后函数检查输入字符是否是图形的。这里我们传递不同的返回非零值的字符。同样，我们将空格(“”)字符传递给了返回零值的 isgraph()函数。

### isgraph()函数的语法

下面是 c 语言中 isgraph()函数的语法。

```

int isgraph( int c);

```

在这里，isgraph()函数包含一个参数来检查有效的图形字符。

### 参数:

“c”变量表示在 isdigit()函数中传递的字符。

### 返回值:

isgraph()函数确定传递的字符是否是图形字符，如果是，该函数返回非零值或零值。

### 示例 1:检查传递的字符是否是图形字符的程序

让我们编写一个简单的程序来检查给定的字符是否是 C 语言中的图形字符。

```

#include #include <conio.h>#include <ctype.h>int main ()
{
	// declare character type variable

	/* use the isgraph () function to check the graphical character. */
	if ( isgraph ('@') )
	{
		printf (" It is a graphical character. \n" );
	}
	else
	{
		printf (" It is not a graphical character. \n");
	}

	// check for new line
	if ( isgraph ('\n' ))
	{
		printf (" It is a graphical character. \n" );
	}
	else
	{
		printf (" It is not a graphical character. \n");
	}

	// check for 'ch character
		if ( isgraph ('Ch') )
	{
		printf (" It is a graphical character. \n" );
	}
	else
	{
		printf (" It is not a graphical character. \n");
	}

	// check for new '\t' tab

		if ( isgraph ('\t' ))
	{
		printf (" It is a graphical character. \n" );
	}
	else
	{
		printf (" It is not a graphical character. \n");
	}

	// check for '#' symbol
		if ( isgraph ('#') )
	{
		printf (" It is a graphical character. \n" );
	}
	else
	{
		printf (" It is not a graphical character. \n");
	}

	// check for white space
		if ( isgraph ( ' ') )
	{
		printf (" It is a graphical character. \n" );
	}
	else
	{
		printf (" It is not a graphical character. \n");
	}

	return 0;
}</ctype.h></conio.h> 
```

**输出:**

```
It is a graphical character.
It is not a graphical character.
It is a graphical character.
It is not a graphical character.
It is a graphical character.
It is not a graphical character.

```

### 示例 2:从用户处获取输入以验证图形字符的程序

让我们编写 C 程序，使用 isgraph()函数输入并验证图形字符。

```

/* input a number from the user to display graphical characters. */
#include #include <ctype.h>int main ()
{
	// declaration of char variables
	char c;

	printf (" \n Enter the graphical character: ");
	scanf (" %c", &c); // get a graphical character

	/* use the isgraph() function to check graphical characters */
	if (isgraph (c))
	{
		printf (" \n '%c' is a graphical character. ", c);
	}
	else
	{
		printf (" \n '%c' is not the graphical character. ", c);
		printf (" \n Please, enter only graphical character. " );
	}
	return 0;
}</ctype.h> 
```

**输出:**

```
Enter the graphical character: 5
'5' is a graphical character.

```

在上面的程序中，我们从用户输入 5 来检查传递的字符是否是图形字符。如果 5 是图形字符，则显示“5 是图形字符”。因此，我们使用 isgraph()函数，以 5 作为参数来验证图形字符。

**2<sup>2</sup>执行:**

```
Enter the graphical character: *
'*' is a graphical character.

```

这里，字符“*”作为参数传递给 isgraph()函数，用于打印图形字符。如果给定的字符是图形字符，函数显示“*是图形字符”。

同样，当我们将空格(')或换行符(\n)传递给 isgraph()函数以验证图形字符时。这里的''空格或新行不是图形函数，所以 isgraph()返回“不是图形字符”。

### 示例 3:用 C 语言打印所有图形字符的程序

让我们编写一个简单的程序来检查和显示 C 编程语言中所有现有的图形字符。

```

#include #include <ctype.h>#include <conio.h>int main ()
{
	// declare and initialize the variables
	int i = 0;
	int count = 0; // it counts the total graphical characters

	// This loop continuously iterates till condition is satisfied
	while ( i < 256)
	{
		/// use isgraph() function to validate the graphical character
		if ( isgraph(i) != 0)
		{
			printf (" %c", i); // It only print the graphical characters
			++count; // update the count by 1
		}	
		++i; // increment i by 1
	}
	printf (" \n There are total %d valid graphical characters. \n", count);

	getch();
}</conio.h></ctype.h> 
```

**输出:**

```
! " # $ % & ' ( ) * + , - . / 0 1 2 3 4 5 6 7 8 9 : ; < = > ? @ A B C D E F G H I J K L M N O P Q R S T U V W X Y Z [ \ ] ^ _ ` a b c d e f g h i j k l m n o p q r s t u v w x y z { | } ~ 
 There are total 94 valid graphical characters.

```

在上面的程序中，我们使用 isgraph()函数来打印 C 库中所有可用的图形字符。因此，我们用 0 声明并初始化了整数变量“I”和“count”，以打印和计数 c 中的有效图形字符。最后，它打印全部有效的图形字符。

* * *