# 逻辑非(！)C 中的运算符

> 原文：<https://www.javatpoint.com/logical-not-operator-in-c>

本节将讨论逻辑非(！)运算符。正如我们已经知道的，逻辑运算符用于通过组合给定表达式上的两个或多个条件来执行逻辑运算。如果操作数的逻辑条件为真，运算符将返回真布尔值或 1。否则，它将返回一个假布尔值或 0。逻辑运算符分为三个部分:**逻辑与、逻辑或和逻辑非运算符。**

![Logical NOT (!) Operator in C](img/49ae4e970e592046855bbf2f2f3970c2.png)

**逻辑与运算符**用于检查给定表达式中两个或多个操作数的条件是否为真；“与”运算符返回真或非零(1)值。否则，它将返回一个 false 或 0 值。因此，我们可以说逻辑 AND 运算符只能在两个操作数的条件都为真时在表达式中执行，如果有任何条件不为真，则返回 0。逻辑“与”操作符被表示为双“与”& &符号。

**语法:**

```

(A > b && b > c)

```

**逻辑 OR 运算符**用于检查两个操作数(A & B)条件，如果其中一个操作数或表达式为真，则运算符返回真布尔值。同样，如果没有表达式为真，它将返回一个假值或零值。逻辑“或”运算符表示为双管“||”符号。

**语法:**

```

(A > B) || (A < C)

```

### 逻辑非运算符

逻辑非运算符表示为“！”符号，用于反转任何给定表达式或条件的结果。如果表达式的结果为非零值或真值，则结果将反转为零值或假值。同样，如果条件的结果为假或 0，非运算符将反转结果并返回 1 或真。

例如，假设用户输入的非零值是 5，则逻辑 NOT(！)运算符返回 0 或假布尔值。如果用户输入零(0)值，运算符将返回真布尔值或 1。

**逻辑非运算符的语法**

```

! (condition); // It '!' represents the NOT operator

```

给你，那个“！”符号表示逻辑“非”运算符，它将给定条件的结果反相。

### 逻辑非运算符的真值表:

下面是 C 语言中逻辑非运算符的真值表

```

condition	!(condition)
1             0
0             1

```

### 示例 1:在 C 语言中使用逻辑非运算符的程序

让我们创建一个简单的程序来反转 C 编程语言中操作数的给定条件。

```

/* demonstration the use of the logical not operator in C. */
#include #include <conio.h>int main ()
{
	// declare an initialize x variable
	int x = 5;

	// display the result generated using the NOT (!) operator
	printf (" The return value = %d \n", ! (x == 5));
	printf (" The return value = %d \n", ! (x != 5));
	printf (" The return value = %d \n", ! (x >= 3));
	printf (" The return value = %d \n", ! (x < 3));

	return 0;
}</conio.h> 
```

**输出:**

```
The return value = 0
The return value = 1
The return value = 0
The return value = 1

```

在上面的程序中，我们使用了 NOT(！)运算符来反转各种表达式的结果，比如变量 x 的条件等于 5，这是真的。尽管如此，“非”运算符还是会反转结果并返回 0。同样，我们定义了条件(x！=5)，但逻辑运算符更改了其结果并返回 1，以此类推。

### 示例 2:输入一个数字来执行逻辑非运算符的程序

让我们创建一个简单的程序，使用逻辑 NOT(！)运算符。

```

/* demonstration the use of the logical not operator in C. */
#include #include <conio.h>int main ()
{
	// declare an initialize x variable
	int x, n;
	printf (" Enter the number: ");
	scanf ("%d", &x);

	n = !x; // use logical not operator to reverse the condition
	printf (" The result of x: %d", n); // display the result

	return 0;
}</conio.h> 
```

**输出:**

```
Enter the number: 7
The result of x: 0

```

在上面的程序中，我们从用户那里输入一个整数 7，并将其存储到 x 变量中。在那之后，逻辑非(！)运算符反转 x 的值(非零)并返回零(0)以打印 x 的结果。

**2<sup>2</sup>执行:**

```
Enter the number: 0
The result of x: 1

```

同样，我们从用户输入零(0)并使用逻辑非(！)运算符将 x 的值反转为非零值，即 1。

### 示例 3:使用逻辑 AND (&&)、OR (||)和 NOT(！)操作员

让我们编写一个简单的程序，使用逻辑 AND (&&)、逻辑 OR (||)和逻辑 not(！)运算符。

```

#include #include <conio.h>int main ()
{
	int yr; // declare int type variable

	printf (" Enter the year: ");
	scanf ("%d", &yr);

	// use the if..else statement to check the condition
	/* '&&' (AND) operator to validate both operand, '||' (OR) operator check ny given expressions are true,
	 '!' (NOT) check the result of (yr % 100 != 0). */ 
	if ( (yr % 400 == 0) || (yr % 4 == 0 && yr % 100 != 0))
	{
		printf (" %d is a leap year. \n", yr);
	}
	else
	{
		printf (" %d is not a leap year. \n", yr);
	}
	return 0;
}</conio.h> 
```

**输出:**

```
Enter the year: 2020
2020 is a leap year.

```

在上面的程序中，我们输入 2020，然后通过定义 if 来检查给定的年份...else 语句。在这个陈述中，我们定义了两个条件；

1.  给定的年份除以 400，等于 0。然后，我们使用逻辑或运算符来检查左或右操作数条件是否为真。
2.  在第二个条件中，给定的年份除以 4 和 100。但是当我们用 4 除 2020 年，等于 0。同样，我们把 2020 年除以 100，也不等于 0。所以，显示“2020 年是闰年”的两个条件都成立。
3.  但是当我们进入 2021 年时，它会打印给定的结果“2021 年不是闰年”。

**2<sup>2</sup>执行:**

```
Enter the year: 2021
2021 is not a leap year.

```

**示例 4:使用“与”、“或”和“非”逻辑运算符**检查不同条件的程序

让我们编写一个程序，用 c 语言中的 AND、OR 和 NOT 逻辑运算符演示给定操作数的多重条件

```

/* program to check the various condition using the logical NOT operator in c. */
#include #include <conio.h>int main ()
{
	// declare and initialize variables
	int a = 20, b = 15;
	int n1 = 15, n2 = 17;

	// use logical 'AND' and logical 'NOT' operator
	if (a > b && a != 0)
	{
		printf (" The AND (&&) operator said: Both conditions are true. \n ");		
	}

	// use logical 'OR' and logical 'NOT' operator
	if (n1 > n2 || n2 != 15)
	{
		printf (" The OR (||) operator said: Only one condition is true. \n ");
	}

	if ( ! (a > b && a != 0 ))
	{
		printf (" The NOT (!) operator: Here both conditions are true. \n ");		
	}
	else
	{
		printf (" The NOT (!) operator: Here, both conditions are true. " 
		" But, the status of the condition is reversed as false. \n");
	}
	return 0;
}</conio.h> 
```

**输出:**

```
The AND (&&) operator is said: Both conditions are true.
The OR (||) operator is said: Only one condition is true.
The NOT (!) operator: Here, both conditions are true. But, the status of the condition is reversed as false.

```

* * *