# 自我参照结构

> 原文：<https://www.javatpoint.com/self-referential-structure>

自指结构是指向同一类型结构的结构。它包含一个或多个最终指向同一结构的指针。

*   结构是在 C 和 C++ 中用户定义的数据结构类型。
*   创建结构的主要好处是它可以保存不同的预定义数据类型。
*   它是用 struct 关键字和该 struct 关键字后面的结构名称初始化的。
*   我们可以很容易地在同一个结构中获取不同的数据类型，如**整数值、浮点、char、**等。
*   它降低了程序的复杂性。
*   使用单一结构可以将值和数据集保存在单一位置。
*   在 C++ 编程语言中，放置结构关键字是可选的或非强制的，但在 C 编程语言中是强制的。
*   自引用结构在创建其他数据结构(如链表)中起着非常重要的作用。
*   在这种类型的结构中，相同结构的对象指向相同的数据结构，并引用相同结构的数据类型。
*   它可以有一个或多个指针指向与其成员相同类型的结构。
*   自指结构广泛应用于动态数据结构，如**树、链表、**等。

![Self-referential structure](img/1705fba0a4bfda03aeefd260a7db8943.png)

## 为什么我们需要一个自我参照结构？

自引用结构在链表、树、图和许多其他数据结构中起着至关重要的作用。通过使用该结构，我们可以轻松高效地实现这些数据结构。对于定义一个特定的节点，结构起着非常重要的作用。在链表中，结构用于存储数据信息和给定链表中下一个节点的地址。主要是数据部分为整数类型，链接地址部分为指针类型，保存下一个节点的地址，以便最终能为链接。

众所周知，链表的作用是用来存储相同类型的数据元素，其中的地址位置不在连续的差上。在这个线性链表中，当前节点保存下一个节点的地址，因此它最终形成当前节点和下一个节点之间的链接。

在这里的链表中，我们将定义一个公共结构，其中包含了数据和地址指针来承载下一个节点的地址，所以要形成这个多个节点，我们从每个节点使用这个节点结构。

与静态数据结构(如数组)不同，在静态数据结构中，数组的大小限制了可以轻松插入数组的元素数量，而自引用结构可以动态扩展或收缩。

像在自引用结构中插入或删除节点这样的操作涉及指针的直接更改。

## 合框架

*   链表是一种有用的数据存储方法，用 C 语言实现非常容易。
*   几种链表，包括**单链表、双链表、**和**二叉树。**
*   每种类型都适合特定类型的数据存储。
*   这些列表的一个共同点是，数据项之间的链接是由包含在数据项本身中的信息以指针的形式定义的。
*   链表明显不同于数组，数组中数据项之间的链接是由数组的布局和存储产生的。

在这里，我们将使用链表概念更详细地讨论自指结构。

让我们使用下面提到的例子来更详细地理解自指结构的概念:

***示例 1:在 C 编程语言中创建随机自引用结构。*T3】**

```

// Dummy Self-referential structure in C language 
struct node                                           // Creating a node of structure type contains data 
// part of integer type and a pointer of structure type to 
// hold the address of the next node
{
            int d1 ;                          // data 1 of integer type
            int d2 ;                         // data 2 of integer type
struct node * link ;            // Self referential structure link is pointing the same
// structure of the type node
} ;
Int main()
{
          Struct node obj;                                  // Creating an object of the node type, this object is // consists of three parts one is data 1 and 
// second is of data 2, and third is of link type pointer 
// carries the address of the next node.
          Return 0 ;
}

```

***示例 2:在 python 编程语言中创建随机自引用结构。*T3】**

```

# Dummy Self-referential structure in python language 
class node:                                             # Creating a node that contains data 
# part of and a pointer of node type to 
# hold the address of the next node
    def __init__(self):
        self.data1=0
        self.data2=' '
        self.link=None                    # Self-referential structure link is pointing the same
# structure of the type node

if __name__ == '__main__':
    ob=node()                              
# Creating a object of node type, this object is 
# consists of three parts one is data 1 and 
# second is of data 2 and third is of link type pointer 
# carries the address of the next node

```

## 自我参照结构的类型

1.  单链接自指结构
2.  多重链接自参照结构

### 单链接自指结构

顾名思义，我们可以很容易地预测这些结构由单个链接组成，主要是结构类型的唯一一个指向同一结构的指针链接。为了更好地理解它，我们可以把这个概念和单链表联系起来。

在单链表中，只有一个指针携带下一个节点的地址，这个指针变量本身就是结构节点类型。它主要用于我们想通过从各种地址中取出不同的数据项，并通过将一个数据项的地址存储到另一个节点的链接部分来连接所有数据项来存储它们的时候。这样，我们可以通过使用这些连接链接轻松地连接所有数据项。

让我们借助一个例子来看看单链接自指结构的工作原理:

```

// Single link self-referential structure implementation in C language
#include<stdio.h>
#include<stdlib.h>
struct node
{
	int info ;
	struct node *link ;                  // Self-referential structure link is pointing the same
// structure of the type node
};

struct node *START = NULL ;   // start pointer to control the linked list //
struct node* createnode() ;
void insertatlast() ;          // insert node at last //
void deleteatfirst() ;          // delete node at first //
void viewlist() ;
void insertatfirst() ;
int getlength() ;
int menu() ;
void insertafteranynode() ;
void deleteatlast() ;
void deleteatposition() ;

struct node* createnode()           // create node dynamically //
{
    struct node *n ;
    n = malloc( sizeof(struct node) ) ;
	return ( n ) ;
}
void insertatlast()
{   
    struct node *temp ,*t ;
	temp = createnode() ;
	printf( "Enter the data in node \n " ) ;
	scanf( " %d" , &temp->info ) ;
	temp->link = NULL ;
	if ( START == NULL )
	START = temp ;
	else
	{
		t = START ;
		while ( t->link != NULL )
		{
			t = t->link ;
		}
		t->link = temp ;
	}
}
void deleteatfirst()                  // delete node at first //
{
	if ( START == NULL )
	printf ( "List is empty \n " ) ;
	else
	{
		struct node *q ;
		q = START ;
		START = START->link ;
		free( q ) ;
	}
}
void viewlist()
{   struct node* t ;
	if ( START == NULL )
	{
		printf ( "No List \n " ) ;
	}
	else
	{
		t = START ;
		while ( t != NULL )
		{
			printf ( " %d" , t->info ) ;
			t = t->link ;
		}
	}
}
void insertatfirst()
{  struct node*New ;
   New = createnode() ;
   printf ( "Enter the data in node \n " ) ;
   scanf ( " %d" , &New->info ) ;

   if ( START == NULL )
   START = New ;
   else
   {
   	New->link = START ;
   	START = New ;
   }
}
int getlength()
{
	int count = 0 ;
	struct node* t ;
	if ( START == NULL )
	printf ( "List is empty \n " ) ;
	else
	{
		t =START ;
		while ( t != NULL )
		{
			count = count + 1 ;
			t = t->link ;
		}
	}
	return count ;
}
void insertafteranynode()
{
	int position ;
	struct node* newnode ,*t ;
	if ( START == NULL )
	printf ( "List is empty \n " ) ;
	else
	{
		printf ( "Enter position after which you want to add: \n " ) ;
		scanf ( " %d" , &position ) ;
		if ( position > getlength() )
		{
			printf ( "Wrong position \n " ) ;
			insertafteranynode() ;      // recursion //

		}
		else
		{
			int i = 1 ;
			newnode = createnode() ;
			printf ( "Enter Data \n " ) ;
			scanf ( " %d" , &newnode->info ) ;
			newnode->link = NULL ;
			if ( START == NULL )
			START = newnode ;
			else
			{
				t = START ;
				while ( i < position )
				{
					t = t->link ;
					i++ ;
				}
				newnode->link = t->link ;
				t->link = newnode ;
			}
		}
	}
}
void deleteatlast()
{
	struct node* t , *q ;
	if ( START == NULL )
	{
		printf ( "List is empty \n " ) ;
    }
	else
	{
		t = START ;
		q = START ;
		while ( t->link != NULL )
		{
			q = t ;
			t = t->link ;
		}
		if ( t == START )
		{
			START == NULL ;
		}
		else
		{
		q->link = NULL ;
		free( t ) ;
    	}
	}
}
void deleteatposition()
{
	struct node *t , *q ;
	int position , i = 1 ;
	t = START ;
	if ( START == NULL)
	{
		printf ( "List is empty \n " ) ;
	}
	else
	{
		printf ( "Enter position after which you want to delete: \n " ) ;
		scanf ( " %d" , &position ) ;
		if ( position > getlength() )
		{
			printf ( "Wrong position \n " ) ;
			deleteatposition() ;                  // recursion //

		}
		else
		{
			while ( i < position )
			{   
			    q = t ;
				t = t->link ;
				i++ ;
	        }
	    if ( t == START )
	    {
	       START == NULL ;	
		}
		else
		{
	        q->link = t->link ;
	        free( t ) ;
        }
		}
	}
}
int menu()
{
	int ch ;
	printf ( " \t \t \t 1.ADD NODE LAST IN LINK \n " ) ;
	printf ( " \t \t \t 2.ADD NODE AT FIRST IN LINK \n " ) ;
	printf ( " \t \t \t 3.VIEW LIST IN LINK \n " ) ;
	printf ( " \t \t \t 4.DELETE NODE AT FIRST IN LINK \n " ) ;
            printf( " \t \t \t 5\. TO SEE THE LENGTH OF LIST \n " ) ;
            printf ( " \t \t \t 6\. INSERT NODE IN BETWEEN \n " ) ;
            printf ( " \t \t \t 7.DELETE NODE AT LAST IN LINK \n " ) ;
            printf ( " \t \t \t 8.DELETE NODE AT SPECIFIC POSITION IN LINK \n " ) ;
	printf ( " \t \t \t 9.EXIT \n " ) ;
	printf ( "ENTER THE CHOICE \n " ) ;
	scanf ( " %d" , &ch ) ;
	return( ch ) ;
}
void main()
{   int k ;
	while ( 1 )
	{
	switch ( menu() )
	{
	 	case 1 :
			insertatlast() ;
			break ;
		case 2 :
			insertatfirst() ;
			break ;
		case 3 :
			viewlist() ;
			break ;
		case 4 :
			deleteatfirst() ;
			break ;
		case 5 :
		    k = getlength() ;
		    printf ( "THE LENGTH OF THE LIST IS %d \n " , k ) ;
		    break ;
		case 6 :
			insertafteranynode() ;
			break ;
		case 7 :
			deleteatlast() ;
			break ;
		case 8 :
			deleteatposition() ;
			break ;
		case 9 :
			exit( 0 ) ;
			break ;
	    default :
	    	printf ( " Not available \n " ) ;
}
}
}

```

***上述程序的输出为:***

![Self-referential structure](img/7cf32ce90ccbf0c5f846942a688c2f44.png)
![Self-referential structure](img/2c6b609ef081dde30a7846860a68ff11.png)

```

# Single link self-referential structure implementation in Python language
class node:
	def __init__(self):
		self.d1=0
		self.d2=0
		self.link=None

if __name__ == '__main__':
	obj1=node()                               # Node1

	                                                      # Initialization
	obj1.link = None
	obj1.d1 = 17
	obj1.d2 = 14

	obj2=node()                                 # Node2

	                                                       # Initialization
	obj2.link = None
	obj2.d1 = 36
	obj2.d2 = 24

	                                                        # Linking obj1 and obj2
	obj1.link = obj2

	                                                         # Accessing data members of obj2 using obj1
	print(obj1.link.d1)
	print(obj1.link.d2)

```

***上述程序的输出为:***

```
36

24 

```

### 多重链接自参照结构

顾名思义，我们可以很容易地预测这些类型的结构由多个链接组成，这里我们将使用指向同一结构的两个结构类型的指针链接，为了更好地理解它，我们可以将这个概念与双链表联系起来。

在双向链表中，两个指针携带下一个节点和上一个节点的地址，指针变量本身就是结构节点类型。主要用于当我们想通过从各种地址中取出不同的数据项，并通过将一个数据项的地址存储到另一个节点的链接部分来连接所有数据项来存储不同的数据项时；这样，我们可以通过使用这些连接链接轻松地连接所有数据项。

让我们借助一个例子来看看多链接自指结构的工作原理:

```

// Multiple link self-referential structure implementation in C language
#include<stdio.h>
#include<stdlib.h>
struct node
{
	int info ;
	struct node *prev ;            // Self-referential structure link is pointing the same
// structure of the type node but to the previous node

	struct node *next;                // Self-referential structure link is pointing the same
// structure of the type node but to the next node

} ;

struct node * START = NULL ;            // Start pointer of the list and initially it must be null, // represents that no node is present
void insertnodeatfirst() ;
void deleteatfirst() ;
void viewlist() ;
int menu() ;
void insertnodeatfirst()                              // Inserting the node at first
{
	struct node * newnode ;
	newnode = malloc( sizeof( struct node ) ) ;
	printf ( "Enter Data: \n " ) ;
	scanf ( " %d" , &newnode->info ) ;
	newnode->prev = NULL ;
	newnode->next = NULL ;
	if ( START == NULL )
	START = newnode ; 
	else
	{
		START->prev = newnode ;
		newnode->next = START ; 
		START = newnode ;
	}
}
void deleteatfirst()                     // deleting the first node
{
	struct node * temp ;
	if ( START == NULL )
	printf ( "List is empty \n " ) ;
	else
	{
	temp = START ;
	START = START->next ;
	START->prev = NULL ;
	free( temp ) ;
    }
}
void viewlist()                               // displaying all the nodes in the list
{
	struct node * t ;
	if ( START == NULL )
	printf ( "List is empty \n " ) ;
	else
	{
		t = START ;
		while ( t != NULL )
		{
			printf ( " %d \n " , t->info ) ;
			t = t->next ;		
		}
	}
}
int menu()
{   int n ;
	printf ( " \t \t \t 1\. VIEW LIST \n " ) ;
	printf ( " \t \t \t 2\. INSERT AT FIRST IN LIST \n " ) ;
	printf ( " \t \t \t 3\. DELETE AT FIRST IN LIST \n " ) ;
	printf ( " \t \t \t 4\. EXIT \n " ) ;
    printf ( "ENTER YOUR CHOICE \n " ) ;
    scanf ( " %d" , &n ) ;
    return ( n ) ;
}
int main()
{  
   while ( 1 )
    {
	switch ( menu() )
	{
		case 1 :
			viewlist() ;
			break ;
		case 2 :
			insertnodeatfirst() ;
			break ;
		case 3 :
			deleteatfirst() ;
			break ;
		case 4 :
		    exit ( 1 ) ;
			break ;	
		default :
			printf ( " NOT AVAILABLE \n " ) ;
	}
}
}

```

***上述程序的输出为:***

![Self-referential structure](img/acd4846c814f0d3543bb2f7d3d5b86e5.png)

```

# Multiple link self-referential structure implementation in Python language
class node:
  def __init__(self):
    self.data = 0
    self.prev = None
    self.next = None

if __name__ == '__main__':
  obj1=node()                                              # Node1

                                                                     # Initialization
  obj1.prev = None
  obj1.next = None
  obj1.data = 15

  obj2=node()                                             # Node2

                                                                     # Initialization
  obj2.prev = None
  obj2.next = None
  obj2.data = 20

  obj3 = node()                                             # Node3

                                                                       # Initialization
  obj3.prev = None
  obj3.next = None
  obj3.data = 25

                                                                       # Forward links
  obj1.next = obj2
  obj2.next = obj3

                                                                        # Backward links
  obj2.prev = obj1
  obj3.prev = obj2

                                                                       # Accessing data of obj1, obj2 and obj3 by obj1
  print(obj1.data , end='\t')
  print(obj1.next.data , end='\t')
  print(obj1.next.next.data)

                                                                      # Accessing data of obj1, obj2 and obj3 by obj2
  print(obj2.prev.data , end='\t')
  print(obj2.data , end='\t')
  print(obj2.next.data)

                                                                      # Accessing data of obj1, obj2 and obj3 by obj3
  print(obj3.prev.prev.data , end='\t')
  print(obj3.prev.data , end='\t')
  print(obj3.data)

```

***上述程序的输出为:***

```
15            20            25
15            20            25
15            20            25   

```

* * *