# C++ 标识符

> 原文：<https://www.javatpoint.com/cpp-identifiers>

程序中的 C++ 标识符用于引用变量、函数、数组或程序员创建的其他用户定义的数据类型的名称。它们是任何语言的基本要求。每种语言都有自己的标识符命名规则。

简而言之，我们可以说 C++ 标识符代表程序中的基本元素，如下所示:

*   **常数**
*   **变量**
*   **功能**
*   **标签**
*   **定义的数据类型**

**一些命名规则在 C 和 C++ 中都很常见。它们如下:**

*   仅允许字母字符、数字和下划线。
*   标识符名称不能以数字开头，即第一个字母应该是字母。在第一个字母之后，我们可以使用字母、数字或下划线。
*   在 C++ 中，大小写字母是不同的。因此，我们可以说 C++ 标识符区分大小写。
*   声明的关键字不能用作变量名。

**例如，**假设我们有两个标识符，分别命名为‘名字’和‘名字’。这两个标识符会有所不同，第一种情况下是大写字母“N”，第二种情况下是小写字母。因此，它证明标识符区分大小写。

### 有效标识符

**以下是有效标识符的示例:**

```

Result
Test2
_sum
power

```

### 无效的标识符

**以下是无效标识符的示例:**

```

Sum-1   // containing special character '-'.
2data    // the first letter is a digit. 
break    // use of a keyword.  

```

#### 注意:标识符不能用作关键字。它可能与关键字不冲突，但强烈建议不要将关键字用作标识符名称。您应该始终使用一致的方式来命名标识符，以便您的代码更加可读和可维护。

C 和 C++ 的主要区别在于变量名称的长度限制。ANSI C 只考虑名称中的前 32 个字符，而 ANSI C++ 对名称的长度没有限制。

常量是指固定值的标识符，在程序执行过程中不变。C 和 C++ 都支持各种文字常量，它们都有任何内存位置。例如 123、12.34、037、0X2 等。是文字常量。

**让我们看一个简单的例子来理解标识符的概念。**

```

#include <iostream>
using namespace std;
int main()
{
    int a;
    int A;
    cout<<"Enter the values of 'a' and 'A'";
    cin>>a;
    cin>>A;
    cout<<"\nThe values that you have entered are : "<<a<<" , "<<A;
    return 0;
}

```

在上面的代码中，我们声明了两个变量‘A’和‘A’。这两个字母是相同的，但它们将作为不同的标识符。我们知道标识符区分大小写，因此两个标识符将具有不同的存储位置。

**输出**

![C++ Identifiers](img/9184f4813638f8ec601bb8daed515e51.png)

### 关键词是什么？

关键字是对编译器有特殊意义的保留字。它们是为特殊目的保留的，不能用作标识符。例如，' For '，' break '，' while '，' if '，' else '等。是预定义的单词，其中预定义的单词是编译器已经知道其含义的单词。而标识符是程序员为程序元素定义的名称，例如变量、函数、数组、对象、类。

**标识符和关键词的区别**

**以下是标识符和关键词的区别列表:**

| 标识符 | 关键词 |
| 标识符是程序员为程序的基本元素定义的名称。 | 关键字是保留字，其含义为编译器所知。 |
| 它用于标识变量的名称。 | 它用于指定实体的类型。 |
| 它可以由字母、数字和下划线组成。 | 它只包含字母。 |
| 它可以同时使用小写和大写字母。 | 它只使用小写字母。 |
| 除下划线外，不能使用任何特殊字符。 | 它不能包含任何特殊字符。 |
| 标识符的起始字母可以是小写、大写或下划线。 | 只能以小写字母开头。 |
| 它可以分为内部和外部标识符。 | 不能进一步分类。 |
| 例如测试、结果、求和、幂等。 | 例子有‘for’、‘if’、‘else’、‘break’等。 |

* * *