# C++ 中的 sizeof()运算符

> 原文：<https://www.javatpoint.com/sizeof-operator-in-cpp>

sizeof()是一个运算符，用于计算数据类型、常数和变量的大小。它是一个编译时运算符，因为它在编译时返回任何变量或常数的大小。

大小由 sizeof()运算符计算，是计算机中占用的内存量。

**sizeof()运算符的语法如下:**

```

sizeof(data_type);

```

在上面的语法中，data_type 可以是数据、变量、常数、联合、结构或任何其他用户定义的数据类型。

**sizeof()运算符可应用于以下操作数类型:**

*   **当操作数是数据类型时**

如果 **sizeof()** 运算符的参数包含变量的数据类型，则 **sizeof()** 运算符将返回数据类型的大小。

**我们通过一个例子来理解这个场景。**

```

#include <iostream>
using namespace std;
int main()
{
  // Determining the space in bytes occupied by each data type.
  std::cout << "Size of integer data type : " <<sizeof(int)<< std::endl;
  std::cout << "Size of float data type : " <<sizeof(float)<< std::endl;
  std::cout << "Size of double data type : " <<sizeof(double)<< std::endl;
  std::cout << "Size of char data type : " <<sizeof(char)<< std::endl;
  return 0;
}

```

在上面的程序中，我们使用 size of()运算符评估了内置数据类型的大小。正如我们所知，int 占用 4 个字节，float 占用 4 个字节，double 占用 8 个字节，char 占用 1 个字节，sizeof()运算符显示了相同的结果，我们可以在下面的输出中观察到。

**输出**

![sizeof() operator in C++](img/fe7f759812db948d2e1af2e615e1aa8a.png)

*   **当操作数是类类型时。**

```

#include <iostream>
using namespace std;
class Base
{
int a;
};
int main()
{
Base b;
std::cout << "Size of class base is : "<<sizeof(b) << std::endl;
return 0;
}

```

在上面的程序中，我们已经计算了类的大小，它有一个整数变量。输出将是 4 个字节，因为 int 变量占用 4 个字节。

**输出**

![sizeof() operator in C++](img/8d672fc136805fee25720d4c4e814111.png)

**如果我们在一个类中再添加一个整数变量，那么代码看起来像:**

```

#include <iostream>
using namespace std;
class Base
{
    int a;
    int d;
};
int main()
{
  Base b;
  std::cout << "Size of class base is : "<<sizeof(b) << std::endl;
  return 0;
}

```

在上面的代码中，我们又增加了一个整数变量。在这种情况下，类的大小将是 8 字节，因为 **int** 变量占用 4 字节，所以两个整数变量占用 8 字节。

**输出**

![sizeof() operator in C++](img/e1fb642cf6267c8f6cf739aaaf8b2cd9.png)

**如果我们在上面的代码中添加一个 char 变量，那么代码看起来像:**

```

#include <iostream>

using namespace std;

class Base
{
    int a;
    int d;
    char ch;
};
int main()
{
  Base b;
  std::cout << "Size of class base is : "<<sizeof(b) << std::endl;
    return 0;
}

```

在上面的代码中，类有两个整数变量和一个字符变量。根据我们的计算，类的大小将等于 9 个字节(int+int+char)，但由于结构填充的概念，这是错误的。

**输出**

![sizeof() operator in C++](img/023f7a762981f6df50a4a7759a7ed1ea.png)

*   **当操作数是数组类型时。**

```

#include <iostream>
using namespace std;
 int main()
{
  int arr[]={10,20,30,40,50};
  std::cout << "Size of the array 'arr' is : "<<sizeof(arr) << std::endl;
  return 0;
}

```

在上面的程序中，我们已经声明了一个包含五个元素的整型数组。我们已经使用 **sizeof()** 运算符评估了数组的大小。根据我们的计算，数组的大小应该是 20 字节，因为 int 数据类型占用 4 字节，数组包含 5 个元素，所以这个数组占用的总内存空间是 5*4 = 20 字节。 **sizeof()** 运算符也显示了相同的结果，我们可以在以下输出中观察到。

**输出**

![sizeof() operator in C++](img/fac9d50f8f87126c0135414bb93014bf.png)

**让我们考虑一个数组的另一个场景。**

```

#include <iostream>
using namespace std;
void fun(int arr[])
{
    std::cout << "Size of array is : " <<sizeof(arr)<< std::endl;
}
int main()
{
  int arr[]={10,20,30,40,50};
  fun(arr);
  return 0;
}

```

在上面的程序中，我们已经尝试使用函数打印数组的大小。在这种情况下，我们创建了一个整数类型的数组，并将“ **arr** 传递给函数 **fun()** 。 **fun()** 将返回整数指针的大小，即 **int*** ，在 64 位操作系统中 int*的大小为 8 字节。

**输出**

![sizeof() operator in C++](img/444216ae2703eba1886ff98ed3141ab3.png)

*   **当操作数是指针类型时。**

```

#include <iostream>
using namespace std;
int main()
{
    int *ptr1=new int(10);
    std::cout << "size of ptr1 : " <<sizeof(ptr1)<< std::endl;                                                                                                                                                                                                                                
   std::cout << "size of *ptr1 : " <<sizeof(*ptr1)<< std::endl;
   char *ptr2=new char('a');
   std::cout <<"size of ptr2 : " <<sizeof(ptr2)<< std::endl;
   std::cout <<"size of *ptr2 : "<<sizeof(*ptr2)<< std::endl;
   double *ptr3=new double(12.78);
    std::cout <<"size of ptr3 : " <<sizeof(ptr3)<< std::endl;
   std::cout <<"size of *ptr3 : "<<sizeof(*ptr3)<< std::endl;
    return 0;
}

```

在上面的程序中，我们已经确定了指针的大小。所有数据类型的指针大小都将保持不变。如果计算机有 32 位操作系统，那么指针的大小将是 4 字节。如果计算机有 64 位操作系统，那么指针的大小将是 8 字节。我在 64 位上运行这个程序，所以输出将是 8 字节。现在，如果我们向指针提供“*”符号，那么输出取决于数据类型，例如，*ptr1 是整数类型，这意味着 sizeof()运算符将返回 4 个字节，因为 int 数据类型占用 4 个字节。

**输出**

![sizeof() operator in C++](img/fbe441e13b1e3d5092d4e3e5ab7e75e4.png)

*   **当操作数是表达式时。**

```

#include <iostream>
using namespace std;

int main()
{
   int num1;
   double num2;
   cout << sizeof(num1+num2);
     return 0;
}

```

在上面的程序中，我们已经分别声明了 int 和 double 类型的两个变量 num1 和 num2。int 的大小是 4 字节，double 的大小是 8 字节。结果将是变量，它是占用 8 个字节的双精度类型。

**输出**

![sizeof() operator in C++](img/3d081d3edf9699a042c6787e8da70371.png)

* * *