# C++ 引用

> 原文：<https://www.javatpoint.com/cpp-references>

到目前为止，我们已经了解到 C++ 支持两种类型的变量:

*   普通变量是包含某种类型的值的变量。例如，我们创建一个 int 类型的变量，这意味着该变量可以保存 integer 类型的值。
*   指针是存储另一个变量地址的变量。可以取消对它的引用，以检索该指针指向的值。
*   C++ 还支持另一个变量，即引用。它是一个变量，充当另一个变量的别名。

## 如何创建引用？

只需使用&运算符即可创建引用。当我们创建一个变量时，它会占用一些内存位置。我们可以创建变量的引用；因此，我们可以通过使用变量的名称或引用来访问原始变量。例如，

```

int a=10;

```

现在，我们创建上述变量的引用变量。

```

int &ref=a;

```

上面的语句意味着‘ref’是‘a’的引用变量，即我们可以用‘ref’变量代替‘a’变量。

## C++ 提供两种类型的引用:

*   对非常值的引用
*   作为别名的引用

**非常数值参考**

它可以通过使用&运算符和引用类型变量来声明。

```

#include <iostream>
using namespace std;
int main()
{
int a=10;
int &value=a;
std::cout << value << std::endl;
return 0;
}

```

**输出**

```
 10 

```

**作为别名的引用**

别名引用是被引用变量的另一个名称。

**例如**

```

int a=10;   // 'a' is a variable.
int &b=a; // 'b' reference to a.
int &c=a; // 'c' reference to a.

```

**我们来看一个简单的例子。**

```

#include <iostream>
using namespace std;
int main()
{
int a=70; // variable initialization
int &b=a;
int &c=a;
std::cout << "Value of a is :" <<a<< std::endl;
std::cout << "Value of b is :" <<b<< std::endl;
std::cout << "Value of c is :" <<c<< std::endl;
return 0;}

```

在上面的代码中，我们创建了一个包含值“70”的变量“a”。我们已经声明了两个引用变量，即 b 和 c，它们都引用同一个变量“a”。因此，我们可以说‘a’变量可以被‘b’和‘c’变量访问。

**输出**

```
 Value of a is :70 
Value of b is :70 
Value of c is :70 

```

## 引用的属性

**以下是引用的属性:**

初始化

它必须在声明时初始化。

```

#include <iostream>
using namespace std;
int main()
{
int a=10; // variable initialization
int &b=a; // b reference to a
std::cout << "value of a is " <<b<< std::endl;
return 0;
}

```

**在上面的代码中，我们已经创建了一个引用变量，即‘b’。在声明时，“a”变量被赋给“b”。如果我们在声明时没有赋值，那么代码看起来像:**

```

int &b;
&b=a;  

```

上面的代码将引发编译时错误，因为在声明时没有分配“a”。

**输出**

```
 value of a is 10 

```

**重新分配**

不能重新分配意味着不能修改引用变量。

```

#include <iostream>
using namespace std;
int main()
{
int x=11; // variable initialization
int z=67;
int &y=x; // y reference to x
int &y=z; // y reference to z, but throws a compile-time error.
return 0;}

```

在上面的代码中，“y”引用变量指的是“x”变量，然后将“z”赋给“y”。但是对于引用变量，这种重新分配是不可能的，所以它会抛出一个编译时错误。

**编译时错误**

```

main.cpp: In function 'int main()':
main.cpp:18:9: error: redeclaration of 'int& y'
int &y=z; // y reference to z, but throws a compile-time error.
^
main.cpp:17:9: note: 'int& y' previously declared here
int &y=x; // y reference to x
^

```

**功能参数**

引用也可以作为函数参数传递。它不会创建参数的副本，而是充当参数的别名。它提高了性能，因为它不创建参数的副本。

**我们通过一个简单的例子来理解。**

```

#include <iostream>
using namespace std;
int main()
{
int a=9; // variable initialization
int b=10; // variable initialization
swap(a, b); // function calling
std::cout << "value of a is :" <<a<< std::endl;
std::cout << "value of b is :" <<b<< std::endl;
return 0;
}
void swap(int &p, int &q) // function definition
{
int temp; // variable declaration
temp=p;
p=q;
q=temp;
}

```

在上面的代码中，我们交换了“a”和“b”的值。我们已经将变量“a”和“b”传递给了 swap()函数。在 swap()函数中，“p”指的是“a”，“q”指的是“b”。当我们交换“p”和“q”的值时，意味着“a”和“b”的值也交换了。

**输出**

```
 value of a is :10 
value of b is :9 

```

**引用为快捷方式**

在引用的帮助下，我们可以很容易地访问嵌套数据。

```

#include <iostream>
using namespace std;
struct profile
{
int id;
};
struct employee
{
profile p;
};
int main()
{
employee e;
int &ref=e.p.id;
ref=34;
std::cout << e.p.id << std::endl;
}

```

在上面的代码中，我们试图访问员工的配置文件结构的“id”。我们通常使用语句 e.p.id 来访问该成员，但是如果我们对该成员有多个访问权限，这将是一项乏味的任务。为了避免这种情况，我们创建了一个引用变量，即 ref，它是“e.p.id”的另一个名称。

**输出**

```
 34 

```

* * *