# C++ 引用与指针

> 原文：<https://www.javatpoint.com/cpp-reference-vs-pointer>

C++ 引用和指针看似相似，但它们之间存在一些差异。引用是现有变量的另一个名称，而指针是存储另一个变量地址的变量。

## 什么是参考？

引用是一个[变量](https://www.javatpoint.com/cpp-variable)，它被称为已经存在的变量的另一个名称。变量的引用是通过存储另一个变量的地址来创建的。

引用变量可以被视为具有自动间接寻址的常量指针。这里，自动间接意味着编译器自动应用间接操作符(*)。

**参考示例:**

```

int &a = i;

```

在上面的声明中，“a”是“I”变量的别名。我们也可以通过“a”变量来引用“I”变量。

**我们通过一个例子来了解一下。**

```

#include <iostream>
using namespace std;
int main()
{  
   int i=8;    // variable initialization
   int &a=i; // creating a reference variable
   cout<<"The value of 'i' variable is :"<<a;
   return 0;
}

```

在上面的代码中，我们创建了一个引用变量，即“I”变量的“a”。创建引用变量后，我们可以借助“a”变量访问“I”的值。

## 什么是指针？

指针是包含另一个变量地址的变量。可以在(*) [操作符](https://www.javatpoint.com/cpp-operators)的帮助下解除引用，以访问指针指向的存储位置。

## 引用和指针的区别

**以下是引用和指针的区别:**

*   **定义**

引用变量是已经存在的变量的另一个名称。它主要用于“**通过引用传递**”，其中引用变量作为参数传递给函数，该变量传递给的函数在该变量的原始副本上工作。

**我们通过一个简单的例子来理解。**

```

#include <iostream>
using namespace std;
void func(int &);
int main()
{
   int a=10;
   std::cout <<"Value of 'a' is :" <<a<< std::endl;
  func(a); 
  std::cout << "Now value of 'a' is :" <<a<< std::endl;
  return 0;
}
void func(int &m)
{
   m=8;
}

```

**输出:**

```
Value of 'a' is :10                                                                                                             
Now value of 'a' is :8  

```

而[指针](https://www.javatpoint.com/cpp-pointers)是存储另一个变量地址的变量。它使编程变得更容易，因为它保存了某个变量的内存地址。

*   **申报**

我们可以通过在变量前添加“&”符号来声明引用变量。如果表达式中使用了此符号，则它将被视为地址运算符。

在使用指针变量之前，我们应该声明一个指针变量，这个变量是通过在变量之前添加一个' * '运算符来创建的。

*   **重新分配**

我们无法重新分配引用变量。现在，我们举一个简单的例子如下:

```

#include <iostream>
using namespace std;
void func(int &);
int main()
{
  int i;    // variable declaration
  int k;    // variable declaration
  int &a=i;
  int &a=k; // error
  return 0;
}

```

上面的代码显示了不允许多次声明 **int & a** 的错误。因此，上述程序得出结论，重新分配操作对于引用变量无效。

然而，指针可以被重新分配。当我们处理数据结构，如链表、树等时，这种重新分配非常有用。

*   **内存地址**

在引用的情况下，引用变量和实际变量都引用同一个地址。在实际变量被删除或超出范围之前，新变量不会被分配给引用变量。

**我们通过一个例子来理解这个场景。**

```

#include <iostream>
using namespace std;
void func(int &);
int main()
{
  int i;
  int &a=i;
  std::cout << "The address of 'a' variable is : " <<&a<< std::endl;
  std::cout << "The address of 'i' variable is : " <<&i<< std::endl;
  return 0;
}

```

**输出:**

```
The address of 'a' variable is : 0x7fff078e7e44                                                                        The address of 'i' variable is : 0x7fff078e7e4

```

上面的输出显示了引用变量和实际变量具有相同的地址。

在指针的情况下，指针变量和实际变量将具有不同的内存地址。让我们通过一个例子来理解这一点。

```

#include <iostream>
using namespace std;
int main()
{
    int k;
    int *p;
    p=&k;
    cout<<"The memory address of p variable is :"<<&p;
    cout<<"\nThe memory address of k variable is :"<<&k;
    return 0;
}

```

**输出:**

```
The memory address of p variable is :0x7ffcc5c164b8                                                           The memory address of k variable is :0x7ffcc5c164b4 

```

*   **空值**

我们不能将空值赋给引用变量，但是可以用空值赋给指针变量。

*   **间接**

指针可以有指向提供多级间接寻址的指针的指针。

```

#include <iostream>
using namespace std;
int main()
{
 int *p;
 int a=8;
 int **q;
 p=&a;
 q=&p;
std::cout << "The value of q is : " <<*q<< std::endl;
return 0;
}

```

在上面的代码中，指针“p”指向变量“a”，而“q”是指向“p”的双指针。因此，我们可以说“p”的值是“a”变量的地址，“q”变量的值是“p”变量的地址。

**输出:**

```
The value of q is : 0x7ffd104891dc  

```

在引用的情况下，引用是不可能的。如果我们尝试做 [c++ 程序](https://www.javatpoint.com/cpp-program)会抛出一个编译时错误

**我们通过一个例子来理解这个场景。**

```

#include <iostream>
using namespace std;
int main()
{
  int a=8; // variable initialization
 int &p=a; // creating a reference variable for ?a? variable.
 int &&q=p;  // reference to reference is not valid, it throws an error.
 return 0;
}

```

**输出:**

```
main.cpp: In function 'int main()':
main.cpp:18:10: error: cannot bind 'int' lvalue to 'int&&'
int &&q=p;

```

*   **算术运算**

我们知道算术运算可以应用于名为“**指针算术**的指针，但是算术运算不能应用于引用。没有文字，即 [C++](https://www.javatpoint.com/cpp-tutorial) 中存在引用算术。

**我们来看一个简单的指针例子。**

```

#include <iostream>
using namespace std;
int main()
{
 int a[]={1,2,3,4,5}; // array initialization
  int *ptr;  // pointer declaration
  ptr=a; assigning base address to pointer ptr.
  cout<<"The value of *ptr is :"<<*ptr;
  ptr=ptr+1;  // incrementing the value of ptr by 1.
  std::cout << "\nThe value of *ptr is: " <<*ptr<< std::endl;
  return 0;
}

```

**输出:**

```
The value of *ptr is :1                                                                                                       
The value of *ptr is: 2

```

**我们通过一个例子来理解参考文献。**

```

#include <iostream>
using namespace std;
int main()
{

 int value=90;  // variable declaration
 int &a=value;   // assigning value to the reference
 &a=&a+5 // arithmetic operation is not possible with reference variable, it throws an error.
 return 0;
}

```

上面的代码将抛出一个编译时错误，因为算术运算不允许使用引用。

* * *