# malloc()与 C++ 中的新

> 原文：<https://www.javatpoint.com/malloc-vs-new-in-cpp>

C++ 中的 **malloc()** 和 new 都用于相同的目的。它们用于在运行时分配内存。但是，malloc()和 new 有不同的语法。malloc()和 new 的主要区别在于 new 是一个运算符，而 malloc()是一个标准库函数，它是在 **stdlib** 头文件中预定义的。

### 什么是新的？

新的是内存分配运算符，用于在运行时分配内存。由新操作符初始化的内存在堆中分配。它返回分配给变量的内存起始地址。C++ 中新的[运算符的功能类似于](https://www.javatpoint.com/cpp-operators) [C 编程语言](https://www.javatpoint.com/c-programming-language-tutorial)中使用的 malloc()函数。 [C++](https://www.javatpoint.com/cpp-tutorial) 也兼容 malloc()函数，但是新的运算符由于其优势而被大量使用。

**新运算符的语法**

```

 type variable = new type(parameter_list);

```

**在上面的语法中**

**类型:**定义新操作符为其分配内存的变量的数据类型。

**变量:**是指向内存的变量名称。

**参数列表:**是初始化为变量的值列表。

新运算符不使用 sizeof()运算符来分配内存。它也不使用调整大小，因为新操作符为对象分配了足够的内存。它是一个在声明时调用构造函数来初始化对象的构造。

正如我们所知，新操作符在堆中分配内存；如果内存在堆中不可用，并且新的操作符试图分配内存，则抛出异常。如果我们的代码不能处理异常，那么程序就会异常终止。

**我们通过一个例子来了解一下新的算子。**

```

#include <iostream>
using namespace std;
int main()
{
 int *ptr;  // integer pointer variable declaration
 ptr=new int; // allocating memory to the pointer variable ptr.
 std::cout << "Enter the number : " << std::endl;
 std::cin >>*ptr;
 std::cout << "Entered number is " <<*ptr<< std::endl;
return 0;
}

```

**输出:**

![malloc() vs new in C++](img/3a415e5615fa896a3ce9f21bec743209.png)

### 什么是 malloc()？

malloc()是一个在运行时分配内存的函数。这个函数返回 void 指针，这意味着它可以被分配给任何指针类型。这个 void 指针可以进一步进行类型转换，以获得指向指定类型内存的指针。

malloc()函数的语法如下:

```

type variable_name = (type *)malloc(sizeof(type)); 

```

**在哪里，**

**类型:**是需要分配内存的变量的数据类型。

**变量 _ 名称:**定义指向内存的变量名称。

**(type*):** 用于类型转换，这样我们就可以得到指向内存的指定类型的指针。

**sizeof():**sizeof()运算符在 malloc()函数中用于获取分配所需的内存大小。

#### 注意:malloc()函数返回 void 指针，因此需要类型转换来为指针分配不同的类型。malloc()函数中需要 sizeof()运算符，因为 malloc()函数返回原始内存，所以 sizeof()运算符将告诉 malloc()函数分配需要多少内存。

如果没有足够的内存，可以使用 realloc()函数调整内存大小。我们知道所有的动态内存需求都是使用堆内存来满足的，所以 malloc()函数也在堆中分配内存并返回指向它的指针。堆内存非常有限，所以当我们的代码开始执行时，它会标记正在使用的内存，当我们的代码完成任务时，它会使用 free()函数释放内存。如果没有足够的内存，并且我们的代码试图访问内存，那么 malloc()函数返回空指针。malloc()函数分配的内存可以通过使用 free()函数来释放。

**我们通过一个例子来了解一下。**

```

#include <iostream>
#include<stdlib.h>
using namespace std;

int main()
{

  int len;   // variable declaration
  std::cout << "Enter the count of numbers :" << std::endl;
  std::cin >> len;
  int *ptr; // pointer variable declaration
  ptr=(int*) malloc(sizeof(int)*len);  // allocating memory to  the poiner variable
  for(int i=0;i<len;i++)
  {
      std::cout << "Enter a number : " << std::endl;
      std::cin >> *(ptr+i);
  }
  std::cout << "Entered elements are : " << std::endl;
   for(int i=0;i<len;i++)
  {
     std::cout << *(ptr+i) << std::endl;
  }
free(ptr);
    return 0;
}

```

**输出:**

![malloc() vs new in C++](img/3be3e4661a85c96ef86559bf39a4b901.png)

如果我们没有在正确的地方使用 **free()** 函数，那么就会导致指针悬空的原因。**我们通过一个例子来理解这个场景。**

```

#include <iostream>
#include<stdlib.h>
using namespace std;
int *func()
{
    int *p;
    p=(int*) malloc(sizeof(int));
    free(p);
    return p;
}
int main()
{

 int *ptr;
 ptr=func();
 free(ptr);
    return 0;
}

```

在上面的代码中，我们调用了 func()函数。func()函数返回整数指针。在 func()函数内部，我们已经声明了一个*p 指针，并且使用 malloc()函数将内存分配给这个指针变量。在这种情况下，我们返回的指针的内存已经释放。ptr 是一个悬空指针，因为它指向释放的内存位置。或者我们可以说 ptr 指的是指针没有指向的内存。

到目前为止，我们已经了解了新的运算符和 malloc()函数。现在，我们将看到新运算符和 malloc()函数之间的区别。

### malloc()和 new 之间的差异

![malloc() vs new in C++](img/895482407fd8c0b25cfe3db4614206ae.png)

*   新运算符构造一个对象，即它调用构造函数来初始化一个对象，而 **malloc()** 函数不调用构造函数。新操作符调用构造函数，删除操作符调用析构函数销毁对象。这是 malloc()和 new 之间最大的区别。
*   new 是一个运算符，而 malloc()是 stdlib 头文件中的预定义函数。
*   运算符 new 可以重载，而 malloc()函数不能重载。
*   如果堆中没有足够的内存，那么当 malloc()函数返回空指针时，新的运算符将引发异常。
*   在新的运算符中，我们需要指定要分配的对象数，而在 malloc()函数中，我们需要指定要分配的字节数。
*   在新操作符的情况下，我们必须使用 delete 操作符来释放内存。但是在 malloc()函数的情况下，我们必须使用 free()函数来释放内存。

**新运算符的语法**

```

type reference_variable = new type name;

```

**在哪里，**

**类型:**定义引用变量的数据类型。

**reference_variable:** 是指针变量的名称。

**new:** 用于分配内存的运算符。

**类型名称:**可以是任何基础数据类型。

**例如**

```

int *p;
p = new int; 

```

在上面的语句中，我们声明了一个整数指针变量。语句**p = new int；**为整数变量分配内存空间。

**malloc()的语法如下:**

```

int *ptr = (data_type*) malloc(sizeof(data_type));

```

**ptr:** 是指针变量。

**数据类型:**可以是任何基础数据类型。

**例如**

```

int *p;
p = (int *) malloc(sizeof(int))

```

上面的语句将为堆中的整数变量分配内存，然后将保留内存的地址存储在“p”变量中。

*   另一方面，使用 malloc()函数分配的内存可以使用 free()函数释放。
*   一旦使用新操作符分配了内存，就不能调整其大小。另一方面，使用 malloc()函数分配内存；然后，可以使用 realloc()函数重新分配它。
*   new 的执行时间比 malloc()函数短，因为 new 是一个构造，malloc 是一个函数。
*   新运算符不返回单独的指针变量；它返回新创建的对象的地址。另一方面，malloc()函数返回 void 指针，该指针可以进一步用指定的类型进行类型转换。

* * *