# C++ 朋友函数

> 原文：<https://www.javatpoint.com/cpp-friend-function>

如果一个函数在 C++ 中被定义为友元函数，那么可以使用该函数访问一个类的受保护的私有数据。

通过使用关键字 friend 编译器知道给定的函数是 friend 函数。

为了访问数据，友元函数的声明应该在以关键字 friend 开始的类体中完成。

## C++ 中朋友函数的声明

```
class class_name  
{  
    friend data_type function_name(argument/s);            // syntax of friend function.
};  

```

在上面的声明中，friend 函数前面是关键字 friend。该函数可以像普通的 C++ 函数一样在程序中的任何地方定义。函数定义既没有使用关键字 **friend，也没有使用范围解析运算符**。

**朋友功能的特征:**

*   该函数不在已声明为友元的类的范围内。
*   不能使用对象调用它，因为它不在该类的范围内。
*   它可以像普通函数一样调用，而无需使用对象。
*   它不能直接访问成员名，必须使用对象名和带成员名的点成员运算符。
*   它可以在私有或公共部分声明。

## C++ 朋友函数示例

让我们看看 C++ friend 函数用来打印一个盒子长度的简单例子。

```
#include <iostream>  
using namespace std;  
class Box  
{  
    private:  
        int length;  
    public:  
        Box(): length(0) { }  
        friend int printLength(Box); //friend function  
};  
int printLength(Box b)  
{  
   b.length += 10;  
    return b.length;  
}  
int main()  
{  
    Box b;  
    cout<<"Length of box: "<< printLength(b)<<endl;  
    return 0;  
}  

```

**输出:**

```
Length of box: 10  

```

**我们来看一个函数对两个类友好的简单例子。**

```
#include <iostream>
using namespace std;
class B;          // forward declarartion.
class A
{
    int x;
    public:
    void setdata(int i)
    {
        x=i;
    }
    friend void min(A,B);         // friend function.
};
class B
{
    int y;
    public:
    void setdata(int i)
    {
        y=i;
    }
    friend void min(A,B);                    // friend function
};
void min(A a,B b)
{
    if(a.x<=b.y)
    std::cout << a.x << std::endl;
    else
    std::cout << b.y << std::endl;
}
   int main()
{
   A a;
   B b;
   a.setdata(10);
   b.setdata(20);
   min(a,b);
    return 0;
 }

```

**输出:**

```
10

```

在上面的例子中，min()函数对两个类都很友好，即 min()函数可以访问 A 类和 b 类的私有成员。

### C++ 朋友类

友元类可以访问已声明为友元的类的私有成员和受保护成员。

**我们来看一个朋友类的简单例子。**

```
#include <iostream>

using namespace std;

class A
{
    int x =5;
    friend class B;           // friend class.
};
class B
{
  public:
    void display(A &a)
    {
        cout<<"value of x is : "<<a.x;
    }
};
int main()
{
    A a;
    B b;
    b.display(a);
    return 0;
}

```

**输出:**

```
value of x is : 5

```

在上例中，B 类被声明为 a 类内部的朋友，因此 B 类是 a 类的朋友，B 类可以访问 a 类的私有成员。