# C++ 继承

> 原文：<https://www.javatpoint.com/cpp-inheritance>

在 C++ 中，继承是一个过程，其中一个对象自动获取其父对象的所有属性和行为。这样，您可以重用、扩展或修改在其他类中定义的属性和行为。

在 C++ 中，继承另一个类的成员的类称为派生类，继承其成员的类称为基类。派生类是基类的专用类。

* * *

## C++ 继承的优势

**代码可重用性:**现在可以重用父类的成员了。所以，没有必要重新定义成员。所以类中需要更少的代码。

## 继承的类型

**C++ 支持五种继承类型:**

*   单一继承
*   多重继承
*   分级继承
*   多级继承
*   混合遗传

![C++ Inheritance](img/f997326607016ef4568445e1381c3f1e.png)

## 派生类

派生类被定义为从基类派生的类。

派生类的语法:

```
class derived_class_name :: visibility-mode base_class_name
{
    // body of the derived class.
}

```

**在哪里，**

**派生类名称:**是派生类的名称。

**可见性模式:**可见性模式指定基类的特性是公开继承还是私有继承。它可以是公共的，也可以是私人的。

**base_class_name:** 是基类的名称。

*   当基类被派生类私有继承时，基类的公共成员成为派生类的私有成员。因此，基类的公共成员不能被派生类的对象访问，只能被派生类的成员函数访问。
*   当基类被派生类公开继承时，基类的公共成员也成为派生类的公共成员。因此，派生类的对象以及基类的成员函数都可以访问基类的公共成员。

### 注意:

*   在 C++ 中，可见性的默认模式是私有的。
*   基类的私有成员永远不会被继承。

## C++ 单一继承

**单一继承**定义为一个派生类只继承一个基类的继承。

![C++ Inheritance](img/40bc1d12890926390dc059aa07ce075d.png)

其中“A”是基类，“B”是派生类。

## C++ 单层继承示例:继承字段

当一个类继承另一个类时，它被称为单级继承。让我们看看只继承字段的单级继承的例子。

```
#include <iostream>
using namespace std;
 class Account {
   public:
   float salary = 60000; 
 };
   class Programmer: public Account {
   public:
   float bonus = 5000;  
   };     
int main(void) {
     Programmer p1;
     cout<<"Salary: "<<p1.salary<<endl;  
     cout<<"Bonus: "<<p1.bonus<<endl;  
    return 0;
}

```

输出:

```
Salary: 60000
Bonus: 5000

```

在上例中，雇员是**基**类，程序员是**派生的**类。

## C++ 单层继承示例:继承方法

让我们看看 C++ 中的另一个继承示例，它只继承方法。

```
#include <iostream>
using namespace std;
 class Animal {
   public:
 void eat() { 
    cout<<"Eating..."<<endl; 
 }  
   };
   class Dog: public Animal  
   {  
       public:
     void bark(){
    cout<<"Barking..."; 
     }  
   }; 
int main(void) {
    Dog d1;
    d1.eat();
    d1.bark();
    return 0;
}

```

输出:

```
Eating...
Barking...

```

让我们看一个简单的例子。

```
#include <iostream>
using namespace std;
class A
{
    int a = 4;
    int b = 5;
    public:
    int mul()
    {
        int c = a*b;
        return c;
    }   
};

class B : private A
{
    public:
    void display()
    {
        int result = mul();
        std::cout <<"Multiplication of a and b is : "<<result<< std::endl;
    }
};
int main()
{
   B b;
   b.display();

    return 0;
}

```

输出:

```
Multiplication of a and b is : 20

```

在上例中，A 类是私有继承的。因此，类“A”的 mul()函数不能被类 b 的对象访问，只能被类 b 的成员函数访问。

## 如何使私有成员可继承

私有成员不可继承。如果我们通过公开可见性模式来修改可见性模式，但是这样会失去数据隐藏的优势。

C++ 引入了第三个可见性修饰符，即**保护的**。声明为受保护的成员将可由类中的所有成员函数以及直接从其派生的类访问。

**能见度模式可分为三类:**

![C++ Inheritance](img/14e4308206ee35a75e948bd3416777fb.png)

*   **公共**:当成员声明为公共时，程序的所有功能都可以访问。
*   **Private** :当成员声明为 Private 时，只能在类内访问。
*   **受保护**:当成员被声明为受保护时，它可以在自己的类以及直接从它派生的类中访问。

## 继承成员的可见性

| 基类可见性 | 派生类可见性 |
| 公众 | 私人的 | 保护 |
| 私人的 | 未继承 | 未继承 | 未继承 |
| 保护 | 保护 | 私人的 | 保护 |
| 公众 | 公众 | 私人的 | 保护 |

## C++ 多级继承

**多级继承**是从另一个派生类派生一个类的过程。

![C++ Inheritance](img/d963102eb2e5631ddd4f41d7f275d11d.png)

## C++ 多级继承示例

当一个类继承另一个类，而这个类又被另一个类继承，这在 C++ 中被称为多级继承。继承是可传递的，因此最后一个派生类获取其所有基类的所有成员。

让我们看看 C++ 中多级继承的例子。

```
#include <iostream>
using namespace std;
 class Animal {
   public:
 void eat() { 
    cout<<"Eating..."<<endl; 
 }  
   };
   class Dog: public Animal 
   {  
       public:
     void bark(){
    cout<<"Barking..."<<endl; 
     }  
   }; 
   class BabyDog: public Dog 
   {  
       public:
     void weep() {
    cout<<"Weeping..."; 
     }  
   }; 
int main(void) {
    BabyDog d1;
    d1.eat();
    d1.bark();
     d1.weep();
     return 0;
}

```

输出:

```
Eating...
Barking...
Weeping...

```

## C++ 多重继承

**多重继承**是从两个或多个类中继承属性的新类的派生过程。

![C++ Inheritance](img/1a7a1a79ec6e738ae8bade421ad90c3e.png)

**派生类的语法:**

```
class D : visibility B-1, visibility B-2, ?
{
    // Body of the class;
} 

```

让我们看一个多重继承的简单例子。

```
#include <iostream>
using namespace std;
class A
{
    protected:
     int a;
    public:
    void get_a(int n)
    {
        a = n;
    }
};

class B
{
    protected:
    int b;
    public:
    void get_b(int n)
    {
        b = n;
    }
};
class C : public A,public B
{
   public:
    void display()
    {
        std::cout << "The value of a is : " <<a<< std::endl;
        std::cout << "The value of b is : " <<b<< std::endl;
        cout<<"Addition of a and b is : "<<a+b;
    }
};
int main()
{
   C c;
   c.get_a(10);
   c.get_b(20);
   c.display();

    return 0;
}

```

输出:

```
The value of a is : 10
The value of b is : 20
Addition of a and b is : 30

```

在上面的示例中，类“C”在公共模式下继承了两个基类“A”和“B”。

## 继承中的模糊解决

当具有相同名称的函数出现在多个基类中时，使用多重继承可能会出现歧义。

让我们通过一个例子来理解这一点:

```
#include <iostream>
using namespace std;
class A
{
    public:
    void display()
    {
        std::cout << "Class A" << std::endl;
    }
};
class B
{
    public:
    void display()
    {
        std::cout << "Class B" << std::endl;
    }
};
class C : public A, public B
{
    void view()
    {
        display();
    }
};
int main()
{
    C c;
    c.display();
    return 0;
}

```

输出:

```
error: reference to 'display' is ambiguous
        display();

```

*   上述问题可以通过将类解析运算符与函数一起使用来解决。在上面的示例中，派生类代码可以重写为:

```
class C : public A, public B
{
    void view()
    {
        A :: display();         // Calling the display() function of class A.
        B :: display();         // Calling the display() function of class B.

    }
};

```

单一继承中也会出现歧义。

考虑以下情况:

```
class A
{
   public:
void display()
{
   cout<<?Class A?;
} 
} ;
class B
{ 
  public:
 void display()
{
 cout<<?Class B?;
}
} ;

```

在上述情况下，派生类的函数重写基类的方法。因此，对 display()函数的调用只会调用派生类中定义的函数。如果我们想调用基类函数，我们可以使用类解析运算符。

```
int main()
{
    B b;
   b.display();               // Calling the display() function of B class.
   b.B :: display();       // Calling the display() function defined in B class.
} 

```

## C++ 混合继承

混合继承是一种以上继承类型的组合。

![C++ Inheritance](img/25b01ccd7fcc9ecb9c060792d56ce91d.png)

让我们看一个简单的例子:

```
#include <iostream>
using namespace std;
class A
{
    protected:
    int a;
    public:
    void get_a()
    {
       std::cout << "Enter the value of 'a' : " << std::endl;
       cin>>a;
    }
};

class B : public A 
{
    protected:
    int b;
    public:
    void get_b()
    {
        std::cout << "Enter the value of 'b' : " << std::endl;
       cin>>b;
    }
};
class C 
{
    protected:
    int c;
    public:
    void get_c()
    {
        std::cout << "Enter the value of c is : " << std::endl;
        cin>>c;
    }
};

class D : public B, public C
{
    protected:
    int d;
    public:
    void mul()
    {
         get_a();
         get_b();
         get_c();
         std::cout << "Multiplication of a,b,c is : " <<a*b*c<< std::endl;
    }
};
int main()
{
    D d;
    d.mul();
    return 0;
}

```

输出:

```
Enter the value of 'a' :
10              
Enter the value of 'b' :    
20      
Enter the value of c is :   
30  
Multiplication of a,b,c is : 6000

```

## C++ 分层继承

层次继承被定义为从基类派生多个类的过程。

![C++ Inheritance](img/e54694beed54a23037ba546c2ee92ba4.png)

**层次继承语法:**

```
class A
{
    // body of the class A.
}  
class B : public A 
{
    // body of class B.
}
class C : public A
{
    // body of class C.
} 
class D : public A
{
    // body of class D.
} 

```

让我们看一个简单的例子:

```
#include <iostream>
using namespace std;
class Shape                 // Declaration of base class.
{
    public:
    int a;
    int b;
    void get_data(int n,int m)
    {
        a= n;
        b = m;
    }
};
class Rectangle : public Shape  // inheriting Shape class
{
    public:
    int rect_area()
    {
        int result = a*b;
        return result;
    }
};
class Triangle : public Shape    // inheriting Shape class
{
    public:
    int triangle_area()
    {
        float result = 0.5*a*b;
        return result;
    }
};
int main()
{
    Rectangle r;
    Triangle t;
    int length,breadth,base,height;
    std::cout << "Enter the length and breadth of a rectangle: " << std::endl;
    cin>>length>>breadth;
    r.get_data(length,breadth);
    int m = r.rect_area();
    std::cout << "Area of the rectangle is : " <<m<< std::endl;
    std::cout << "Enter the base and height of the triangle: " << std::endl;
    cin>>base>>height;
    t.get_data(base,height);
    float n = t.triangle_area();
    std::cout <<"Area of the triangle is : "  << n<<std::endl;
    return 0;
}

```

输出:

```
Enter the length and breadth of a rectangle:
23  
20  
Area of the rectangle is : 460          
Enter the base and height of the triangle:  
2   
5
Area of the triangle is : 5 

```