# C++ 虚拟函数

> 原文：<https://www.javatpoint.com/cpp-virtual-function>

*   C++ 虚拟函数是您在派生类中重新定义的基类中的成员函数。它是使用虚拟关键字声明的。
*   它用于告诉编译器对函数执行动态链接或后期绑定。
*   有必要使用单个指针来引用不同类的所有对象。因此，我们创建指向基类的指针，该基类引用所有派生对象。但是，当基类指针包含派生类对象的地址时，总是执行基类函数。这个问题只能通过使用“虚拟”功能来解决。
*   “virtual”是函数的正常声明之前的一个关键字。
*   当函数虚拟化时，C++ 根据基类指针所指向的对象的类型来确定在运行时调用哪个函数。

* * *

## 后期绑定或动态链接

后期绑定函数调用是在运行时解决的。因此编译器在运行时确定对象的类型，然后绑定函数调用。

* * *

**虚函数规则**

*   虚函数必须是某个类的成员。
*   虚函数不能是静态成员。
*   它们是通过对象指针访问的。
*   他们可以是另一个班级的朋友。
*   虚拟函数必须在基类中定义，即使它没有被使用。
*   基类和所有派生类的虚函数的原型必须相同。如果两个函数同名但原型不同，C++ 会认为它们是重载函数。
*   我们不能有一个虚拟构造函数，但是我们可以有一个虚拟析构函数
*   考虑一下我们不用 virtual 关键字的情况。

```
#include <iostream>
using namespace std;
class A
{
   int x=5;
    public:
    void display()
    {
        std::cout << "Value of x is : " << x<<std::endl;
    }
};
class B: public A
{
    int y = 10;
    public:
    void display()
    {
        std::cout << "Value of y is : " <<y<< std::endl;
    }
};
int main()
{
    A *a;
    B b;
    a = &b;
   a->display();
    return 0;
}

```

**输出:**

```
Value of x is : 5

```

在上面的例子中，a *是基类指针。指针只能访问基类成员，而不能访问派生类成员。虽然 C++ 允许基指针指向从基类派生的任何对象，但它不能直接访问派生类的成员。因此，需要一个允许基指针访问派生类成员的虚拟函数。

## C++ 虚拟函数示例

让我们看一个 C++ 虚拟函数的简单例子，该函数用于在程序中调用派生类。

```
#include <iostream>  
{  
 public:  
 virtual void display()  
 {  
  cout << "Base class is invoked"<<endl;  
 }  
};  
class B:public A  
{  
 public:  
 void display()  
 {  
  cout << "Derived Class is invoked"<<endl;  
 }  
};  
int main()  
{  
 A* a;    //pointer of base class  
 B b;     //object of derived class  
 a = &b;  
 a->display();   //Late Binding occurs  
}  

```

**输出:**

```
Derived Class is invoked  

```

## 纯虚函数

*   虚拟函数不用于执行任何任务。它只是一个占位符。
*   当函数没有定义时，这样的函数称为“**无为**函数。
*   **无所事事**功能被称为**纯虚拟功能**。纯虚函数是在基类中声明的、相对于基类没有定义的函数。
*   包含纯虚函数的类不能用来声明它自己的对象，这样的类被称为抽象基类。
*   基类的主要目标是为派生类提供特性，并创建用于实现运行时多态性的基指针。

**纯虚函数可以定义为:**

```
virtual void display() = 0; 

```

**我们来看一个简单的例子:**

```
#include <iostream>
using namespace std;
class Base
{
    public:
    virtual void show() = 0;
};
class Derived : public Base
{
    public:
    void show()
    {
        std::cout << "Derived class is derived from the base class." << std::endl;
    }
};
int main()
{
    Base *bptr;
    //Base b;
    Derived d;
    bptr = &d;
    bptr->show();
    return 0;
}

```

**输出:**

```
Derived class is derived from the base class.

```

在上例中，基类包含纯虚函数。因此，基类是一个抽象基类。我们无法创建基类的对象。