# C++ 信号处理

> 原文：<https://www.javatpoint.com/cpp-signal-handling>

*   信号是由操作系统传递给进程的中断，用以停止正在进行的任务，并处理产生中断的任务。
*   操作系统也可以根据系统或错误情况生成信号。
*   您可以在 [Linux](https://www.javatpoint.com/linux-tutorial) 、UNIX、Mac [OS](https://www.javatpoint.com/os-tutorial) X 或 Windows 系统上按 Ctrl+ [C](https://www.javatpoint.com/c-programming-language-tutorial) 生成中断。

有些信号程序无法捕捉到，但有以下信号列表，您可以在程序中捕捉到这些信号，并根据这些信号采取适当的措施。

这些信号在<csingnal>头文件中定义。</csingnal>

以下是信号列表及其描述和工作能力:

| 信号 | 描述 |
| 西格布 | (信号异常终止)程序异常终止，如调用异常终止。 |
| 西格弗 | (信号浮点异常)错误的算术运算，如被零除或导致溢出的运算。 |
| -是啊 | (发出非法指令信号)用于检测非法指令。 |
| 信号情报 | (信号中断)用于接收交互式程序中断信号。 |
| 西格尔瑟夫 | (信号分段冲突)对存储的无效访问。 |
| 是 SIGTERM | (信号终止)发送给程序的终止请求。 |
| 嘘嘘嘘 | (信号挂机)挂机(POSIX)，其报告用户终端断开。用于报告控制过程的终止。 |
| 继续走 | 用于终止进程并生成核心转储。 |
| SIGTRAP(陷阱) | 追踪陷阱。 |
| 西格布斯 | 这是一个总线错误，表示对无效地址的访问。 |
| 西格 1 号 | 用户定义信号 1。 |
| 西格玛瑟鲁瑟鲁瑟鲁瑟鲁瑟鲁瑟鲁瑟鲁瑟鲁瑟鲁瑟鲁瑟鲁瑟鲁瑟鲁瑟鲁瑟鲁瑟鲁瑟鲁瑟鲁瑟鲁瑟鲁瑟鲁瑟鲁瑟鲁 | 用户定义信号 2。 |
| 跟着我 | 闹钟，表示对无效地址的访问。 |
| 是 SIGTERM | 用于终止。该信号可以被阻止、处理和忽略。由 kill 命令生成。 |
| 打折 | 该信号被发送到进程以使其继续。 |
| 停下来 | 停下，不可阻挡。该信号用于停止一个过程。该信号不能被处理、忽略或阻止。 |

* * *

## 信号()函数

[C++](https://www.javatpoint.com/cpp-tutorial) 信号处理库提供函数信号来捕获意外中断或事件。

### 句法

```

void (*signal (int sig, void (*func)(int)))(int);

```

### 因素

该功能被设置为处理信号。

它指定了一种方式来处理由 ***sig*** 指定的信号编号。

参数 ***功能*** 指定程序处理信号的三种方式之一。

*   **默认处理(SIG_DFL):** 由该特定信号的默认操作处理的信号。
*   **忽略信号(SIG_IGN):** 信号被忽略，即使没有目的，代码执行也会继续。
*   **功能处理程序:**定义一个特定的功能来处理信号。

我们必须记住，我们想要捕捉的信号必须使用信号功能进行注册，并且必须与信号处理功能相关联。

#### 注意:信号处理功能应为空型。

### 返回值

此函数的返回类型与参数函数的类型相同。

如果这个函数的请求成功，这个函数返回一个指针，指向在调用之前负责处理这个信号的特定处理函数(如果有的话)。

### 数据竞赛

数据竞争未定义。如果你在多线程程序中调用这个函数，那么它将导致未定义的行为。

### 例外

这个函数从不抛出异常。

### 例 1

让我们看一个简单的例子来演示 signal()函数的使用:

```

#include <iostream>
#include <csignal>

using namespace std;

sig_atomic_t signalled = 0;

void handler(int sig)
{
    signalled = 1;
}

int main()
{
    signal(SIGINT, handler);

    raise(SIGINT);
    if (signalled)
        cout << "Signal is handled";
    else
        cout << "Signal is not handled";

    return 0;
}

```

**输出:**

```
Signal is handled

```

### 例 2

让我们看另一个简单的例子:

```

#include <csignal>
#include <iostream>

namespace
{
  volatile std::sig_atomic_t gSignalStatus;
}

void signal_handler(int signal)
{
  gSignalStatus = signal;
}

int main()
{
  // Install a signal handler
  std::signal(SIGINT, signal_handler);

  std::cout << "SignalValue: " << gSignalStatus << '\n';
  std::cout << "Sending signal " << SIGINT << '\n';
  std::raise(SIGINT);
  std::cout << "SignalValue: " << gSignalStatus << '\n';
}

```

**输出:**

```
SignalValue: 0
Sending signal 2
SignalValue: 2

```

* * *

## 提升()功能

C++ 信号提升()函数用于向当前正在执行的程序发送信号。

**<cssignal>**头文件声明了函数 raise()来处理特定的信号。

### 句法

```

int raise (int sig);

```

### 因素

**sig:** 待发送处理的信号编号。它可以采用以下值之一:

*   信号情报
*   西格布
*   西格弗
*   -是啊
*   西格尔瑟夫
*   是 SIGTERM
*   嘘嘘嘘

### 返回值

成功时返回 0，失败时返回非零值。

### 数据竞赛

同时调用这个函数是安全的，不会造成数据竞争。

### 例外

如果没有用信号定义函数处理程序来处理引发的信号，这个函数就不会抛出异常。

### 例 1

让我们看一个简单的例子来说明在传递 SIGABRT 时使用 raise()函数:

```

#include <iostream>
#include <csignal>

using namespace std;

sig_atomic_t sig_value = 0;

void handler(int sig)
{
    sig_value = sig;
}

int main()
{
    signal(SIGABRT, handler);
    cout << "Before signal handler is called" << endl;
    cout << "Signal = " << sig_value << endl; 
    raise(SIGABRT);
    cout << "After signal handler is called" << endl;
    cout << "Signal = " << sig_value << endl;

    return 0;
}

```

**输出:**

```
Before signal handler is called
Signal = 0
After signal handler is called
Signal = 6

```

### 例 2

让我们看一个简单的例子来说明在传递 SIGINT 时使用 raise()函数:

```

#include <csignal> 
#include <iostream> 
using namespace std; 

sig_atomic_t s_value = 0; 
void handle(int signal_) 
{ 
    s_value = signal_; 
} 

int main() 
{ 
    signal(SIGINT, handle); 
    cout << "Before called Signal = " << s_value << endl; 
    raise(SIGINT); 
    cout << "After called Signal = " << s_value << endl; 
    return 0; 
}

```

**输出:**

```
Before called Signal = 0
After called Signal = 2

```

### 例 3

让我们看一个简单的例子来说明在传递 SIGTERM 时使用 raise()函数:

```

#include <csignal> 
#include <iostream> 
using namespace std; 

sig_atomic_t s_value = 0; 
void handle(int signal_) 
{ 
    s_value = signal_; 
} 

int main() 
{ 
    signal(SIGTERM, handle); 
    cout << "Before called Signal = " << s_value << endl; 
    raise(SIGTERM); 
    cout << "After called Signal = " << s_value << endl; 
    return 0; 
}

```

**输出:**

```
Before called Signal = 0
After called Signal = 15

```

### 例 4

让我们看一个简单的例子来说明在传递 SIGSEGV 时使用 raise()函数:

```

#include <csignal> 
#include <iostream> 
using namespace std; 

sig_atomic_t s_value = 0; 
void handle(int signal_) 
{ 
    s_value = signal_; 
} 

int main() 
{ 
    signal(SIGSEGV, handle); 
    cout << "Before called Signal = " << s_value << endl; 
    raise(SIGSEGV); 
    cout << "After called Signal = " << s_value << endl; 
    return 0; 
}

```

**输出:**

```
Before called Signal = 0
After called Signal = 11

```

### 例 5

让我们看一个简单的例子来说明在传递 SIGFPE 时使用 raise()函数:

```

#include <csignal> 
#include <iostream> 
using namespace std; 

sig_atomic_t s_value = 0; 
void handle(int signal_) 
{ 
    s_value = signal_; 
} 

int main() 
{ 
    signal(SIGFPE, handle); 
    cout << "Before called Signal = " << s_value << endl; 
    raise(SIGFPE); 
    cout << "After called Signal = " << s_value << endl; 
    return 0; 
}

```

**输出:**

```
Before called Signal = 0
After called Signal = 8

```

* * *