# C++ getline()

> 原文：<https://www.javatpoint.com/cpp-getline>

cin 是一个用于接受用户输入的对象，但不允许接受多行输入。为了接受多行，我们使用 getline()函数。它是一个预定义的函数，定义在一个 **<字符串中。h >** 头文件，用于接受输入流中的一行或一个字符串，直到遇到定界字符。

### getline()函数的语法:

**有两种表示函数的方式:**

*   第一种声明方式是传递三个参数。

```

istream& getline( istream& is, string& str, char delim );

```

上面的语法包含三个参数，即 **is，str** ，和 **delim** 。

**在哪里，**

**是:**它是 istream 类的一个对象，定义从哪里读取输入流。

**str:** 是存储字符串的字符串对象。

**delim:** It is the delimiting character.

**返回值**

此函数返回输入流对象，该对象作为参数传递给函数。

*   第二种声明方式是传递两个参数。

```

istream& getline( istream& is, string& str );

```

以上语法包含两个参数，即**为**和 **str** 。这个语法和上面的语法差不多；唯一的区别是它没有任何定界符。

**在哪里，**

**是:**它是 istream 类的一个对象，定义从哪里读取输入流。

**str:** 是存储字符串的字符串对象。

**返回值**

此函数还返回输入流，该输入流作为参数传递给函数。

**我们通过一个例子来了解一下。**

首先，我们将看一个不使用 getline()函数获取用户输入的例子。

```

#include <iostream>
#include<string.h>
using namespace std;
int main()
{
string name; // variable declaration
std::cout << "Enter your name :" << std::endl;
cin>>name;
cout<<"\nHello "<<name;
return 0;
}

```

在上面的代码中，我们使用语句 **cin > >名称**作为用户输入，即我们没有使用 **getline()** 功能。

**输出**

```
Enter your name : 
John Miller 
Hello John

```

在上面的输出中，我们给出了名称“约翰·米勒”作为用户输入，但是只显示了“约翰”。因此，我们得出结论，当遇到空间字符时，cin 不考虑字符。

**我们用 getline()函数来解决上面的问题。**

```

#include <iostream>
#include<string.h>
using namespace std;
int main()
{
string name; // variable declaration.
std::cout << "Enter your name :" << std::endl;
getline(cin,name); // implementing a getline() function
cout<<"\nHello "<<name;
return 0;}

```

在上面的代码中，我们使用了 **getline()** 函数来接受字符，即使遇到了空格字符。

**输出**

```
Enter your name : 
John Miller 
Hello John Miller

```

在上面的输出中，我们可以观察到两个单词，即 John 和 Miller，都被显示出来，这意味着 getline()函数也考虑了空格字符之后的字符。

**当我们不想读空格后的字符时，我们使用以下代码:**

```

#include <iostream>
#include<string.h>
using namespace std;
int main()
{
string profile; // variable declaration
std::cout << "Enter your profile :" << std::endl;
getline(cin,profile,' '); // implementing getline() function with a delimiting character.
cout<<"\nProfile is :"<<profile;
}

```

在上面的代码中，我们使用 getline()函数接受用户输入，但这次我们还在第三个参数中添加了定界字符(' ')。这里，定界字符是一个空格字符，意味着出现在空格之后的字符将不被考虑。

**输出**

```
Enter your profile : 
Software Developer 
Profile is: Software 

```

### 获取行字符数组

我们也可以为字符数组定义 getline()函数，但是它的语法与前面的不同。

**语法**

```

istream& getline(char* , int size);

```

在上面的语法中，有两个参数；一个是 **char** *，另一个是 **size** 。

**在哪里，**

**char*:** 是指向数组的字符指针。

**大小:**它作为定义数组大小的定界符，意味着输入不能跨越这个大小。

**我们通过一个例子来了解一下。**

```

#include <iostream>
#include<string.h>
using namespace std;
int main()
{
char fruits[50]; // array declaration
cout<< "Enter your favorite fruit: ";
cin.getline(fruits, 50); // implementing getline() function
std::cout << "\nYour favorite fruit is :"<<fruits << std::endl;
return 0;
}

```

**输出**

```
Enter your favorite fruit: Watermelon 
Your favorite fruit is: Watermelon 

```

* * *