# C++ 中结构和类的区别

> 原文：<https://www.javatpoint.com/structure-vs-class-in-cpp>

在 C++ 中，结构与类相同，但有些不同。安全性对于结构和类都是最重要的。结构是不安全的，因为它不能向最终用户隐藏其实现细节，而类是安全的，因为它可能隐藏其编程和设计细节。在本文中，我们将讨论 [C++](https://www.javatpoint.com/cpp-tutorial) 中结构和类的区别。但是在讨论差异之前，我们将了解 C++ 中的结构和类。

## C++ 中的结构是什么？

结构是由同名引用的各种 [**数据类型**](https://www.javatpoint.com/cpp-data-types) 的变量组成的**分组。结构声明用作创建结构实例的模板。**

### 语法:

该结构的语法如下:

```

Struct Structurename
{
Struct_member1;
Struct_member2;
Struct_member3;
.
.
.
Struct_memberN;
};

```

**“struct”**关键字向编译器指示已经声明了一个结构。**“结构名称”**定义了结构的名称。由于结构声明被视为一条语句，因此它通常以分号结尾。

## C++ 中的类是什么？

C++ 中的类类似于 C 结构，因为它由一系列**数据成员**和一组对该类执行的操作组成。换句话说，类是面向对象编程的**构件**。它是用户定义的对象类型，具有自己的一组数据成员和成员函数，可以通过创建类实例来访问和使用。C++ 类类似于对象的蓝图。

### 语法:

结构和类在语法上是相似的。C++ 中类的语法如下:

```

class class_name
{
// private data members and member functions.
Access specifier;
Data member;
Member functions (member list){ . . }
};

```

在这种语法中，类是一个关键字，用来指示编译器已经声明了一个类。OOP 的主要功能是数据隐藏，这是通过拥有三个访问说明符来实现的:**“公共”、“私有”**、**“安全”**。如果在声明数据成员或成员函数时没有在类中指定访问说明符，默认情况下它们都被认为是私有的。

公共访问说明符允许其他人访问程序功能或数据。该类的成员只能访问该类的私有成员。在继承过程中，使用安全访问说明符。如果声明了访问说明符，则不能在程序中再次更改它。

## 结构和类的主要区别

在这里，我们将讨论结构和类之间的主要区别。其中一些如下:

*   默认情况下，结构的所有成员都是公共的。相比之下，类的所有成员都是私有的。
*   该结构将自动初始化其成员。相反，构造函数和析构函数用于初始化类成员。
*   当实现一个结构时，内存在堆栈上分配。相比之下，内存是在类的堆上分配的。
*   结构中的变量不能在声明过程中初始化，但它们可以在类中完成。
*   任何结构成员中不能有空值。另一方面，类变量可能有空值。
*   结构是值类型，而类是引用类型。
*   操作新数据表单的操作者可以用一种特殊的方法来描述。

## 结构和类之间的直接比较

在这里，我们将讨论结构和类之间的直接比较。其中一些如下:

| 特征 | 结构 | 班级 |
| 定义 | 结构是由同名引用的各种数据类型的变量组成的分组。 | 在 C++ 中，类被定义为包含在单个结构中的相关变量和函数的集合。 |
| 基础 | 如果未指定访问说明符，所有成员都将设置为“public”。 | 如果未定义访问说明符，所有成员都将设置为“私有”。 |
| 申报 | 

```
struct structure_name{
type struct_member 1;
type struct_member 2;
type struct_member 3;
.
type struct_memberN;
};
```

 | 

```
class class_name{
data member;
member function;
};
```

 |
| 情况 | 结构实例称为“结构变量”。 | 类实例称为“对象”。 |
| 遗产 | 它不支持继承。 | 它支持继承。 |
| 分配的内存 | 内存分配在堆栈上。 | 内存在堆上分配。 |
| 自然 | 值类型 | 参考类型 |
| 目的 | 数据分组 | 数据抽象和进一步继承。 |
| 使用 | 它用于较小数量的数据。 | 它用于大量数据。 |
| 空值 | 不可能 | 它可能有空值。 |
| 需要构造函数和析构函数 | 它可能只有参数化构造函数。 | 它可能有所有类型的构造函数和析构函数。 |

## 类似

下面是结构和类之间的相似之处:

*   类和结构都可以声明它们的任何成员是私有的。
*   类和结构都支持继承机制。
*   在 C++ 中，类和结构在语法上是相同的。
*   类或结构的名称可以用作独立类型。

## 结论

C 语言中的结构有一些局限性，比如不能隐藏数据，不能把‘struct’数据当作内置类型，缺乏继承支持。C++ 结构克服了这些缺点。

C++ 中结构的扩展版本称为类。程序员很容易使用类来保存数据和函数，而结构只保存数据。

* * *