# C++ 中构造函数和析构函数的区别？

> 原文：<https://www.javatpoint.com/constructor-vs-destructor-in-cpp>

在本文中，我们将看到 C++ 编程语言中构造函数和析构函数之间的比较。我们将从本文中学到的第一件事是构造函数和析构函数的基本思想。之后，我们将学习 C++ 编程中构造函数和析构函数的各种比较。

![Constructor vs Destructor in C++](img/54fe2f46655fa79ee8a5e845523a9259.png)

## 什么是 C++？

[C++](https://www.javatpoint.com/cpp-tutorial) 是 [C](https://www.javatpoint.com/c-programming-language-tutorial) 的超集，因为它支持面向过程和面向对象的[编程语言](https://www.javatpoint.com/programming-language)。它是一种中级语言。它具有各种特性，如封装、继承、抽象、数据隐藏、构造函数和析构函数。

## C++ 中的构造函数？

一个[构造函数](https://www.javatpoint.com/cpp-constructor)是一个与类名同名的特殊成员函数。每当创建类的对象时，它都会自动调用。

### 语法:

**c++ 中构造函数的语法如下。**

```

class class_name
{
……….
public
class_name ([parameter list])
{
……………….
}
};

```

在上面给出的语法中，class_name 是构造函数的名称，public 是访问说明符，参数列表是可选的。

### 构造器示例:

```

#include <iostream.h>
#include <conio.h>
using namespace std;
class hello {     // The class
  public:           // Access specifier
   hello () {     // Constructor
      cout << "Hello World! Program in C++ by using Constructor";
    }
   void display() {
     cout <<"Hello World!" <<endl;
   }
};
int main() {
  hello myObj;   /
  return 0;
}

```

**c++ 中使用的构造函数有四种类型。**

*   默认构造函数
*   动态构造函数
*   参数化构造函数
*   复制构造函数

**默认构造函数:**构造函数是不接受参数的类，称为默认构造函数。如果类没有构造函数，编译器会隐式创建一个默认构造函数。

**以下是默认构造函数**的语法:

```

class class_name {
private:
………..
………..
public:
class_name ()
{
…….
}
}

```

在这种类型的构造函数中，没有参数和参数列表。

如果类中没有定义构造函数，编译器会自动创建类的默认构造函数。

**示例:**

```

class student {
private:
………..
………..
public:
student ()
{
…….
}
}

```

班级学生的默认构造函数如下所示:

```
hello::hello()

```

**参数化构造函数:**构造函数是可以取参数的类，称为参数化构造函数。它用于用一组不同的值初始化对象。

**参数化构造函数的语法如下。**

```

Class classname
{
…………;
…………;
Public:
Class name (parameter list)
{
………….;
}
};

```

在这里，我们可以定义构造函数的参数列表。

**复制构造函数:**用于创建现有对象的特定构造函数。复制构造函数用于从另一个相同类型的对象中初始化该对象。

**语法:**

**复制构造函数的语法如下。**

```

Class (classname, &object)
{
………….;
………….;
}

```

在上面的语法中，对象指的是用来初始化另一个对象的东西。

**动态构造函数:**这种类型的构造函数可用于在创建对象时分配内存。对象创建后的数据成员可以初始化，称为动态初始化。

## C++ 中的析构函数？

[析构函数](https://www.javatpoint.com/cpp-destructor)具有相同的类名，前面带有(~)波浪符号。它移除并销毁对象的内存，该内存是构造函数在创建对象期间分配的。

### **语法:**

**c++ 中析构函数的语法如下。**

```

class class_name
{
…………….;
…………….;
public:
xyz();            //constructor
~xyz();           //destructor
};

```

在这里，我们使用波浪号来定义 C++ 编程中的析构函数。

析构函数没有参数，也不返回值，所以不能重载。

### 析构函数的例子:

```

#include <iostream.h>
#include <conio.h>
using namespace std;
class Hello {
public:
  //Constructor
  Hello () {
    cout<< "Constructor function is called" <<endl;
  }
  //Destructor
  ~Hello () {
    cout << "Destructor function is called" <<endl;
   }
   //Member function
   void display() {
     cout <<"Hello World!" <<endl;
   }
};
int main(){
   //Object created
   Hello obj;
   //Member function called
   obj.display();
   return 0;
}

```

## C++ 编程中构造函数和析构函数的区别

下表显示了 C++ 编程语言中构造函数和析构函数之间的各种差异:

| 基础 | 构造器 | 破坏者 |
| **使用目的** | 为了给对象分配内存，我们在 C++ 中使用了一个构造函数。 | 为了释放构造函数为此分配给对象的内存，我们在 C++ 中使用析构函数的概念。 |
| **论据** | 它可能包含也可能不包含参数。 | 它不能包含参数。 |
| **呼叫** | 每当创建类的对象时，都会自动调用它。 | 每当程序终止时都会自动调用它。 |
| **记忆** | 构造函数占用内存。 | 析构函数释放内存。 |
| **返回式** | 它有返回类型。 | 它没有任何返回类型。 |
| **特殊符号** | 在 C++ 编程语言中声明构造函数时，不需要特殊符号。 | 在 C++ 编程语言中声明析构函数时，需要一个特定的符号，即 tilde 符号。 |
| **在数字中** | 我们可以在程序中使用多个构造函数。 | 我们不能在程序中使用多个析构函数。 |
| **继承** | 可以遗传。 | 它不能被继承。 |
| **过载** | 它可能会过载。 | 它不能过载。 |
| **执行令** | 它们是按顺序执行的。 | 它们以构造函数的相反顺序执行；基本上，它们是构造函数的反函数。 |
| **类型** | 构造函数有四种类型:

*   Default constructor
*   Copy constructor
*   Parameterized constructor
*   Dynamic constructor

 | 析构函数没有类。 |
| **申报** | 以下声明用于创建构造函数:

```
class class_name
{
……….
public
class_name ([parameter list])
{
……………….
}
};

```

 | 以下声明用于创建析构函数:

```
class class_name
{
…………….;
…………….;
public:
~xyz();  
{
…………         
};

```

 |

* * *