# C++ 中的朋友函数

> 原文：<https://www.javatpoint.com/friend-function-in-cpp>

我们已经知道，在面向对象的编程语言中，类的成员只能访问类的数据和函数，而外部函数不能访问类的数据。可能会出现外部函数需要访问类的私有成员的情况，因此在这种情况下，friend 函数就出现了。

## 什么是朋友功能？

友元函数是在类范围之外定义的类的函数，但它有权访问该类的所有私有和受保护成员。

朋友函数出现在类定义中，但朋友是成员函数。

## 朋友功能的特征:

*   该函数不在已声明为友元的类的范围内。
*   不能使用对象调用它，因为它不在该类的范围内。
*   它可以像普通函数一样调用，而无需使用对象。
*   它不能直接访问成员名，必须使用对象名和带成员名的点成员运算符。
*   它可以在私有或公共部分声明。

## 为什么我们在 C++ 中需要一个朋友函数？

*   当需要直接访问类私有数据而不使用该类的对象时，使用 C++ 中的 Friend 函数。
*   Friend 函数也用于执行运算符重载。正如我们已经知道的函数重载一样，运算符也可以在运算符重载的帮助下重载。

**朋友功能的特征**

*   使用 friend 关键字声明 friend 函数。
*   它不是班级的成员，但它是班级的朋友。
*   因为它不是类的成员，所以它可以像普通函数一样定义。
*   Friend 函数不直接访问类数据成员，但是它们传递一个对象作为参数。
*   这就像一个正常的功能。
*   如果我们想在一个函数中共享多个类的数据，那么我们可以使用 friend 函数。

**友元函数声明的语法。**

```

class class_name    
{    
    friend data_type function_name(argument/s);            // syntax of friend function  
};    

```

在上面的声明中，friend 函数前面是关键字 friend。该函数可以像普通的 [C++](https://www.javatpoint.com/cpp-tutorial) 函数一样在程序中的任何地方定义。函数定义既没有使用关键字 **friend，也没有使用范围解析运算符**。

**我们通过一个例子来了解一下好友功能。**

```

#include 
using namespace std;
class Distance
{
    private:
    int meters;
    public:
// constructor
    Distance()
    {
        meters = 0;
    }
    // definition of display_data() method
    void display_data()
    {
        std::cout << "Meters value : " << meters<<:endl of="" a="" friend="" function.="" void="" addvalue="" definition="" function="" argument="" contain="" the="" reference="" d.meters="d.meters+10;" incrementing="" value="" meters="" by="" main="" method="" int="" distance="" d1="" creating="" object="" class="" distance.="" d1.display_data="" calling="" return=""/>
```

在上面的代码中，**距离**是包含名为“**米**的私有字段的类。**距离()**是用 0 初始化‘米’值的构造方法。 **display_data()** 是显示“米”值的方法。**加数()**是距离类的友元函数，修改**【米】**的值。在 **main()** 方法内部，d1 是一个 Distance 类的对象。

**输出**

![Friend Function in C++](img/0f1c5b0af9f88f0d0e269089ee82b5f1.png)

当我们处理两个不同类的对象时，Friend 函数也很有用。

**我们通过一个例子来了解一下。**

```

// Add members of two different classes using friend functions
#include using namespace std;
// forward declaration of a class
class ClassB;

// declaration of a class
class ClassA {
 public:
        // constructor ClassA() to initialize num1 to 12
        ClassA()
        {
            num1 =12;

        }

    private:
        int num1;  // declaration of integer variable

         // friend function declaration
         friend int multiply(ClassA, ClassB);
};
class ClassB {
public:
        // constructor ClassB() to initialize num2 to 2
        ClassB()  
        {
            num2 = 2;
        }
    private:
        int num2;  // declaration of integer variable
 // friend function declaration
        friend int multiply(ClassA, ClassB);
};

// access members of both classes
int multiply(ClassA object1, ClassB object2) 
{
    return (object1.num1 * object2.num2);
}

int main() {
    ClassA object1;   // declaration of object of ClassA
    ClassB object2;   // declaration of object of ClassB
    cout << "Result after multiplication of two numbers is : " << multiply(object1, object2);
    return 0;
} 
```

在上面的代码中，我们定义了两个名为**类**和**类**的类。这两个类都包含友元函数“**乘法()**”。friend 函数可以访问两个类的数据成员，即 **ClassA** 和 **ClassB** 。**乘()**功能分别访问 **ClassA** 和 **ClassB** 的 **num1** 和 **num2** 。在上面的代码中，我们分别创建了 ClassA 和 ClassB 的 object1 和 object2。函数的作用是:将 num1 和 num2 相乘，然后返回结果。

从上面的代码中我们可以观察到 **ClassA** 中的 friend 函数也在使用 **ClassB** 而没有事先声明 **ClassB** 。所以，在这种情况下，我们需要提供 **ClassB** 的远期申报。

**输出**

![Friend Function in C++](img/5ef279b48622316e0c64587e9d07b612.png)

## C++ 中的朋友类

我们也可以借助**好友**关键字创建好友类。

```

class Class1;
class Class2
{
  // Class1 is a friend class of Class2
     friend class Class1;
     .. .....
}
class Class1
{
   ....
}

```

在上面的声明中，类 1 被声明为类 2 的朋友类。类 2 的所有成员都可以在类 1 中访问。

**我们通过一个例子来了解一下。**

```

// C++ program to demonstrate the working of friend class
#include using namespace std;
// forward declaration
class ClassB;

class ClassA {
    private:
        int num1;

        // friend class declaration
        friend class ClassB;

    public:
        // constructor to initialize numA to 10
        ClassA()
        {
            num1 = 10; 
        }
};

class ClassB {
    private:
        int num2;

    public:
        // constructor to initialize numB to 1
        ClassB()
        {
            num2 = 1; 
        }

    // member function to add num1
    // from ClassA and num2 from ClassB
    int add() {
        ClassA objectA;
        return objectA.num1 + num2;
    }
};

int main() {
    ClassB objectB;
    cout << "Sum: " << objectB.add();
    return 0;
} 
```

在上面的代码中，我们创建了两个名为 ClassA 和 ClassB 的类。因为类 a 被声明为类 b 的朋友，所以类 a 可以访问类 b 的所有数据成员。在 ClassB 中，我们定义了一个函数 add()，它返回 num1 和 num2 的和。因为类 B 被声明为类 A 的朋友，所以我们可以在类 B 中创建类 A 的对象。

**输出**

![Friend Function in C++](img/341fd2e370e5a87e93168f0a23edcb32.png)

* * *