# C++ 中的内联函数

> 原文：<https://www.javatpoint.com/inline-function-in-cpp>

如果将函数设置为内联函数，则编译器会在编译时用内联函数的定义替换函数调用位置。

对内联函数所做的任何更改都需要再次重新编译内联函数，因为编译器需要用新代码替换所有代码；否则，它将执行旧的功能。

**内联函数的语法:**

```

inline return_type function_name(parameters)
{
   // function code?
} 

```

**我们来了解一下普通函数和内联函数的区别。**

在 **main()** 方法内部，调用 fun1()函数时，控制权转移到被调用函数的定义上。调用函数的地址和函数的定义是不同的。这种控制转移花费了大量时间，并增加了开销。

遇到内联函数时，会将函数的定义复制到该函数中。在这种情况下，没有控制转移，这节省了大量时间，也减少了开销。

**我们通过一个例子来了解一下。**

```

#include 
using namespace std;
inline int add(int a, int b)
{
    return(a+b);
}
int main()
{
    cout<
```

编译完成后，代码如下所示:

```

#include using namespace std;
inline int add(int a, int b)
{
     return(a+b); 
}
int main()
{
      cout<
```

**为什么我们在 C++ 中需要一个内联函数？**

C++ 中内联函数的主要用途是节省内存空间。无论何时调用函数，都需要花费大量的时间来执行任务，例如转移到调用函数。如果函数的长度很小，那么大量的执行时间将花费在这种开销上，并且有时转移到调用函数所需的时间将大于执行该函数所需的时间。

这个问题的解决方案是使用称为宏的宏定义。预处理器宏在 C 语言中被广泛使用，但是宏的主要缺点是这些不是正常的函数，这意味着错误检查过程不会在编译过程中完成。

C++ 为这个问题提供了一个解决方案。在函数调用的情况下，调用如此小的函数的时间是巨大的，所以为了克服这样的问题，引入了一个新的概念，称为内联函数。当在 main()方法中遇到该函数时，它会用其定义进行扩展，从而节省时间。

在下列情况下，我们不能提供函数的内联:

*   如果函数是递归的。
*   如果函数包含一个循环，如 for、while、do-while 循环。
*   如果函数包含静态变量。
*   如果函数包含开关或 go to 语句

**我们什么时候需要内联函数？**

内联函数可用于以下情况:

*   当需要性能时，可以使用内联函数。
*   它可以在宏上使用。
*   我们可以在类外使用内联函数，这样我们就可以隐藏函数的内部实现。

### 内联函数的优点

*   在内联函数中，我们不需要调用函数，因此不会造成任何开销。
*   它还节省了函数返回语句的开销。
*   它不需要任何堆栈，我们可以在上面推送或弹出变量，因为它不执行任何函数调用。
*   内联函数主要对嵌入式系统有益，因为它产生的代码比普通函数少。

### 内联函数的缺点

**以下是内联函数的缺点:**

*   在内联函数中创建的变量将消耗额外的寄存器。如果变量增加，那么寄存器的使用也会增加，这可能会增加寄存器变量资源利用的开销。这意味着当函数调用被内联函数体替换时，变量的数量也会增加，导致寄存器的数量增加。这导致了资源利用的开销。
*   如果我们使用许多内联函数，那么二进制可执行文件也会变大。
*   使用如此多的内联函数可以降低指令缓存命中率，从而降低从缓存内存到主内存的指令提取速度。
*   它还增加了编译时开销，因为每当在内联函数内部进行更改时，都需要再次重新编译代码以反映这些更改；否则，它将执行旧的功能。
*   有时内联函数对许多嵌入式系统没有用处，因为在某些情况下，嵌入式的大小被认为比速度更重要。
*   由于二进制可执行文件的大小增加，它也可能导致抖动。如果内存中出现抖动，则会导致计算机性能下降。

* * *