# 如何在 C++ 中拆分字符串？

> 原文：<https://www.javatpoint.com/how-to-split-strings-in-cpp>

本主题将讨论如何在 [C++ 编程语言](https://www.javatpoint.com/cpp-tutorial)中将给定的字符串拆分成一个单词。当我们将一组单词或字符串集合划分为单个单词时，这被称为**分裂**或字符串的分裂。但是，只有使用一些分隔符(如空格( )、逗号(，)和连字符(-)等)才能拆分字符串。，使文字成为一个个体。此外，没有预定义的分割函数将字符串集合分割成单个字符串。因此，这里我们将学习在 C++ 中将字符串拆分成单个字符串的不同方法。

![How to Split strings in C++](img/67ad9dab2e45a3e63dba09eca3bab126.png)

## 用 C++ 实现字符串拆分的不同方法

1.  使用 strtok()函数拆分字符串
2.  使用自定义 split()函数拆分字符串
3.  使用 std::getline()函数拆分字符串
4.  使用 find()和 substr()函数拆分字符串

### 使用 strtok()函数拆分字符串

**strtok():**strtok()函数用于根据传递的分隔符将原始字符串拆分成片段或标记。

**语法**

```

char *ptr = strtok( str, delim)

```

在上面的语法中，strtok()有两个参数， **str** 和 **delim** 。

**字符串**:字符串是 strtok()函数从中拆分字符串的原始字符串。

**delim** :是用来拆分字符串的字符。例如，逗号(，)，空格( )，连字符(-)，等等。

**返回**:返回引用下一个字符标记的指针。最初，它指向字符串的第一个标记。

#### 注意:strtok()函数会修改原始字符串，并在每次调用 strtok()函数时在分隔符位置放置一个空字符(“\0”)。这样，它可以轻松跟踪令牌的状态。

### 使用 strtok()函数拆分字符串的程序

让我们考虑一个使用 strtok()函数在 C++ 中拆分字符串的例子。

**Program.cpp**

```

#include 
#include <cstring>
using namespace std;

int main()
{
	char str[100]; // declare the size of string	
	cout << " Enter a string: " <</cstring>
```

**输出**

```
Enter a string:
Learn how to split a string in C++ using the strtok() function.

 Split string using strtok() function:
Learn
how
to
split
a
string
in
C++
Using
the
strtok()
function.

```

### 使用自定义 split()函数拆分字符串的程序

让我们编写一个程序，使用自定义 split()函数在 C++ 中拆分字符串序列。

**Program2.cpp**

```

#include 
#include <string>
#define max 8 // define the max string
using namespace std;

string strings[max]; // define max string

// length of the string
int len(string str)
{
	int length = 0;
	for (int i = 0; str[i] != '\0'; i++)
	{
		length++;

	}
	return length;   
}

// create custom split() function
void split (string str, char seperator)
{
	int currIndex = 0, i = 0;
	int startIndex = 0, endIndex = 0;
	while (i <= len(str))
	{
		if (str[i] == seperator || i == len(str))
		{
			endIndex = i;
			string subStr = "";
			subStr.append(str, startIndex, endIndex - startIndex);
			strings[currIndex] = subStr;
			currIndex += 1;
			startIndex = endIndex + 1;
		}
		i++;
		}	
}

int main()
{
	string str = "Program to split strings using custom split function.";
	char seperator = ' '; // space
	split(str, seperator);
	cout <</string>
```

**输出**

```
The split string is:
 i : 0 Program
 i : 1 to
 i : 2 split
 i : 3 strings
 i : 4 using
 i : 5 custom
 i : 6 split
 i : 7 function.

```

### 使用 std::getline()函数拆分字符串

getline()函数是 C++ 的标准库函数，用于从输入流中读取字符串，并将其放入向量字符串中，直到找到分隔符。我们可以通过导入<字符串>头文件来使用 **std::getline()** 函数。

**语法**

```

getline(str, token, delim);

```

它有三个参数:

**字符串:**字符串是存储原始字符串的变量。

**令牌:**存储从原始字符串中提取的字符串令牌。

**delim:** 是用来拆分字符串的字符。例如，逗号(，)，空格( )，连字符(-)，等等。

### 使用 getline()函数拆分字符串的程序

让我们考虑一个在 C++ 中使用 getline()函数拆分字符串的例子。

**Program3.cpp**

```

#include #include <string>#include <vector>#include <sstream>using namespace std;

int main()
{
    string S, T;  // declare string variables

    getline(cin, S); // use getline() function to read a line of string and store into S variable.

    stringstream X(S); // X is an object of stringstream that references the S string

 	// use while loop to check the getline() function condition
    while (getline(X, T, ' ')) {
    	/* X represents to read the string from stringstream, T use for store the token string and,
		 ' ' whitespace represents to split the string where whitespace is found. */

        cout << T << endl; // print split string
    }

    return 0;
}</sstream></vector></string> 
```

**输出**

```
Welcome to the JavaTpoint and Learn C++ Programming Language.
Welcome
to
the
JavaTpoint
and
Learn
C++
Programming
Language.

```

### 使用 getline()函数分割给定字符串的程序

让我们考虑一个使用 getline()函数在 C++ 中拆分给定字符串的例子。

**Program4.cpp**

```

#include #include <string>#include <vector>#include <sstream>void split_str( std::string const &str, const char delim,
		std::vector <:string> &out )
		{
			// create a stream from the string
			std::stringstream s(str);

			std::string s2;
			while (std:: getline (s, s2, delim) )
			{
				out.push_back(s2); // store the string in s2
			}
		}

		int main()
		{
			std:: string s2 = "Learn How to split a string in C++";
			const char delim = ' '; /* define the delimiter like space (' '), comma (,), hyphen (-), etc. */

			std::cout << "Your given string is: " << s2;  
			std::vector <:string> out; // store the string in vector
			split_str (s2, delim, out); // call function to split the string

			// use range based for loop
			for (const auto &s2: out)
			{
				std::cout << "\n" << s2;
			}
			return 0;
		}</sstream></vector></string> 
```

**输出**

```
Your given string is: Learn How to split a string in C++
Learn
How
to
split
a
string
in
C++

```

### 使用 find()和 substr()函数拆分字符串

让我们编写一个程序，使用 find()函数和 substr()函数在 C++ 中拆分给定的字符串。

**Program4.cpp**

```

#include #include <string>using namespace std;
int main()
{
// given string with delimiter
string given_str = "How_to_split_a_string_using_find()_and_substr()_function_in_C++";
string delim = "_"; // delimiter

cout << " Your string with delimiter is: " << given_str << endl;
size_t pos = 0;
string token1; // define a string variable

// use find() function to get the position of the delimiters
while (( pos = given_str.find (delim)) != std::string::npos)
{
token1 = given_str.substr(0, pos); // store the substring 
cout << token1 << endl;
given_str.erase(0, pos + delim.length());  /* erase() function store the current positon and move to next token. */ 
}
cout << given_str << endl; // it print last token of the string.
}</string> 
```

**输出**

```
Your string with delimiter is: How_to_split_a_string_using_find()_and_substr()_function_in_C++
How
to
split
a
string
using
find()
and
substr()
function
in
C++

```

在上面的程序中，我们在循环内部使用了一个 **find()** 函数，反复查找给定字符串中分隔符的出现，然后在分隔符出现时将其拆分为记号。 **substr()** 函数存储要打印的子字符串。另一方面，erase()函数存储字符串的当前位置，并移动到下一个标记，这个过程一直持续到我们得到所有拆分的字符串。

* * *