# C++ 中的类型转换

> 原文：<https://www.javatpoint.com/type-conversion-in-cpp>

在本主题中，我们将讨论在 C++ 编程语言中将一种数据类型转换为另一种数据类型。类型转换是将一个变量的预定义数据类型转换为适当数据类型的过程。类型转换背后的主要思想是将两个不同的数据类型变量转换为单个数据类型，以轻松解决数学和逻辑表达式，而不会丢失任何数据。

![Type Conversion in C++](img/15b26b464888522d651d842d70152131.png)

例如，我们正在添加两个数字，其中一个变量是 int 类型，另一个是 float 类型；我们需要将 int 变量转换或类型转换为 float，使它们都成为 float 数据类型来添加它们。

类型转换在 C++ 中有两种方式可以完成，一种是**隐式类型转换**，第二种是**显式类型转换**。这些转换由编译器自己完成，称为隐式类型转换或自动类型转换。由用户完成或需要用户干预的转换称为显式或用户定义类型转换。让我们讨论一下 C++ 中的隐式和显式类型转换。

### 隐式类型转换

隐式类型转换是由编译器自动完成的转换类型，无需任何人工操作。这意味着隐式转换会根据 C++ 编译器的一些预定义规则，自动将一种数据类型转换为另一种类型。因此，它也被称为**自动类型转换**。

**例如:**

```

int x = 20;
short int y = 5;
int z = x + y;

```

在上面的例子中，有两个不同的数据类型变量，x 和 y，其中 x 是 int 类型，y 是短 int 数据类型。结果变量 z 也是存储 x 和 y 变量的整数类型。但是 C++ 编译器会在得出两个数的和之前，自动将低秩数据类型(短 int)值转换为高秩数据类型(int)。因此，它避免了 C++ 隐式类型转换中的数据丢失、溢出或符号丢失。

### 隐式转换中类型转换的顺序

以下是数据类型从低级到高级的正确顺序:

```

bool -> char -> short int -> int -> unsigned int -> long int -> unsigned long int -> long  long int -> float -> double -> long double

```

### 使用隐式类型转换将 int 转换为 float 类型的程序

让我们创建一个程序，使用隐式类型转换将较小的等级数据类型转换为较高的类型。

**Program1.cpp**

```

#include using namespace std; 
int main ()
{
// assign the integer value
int num1 = 25;
// declare a float variable
float num2;
// convert int value into float variable using implicit conversion
num2 = num1;    
cout <<  " The value of num1 is: " << num1 << endl;
cout <<  " The value of num2 is: " << num2 << endl;
return 0;	
} 
```

**输出**

```
The value of num1 is: 25
The value of num2 is: 25

```

### 使用隐式类型转换将 double 转换为 int 数据类型的程序

让我们创建一个程序，使用隐式类型转换将较高的数据类型转换为较低的类型。

**Program2.cpp**

```

#include using namespace std;
int main()
{
int num; // declare int type variable 
double num2 = 15.25; // declare and assign the double variable 

// use implicit type conversion to assign a double value to int variable
num = num2;
cout << " The value of the int variable is: " << num << endl;
cout << " The value of the double variable is: " << num2 << endl;
return 0;
} 
```

**输出**

```
The value of the int variable is: 15
 The value of the double variable is: 15.25

```

在上面的程序中，我们已经将 num 声明为整数类型，num2 声明为双数据类型变量，然后将 num2 赋值为 15.25。之后，我们使用赋值运算符将 num2 值赋给 num 变量。因此，C++ 编译器在将双精度数据值赋给 num 变量之前，会自动将其转换为整数类型，并将截断值打印为 15。

### 显式类型转换

需要**用户干预**将一个变量的数据类型更改为另一个变量的转换称为**显式类型转换**。换句话说，显式转换允许程序员手动将数据类型从一个变量更改或类型转换为另一个类型。因此，它也被称为类型转换。通常，我们强制显式类型转换将数据从一种类型转换为另一种类型，因为它不遵循隐式转换规则。

显式类型转换分为两种方式:

1.  使用强制转换运算符的显式转换
2.  使用赋值运算符的显式转换

### 使用强制转换运算符将浮点值转换为 int 类型的程序

**强制转换运算符:**在 C++ 语言中，强制转换运算符是将一种类型强制转换为另一种类型的一元运算符。

让我们考虑一个使用 C++ 语言中显式转换的强制转换运算符将浮点数据类型转换为 int 类型的示例。

**Program3.cpp**

```

#include using namespace std;
int main ()
{
float f2 = 6.7;
// use cast operator to convert data from one type to another
int x = static_cast <int>(f2);
cout << " The value of x is: " << x;
return 0;
}</int> 
```

**输出**

```
The value of x is: 6

```

### 使用赋值运算符将一种数据类型转换为另一种数据类型的程序

让我们考虑一个使用 C++ 程序中的赋值运算符将一个变量的数据类型转换成另一个变量的例子。

**Program4.cpp**

```

#include using namespace std;
int main ()
{
// declare a float variable
float num2;
// initialize an int variable
int num1 = 25;

// convert data type from int to float
num2 = (float) num1;
cout << " The value of int num1 is: " << num1 << endl;
cout << " The value of float num2 is: " << num2 << endl;
return 0;
} 
```

**输出**

```
The value of int num1 is: 25
The value of float num2 is: 25.0

```

* * *