# 在 C++ 中将字符串转换为整数

> 原文：<https://www.javatpoint.com/convert-string-to-integer-in-cpp>

本节将讨论使用 C++ 编程语言将给定的字符串数据转换为整数的不同方法。在某些情况下，我们需要将某个数据转换为另一种类型，其中一种情况是在编程中将字符串转换为 int 数据。

例如，我们有一个数字字符串作为“ **143** ”，我们希望将其转换为数字类型。我们需要使用一个函数，将字符串转换为整数，并将数字数据返回为 143。现在，我们将学习 C++ 编程语言中帮助将字符串数据转换为整数的每种方法。

![Convert string to integer in C++](img/5a3cadc29d75c6417ffbfbcf565def28.png)

在 C++ 编程语言中将字符串数据转换为整数的不同方法。

1.  使用 stringstream 类
2.  使用 stoi()函数
3.  使用 atoi()函数
4.  使用 sscanf()函数

### 使用 stringstream 类

**字符串流**是一个用于将数字字符串转换为整型的类。stringstream 类声明一个流对象，将字符串作为流对象插入，然后基于流提取转换后的整数数据。stringstream 类有“< <”和“> >”运算符，用于从(< <)运算符获取数据，并通过将流传递给(> >)左运算符来插入数据。

让我们创建一个程序来演示用 C++ 编程语言将字符串数据转换成整数的 stringstream 类。

**Program1.cpp**

```

#include #include <sstream>// use stringstream class
using namespace std;

int main()
{
	string str1 = "143"; // declare a string

	int intdata; // declare integer variable

	/* use stringstream class to declare a stream object to insert a string and then fetch as integer type data. */

	 stringstream obj;
	 obj << str1; // insert data into obj
	 obj >> intdata; // fetch integer type data

	 cout << " The string value is: " << str1 << endl;
	 cout << " The representation of the string to integer type data is: " << intdata << endl;
	 return 0;
}</sstream> 
```

**输出**

```
The string value is: 143
 The representation of the string to integer type data is: 143	

```

在上面的程序中，我们使用 stringstream 类创建了一个 obj 对象，它有助于将字符串数据转换为整数。然后，我们使用“<>”运算符将转换后的字符串从 obj 提取为数字数据。

### 使用 sscanf()函数

sscanf()函数将给定的字符串转换为指定的数据类型，如整数。

**语法**

```

sccanf ( str, %d, &intvar);

```

sscanf()函数有三个参数来指定字符字符串(str)、数据说明符(%d)和整数变量(&intvar)来存储转换后的字符串。

**sscanf()函数的算法**

1.  sscanf()函数属于 stringstream 类，因此我们需要将该类导入到我们的程序中。
2.  初始化一个常量字符串。
3.  创建一个整数变量，将转换后的字符串保存为整数值。
4.  将字符串变量传递给 sscanf()函数，并将 sscanf()函数赋给整数变量以存储该函数生成的整数值。
5.  打印整数值。

让我们考虑一个在 C++ 中使用 sscanf()函数将字符串转换为数字的例子。

**Program2.cpp**

```

#include 
#include <sstream> // use stringstream class
using namespace std;

int main ()
{
	// declare the character strings
	const char *str1 = "555"; 
	const char *str2 = "143"; 
	const char *str3 = "101"; 

	// declare the integer variables 
	int numdata1; 
	int numdata2; 
	int numdata3; 

	/* use sscanf() function and to pass the character string str1,
	 and an integer variable to hold the string. */
	 sscanf (str1, "%d", &numdata1);
	 cout <</sstream>
```

**输出**

```
The value of the character string is: 555
 The representation of string to int value of numdata is: 555

 The value of the character string is: 143
 The representation of string to int value of numdata is: 143

 The value of the character string is: 101
 The representation of string to int value of numdata is: 101

```

### 使用 stoi()函数

stoi()函数通过将字符串作为参数传递来返回整数值，从而将字符串数据转换为整数类型。

**语法**

```

stoi(str);

```

stoi()函数包含一个字符串参数。str 字符串在 stoi()函数中传递，以将字符串数据转换为整数值。

**stoi()函数的算法**

1.  初始化字符串变量以存储字符串值。
2.  之后，它创建一个整数类型变量，使用 stoi()函数存储字符串到整数类型数据的转换。
3.  打印整数变量值。

让我们创建一个程序，使用 stoi()函数将字符串值转换为 C++ 编程语言中的整数类型。

**Program3.cpp**

```

#include 
#include <string>
using namespace std;

int main ()
{
	string strdata1 = "108";
	string strdata2 = "56.78";
	string strdata3 = "578 Welcome";

	// use stoi() function to pass string as arguments
	int intdata1 = stoi (strdata1);
	int intdata2 = stoi (strdata2);
	int intdata3 = stoi (strdata3);

	// print the converted values
	cout << " The conversion of string to an integer using stoi(\"" << strdata1 << "\") is " << intdata1 <</string>
```

**输出**

```
The conversion of string to an integer using stoi("108") is 108
 The conversion of string to an integer using stoi("56.78") is 56
 The conversion of string to an integer using stoi("578 Welcome") is 578

```

### 使用 atoi()函数

atoi()函数用于将字符串转换为整数值。atoi()函数传递字符类型字符串以返回整数数据。

**语法**

```

atoi (const char *str);

```

**atoi()函数的算法**

1.  初始化指针类型的字符数组来存储字符串。
2.  之后，它创建一个整数类型变量，使用 atoi()函数存储字符串到整数类型数据的转换。
3.  打印整数变量值。

让我们创建一个程序，使用 atoi()函数将字符串值转换为 C++ 编程语言中的整数类型。

**Program4.cpp**

```

#include 
#include <string>
using namespace std;

int main ()
{
	// declare a constant character array of string 
	const char *strdata1 = "256";
	const char *strdata2 = "16.18";
	const char *strdata3 = "1088 Good Bye";

	// use atoi() function to pass character type array as arguments
	int intdata1 = atoi (strdata1);
	int intdata2 = atoi (strdata2);
	int intdata3 = atoi (strdata3);

	// print the converted values
	cout << " The conversion of string to an integer value using atoi(\"" << strdata1 << "\") is " << intdata1 <</string>
```

**输出**

```
The conversion of string to an integer value using atoi("256") is 256
 The conversion of string to an integer value using atoi("16.18") is 16
 The conversion of string to an integer value using atoi("1088 Good Bye") is 1088

```

* * *