# 用 C++ 初始化向量

> 原文：<https://www.javatpoint.com/initialize-vector-in-cpp>

向量可以像数组一样存储多个数据值，但它们只能存储对象引用，而不能存储基本数据类型。它们存储对象的引用意味着它们指向包含数据的对象，而不是存储它们。与数组不同，向量不需要用大小初始化。它们可以根据对象引用的数量灵活调整，这是可能的，因为它们的存储是由容器自动处理的。容器将保留 alloc 的内部副本，该副本用于在生存期内分配存储。向量可以使用迭代器来定位和遍历，所以它们被放在连续的存储器中。Vector 也有安全功能，不像 Array 那样可以避免程序崩溃。我们可以给向量预留空间，但不能给数组。数组不是类，但向量是类。在 vector 中，可以删除元素，但不能删除数组中的元素。

对于父“集合类”，向量以模板类的形式发送。数组是具有特定属性的低级数据结构。向量有函数和构造函数；它们不是基于索引的。它们与数组相反，数组是基于索引的数据结构。这里，最低地址被提供给第一个元素，最高地址被提供给最后一个元素。向量用于对象的插入和删除，而数组用于对象的频繁访问。阵列是节省内存的数据结构，而矢量利用更多的内存来管理存储并动态增长。Vector 需要更多的时间来访问元素，但 Arrays 却不是这样。

在 C++ 中有四种初始化[向量的方法:](https://www.javatpoint.com/cpp-vector)

*   通过逐个输入值
*   通过使用向量类的重载构造函数
*   借助于数组
*   通过使用另一个初始化的向量

### 通过一个接一个地输入值-

可以使用向量类方法“push_back”逐个插入向量中的所有元素。

**算法**

```

   Begin
   Declare v of vector type.
   Then we call push_back() function. This is done to insert values into vector v.
   Then we print "Vector elements: \n".
  " for (int a: v)
      print all the elements of variable a."

```

**代码-**

```

#include <iostream>
#include <vector>
using namespace std;
int main() 
{
  vector<int> vec;  
  vec.push_back(1); 
  vec.push_back(2); 
  vec.push_back(3);
  vec.push_back(4); 
  vec.push_back(5);
  vec.push_back(6); 
  vec.push_back(7); 
  vec.push_back(8);
  vec.push_back(9); 
  vec.push_back(101);
  for (int i = 0; i < vec.size(); i++)
  {
    cout << vec[i] << " "; 
  }
  return 0; 
}

```

**输出**

![Initialize Vector in C++](img/2210ffb8f2a52c41131fb9c7c196db40.png)

### 使用重载构造函数-

当一个向量有多个具有相同值的元素时，我们就用这个方法。

通过使用向量类的重载构造函数-

这种方法主要用于向量被多个相同值的元素填充时。

**算法**

```

Begin
   First, we initialize a variable say 's'.
   Then we have to create a vector say 'v' with size's'.
   Then we initialize vector v1.
   Then initialize v2 by v1.
   Then we print the elements.
End.

```

**代码-**

```

#include <iostream>
#include <vector>
using namespace std;
int main()
 {
  int elements = 12; 
  vector<int> vec(elements, 8); 
  for (int i = 0; i < vec.size(); i++)
  {
    cout << vec[i] << " \n"; 
  }
  return 0; 
}  

```

**输出**

```
8 
8 
8 
8 
8 
8 
8 
8 
8 
8 
8 
8

```

### 借助数组-

我们将数组传递给向量类的构造函数。数组包含将填充向量的元素。

**算法-**

```

Begin
   First, we create a vector say v.
   Then, we initialize the vector.
   In the end, print the elements.
End.

```

**代码-**

```

#include <iostream>
#include <vector>
using namespace std;
int main() 
{
  vector<int> vectr{9,8,7,6,5,4,3,2,1,0}; 
  for (int i = 0; i < vectr.size(); i++)
  {
    cout << vectr[i] << " \n"; 
  }
  return 0;
}

```

**输出**

```
9 
8 
7 
6 
5 
4 
3 
2 
1 
0

```

### 使用另一个初始化的向量-

这里，我们必须将初始化向量的 begin()和 end()迭代器传递给向量类构造函数。然后我们初始化一个新向量，并用旧向量填充它。

**算法-**

```

Begin
   First, we have to create a vector v1.
   Then, we have to initialize vector v1 by an array.
   Then we initialize vector v2 by v1.
   We have to print the elements.
End.

```

**代码-**

```

#include <iostream>
#include <vector>
using namespace std;
int main() 
{
  vector<int> vec_1{1,2,3,4,5,6,7,8};
  vector<int> vec_2(vec_1.begin(), vec_1.end());
  for (int i = 0; i < vec_2.size(); i++)
  {
    cout << vec_2[i] << " \n"; 
  }
  return 0; 
}

```

**输出**

```
1 
2 
3 
4 
5 
6 
7 
8

```

* * *