# C++ STL 集

> 原文：<https://www.javatpoint.com/cpp-set>

## 布景介绍

**集**是 **C++ STL(标准模板库)**的一部分。集合是存储排序关键字的关联容器，其中每个关键字都是唯一的，可以插入或删除，但不能更改。

## 句法

```

template < class T,                             // set::key_type/value_type
           class Compare = less<T>,        // set::key_compare/value_compare
           class Alloc = allocator<T>         // set::allocator_type
           > class set;

```

## 参数

**T** :储存在容器组中的元素类型。

**Compare** :一个比较类，接受两个相同类型 bool 的参数并返回一个值。这个参数是可选的，二进制谓词少了< T >，是默认值。

**Alloc** :用于定义存储分配模型的分配器对象的类型。

## 成员函数

下面是集合的所有成员函数的列表:

### 构造函数/析构函数

| 功能 | 描述 |
| [(建造师)](cpp-set-constructor) | 构造集合 |
| [(毁灭者)](cpp-set-destructor) | 设置析构函数 |
| [运算符=](cpp-set-operator=()-function) | 将集合的元素复制到另一个集合。 |

### 迭代程序

| 功能 | 描述 |
| [开始](cpp-set-begin-function) | 返回指向集合中第一个元素的迭代器。 |
| [cbegin](cpp-set-cbegin-function) | 返回指向集合中第一个元素的常量迭代器。 |
| [结束](cpp-set-end-function) | 返回指向过去结束的迭代器。 |
| [Cend](cpp-set-cend-function) | 返回指向过去结束的常量迭代器。 |
| [rbegin](cpp-set-rbegin-function) | 返回指向末尾的反向迭代器。 |
| [渲染](cpp-set-rend-function) | 返回指向开头的反向迭代器。 |
| crbegin | 返回一个指向末尾的常量反向迭代器。 |
| 信仰 | 返回指向开头的常量反向迭代器。 |

### 容量

| 功能 | 描述 |
| [空](cpp-set-empty-function) | 如果集合为空，则返回 true。 |
| [尺寸](cpp-set-size-function) | 返回集合中元素的数量。 |
| [最大尺寸](cpp-set-max_size-function) | 返回集合的最大大小。 |

### 修饰语

| 功能 | 描述 |
| [插入](cpp-set-insert-function) | 在集合中插入元素。 |
| [擦除](cpp-set-erase-function) | 从集合中删除元素。 |
| [互换](cpp-set-swap-function) | 交换集合的内容。 |
| [清除](cpp-set-clear-function) | 删除集合中的所有元素。 |
| [就位](cpp-set-emplace-function) | 构造新元素并将其插入集合中。 |
| 提示位置 | 通过提示构造新元素并将其插入集合中。 |

### 观察者

| 功能 | 描述 |
| [键 _comp](cpp-set-key_comp-function) | 返回密钥比较对象的副本。 |
| [值 _comp](cpp-set-value_comp-function) | 返回值比较对象的副本。 |

### 操作

| 功能 | 描述 |
| [查找](cpp-set-find-function) | 搜索具有给定关键字的元素。 |
| [计数](cpp-set-count-function) | 获取与给定键匹配的元素数。 |
| [下限](cpp-set-lower_bound-function) | 将迭代器返回到下限。 |
| [上限](cpp-set-upper_bound-function) | 将迭代器返回到上限。 |
| [等范围](cpp-set-equal_range-function) | 返回与给定键匹配的元素范围。 |

### 分配算符

| 功能 | 描述 |
| [get _ 分配器](cpp-set-get_allocator-function) | 返回用于构造集合的分配器对象。 |

## 非成员重载函数

| 功能 | 描述 |
| [运算符==](cpp-set-non-member-operator==) | 检查两个集合是否相等。 |
| [符！=](cpp-set-non-member-operator!=) | 检查两个集合是否相等。 |
| [操作员<](cpp-set-non-member-operator-less-than) | 检查第一个集是否小于其他集。 |
| [操作员< =](cpp-set-non-member-operator-less-than=) | 检查第一个集合是否小于或等于其他。 |
| [操作员>](cpp-set-non-member-operator-greater-than) | 检查第一个集合是否大于其他集合。 |
| [操作员> =](cpp-set-non-member-operator-greater-than=) | 检查第一个集合是否大于等于其他。 |
| [互换()](cpp-set-non-member-swap-function) | 交换两组元素。 |