# C++ 堆栈

> 原文：<https://www.javatpoint.com/cpp-stack>

在计算机科学中，我们致力于开发各种各样的程序。每个都有自己的领域和用途。基于程序创建的目的和环境，我们有大量的数据结构可供选择。其中之一就是‘栈’。在讨论这种数据类型之前，让我们先看看它的语法。

## 句法

```

template<class T, class Container = deque<T> > class stack;

```

这种数据结构基于后进先出技术，其中后进先出代表后进先出。第一次插入的元素将在最后被提取，以此类推。有一个名为“top”的元素，它是位于最上方的元素。所有的插入和删除操作都是在栈顶元素本身进行的。

应用程序区域中的堆栈被隐含为容器适配器。

容器应该支持以下操作列表:

*   空的
*   大小
*   背部
*   推回
*   弹回

## 模板参数

**T** :该参数指定容器适配器将要容纳的元素的类型。

**容器**:参数指定容器的内部对象，堆栈的元素保存在该对象中。

## 成员类型

下面给出了堆栈成员类型的列表，并对其进行了简短描述。

| 成员类型 | 描述 |
| 值类型 | 指定了元素类型。 |
| 容器类型 | 指定了基础容器类型。 |
| 大小类型 | 它指定元素的大小范围。 |

## 功能

在函数的帮助下，对象或变量可以在编程领域中使用。堆栈提供了大量可以在程序中使用或嵌入的功能。下面列出了相同的内容:

| 功能 | 描述 |
| (构造函数) | 该函数用于构造堆栈容器。 |
| [空](cpp-stack-empty-function) | 该函数用于测试堆栈是否为空。如果堆栈为空，函数返回 true，否则返回 false。 |
| [尺寸](cpp-stack-size-function) | 函数返回堆栈容器的大小，这是存储在堆栈中的元素数量的度量。 |
| [顶部](cpp-stack-top-function) | 该函数用于访问堆栈的顶部元素。元素起着非常重要的作用，因为所有的插入和删除操作都是在顶部元素上执行的。 |
| [推](cpp-stack-push-function) | 函数用于在堆栈顶部插入新元素。 |
| [流行](cpp-stack-pop-function) | 该函数用于删除元素，堆栈中的元素从顶部删除。 |
| [就位](cpp-stack-emplace-function) | 该函数用于在当前顶部元素上方的堆栈中插入新元素。 |
| 交换 | 该函数用于交换两个参考容器中的内容。 |
| 关系运算符 | 非成员函数指定堆栈所需的关系运算符。 |
| 使用分配器<stack></stack> | 顾名思义，非成员函数将分配器用于堆栈。 |

### 示例:一个简单的程序，展示了基本堆栈函数的使用。

```

#include <iostream>
#include <stack>
using namespace std;
void newstack(stack <int> ss)
{
	stack <int> sg = ss;
	while (!sg.empty())
	{
		cout << '\t' << sg.top();
		sg.pop();
	}
	cout << '\n';
}
int main ()
{
	stack <int> newst;
	newst.push(55);
	newst.push(44);
	newst.push(33);
	newst.push(22);
	newst.push(11);

	cout << "The stack newst is : ";
	newstack(newst);
	cout << "\n newst.size() : " << newst.size();
	cout << "\n newst.top() : " << newst.top();
	cout << "\n newst.pop() : ";
	newst.pop();
	newstack(newst); 
	return 0;
}

```

**输出:**

```
The stack newst is : 	11	22	33	44	55

 newst.size() : 5
 newst.top() : 11
 newst.pop() : 	22	33	44	55

```