# C++ 多重 ap

> 原文：<https://www.javatpoint.com/post/cpp-multimap>

**多映射**是 **C++ STL(标准模板库)**的一部分。多重映射是存储排序的键值对的关联容器，例如 map，但是与只存储唯一键的映射不同，**多重映射可以有重复的键**。默认情况下，它使用<运算符来比较按键。

**例如**:以员工年龄为关键，姓名为数值的员工多图可以表示为:

| 键 | 价值观念 |
| Twenty-three | 尼基塔 |
| Twenty-eight | 知更鸟 |
| Twenty-five | 深的 |
| Twenty-five | 等于 Haman） |

多重映射员工有重复的键年龄。

## 句法

```

template < class Key,                                     // multimap::key_type
           class T,                                                     // multimap::mapped_type
           class Compare = less,                        // multimap::key_compare
           class Alloc = allocator <pair key="">>    // multimap::allocator_type
           > class multimap;</pair> 
```

## 参数

**键**:要存储在多映射中的键数据类型。

**类型**:要存储在多映射中的值的数据类型。

**compare** :一个比较类，接受两个相同类型 bool 的参数并返回一个值。此参数是可选的，二进制谓词 less 是默认值。

**alloc** :分配器对象的类型。这个参数是可选的，默认值是分配器<value_type>。</value_type>

## 创建多重映射

使用以下语句可以轻松创建多地图:

```

typedef pair value_type; 
```

上面的表单将用于创建一个多映射，其键类型为**键类型为**，值类型为**值类型为**。重要的一点是，多重映射的键和相应的值总是成对插入，您不能在多重映射中只插入键或值。

## 例子

```

#include #include <map>#include <string>using namespace std;

int main()
{
    multimap <string string="">m = {
            {"India","New Delhi"},
            {"India", "Hyderabad"},
            {"United Kingdom", "London"},
            {"United States", "Washington D.C"}
    };

    cout << "Size of map m: " << m.size() <<endl cout="" in="" m:="" endl="" for="" string="">::iterator it = m.begin(); it != m.end(); ++it)
    {
       cout << "  [" << (*it).first << ", " << (*it).second << "]" << endl;
    }

    return 0;
}</endl></string></string></map> 
```

**输出:**

```
Size of map m: 4
Elements in m: 
  [India, New Delhi]
  [India, Hyderabad]
  [United Kingdom, London]
  [United States, Washington D.C]

```

## 成员函数

以下是 multimap 的所有成员函数列表:

### 构造函数/析构函数

| 功能 | 描述 |
| 构造器 | 构建多重映射 |
| 破坏者 | 多用途破坏者 |
| 运算符= | 将多重映射的元素复制到另一个多重映射。 |

### 迭代程序

| 功能 | 描述 |
| [开始](cpp-multimap-begin-function) | 返回指向 multimap 中第一个元素的迭代器。 |
| [cbegin](cpp-multimap-cbegin-function) | 返回指向 multimap 中第一个元素的 const_iterator。 |
| [结束](cpp-multimap-end-function) | 返回指向过去结束的迭代器。 |
| [cend](cpp-multimap-cend-function) | 返回指向过去结束的常量迭代器。 |
| [rbegin](cpp-multimap-rbegin-function) | 返回指向末尾的反向迭代器。 |
| [渲染](cpp-multimap-rend-function) | 返回指向开头的反向迭代器。 |
| crbegin | 返回一个指向末尾的常量反向迭代器。 |
| 信仰 | 返回指向开头的常量反向迭代器。 |

### 容量

| 功能 | 描述 |
| [空](cpp-multimap-empty-function) | 如果 multimap 为空，则返回 true。 |
| 大小 | 返回多重映射中的元素数量。 |
| 最大尺寸 | 返回多重映射的最大大小。 |

### 修饰语

| 功能 | 描述 |
| [插入](cpp-multimap-insert-function) | 在多重映射中插入元素。 |
| [擦除](cpp-multimap-erase-function) | 从多重映射中删除元素。 |
| [互换](cpp-multimap-swap-function) | 交换多重映射的内容。 |
| [清除](cpp-multimap-clear-function) | 删除多重映射的所有元素。 |
| [就位](cpp-multimap-emplace-function) | 构造新元素并将其插入到 multimap 中。 |
| 提示位置 | 通过提示构造新元素并将其插入到 multimap 中。 |

### 观察者

| 功能 | 描述 |
| 密钥 _comp | 返回密钥比较对象的副本。 |
| 价值 _ 比较 | 返回值比较对象的副本。 |

### 操作

| 功能 | 描述 |
| 发现 | 搜索具有给定关键字的元素。 |
| 数数 | 获取与给定键匹配的元素数。 |
| 下限 | 将迭代器返回到下限。 |
| 上限 | 将迭代器返回到上限。 |
| [equal_range()](cpp-multimap-equal_range-function) | 返回与给定键匹配的元素范围。 |

### 分配算符

| 功能 | 描述 |
| get _ 分配器 | 返回用于构造 multimap 的分配器对象。 |

## 非成员重载函数

| 功能 | 描述 |
| [运算符==](cpp-multimap-non-member-operator==-function) | 检查两个多重映射是否相等。 |
| [符！=](cpp-multimap-non-member-operator!=-function) | 检查两个多重映射是否相等。 |
| [操作员<](cpp-multimap-non-member-operator<-function) | 检查第一个 multimap 是否小于其他。 |
| [操作员< =](cpp-multimap-non-member-operator<=-function) | 检查第一个 multimap 是否小于或等于其他。 |
| [操作员>](cpp-multimap-non-member-operator>-function) | 检查第一个 multimap 是否大于其他。 |
| [操作员> =](cpp-multimap-non-member-operator>=-function) | 检查第一个 multimap 是否大于等于其他。 |
| [互换()](cpp-multimap-non-member-swap-function) | 交换两个多重映射的元素。 |