# C++ 映射函数

> 原文：<https://www.javatpoint.com/post/cpp-map>

地图是 C++ STL(标准模板库)的一部分。映射是存储排序的键值对的关联容器，其中每个键都是唯一的，可以插入或删除，但不能更改。与键相关联的值可以更改。

**例如:**以员工 ID 为键、姓名为值的员工图可以表示为:

| 键 | 价值观念 |
| One hundred and one | 尼基塔 |
| One hundred and two | 知更鸟 |
| One hundred and three | 深的 |
| One hundred and four | 约翰 |

## 句法

```

template < class Key,                                             // map::key_type
           class T,                                                     // map::mapped_type
           class Compare = less,                        // map::key_compare
           class Alloc = allocator <pair key="">>    // map::allocator_type
           > class map;</pair> 
```

## 参数

**键:**要存储在地图中的键数据类型。

**类型:**要存储在地图中的值的数据类型。

**compare:** 接受两个相同 bool 类型的参数并返回一个值的比较类。此参数是可选的，二进制谓词 less 是默认值。

**alloc:** 分配器对象的类型。这个参数是可选的，默认值是分配器<value_type>。</value_type>

## 创建地图

使用以下语句可以轻松创建地图:

```

typedef pair value_type; 
```

上面的表单将用于创建一个键类型为**键类型为**值类型为**值类型的地图。**有一点很重要，映射的键和对应的值总是成对插入，不能在映射中只插入键或者只插入值。

## 例 1

```

#include #include <iostream>#include <map>#include <utility>using namespace std;
int main()
{
   map <int string="">Employees;
   // 1) Assignment using array index notation
   Employees[101] = "Nikita";
   Employees[105] = "John";
   Employees[103] = "Dolly";
   Employees[104] = "Deep";
   Employees[102] = "Aman";
   cout << "Employees[104]=" << Employees[104] << endl << endl;
   cout << "Map size: " << Employees.size() << endl;
   cout << endl << "Natural Order:" << endl;
   for( map<int>::iterator ii=Employees.begin(); ii!=Employees.end(); ++ii)
   {
       cout << (*ii).first << ": " << (*ii).second << endl;
   }
   cout << endl << "Reverse Order:" << endl;
   for( map<int>::reverse_iterator ii=Employees.rbegin(); ii!=Employees.rend(); ++ii)
   {
       cout << (*ii).first << ": " << (*ii).second << endl;
   }
}</int></int></int></utility></map></iostream> 
```

**输出:**

```
Employees[104]=Deep

Map size: 5

Natural Order:
101: Nikita
102: Aman
103: Dolly
104: Deep
105: John

Reverse Order:
105: John
104: Deep
103: Dolly
102: Aman
101: Nikita

```

## 成员函数

以下是 map 所有成员函数的列表:

### 构造函数/析构函数

| 功能 | 描述 |
| 构造器 | 构建地图 |
| 析构函数 | 破坏性贴图 |
| [运算符=](cpp-map-operator=()-function) | 将地图的元素复制到另一张地图。 |

### 迭代程序

| 功能 | 描述 |
| [开始](cpp-map-begin-function) | 返回指向映射中第一个元素的迭代器。 |
| [cbegin](cpp-map-cbegin-function) | 返回指向映射中第一个元素的常量迭代器。 |
| [结束](cpp-map-end-function) | 返回指向过去结束的迭代器。 |
| [cend](cpp-map-cend-function) | 返回指向过去结束的常量迭代器。 |
| [rbegin](cpp-map-rbegin-function) | 返回指向末尾的反向迭代器。 |
| [渲染](cpp-map-rend-function) | 返回指向开头的反向迭代器。 |
| crbegin | 返回一个指向末尾的常量反向迭代器。 |
| 信仰 | 返回指向开头的常量反向迭代器。 |

### 容量

| 功能 | 描述 |
| [空](cpp-map-empty-function) | 如果映射为空，则返回 true。 |
| [尺寸](cpp-map-size-function) | 返回地图中的元素数量。 |
| [最大尺寸](cpp-map-max_size-function) | 返回地图的最大大小。 |

### 元素访问

| 功能 | 描述 |
| [运算符[]](cpp-map-operator[]-function) | 用给定的键检索元素。 |
| [在](cpp-map-at-function) | 用给定的键检索元素。 |

### 修饰语

| 功能 | 描述 |
| [插入](cpp-map-insert-function) | 在地图中插入元素。 |
| [擦除](cpp-map-erase-function) | 从地图上删除元素。 |
| [互换](cpp-map-swap-function) | 交换地图的内容。 |
| [清除](cpp-map-clear-function) | 删除地图的所有元素。 |
| [就位](cpp-map-emplace-function) | 构建新元素并将其插入地图。 |
| 提示位置 | 通过提示构造新元素并将其插入地图。 |

### 观察者

| 功能 | 描述 |
| 密钥 _comp | 返回密钥比较对象的副本。 |
| 价值 _ 比较 | 返回值比较对象的副本。 |

### 操作

| 功能 | 描述 |
| [找到](cpp-map-find-function) | 搜索具有给定关键字的元素。 |
| 数数 | 获取与给定键匹配的元素数。 |
| 下限 | 将迭代器返回到下限。 |
| 上限 | 将迭代器返回到上限。 |
| 相等范围 | 返回与给定键匹配的元素范围。 |

### 分配算符

| 功能 | 描述 |
| get _ 分配器 | 返回用于构造映射的分配器对象。 |

### 非成员重载函数

| 功能 | 描述 |
| 运算符== | 检查两个地图是否相等。 |
| 接线员！= | 检查两个地图是否相等。 |
| 运算符< | 检查第一张地图是否小于其他地图。 |
| 运算符< = | 检查第一个映射是否小于或等于其他映射。 |
| 操作员> | 检查第一个地图是否大于其他地图。 |
| 运算符> = | 检查第一个映射是否大于等于其他。 |
| [互换()](cpp-map-swap-function) | 交换两张地图的元素。 |