# C++ 前向迭代器

> 原文：<https://www.javatpoint.com/cpp-forward-iterator>

*   **正向迭代器**是双向和随机访问迭代器的组合。因此，我们可以说正向迭代器可以用来读写容器。
*   **前向迭代器**用于从容器的开头到结尾读取内容。
*   **向前迭代器**仅使用递增运算符(++)来遍历容器的所有元素。因此，我们可以说向前迭代器只能向前移动。
*   向前迭代器是多遍迭代器。

## 在前向迭代器上执行的操作:

| 性能 | 有效表达式 |
| 它是默认可构造的。 | a x； |
| 它是可复制的。 | a x(y)； |
| 这是一个可转让的副本。 | y = x； |
| 可以通过使用等式或不等式运算符进行比较。 | a = = b；
一个！= b； |
| 它可以递增。 | a++；
++a； |
| 它可以作为右值取消引用。 | * a； |
| 它也可以作为左值取消引用。 | * a = t； |

**其中‘A’是前向迭代器类型，x 和 y 是前向迭代器类型的对象，t 是迭代器类型对象指向的对象。**

**我们来看一个简单的例子:**

```
#include <iostream>
#include <fstream>
#include <iterator>
#include <vector>

using namespace std;

template<class ForwardIterator>                                       // function template
void display(ForwardIterator first, ForwardIterator last)            // display function
{
 while(first!=last)
 {
     cout<<*first<<" ";
     first++;
 }
}

int main()
{

  vector<int> a;                          // declaration of vector.
  for(int i=1;i<=10;i++)
  {
      a.push_back(i);
  }
  display(a.begin(),a.end());                // calling display() function.

  return 0;
}

```

**输出:**

```
1 2 3 4 5 6 7 8 9 10

```

## 前向迭代器的特点:

![C++ Forward Iterator](img/3c63baab3cc5b21132056f1ee984fddf.png)

*   **等式/不等式运算符**:前向迭代器可以使用等式或不等式运算符进行比较。

**假设‘A’和‘B’是两个迭代器:**

```
A==B;           // equality operator
A!=B;            // inequality operator

```

*   **取消引用**:我们可以取消引用正向迭代器作为右值和左值。因此，我们可以访问输出迭代器，也可以将值赋给输出迭代器。

**假设‘A’是迭代器，‘t’是整型变量:**

```
*A = t;
  t = *A; 

```

*   **可递增**:正向迭代器可以递增，但不能递减。

**假设‘A’是一个迭代器:**

```
A++;
++A;

```

## 前向迭代器的局限性:

*   **递减**:向前迭代器不能递减，因为它只向前移动。

**假设‘A’是一个迭代器:**

```
A--;          // invalid

```

*   **关系运算符**:前向迭代器可以和等式运算符一起使用，但是不能在前向迭代器上应用其他关系运算符。

**假设‘A’和‘B’是两个迭代器:**

```
A==B;        // valid
A>=B;        // invalid

```

*   **算术运算符**:算术运算符不能与前向迭代器一起使用。

```
A+2;         // invalid
A+3;         // invalid

```

*   **随机访问**:正向迭代器不提供元素的随机访问。它只能遍历容器的元素。