# C++ 输出迭代器

> 原文：<https://www.javatpoint.com/cpp-output-iterator>

*   输出迭代器是用于修改容器中值的迭代器。
*   取消对输出迭代器的引用允许我们改变容器的值。
*   它不允许我们从容器中读取值。
*   这是一个单向且只写的迭代器。
*   它可以增加，但不能减少。
*   可用于输出迭代器**的运算符有递增运算符(+)、递减运算符(-)和赋值运算符(=)** 。
*   **输出迭代器主要有两个子类:**
    *   **插入迭代器**
    *   **牡蛎迭代器**

![C++ Output Iterator](img/9cb335a63cb17a561189e35f8e3dc634.png)

## 插入迭代器

*   插入迭代器是用于在指定位置插入元素的迭代器。
*   insert_iterator 上的赋值运算符在当前位置插入新元素。

## 句法

```
template<class Container, class Iterator>
insert_iterator<container> inserter(Container &x,Iterator it);

```

## 因素

**x** :是要插入新元素的容器。

**它**:是一个迭代器对象，指向要修改的位置。

**我们来看一个简单的例子:**

```
#include <iostream>     // std::cout
#include <iterator>     // std::front_inserter
#include <vector>         // std::list
#include <algorithm>    // std::copy
using namespace std;
int main () {
  vector<int> v1,v2;
  for (int i=1; i<=5; i++)
  { 
  v1.push_back(i); 
  v2.push_back(i+2);
  }
 vector<int>::iterator it = v1.begin();
  advance (it,3);
 copy (v2.begin(),v2.end(),inserter(v1,it));
  cout<<"Elements of v1 are :";
  for (  it = v1.begin(); it!= v1.end(); ++it )
  cout << ' ' << *it;
  cout << '\n';
  return 0;
}

```

**输出:**

```
Elements of v1 are : 1 2 3 3 4 5 6 7 4 5

```

在上面的例子中，insert_iterator 应用于复制算法，将向量 v2 的元素插入向量 v1 的指定位置。

## 牡蛎迭代器

*   ostream 迭代器是用于连续写入输出流(如 cout)的输出迭代器。
*   ostream 迭代器是使用 basic_ostream 对象创建的。
*   当在 ostream 迭代器上使用赋值运算符时，它会在输出流中插入一个新元素。

## 句法

```
template<class T, class charT=char, class traits=char_traits<charT>>
class ostream_iterator;

```

**Ostream 迭代器类的成员函数**

```
Ostream_iterator<T, charT, traits>& operator=(const T& value);
Ostream_iterator<T, charT, traits>& operator*();
Ostream_iterator<T, charT, traits>& operator++();
Ostream_iterator<T, charT, traits>& operator++(int);

```

## 因素

*   **T** :是要插入容器的元素类型。
*   **图表**:牡蛎可以处理的元素类型，例如，牡蛎炭。
*   **特征**:这些是流为元素处理的性格特征。

**我们来看一个简单的例子:**

```
#include <iostream>
#include<iterator>
#include<vector>
#include<algorithm>
using namespace std;
int main()
{
   vector<int> v;
   for(int i=1;i<=5;i++)
   {
       v.push_back(i*10);
   }
 ostream_iterator<int> out(cout,",");
 copy(v.begin(),v.end(),out);
    return 0;
}

```

**输出:**

```
10,20,30,40,50

```

在上面的例子中，out 是 ostream_iterator 的一个对象，用于在向量元素之间添加分隔符' '。

**让我们看看另一个简单的 ostream 迭代器示例:**

```
#include <iostream>
#include<iterator>
#include<vector>
#include<algorithm>
using namespace std;
int main()
{
   ostream_iterator<int> out(cout,",");
   *out = 5;
   out++;
   *out = 10;
   out++;
   *out = 15;
   return 0;
}

```

**输出:**

```
5,10,15,

```

## 输出迭代器的特点

*   **等式/不等式运算符**:输出迭代器不能使用等式或不等式运算符进行比较。假设 X 和 Y 是两个迭代器:

```
X==Y;  invalid
X!=Y;   invalid

```

*   **取消引用**:输出迭代器可以作为左值取消引用。

```
*X=7;

```

*   **递增**:输出迭代器可以使用运算符++()函数递增。

```
X++;
++X;

```

## 输出迭代器的局限性

*   **赋值但不访问**:我们可以将输出迭代器赋值为左值，但不能将其作为右值访问。

**假设‘A’是输出迭代器类型，‘x’是整数变量:**

```
*A = x;                   // valid
  x = *A;                 // invalid

```

*   **不能递减**:我们可以用运算符++()函数来递增输出迭代器，但是不能递减输出迭代器。

**假设‘A’是输出迭代器类型:**

```
A++;            // not valid
++A;            // not valid

```

*   **多遍算法**:输出迭代器不能作为多遍算法使用。因为输出迭代器是单向的，只能向前移动。因此，它不能用于在容器中移动多次

*   **关系运算符**:输出迭代器不能使用任何关系运算符进行比较。

**假设‘A’和‘B’是两个迭代器:**

```
A = =B;        // not valid
A = =B;        // not valid

```

*   **算术运算符**:输出迭代器不能与算术运算符一起使用。因此，我们可以说输出迭代器只是以顺序的方式向前移动。

**假设‘A’是输出迭代器**:

```
A + 2;               // invalid
A + 5;               // invalid   

```