# 使用堆栈数据结构将 C++ 中缀转换为后缀表达式的程序

> 原文：<https://www.javatpoint.com/program-to-convert-infix-to-postfix-expression-in-cpp-using-the-stack-data-structure>

### 插入表达式

中缀表达式是在两个操作数之间写入运算符(+、-、*、/)的表达式。例如，考虑以下表达式:

```

A + B
A + B - C
(A + B) + (C - D)

```

这里我们在操作数 A 和 B 之间写了 **'+'** 运算符，在 C 和 D 操作数之间写了 **-** 运算符。

### 后缀表达式

后缀运算符还包含运算符和操作数。在后缀表达式中，运算符写在操作数之后。也称为**逆波兰符号**。例如，考虑以下表达式:

```

A B +   
A B + C -   
A B C * +
A B + C * D -

```

### 使用堆栈将中缀转换为后缀表达式的算法

下面是**算法**将中缀表达式转换为逆波兰符号。

1.  初始化堆栈。
2.  在中缀表达式中从左到右扫描运算符。
3.  如果最左边的字符是操作数，将其设置为后缀字符串的当前输出。
4.  如果扫描的字符是运算符，而堆栈为空或包含“(”、“)”符号，则将运算符推入堆栈。
5.  如果扫描的运算符的优先级高于堆栈中现有的**优先级**运算符，或者堆栈为空，则将其放在堆栈上。
6.  如果扫描的运算符的优先级低于堆栈中的现有运算符，则弹出所有堆栈运算符。之后，将扫描的操作员推入堆栈。
7.  如果扫描的字符是左括号“(”，将其推入堆栈。
8.  如果我们遇到右括号“)”，弹出堆栈并打印所有输出字符串，直到遇到“(”并丢弃这两个括号。
9.  重复从 2 到 8 的所有步骤，直到中缀表达式被扫描。
10.  打印堆栈输出。
11.  弹出并输出堆栈中的所有字符，包括运算符，直到它不为空。

让我们将堆栈中的中缀表达式转换为后缀表达式:

这里我们有中缀表达式 **(( A * (B + D)/E) - F * (G + H / K)))** 来转换成它的等价后缀表达式:

| 标签号 | 符号扫描 | 堆 | 表示 |
| one | （ | （ |  |
| Two | （ | (( |  |
| three | A | (( | A |
| four | * | ((* | A |
| five | （ | ((*( | A |
| six | B | ((*( | AB 型血 |
| seven | + | ((*(+ | AB 型血 |
| eight | D | ((*(+ | 准博士 |
| nine | ) | ((* | ABD+ |
| Ten | / | ((*/ | ABD+ |
| Eleven | E | ((*/ | 阿卜杜勒·e |
| Twelve | ) | （ | ABD+E/* |
| Thirteen | - | (- | ABD+E/* |
| Fourteen | （ | (-( | ABD+E/* |
| Fifteen | F | (-( | 阿卜杜勒·阿齐兹·阿齐兹 |
| Sixteen | * | (-(* | 阿卜杜勒·阿齐兹·阿齐兹 |
| Seventeen | （ | (-(*( | 阿卜杜勒·阿齐兹·阿齐兹 |
| Eighteen | G | (-(*( | ABD+E/*FG |
| Nineteen | + | (-(*(+ | ABD+E/*FG |
| Twenty | H | (-(*(+ | 美国+E/*FGH |
| Twenty-one | / | (-(*(+/ | 美国+E/*FGH |
| Twenty-two | K | (-(*(+/ | ABD+E/*FGHK |
| Twenty-three | ) | (-(* | ABD+E/*FGHK/+ |
| Twenty-four | ) | (- | ABD+E/*FGHK/+* |
| Twenty-five | ) |  | ABD+E/*FGHK/+*- |

### 将中缀表达式转换为后缀表达式的程序

让我们创建一个 C++ 程序，将中缀表达式转换为后缀表达式

```

#include<iostream>
#include<stack>
using namespace std;
// defines the Boolean function for operator, operand, equalOrhigher precedence and the string conversion function.
bool IsOperator(char);
bool IsOperand(char);
bool eqlOrhigher(char, char);
string convert(string);

int main()
{
string infix_expression, postfix_expression;
int ch;
do
{
cout << " Enter an infix expression: ";
cin >> infix_expression;
 postfix_expression = convert(infix_expression);
 cout << "\n Your Infix expression is: " << infix_expression;
cout << "\n Postfix expression is: " << postfix_expression;
cout << "\n \t Do you want to enter infix expression (1/ 0)?";
cin >> ch;
//cin.ignore(); 
} while(ch == 1);
return 0;
}

// define the IsOperator() function to validate whether any symbol is operator.
/* If the symbol is operator, it returns true, otherwise false. */
bool IsOperator(char c)
{
if(c == '+' || c == '-' || c == '*' || c == '/' || c == '^' )
return true;   
return false;
}

// IsOperand() function is used to validate whether the character is operand.
bool IsOperand(char c)
{
if( c >= 'A' && c <= 'Z')  /* Define the character in between A to Z. If not, it returns False.*/
return true;
if (c >= 'a' && c <= 'z')  // Define the character in between a to z. If not, it returns False. */
return true;
if(c >= '0' && c <= '9')   // Define the character in between 0 to 9\. If not, it returns False. */
return true;
return false;
}
// here, precedence() function is used to define the precedence to the operator.
int precedence(char op)
{
if(op == '+' || op == '-')                   /* it defines the lowest precedence */
return 1;
if (op == '*' || op == '/')
return 2;
if(op == '^')                                  /* exponent operator has the highest precedence *
return 3;      
return 0;
}
/* The eqlOrhigher() function is used to check the higher or equal precedence of the two operators in infix expression. */
bool eqlOrhigher (char op1, char op2)
{
int p1 = precedence(op1);
int p2 = precedence(op2);
if (p1 == p2)
{
if (op1 == '^' )
return false;
return true;
}
return  (p1>p2 ? true : false);
}

/* string convert() function is used to convert the infix expression to the postfix expression of the Stack */
string convert(string infix)
{
stack <char> S;
string postfix ="";  
char ch;

S.push( '(' );
infix += ')';

for(int i = 0; i<infix.length(); i++)
{
ch = infix[i];

if(ch == ' ')
continue;
else if(ch == '(')
S.push(ch);
else if(IsOperand(ch))
postfix += ch;
else if(IsOperator(ch))
{
while(!S.empty() && eqlOrhigher(S.top(), ch))
{
postfix += S.top();
S.pop();
}
S.push(ch);
}
else if(ch == ')')
{
while(!S.empty() && S.top() != '(')
{
postfix += S.top();
S.pop();
}
S.pop();
}
}
return postfix;
}

```

**输出:**

![Program to convert infix to postfix expression in C++ using the Stack Data Structure](img/1320b7646f3b1a80732486c4cb96006f.png)

* * *