# C++ 硬币兑换程序

> 原文：<https://www.javatpoint.com/cpp-coin-change-program>

在这篇文章中，我们将看到最常被问到的面试问题。硬币兑换问题是动态规划方法的一个很好的例子。现在让我们理解问题陈述。

**问题陈述**

给定 N 和一个包含一些数字(卢比硬币)的数组(比如硬币[])。n 是硬币，数组包含各种硬币。任务是利用数组的硬币进行 N 的变化。改变使用最少硬币的方式。

**例**

让我们取一个输入数组硬币[] = {10，25，5}，硬币总数= 3

我们有 N = 30。

输出是**两个**，因为我们可以用一枚 25 卢比的硬币和一枚 5 卢比的硬币做 30 个。(25 + 5 = 30)

同样，硬币[] = {1，9，6，5}，硬币总数= 4

N = 13

输出是**三个**，因为我们需要两个 6 卢比硬币和一个 1 卢比硬币。(6 + 6 + 1 = 13)

**接近 1**

该方法使用递归方法。我们从 N 开始，在每次迭代中，我们把问题分成更小的子问题。这是通过从硬币阵列中取出每一枚硬币，并从 N 开始减少来实现的。N 变为零的情况为我们提供了所需的解决方案。对于最优答案，我们返回所有组合的最小值。

**C++ 代码**

```

#include using namespace std;

int minCoins(int coins[], int total_coins, int N) // Function to return the minimum // coins needed 
{
        if (N == 0) // If we have a combination then 
        return 0;

    int result = INT_MAX; // Currently result is initialised as INT_MAX 

    for (int i = 0; i < total_coins; i++) // run until availability of coins
    {
        if (coins[i] <= N) { // Add to the list of counting 
            int sub_res = 1 + minCoins(coins, total_coins, N - coins[i]); // add 1 due to the coin inclusion
            // see if result can minimize
            if (sub_res < result)
                result = sub_res;
        }
    }
    return result;
}

int main()
{
    int coins[] = { 10, 25, 5 };
    int sum = 30; // the money to convert
    int total_coins = 3; // total availability of coins
    cout << "Minmum coins needed are " << minCoins(coins, total_coins, sum);
} 
```

**输出**

```
Minimum coins needed are 2

```

上述解决方案不适用于更重要的输入。在这种情况下，递归方法失败了。

现在让我们看看一个优化的方法。

**接近 2**

这种方法使用自底向上动态编程的思想。

由于子问题被一次又一次地计算，所以存在子问题重叠的条件。重新计算的问题可以通过使用记忆化的属性来解决，即创建一个 dp[]数组来存储特定阶段的计算值。在每个阶段计算所有可能的组合。在所有的组合之后，dp[]数组中的最后一个值给出了答案。

**C++ 代码**

```

#include <bits/stdc++.h>
using namespace std;

int coins[] = { 10, 25, 5 }; // coins array
int dp[1000] = { 0 }; // array for memoisation
int minCoins(int N, int M) // N is the sum , M is total_coins
{

    for (int i = 0; i <= N; i++)
        dp[i] = INT_MAX; // Initialise all dp[] value to INT_MAX

    dp[0] = 0; // Base case if sum becomes zero min rupees = 0

    //Iterating in the outer loop for possible values of sum between 1 to N
    //Since our final solution for sum = N might depend upon any of these values
    for (int i = 1; i <= N; i++) {
        //Inner loop denotes the index of coin array.
        //For each value of sum, to obtain the optimal solution.
        for (int j = 0; j < M; j++) {
            //i ?> sum
            //j ?> next coin index
            //If we can include this coin in our solution
            if (coins[j] <= i) {
                //Solution might include the newly included coin
                dp[i] = min(dp[i], 1 + dp[i - coins[j]]);
            }
        }
    }
    return dp[N];
}

int main()
{

    int sum = 30; // the money to convert
    int total_coins = 3; // total availability of coins
    cout << "Minimum coins needed are " << minCoins(sum, total_coins);
}

```

**输出**

```
Minimum coins needed are 2

```

代码的时间复杂度为 O(total_coins + sum)。这是一个非常优化的方法，因为在每个阶段都存储结果，并在其他迭代中使用它。

* * *