# C++ 程序求两个数的 GCD

> 原文：<https://www.javatpoint.com/cpp-program-to-find-the-gcd-of-two-numbers>

在本教程中，我们将编写一个 c++ 程序来查找两个数字的 GCD。

最大公约数也被称为最高公约数。

**例如**

36 = 2 * 2 * 3 * 3

60 = 2 * 2 * 3 * 5

这两个数字的最高公因数是 2、2 和 3。

所以，两个数的 HCF 是 2 * 2 * 3 = 12

20 = 2 * 2 * 5

28 = 2 * 2 * 7

这两个数字的最高公因数是 2 和 2。

所以，两个数的 HCF 是 2 * 2 = 4。

**接近 1**

这个问题可以通过找到这两个数字的所有质因数，然后找到公共因数并返回它们的乘积来解决。

*   找出第一个数字的因子
*   找出第二个数的因子
*   找出这两个数字的共同因素
*   将它们相乘得到 GCD

**C++ 代码**

```

#include #define MAXFACTORS 1024 // Let us consider max factors can be 1024
using namespace std;

typedef struct 
{

	int size;
	int factor[MAXFACTORS + 1];
	int exponent[MAXFACTORS + 1];

} FACTORIZATION;

// Function to find the factorization of M and N
void FindFactorization(int x, FACTORIZATION* factorization)
{
	int i, j = 1;
	int n = x, c = 0;
	int k = 1;
	factorization->factor[0] = 1;
	factorization->exponent[0] = 1;

	for (i = 2; i <= n; i++) {
		c = 0;

		while (n % i == 0) {
			c++;

			// factorization->factor[j]=i;
			n = n / i;
			// j++;
		}

		if (c > 0) {
			factorization->exponent[k] = c;
			factorization->factor[k] = i;
			k++;
		}
	}

	factorization->size = k - 1;
}

// function to find the gcd using Middle School procedure
int gcdMiddleSchoolProcedure(int m, int n)
{

	FACTORIZATION mFactorization, nFactorization;

	int r, mi, ni, i, k, x = 1, j;

	// Step 1.
	FindFactorization(m, &mFactorization);

	// Step 2.
	FindFactorization(n, &nFactorization);

	// Steps 3 and 4.
	// Procedure algorithm for computing the
	// greatest common divisor.
	int min;
	i = 1;
	j = 1;
	while (i <= mFactorization.size && j <= nFactorization.size) {
		if (mFactorization.factor[i] < nFactorization.factor[j])
			i++;

		else if (nFactorization.factor[j] < mFactorization.factor[i])
			j++;

		else /* if arr1[i] == arr2[j] */
		{
			min = mFactorization.exponent[i] > nFactorization.exponent[j]
					? nFactorization.exponent[j]
					: mFactorization.exponent[i];

			x = x * mFactorization.factor[i] * min;
			i++;
			j++;
		}
	}

	return x;
}

int main()

{

	int m = 36, n = 60;
	cout << "GCD of " << m << " and " << n << " is "
		<< gcdMiddleSchoolProcedure(m, n);

	return (0);
} 
```

**输出**

```
GCD of 36 and 60 is 12

```

**接近 2**

方法 1 可以使用欧几里德算法以有效的方式解决。该算法遵循这样的思想，即如果从较大的数字中减去较小的数字，GCD 不会改变。

**C++ 代码**

```

#include <iostream>
using namespace std;

int gcd(int a, int b) // The function runs recursive in nature to return GCD
{

    if (a == 0) // If a becomes zero
       return b; // b is the GCD 
    if (b == 0)// If b becomes zero
       return a;// a is the GCD 

    if (a == b) // The case of equal numbers 
        return a; // return any one of them 

   // Apply case of substraction 
    if (a > b) // if a is greater subtract b 
        return gcd(a-b, b);
    return gcd(a, b-a); //otherwise subtract a 
}

int main()
{
    int a = 36, b = 60;
    cout<<"GCD of "<<a<<" and "<<b<<" is "<<gcd(a, b);
    return 0;
}

```

**输出**

```
GCD of 36 and 60 is 12

```

**接近 3**

方法二可以进一步优化，使用模运算符代替减法。

**C++ 代码**

```

#include <iostream>
using namespace std;

int gcd(int a, int b) // The function runs recursive in nature to return GCD
{
    if (b == 0) // if b becomes 0 return a 
        return a;
    return gcd(b, a % b); // divide to a by b to make smaller number 

}

int main()
{
    int a = 60, b = 36;
    cout<<"GCD of "<<a<<" and "<<b<<" is "<<gcd(a, b);
    return 0;
}

```

**输出**

```
GCD of 60 and 36 is 12

```

* * *