# 如何在 c++ 中连接两个字符串？

> 原文：<https://www.javatpoint.com/how-to-concatenate-two-strings-in-cpp>

本节将讨论 C++ 编程语言中两个或多个字符串的连接。字符串的串联意味着将两个或多个字符串组合在一起以返回串联的单个字符串的一组字符。在连接字符串时，第二个字符串被添加到第一个字符串的末尾，形成一个字符串。

例如，我们有两个字符串，' **Java** '和' **Tpoint** '，我们想要连接起来，使单个字符串成为 Java+Tpoint = JavaPoint。

![How to concatenate two strings in c++](img/126ce7e59b14f52d56ef0a6382f05237.png)

让我们讨论在 C++ 编程语言中连接给定字符串的不同方法。

1.  使用 for 循环连接两个字符串
2.  使用 while 循环连接两个字符串
3.  使用+运算符连接两个字符串
4.  使用 strcat()函数连接两个字符串
5.  使用 append()函数连接两个字符串
6.  使用继承连接两个字符串
7.  使用 friend 函数和 strcat()函数连接两个字符串

### 使用 for 循环连接两个字符串的程序

让我们考虑一个在 C++ 编程中使用 for 循环组合两个字符串的例子。

**Program.cpp**

```

#include 
using namespace std;
int main ()
{
string str1, str2, result; // declare string variables
int i;
cout <> str1; // take string
cout << "  Enter the second string: ";
cin >> str2; // take second string
// use for loop to enter the characters of the str1 into result string 
for ( i = 0; i < str1.size(); i++)
{
result = result + str1[i]; // add character of the str1 into result 
} 

// use for loop to enter the characters of the str2 into result string 
for ( i = 0; i < str2.size(); i++)
{
result = result + str2[i]; // add character of the str2 into result 
}
cout << " The Concatenation of the string " << str1 << " and " << str2 << " is " <
```

**输出**

```
  Enter the first string: Java
  Enter the second string: Tpoint
 The Concatenation of the string Java and Tpoint is JavaTpoint

```

### 使用 while 循环连接两个字符串的程序

让我们考虑一个在 C++ 编程中使用 while 循环组合两个字符串的例子。

**Program2.cpp**

```

#include 
using namespace std;
int main ()
{
	// declare and initialize the string 
	char str1[100] = " We Love";
	char str2[100] = " C++ Programming Language";
	int i, j; // declare variable

	cout << " The first string is: " << str1 << endl;
	cout << " The second string is: "<< str2 <
```

**输出**

```
The first string is:  We Love
 The second string is:  C++ Programming Language
 The concatenated string is:  We Love C++ Programming Language

```

### C++ 中使用+运算符连接两个字符串的程序

**+运算符:**它是一个算术“+”运算符，简单地将两个字符串相加，返回一个新的串联字符串。

让我们考虑一个在 C++ 编程中使用+运算符组合两个字符串的例子。

**Program3.cpp**

```

#include 
using namespace std;
int main ()
{
	string str1, str2; // declare string variables

	cout << " Enter the first string: ";
	cin >> str1;

	cout << "\n Enter the second string: ";
	cin >> str2;

	// use '+' operator to concatenate the str1 and str2
	string result = str1 + str2;
	cout << " The concatenated string " << str1 << " and " << str2 <
```

**输出**

```
Enter the first string: Java
 Enter the second string: Tpoint
 The concatenated string Java and Tpoint is: JavaTpoint

```

### 使用 strcat()方法连接两个字符串的程序

**strcat()函数:**strcat 是 string 类的内置函数，它将两个字符串相加，返回一个串联的字符串。

**语法**

```

strcat ( char *arr1, char *arr2)

```

在上面的语法中有两个字符数组，arr1 和 arr2，它们在 strcat()函数中传递，以返回一个串联的字符串。

让我们考虑一个在 C++ 编程中使用 strcat()函数组合两个字符串的例子。

**Program4.cpp**

```

#include 
#include <string>
using namespace std;
int main()
{
	// declare and initialize the string
	char str1[] = " We love";
	char str2[] = " C++ Programming";

	cout << " String 1: " <</string>
```

**输出**

```
String 1:  We love
String 2: C++ Programming
 The concatenated string is:  We love C++ Programming

```

### 使用 append 函数连接两个字符串的程序

**append()函数:** An **append()** 函数是一个预定义的库函数，用于在第一个字符串的末尾插入或添加第二个字符串以返回单个字符串。

**语法**

```

str1.append(str2);

```

在上面的语法中，str2 是在 append()函数中传递的第二个字符串，该函数在 str1 字符串的末尾插入 str2 字符串。

让我们考虑一个在 C++ 编程中使用 append()函数组合两个字符串的例子。

**Program5.cpp**

```

#include using namespace std;
int main ()
{
string str1, str2, result; // declare string variables

cout <> str1; // take string
cout << "  Enter the second string: ";
cin >> str2; // take second string

// use append() function to insert element at the end of the str1
str1.append(str2);
cout << " \n The concatenation of the string is: "<< str1;
return 0;
} 
```

**输出**

```
  Enter the first string: Hello
  Enter the second string: Friends!

 The concatenation of the string is: HelloFriends!

```

### 程序使用类的继承来连接两个字符串

让我们考虑一个在 C++ 编程中使用继承来组合两个字符串的例子。

**Program6.cpp**

```

#include 
#include <string>
using namespace std;

// create base class
class base
{
	protected:
		virtual string concatenate(string &str1, string &str2) = 0;
};	

// create derive class to acquire features of base class
class derive: protected base {
	public:
		string concatenate (string &str1, string &str2) {
			string temp;
			temp = str1 + str2;
			return temp;
		}
};

int main()
{
	// declare variable
	string str1, str2;

	cout <>str1;
	cout <>str2;

	// create string object
	derive obj;

	// print string
	cout <</string>
```

**输出**

```
Enter first string: C++

 Enter second string: Programming

 The concatenated string is: C++Programming

```

### 使用 friend 函数和 strcat()函数连接两个字符串的程序

让我们考虑一个在 C++ 编程中使用 friend 函数和 strcat()函数组合两个字符串的例子。

**Program7.cpp**

```

#include 
#include <cstring>
using namespace std;

class Base {
	private:
		char st[100], st2[100];

	public:

		void inp()
		{
			cout <</cstring>
```

**输出**

```
Enter the first string: javatpoint
 Enter the second string: .com
 The concatenated string: javatpoint.com

```

* * *