# C++ 中的上转换和下转换

> 原文：<https://www.javatpoint.com/upcasting-and-downcasting-in-cpp>

本节将通过一个 C++ 编程语言的例子来讨论向上转换和向下转换。当我们将一种数据类型转换成另一种类型时，这个过程被称为类型转换。但是，向上转换和向下转换是对象类型转换的类型。假设父类和子类有两种类型的对象，parent_obj 和 child_obj，它们可以使用 C++ 编程中的向上转换和向下转换转换为父到子和子到父。

![Upcasting and Downcasting in C++](img/2240c3fe4d2e4018f698d227e5f4c40d.png)

## 向上抛

它是从基类的指针或引用创建派生类的指针或引用的过程，这个过程被称为向上转换。它意味着用于将派生类的引用或指针转换为基类的上转换。与向下铸造相比，向上铸造是安全的铸造。它允许公共继承隐式地将引用从一个类转换到另一个类，而不需要显式的类型转换。默认情况下，upcasting create 是基类和派生类之间的关系。

```

Base *ptr = &derived_obj;

```

派生类可以继承所有基类属性，包括数据成员和成员函数，以使用派生类对象执行函数，就像我们使用基类对象一样。

### 用 C++ 演示向上转换的程序

让我们考虑一个例子，在 C++ 编程语言中将派生类的指针转换为基类的指针。

**Program1.cpp**

```

#include using namespace std;
class Base
{
	public:
		void disp()
	{
		cout << " It is the Super function of the Base class ";
	}
};

class derive : public Base
{
	public:
		void disp()
		{
			cout << "\n It is the derive class function ";
		}

};

int main ()
{
	// create base class pointer
	Base *ptr;

	derive obj; // create object of derive class
	ptr = &obj; // assign the obj address to ptr variable

	// create base class's reference
	 Base &ref = obj; 
	// Or
	// get disp() function using pointer variable

	ptr->disp();
	return 0;
} 
```

**输出**

```
It is the Super function of the Base class

```

## 向下投射

向下转换是与向上转换相反的过程，向上转换将基类的指针或引用转换为派生类的指针或引用。它手动将基类的对象转换为派生类的对象，因此我们必须指定显式类型转换。向下预测在大多数情况下不遵循**是-一个**关系。它不如向上广播安全。此外，派生类可以添加新的功能，例如；新的数据成员和使用这些数据成员的类成员函数。但是，这些功能不能应用于基类。

```

Derived *d_ptr = &b_obj;

```

### 用 C++ 演示向下转换的程序

让我们创建一个示例，在 C++ 编程语言中将基类的对象向下转换为派生类。

**Program2.cpp**

```

#include using namespace std;
class Parent
{
	public:
		void base()
		{
			cout << " It is the function of the Parent class "<< endl; 
		}
};

class Child : public Parent
{
	public:
		void derive()
		{
			cout << " it is the function of the Child class " < <endl int="" main="" parent="" pobj="" create="" object="" child="" explicit="" type="" cast="" is="" required="" in="" downcasting="" cobj="(Child">derive();

	return 0;
}</endl> 
```

**输出**

```
It is the function of the Child class

```

### 用 C++ 演示向上转换和向下转换的程序

让我们考虑一个例子，在 C++ 中使用向下转换和向上转换将基类转换为派生类，并将派生类的对象转换为基类。

**Program3.cpp**

```

#include using namespace std;

class Parent {
	private:
		int id;

	public:
		void showid ()
		{
			cout << " I am in the Parent class " << endl;
			}	
};

class Myson : public Parent {
	public:
		void disp ()
		{
			cout << " I am in the Myson class " << endl;
		}
};

int main ( int argc, char * argv[])
{
	// create object of the Parent class
	Parent par_obj;

	// create object of the Myson class
	Myson my_obj;

	// upcast - here upcasting can be done implicitly
	Parent *ptr1 = &my_obj; // base class's reference the derive class's object

	// downcast - here typecasting is done explicitly 
	Myson *ptr2 = (Myson *) &par_obj;

	// Upcasting is safe:
	ptr1->showid();
	ptr2->showid();

	// downcasting is unsafe:
	ptr2->disp();

	getchar();
	return 0;

} 
```

**输出**

```
I am in the Parent class
 I am in the Parent class
 I am in the Myson class

```

* * *