# 使用优先级队列的 C++ Dijkstra 算法

> 原文：<https://www.javatpoint.com/cpp-dijkstra-algorithm-using-priority-queue>

在本文中，我们将看到使用 C++ STL 的优先级队列实现 Dijkstra 算法。Dijkstra 算法用于在无向图中寻找从源到目的地的最短路径。

边上有权重的图如下所示:

![C++ Dijkstra Algorithm using the priority queue](img/4e28b2d0f0adf87214156093cde8a40d.png)

让我们考虑一个源顶点 **0，**我们必须找到从源顶点到图中所有顶点的最短路径。

源顶点= 0

| 顶点 | 距离源的距离 |
| Zero | 0
相同的源和目的地 |
| one | 4
直接转到 1 |
| Two | 12
路径:0 - > 1 - > 2
(8 + 4 = 12) |
| three | 19
路径:0->1->2->3
(8+4+7 = 19) |
| four | 21
路径:0->7->6->5->4
(8+1+2+10 = 21) |
| five | 11
路径:0->7->6->5
(8+1+2 = 11) |
| six | 9 路径:0 -> 7 -> 6
(8 + 1 = 9) |
| seven | 8
路径:0 - > 7 |
| eight | 14
路径:0->1->2->8
(4+8+2 = 14) |

## 创建图表结构

我们将创建一个数据成员为的类图

*   **int v** -存储图形中的顶点数
*   对列表-存储与特定顶点相关的顶点和权重。

**名单<pair>>*形容词；</pair>T3】**

**施工人员:**

我们需要一个构造函数来分配邻接表的内存。

```

	Graph(int vertex)
	{
		this->V = vertex; // Allocate the number of vertices 
		adj = list [vertex]; // Allocate memory for adjacency list 
	} 
```

## 如何给图加边？

创建的配对列表有两个参数。一个包含顶点，另一个包含与之相关的权重。

由于图形是双向的，我们可以将相同的权重添加到相反的顶点。

**代码:**

```

 void addanEdge(int u, int v, int w)
{
	adj[u].push_back(make_pair(v,w)); // add v to w 
	adj[v].push_back(make_pair(u,w)); add w to v 
// To add a vertex with weight associated with it 
}

```

## 算法

1.  标记距源的初始距离是无限的。
2.  创建一个空的优先级队列 PQ。PQ 的每一项都是一对(权重、顶点)。重量(或距离)用作配对的第一项，因为默认情况下，第一项用于比较两对。
3.  将源顶点插入 PQ，使其距离为 0。
4.  直到定义为 PQ 的优先级队列不为空。执行操作 a 和 b。
    1.  从 PQ 中提取最小距离顶点，并使其为 u。
    2.  循环通过所有相邻的 u，并对每个顶点执行
        跟随 v.
        //如果有一条到 v 的较短路径
        //通过 u.
        如果 dist[v] > dist[u] +权重(u，v) //距离(v) >距离(u)和权重从 u 到 v
        1.  更新 v 的距离，即做
            dist[v] = dist[u] +权重(u，v)
        2.  将 v 插入 pq(即使 v 已经在那里

5.  循环通过 dist[]数组打印从源到所有顶点的最短路径。

## C++ 代码

```

#include using namespace std;
#define INF 0x3f3f3f3f // The distance to other vertices is initialized as infinite
// iPair ==> Integer Pair
typedef pair <int int="">iPair;
class Graph // Graph structure
    {
    int V; // No. of vertices in the graph
    list<pair int="">>* adj; // the list of pair to store vertex and its weight
public:
    // Constructor that accept number of vertices in graph
    Graph(int V) // allocate the vertex memory
    {
        this->V = V; // assign the vertex 
        adj = new list<ipair>[V]; // allocate space for vertices 
    }
    void addEdge(int u, int v, int w); // add edges in the graph
    // prints shortest path from s
    void shortestPathingraph(int s); // pass source vertex
};
void Graph::addEdge(int u, int v, int w) // add an edge
{
    adj[u].push_back(make_pair(v, w)); // make a pair of vertex and weight and // add it to the list
    adj[v].push_back(make_pair(u, w)); // add oppositely by making a pair of weight and vertex
}
// Calling function outside the Graph class
void Graph::shortestPathingraph(int src) // src is the source vertex
{
    // Create a priority queue to store vertices that
    // are being preprocessed.
    priority_queue<ipair vector="">, greater<ipair>> pq;
    vector <int>dist(V, INF); // All distance from source are infinite
    pq.push(make_pair(0, src)); // push spurce node into the queue
    dist[src] = 0; // distance of source will be always 0
    while (!pq.empty()) { // While queue is not empty
        // Extract the first minimum distance from the priority queue
        // vertex label is stored in second of pair (it
        // has to be done this way to keep the vertices
        // sorted distance
        int u = pq.top().second;
        pq.pop();
        // 'i' is used to get all adjacent vertices of a vertex
        list<pair int="">>::iterator i;
        for (i = adj[u].begin(); i != adj[u].end(); ++i) {
            // Get vertex label and weight of current adjacent
            // of u.
            int v = (*i).first;
            int weight = (*i).second;

            // If there is shorted path to v through u.
            if (dist[v] > dist[u] + weight) {
                // Updating distance of v
                dist[v] = dist[u] + weight;
                pq.push(make_pair(dist[v], v));
            }
        }
    }
    printf("Vertex \tDistance from Source\n"); // Print the result
    for (int i = 0; i < V; ++i)
        printf("%d \t\t %d\n", i, dist[i]); // The shortest distance from source
}
int main()
{
    int V = 9; // vertices in given graph are 9
    Graph g(V); //  call Constructor by creating an object of graph
    g.addEdge(0, 1, 4); // add root node with neighour vertex and weight
    g.addEdge(0, 7, 8);
    g.addEdge(1, 2, 8);
    g.addEdge(1, 7, 11);
    g.addEdge(2, 3, 7);
    g.addEdge(2, 8, 2);
    g.addEdge(2, 5, 4);
    g.addEdge(3, 4, 9);
    g.addEdge(3, 5, 14);
    g.addEdge(4, 5, 10);
    g.addEdge(5, 6, 2);
    g.addEdge(6, 7, 1);
    g.addEdge(6, 8, 6);
    g.addEdge(7, 8, 7);
    g.shortestPathingraph(0); // call the function to find shortest path of graph
    return 0; // end of main function()
}</pair></int></ipair></ipair></ipair></pair></int> 
```

**输出**

```
Vertex   Distance from Source
0 		   0
1 		   4
2 		  12
3 		  19
4 		  21
5 		  11
6 		   9
7 	           8
8 		  14

```

* * *