# C++ 中的构造函数重载

> 原文：<https://www.javatpoint.com/constructor-overloading-in-cpp>

构造函数是类的成员函数，用于初始化类的对象。构造函数没有任何返回类型，并且在创建对象时自动调用。

## 构造函数的特征

*   构造函数的名称与类名相同
*   构造函数没有返回类型
*   创建对象时自动调用
*   总是放在类的公共范围内
*   如果未创建构造函数，将自动创建默认构造函数，并将数据成员初始化为零
*   构造函数名称的声明区分大小写
*   构造函数不是隐式继承的

## 构造函数的类型

有三种构造函数-

*   **默认构造函数-** 默认构造函数是没有函数参数的构造函数。它用于用值初始化数据成员。创建对象时会调用默认构造函数。

**代码**

```

#include 
using namespace std;
class construct // create a class construct
{
public:
	int a, b; // initialise two data members 
	construct() // this is how default constructor is created 
	{
	    // We can also assign both values to zero 
		a = 10; // intialise a with some value 
		b = 20; // initialise b with some value
	}
};
int main()
{	
	construct c; // creating an object of construct calls defualt constructor
	cout<< "a:" <<c.a print="" a="" and="" b="" return=""></c.a>
```

**输出**

```
a:10
b:20 

```

*   **参数化构造函数-** 非参数化构造函数确实有构造函数参数，参数中传递的值被初始化为其数据成员。参数化构造函数用于构造函数重载。

**代码**

```

#include using namespace std;
class Point // create point class
    {
private:
int x, y; // the two data members of class Point
public:
Point(int x1, int y1) // create paramterised Constructor and initialise data member
    {
        x = x1; // x1 is now intialised to x
        y = y1; // y1 is now intialised to y
    }
intgetX()
    {
return x; // to get the value of x
    }
intgetY()
    {
return y; // to get the value of y
    }
};
int main()
{
    Point p1(10, 15); // created object for paramterised constructor

cout<< "p1.x = " << p1.getX() << ", p1.y = " << p1.getY(); // print x and y

return 0;
} 
```

**输出**

```
p1.x = 10, p1.y = 15   

```

**解释**

用两个数据成员 x 和 y 创建一个类点。用点 x1 和 y1 作为参数创建一个参数化构造函数，x 和 y 的值用 x1 和 y1 赋值。在主函数中，我们用值(10，15)创建一个参数化构造函数。使用 getter 函数，我们得到数据成员的值。

*   **复制构造函数-** 复制构造函数使用同一类的另一个对象初始化一个对象。

**语法**

**类名(constclassname & old_object)。**

**代码**

```

#include using namespace std;
class Point // create point class
    {
private:
int x, y; // data members of the class
public:
Point(int x1, int y1)
    {
        x = x1;
        y = y1;
    } // parameterised constructor

    // Copy constructor
Point(const Point& p1) // initialisation according to syntax
    {
        x = p1.x;
        y = p1.y;
    }
intgetX() { return x; } // return value of x
intgetY() { return y; } // return valur of y
};
int main()
{
    Point p1(10, 15); // call parameterised constructor
    Point p2 = p1; // call Copy constructor
    //  use getter and setter to print x and y
cout<< "p1.x = " << p1.getX() << ", p1.y = " << p1.getY();
cout<< "\np2.x = " << p2.getX() << ", p2.y = " << p2.getY();
return 0;
} 
```

**输出**

```
p1.x = 10, p1.y = 15
p2.x = 10, p2.y = 15 

```

## C++ 中的构造函数重载

由于存在函数重载的概念，因此类似地应用了构造函数重载。当我们重载一个构造函数超过一个目的时，这叫做构造函数重载。

声明与类名相同，但是因为它们是构造函数，所以没有返回类型。

重载构造函数的标准是不同的参数数量或参数类型。

**代码**

```

// C++ program to demonstrate constructor overloading
#include using namespace std;
class Person { // create person class
private:
int age; // data member
public:
    // 1\. Constructor with no arguments
Person()
    {
age = 20; // when object is created the age will be 20
    }
    // 2\. Constructor with an argument
Person(int a)
{ // when parameterised Constructor is called with a value the
        // age passed will be initialised
age = a;
    }
intgetAge()
{ // getter to return the age
return age;
    }
};
int main()
{
    Person person1, person2(45); // called the object of person class in differnt way

cout<< "Person1 Age = " << person1.getAge() < <endl cout="" age=" << person2.getAge() <<endl;
return 0;
}
</textarea>```
Person1 Age = 20
Person2 Age = 45    

```</div>
<p><strong>Output</strong></p>
<div class=" codeblock3=""></endl> 
```

**解释**

在上面的程序中，我们用一个数据成员(年龄)创建了一个类 **Person** 。类中有两个重载的构造函数。我们通过提供一个参数并将其参数化来重载第二个构造函数。

因此，在主函数中，当创建对象 person1 时，它调用非参数化构造函数，而当创建 person2 时，它调用参数化构造函数并执行初始化 age 所需的操作。因此，当打印对象 person1 age 时，它给出默认设置的 20，person2 age 给出 45，因为它是由对象传递给参数化构造函数的。

* * *