# C++ 中的默认参数

> 原文：<https://www.javatpoint.com/default-arguments-in-cpp>

在函数中，参数被定义为调用函数时传递的值。传递的值是源，接收函数是目标。

现在让我们详细了解默认参数的概念。

![Default arguments in C++](img/e20d9bd6f27a835a780877440f774d68.png)

**定义**

默认参数是函数声明中的一个值，如果调用函数没有向该参数传递任何值，则由编译器自动赋值。

**定义默认参数的特征**

以下是声明默认参数的规则-

*   默认参数中传递的值不是常量。如果将值传递给函数，这些值可能会被覆盖。如果没有，则保留先前声明的值。
*   在函数调用过程中，值从左向右复制。
*   所有给定默认值的值都在右边。

**例**

*   void 函数(int x，int y，int z = 0)
    说明-以上函数有效。这里 z 是作为默认参数的一部分预定义的值。
*   Void 函数(int x，int z = 0，int y)
    说明-以上函数无效。这里 z 是定义在两者之间的值，不被接受。

**代码**

```

#include using namespace std;
int sum(int x, int y, int z=0, int w=0) // Here there are two values in the default arguments 
{ // Both z and w are initialised to zero 
	return (x + y + z + w); // return sum of all parameter values
}
int main()
{
	cout << sum(10, 15) << endl; // x = 10, y = 15, z = 0, w = 0
	cout << sum(10, 15, 25) << endl; // x = 10, y = 15, z = 25, w = 0
	cout << sum(10, 15, 25, 30) << endl; // x = 10, y = 15, z = 25, w = 30
	return 0;
} 
```

**输出**

```
25
50
80    

```

**解释**

在上面的程序中，我们已经调用了 sum 函数三次。

*   Sum(10，15)
    当调用这个函数时，就达到了 Sum 的定义。在那里，它将 x 初始化为 10 y 初始化为 15，其余的值默认为零，因为没有传递任何值。求和后的所有值给出 25 作为输出。
*   Sum(10，15，25)
    调用此函数时，x 保持 10，y 保持 15，传递的第三个参数 z 初始化为 25 而不是零。最后一个值保持为 0。x，y，z，w 的和是 50，作为输出返回。
*   Sum(10，15，25，30)
    在这个函数调用中，有四个参数值传入函数，x 为 10，y 为 15，z 为 25，w 为 30。然后将所有值相加，得出 80 作为输出。

#### 注意如果函数重载了包含默认参数的不同数据类型，可能会导致不明确的匹配，从而导致错误。

**例**

```

#include using namespace std;
int sum(int x, int y, int z=0, int w=0) // Here there are two values in the default arguments 
{ // Both z and w are initialised to zero 
	return (x + y + z + w); // return sum of all parameter values
}
int sum(int x, int y, float z=0, float w=0) // Here sum is overloaded with two float parameter values 
{ // This results in ambiguity 
	return (x + y + z + w);
}
int main()
{
	cout << sum(10, 15) << endl; // x = 10, y = 15, z = 0, w = 0
	cout << sum(10, 15, 25) << endl; // x = 10, y = 15, z = 25, w = 0
	cout << sum(10, 15, 25, 30) << endl; // x = 10, y = 15, z = 25, w = 30
	return 0;
} 
```

**输出**

```
prog.cpp: In function 'int main()':
prog.cpp:15:20: error: call of overloaded 'sum(int, int)' is ambiguous
  cout << sum(10, 15) << endl; // x = 10, y = 15, z = 0, w = 0
                    ^
prog.cpp:4:5: note: candidate: int sum(int, int, int, int)
 int sum(int x, int y, int z=0, int w=0) // Here there are two values in the default arguments 
     ^
prog.cpp:9:5: note: candidate: int sum(int, int, float, float)
 int sum(int x, int y, float z=0, float w=0) // Here sum is overloaded with two float parameter values    

```

**解释**

这里，当我们用所有**参数(x，y，z，w)** 或者 z 或 w 的任何一个参数值调用 sum 函数时，编译器会对执行哪个函数感到困惑。因此，它产生了导致错误的模糊性。

* * *