# C++ 中的动态内存分配

> 原文：<https://www.javatpoint.com/dynamic-memory-allocation-in-cpp>

有时要输入的数据是在执行时分配的。例如，当组织雇用新员工时，员工列表会增加，而当一个人离开组织时，员工列表也会减少。这叫做管理内存。现在，让我们讨论动态内存分配的概念。

![Dynamic memory allocation in C++](img/ea9784a5bc4559e4c01ed9a067c42350.png)

**内存分配**

为变量保留或提供空间称为内存分配。为了存储数据，内存分配可以通过两种方式完成-

*   **静态分配或编译时分配-** 静态内存分配意味着为变量提供空间。变量的大小和数据类型是已知的，并且在整个程序中保持不变。
*   **动态分配或运行时分配-** 动态分配内存的分配。在这种类型的分配中，变量的确切大小事先是不知道的。指针在动态内存分配中起着重要作用。

**为什么是动态内存分配？**

当程序处于运行状态时，我们可以动态地分配存储，但是不能“动态”创建变量。因此，动态内存分配有两个标准-

*   内存中需要一个动态空间。
*   存储从存储器访问变量的地址

同样，我们对内存中的变量进行内存分配。

在 C++ 中，内存分为两部分-

*   **堆栈-** 任何函数内部声明的所有变量都从堆栈中获取内存。
*   **Heap -** 一般用于动态内存分配的是程序中未使用的内存。

**使用新运算符**进行动态内存分配

为了动态分配空间，使用了运算符 new。这意味着在空闲存储上创建一个内存分配请求。如果内存可用，则初始化内存，并将该空间的地址返回给指针变量。

**语法**

**指针 _ 变量=新数据 _ 类型；**

指针变量属于指针数据类型。数据类型可以是 int、float、string、char 等。

**例**

int *m = NULL //最初我们有一个空指针

m =向变量请求新的 int //内存

它可以通过将以下语句放在一行中来直接声明-

**int *m =新 int**

**初始化内存**

我们也可以使用新的操作符初始化内存。

例如

int * m = new int(20)；

Float *d =新的 float(21.01)；

**分配一块内存**

我们还可以使用新的运算符来分配特定数据类型的块(数组)。

例如

int *arr = new int[10]

这里我们为十个整数动态分配了内存，这也返回了指向数组第一个元素的指针。因此，arr[0]是第一个元素，依此类推。

**注**

*   创建普通数组和使用新的普通数组分配块之间的区别由编译器解除分配。而块是动态创建的，直到程序员删除它或者程序终止。
*   如果堆内存中没有空间，新的请求将导致抛出异常失败(std::bad_alloc)，直到我们对新的操作符使用*non-throw*。因此，最佳实践是首先检查指针变量。

**代码**

```

int *m = new(nonthrow) int;
if(!m) // check if memory is available 
{
	cout<< "No memory allocated";
}

```

现在我们已经动态地分配了内存。让我们学习如何删除它。

**删除操作符**

我们使用 **delete** 运算符删除 C++ 中分配的空间。

**语法**

删除指针变量名称

**例**

删除 m；// free m 这是一个变量

删除[]arr；//释放一块内存

**演示动态内存分配的示例**

```

// The program will show the use of new and delete
#include 
using namespace std;
int main ()
{
	// Pointer initialization to null
	int* m = NULL;

	// Request memory for the variable
	// using new operator
	m = new(nothrow) int;
	if (!m)
		cout<< "allocation of memory failed\n";
	else
	{
		// Store value at allocated address
		*m=29;
		cout<< "Value of m: " << *m <
```

**输出**

```
Value of m: 29
Value of f: 75.25
Value store in block of memory: 1 2 3 4 5     

```

* * *