# C++ 日期和时间

> 原文：<https://www.javatpoint.com/cpp-date-and-time>

在本文中，我们将学习 C++ 中的日期和时间格式。C++ 中没有完整的日期和时间格式，所以我们从 C 语言继承了它。要在 c++ 中使用日期和时间， **< ctime >** 头文件被添加到程序中。

这个头文件有如下四种与时间相关的类型-

*   **Clock_t -** 代表时钟类型，是算术类型的别名。它表示时钟滴答计数(具有系统特定长度的常数的时间单位)。Clock_t 是 **clock()返回的类型。**
*   **Time_t -** 代表 time_type。它表示由函数 **time()返回的时间。**当时间经过 00:00 小时时，它输出一个整数值作为经过的秒数。
*   **Size_t -** 它是无符号整数类型的别名，以字节为单位表示任何对象的大小。Size_t 是 **sizeof()** 运算符打印尺寸和计数的结果。
*   **TM-**TM 结构在 C 结构中保存日期和时间。其定义如下-

```

struct tm {
    int tm_sec; // seconds of minutes from 0 to 61
    int tm_min; // minutes of hour from 0 to 59
    int tm_hour; // hours of day from 0 to 24
    int tm_mday; // day of month from 1 to 31
    int tm_mon; // month of year from 0 to 11
    int tm_year; // year since 1900
    int tm_wday; // days since sunday
    int tm_yday; // days since January 1st
    int tm_isdst; // hours of daylight savings time
}

```

## c++ 中的日期和时间函数

| 函数的名称 | 函数的原型 | 关于功能的描述 |
| mktime | time _ t MK time(struct TM * time)； | 该函数将 mktime 转换为 time_t 或日历日期和时间。 |
| 阿蒂米 | char * ctime(const time _ t * time)； | 它将指针返回到格式为日、月、年、小时、分钟、秒、年的字符串。 |
| 差异时间 | 双倍 difftime ( time_t time2，time _ t time 1)； | 它返回两个时间对象 t1 和 t2 的差值。 |
| 断续器 | struct TM * gmtime(const time _ t * time)； | 该函数以结构的形式返回时间指针。时间以世界协调时为单位。 |
| 时钟 | clock_t 时钟(无效)； | 它返回调用程序运行时间的近似值。如果不可用，则返回值. 1。 |
| localtime(本地时间) | struct TM * local time(const time _ t * time)； | 该函数返回表示本地时间的 tm 结构的指针。 |
| 时间 | time _ t time(time _ t * time)； | 它代表当前时间。 |
| strftime | size_t strftime（）; | 借助这个功能，我们可以以特定的方式格式化日期和时间。 |
| asctime | char * asctime(const struct TM * time)： | 该函数将 tm 的类型对象转换为字符串，并返回指向该字符串的指针。 |

### 打印当前日期和时间的示例

下面是以世界协调时格式打印当前日期和时间的示例。

**代码**

```

#include #include <iostream>using namespace std;

int main()
{

    time_t now = time(0); // get current dat/time with respect to system

    char* dt = ctime(&now); // convert it into string

    cout << "The local date and time is: " << dt << endl; // print local date and time

    tm* gmtm = gmtime(&now); // for getting time to UTC convert to struct
    dt = asctime(gmtm);
    cout << "The UTC date and time is:" << dt << endl; // print UTC date and time
}</iostream> 
```

**输出**

```
The local date and time is: Wed Sep 22 16:31:40 2021

The UTC date and time is: Wed Sep 22 16:31:40 2021

```

下面的代码讲述了如何使用 **- >** 运算符打破 tm 结构并独立打印每个属性。

**代码**

```

#include #include <ctime>using namespace std;

int main()
{
    time_t now = time(0); // get current date and time

    cout << "Number of seconds since January 1,2021 is:: " << now << endl;

    tm* ltm = localtime(&now);

    // print various components of tm structure.
    cout << "Year:" << 1900 + ltm->tm_year << endl; // print the year
    cout << "Month: " << 1 + ltm->tm_mon << endl; // print month number
    cout << "Day: " << ltm->tm_mday << endl; // print the day
    // Print time in hour:minute:second
    cout << "Time: " << 5 + ltm->tm_hour << ":";
    cout << 30 + ltm->tm_min << ":";
    cout << ltm->tm_sec << endl;
}</ctime> 
```

**输出**

```
Number of seconds since January 1,2021 is:: 1632328553
Year:2021
Month: 9
Day: 22
Time: 21:65:53

```

* * *