# C++ 中多态性的类型

> 原文：<https://www.javatpoint.com/types-of-polymorphism-in-cpp>

多态性被定义为将函数或运算符用于多个目的的过程。换句话说，我们也可以说，一个运算符或函数可以以不同的方式为我们服务。

**例如**

假设一个运算符“+”用于将两个整数相加，并且还用于连接两个字符串。

因此‘+’运算符有两个目的——加法和串联。

现在让我们了解 C++ 中多态性的类型。

## 编译时多态性

它被定义为在编译时调用函数的多态性。这种类型的过程也被称为*早期或静态绑定。*

### 编译时多态性的例子

**1)功能过载**

函数重载被定义为将一个函数用于不同的目的。这里，一个函数通过改变函数签名(参数数量和参数类型)来执行许多任务。这是编译时多态性的一个例子，因为调用什么函数是在编译时决定的。

**例**

在下面的代码中，我们采用了一个**类加法**，它执行两个数字的加法并将两个字符串连接起来。它有一个功能 **ADD()** 重载了两次。

函数 **ADD(int X，int Y)** 将两个整数相加，没有参数的函数 **ADD()** 执行字符串连接。

**代码**

```

#include using namespace std;
class Addition { // Create Addition class
public:
    int ADD(int X, int Y) // Add function add two numbers
    {
        return X + Y; // return the Addition of two numbers
    }
    int ADD()
    { // this ADD function concatenates two strings
        string a = "HELLO";
        string b = " JAVATPOINT";
        string c = a + b; // concatenate two strings
        cout << c << endl; // print result
    }
};
int main(void)
{
    Addition obj; // Object is created  of Addition class
    cout << obj.ADD(120, 105) << endl; //first method is called to add two integers
    obj.ADD(); // second method is called to concatenate two strings
    return 0;
} 
```

**输出**

```
225
HELLO JAVATPOINT

```

## 操作员超载

运算符重载被定义为在原始运算符之外使用一个运算符进行加法运算。

使用运算符重载的概念是因为它为用户定义的数据类型提供了特殊的含义。运算符重载的好处是我们可以使用相同的操作数来服务两个不同的操作。基本的运算符重载示例是“+”运算符，因为它用于添加数字和字符串。

操作员**，::？:尺寸**不能过载。

### 例子

在下面的例子中，我们重载了“+”来添加两个字符串。

通过将**运算符**关键字与要重载的运算符一起使用，运算符被重载。

**代码**

```

#include using namespace std;
class A // Create a class A
    {

    string x; // private data member x
public:
    A() {}
    A(string i)
    {
        x = i; // Assign the data member
    }
    void operator+(A); // operator overloading
};

void A::operator+(A a) // concetenate the strings and print output
{

    string m = x + a.x;
    cout << "The result of the addition of two objects is: " << m;
}
int main()
{
    A a1("Welcome "); // string 1
    A a2("to javatpoint"); // string 2
    a1 + a2; // concetenate two strings using operator overloading
    return 0;
} 
```

**输出**

```
The result of the addition of two objects is: Welcome to javatpoint

```

## 运行时多态性

运行时多态性被定义为在程序执行时调用函数的过程。

运行时多态性的一个例子是*函数覆盖。*

### 函数覆盖

当我们说一个函数被重写时，这意味着在派生类中给出了该函数的新定义。因此，在函数重写中，我们有两个定义，一个在基类中，另一个在派生类中。选择函数的决定是在运行时决定的。

**例**

在下面的例子中，类动物有一个函数 **f()** ，它也在衍生类 **Man 中。**当我们用基对象调用函数 f()时，它打印基的内容，用派生对象打印派生的内容。因此，函数 f()的选择取决于运行时间。

**代码**

```

#include using namespace std;
class Animal { // Create a new class
public:
    void f()
    { // the function f will be overriden in the class Man
        cout << "Eating..." << endl;
    }
};
class Man : public Animal // Base class inheriting derived class
{
public:
    void f() // The function f being overriden
    {
        cout << "Walking ..." << endl;
    }
};
int main(void)
{
    Animal A = Animal();
    A.f(); //parent class object
    Man m = Man();
    m.f(); // child class object

    return 0;
} 
```

**输出**

```
Eating...
Walking ...

```

* * *