# 实现没有 C++ STL 容器的集合

> 原文：<https://www.javatpoint.com/implementing-the-sets-without-cpp-stl-containers>

集合被定义为元素的集合，其中每个元素都是唯一的。它不同于数组，因为集合可以有不同的长度。一次添加到集合中的元素不能更改。如果我们想添加相同的修改号码，删除该号码并在集合中添加修改的号码。

以下是可以在集合上执行的操作-

*   **add(value) -** 该函数在集合中添加一个元素
*   **交集集合(S)—**返回集合 S 中两个集合的交集
*   **toArray() -** 将集合转换为元素数组
*   **包含(s) -** 如果集合中存在要搜索的元素，则返回集合
*   **显示设置()-** 从头到尾打印设置
*   **getSize() -** 获取集合的大小
*   **并集-** 显示两个集合与集合的并集

## 使用 BST 实现集合

set 数据结构在内部实现 BST(二叉查找树)数据结构。因此，我们将在树中添加元素，并使用这个树模板来实现集合。

*   **创建 BST 的模板**

在树中，我们有三个成员——节点的数据和指向节点的左右指针。如下所示-

```

template struct Node { // Create a node of BST
    T data; // Node value
    Node* left; // Pointer to the left child
    Node* right; // Pointer to the right child
		}; 
```

创建树后，我们使用 **insert()** 函数在树中插入节点。在 BST 中，小于根的数据位于树的左侧，较大的数据位于树的右侧。

函数**包含节点()**用于检查树中是否存在节点。

函数**order()**用于打印 BST 的有序遍历。

*   **在 Set 类**中实现 BST 模板

在我们为集合的内部工作创建了 BST 之后，创建了一个集合模板来实现 BST。它有一个根指针节点来存储数据，大小变量返回集合的大小。

Set 类有一个默认的构造函数将 BST 的根初始化为 NULL，还有一个复制构造函数将一个集合复制到另一个集合中。

```

// create a class template for implementing a set in BST
template class Set { // Create class set
    Node<t>* root; // Root to store the data
    int size; // It indicates the size of the set
	      };</t> 
```

功能 **add()** 用于添加集合中的值。它不会通过调用函数 **containsNode()来添加集合中的重复数据。**如果有新元素，它会添加到集合中。

功能**包含()**检查集合中是否存在特定元素。它在 BST 内部调用 **containsNode()** 。

功能**显示设置()**用于打印设置的元素。它在内部调用 BST 的**inoder()**功能。

函数 **getSize()** 返回集合的大小。

**代码**

```

#include #include <iostream>#include <math.h>#include <stack>#include <string>using namespace std;

template <typename t="">struct Node { // Create a node of BST

    T data; // Node value

    Node* left; // Pointer to the left child

    Node* right; // Pointer to the right child

public:
    // this function prints inorder traversal of BST
    void inorder(Node* r)
    {
        if (r == NULL) { // If we  reach last level
            return;
        }
        inorder(r->left); // print left child
        cout << r->data << " "; // print the node value
        inorder(r->right); // print the right child
    }

    /*
		Function to check if BST contains a node
		with the given data

		r pointer to the root node
		 d the data to search in the BST
		The function returns 1 if the node is present in the BST else 0
	*/
    int containsNode(Node* r, T d)
    {
        if (r == NULL) { // If we reach last level or tree is empty
            return 0;
        }
        int x = r->data == d ? 1 : 0; // Check for duplicacy
        // Traverse in right and left subtree
        return x | containsNode(r->left, d) | containsNode(r->right, d);
    }

    /*
		Function to insert a node with
		given data into the BST

		r pointer to the root node in the BST 
		d the data to insert in the BST
		return pointer to the root of the resultant BST
	*/
    Node* insert(Node* r, T d)
    {

        if (r == NULL) { // Add where NULL is encountered which means space is present
            Node<t>* tmp = new Node<t>; // Create a new node in BST
            tmp->data = d; // insert the data in the BST
            tmp->left = tmp->right = NULL; // Allocate left and right pointers a NULL
            return tmp; // return current node
        }

        //    Insert the node in the left subtree if data is less than current node data
        if (d < r->data) {
            r->left = insert(r->left, d);
            return r;
        }

        //   Insert the node in the right subtree if data is greater than current node data
        else if (d > r->data) {
            r->right = insert(r->right, d);
            return r;
        }
        else
            return r;
    }
};

template <typename t="">// create a class template for implementing a set in BST
class Set { // Create class set

    Node<t>* root; // Root to store the data

    int size; // It indicates the size of the set

public:
    Set() // If no value passed
    {
        root = NULL; // It points to NULL
        size = 0; // size becomes zero
    }

    Set(const Set& s) // Copy constructor
    {
        root = s.root;
        size = s.size;
    }

    void add(const T data) // It add an element to the set
    {
        if (!root->containsNode(root, data)) { // Check if it is the first element
            root = root->insert(root, data); // Insert  the data into the set
            size++; // Increment the size of the set
        }
    }

    bool contains(T data)
    {
        return root->containsNode(root, data) ? true : false;
    }

    void displaySet()
    {
        cout << "{ ";
        root->inorder(root);
        cout << "}" << endl;
    }

    /*
        Function to return the current size of the Set

        @return size of set
    */
    int getSize()
    {
        return size;
    }
};

int main()
{

    // Create Set A
    Set <int>A;

    // Add elements to Set A
    A.add(1);
    A.add(2);
    A.add(3);
    A.add(2);

    // Display the contents of Set A
    cout << "A = ";
    A.displaySet();

    // Check if Set A contains some elements
    cout << "A " << (A.contains(3) ? "contains"
                                   : "does not contain")
         << " 3" << endl;
    cout << "A " << (A.contains(4) ? "contains"
                                   : "does not contain")
         << " 4" << endl;
    cout << endl;

    return 0;
}</int></t></typename></t></t></typename></string></stack></math.h></iostream> 
```

**输出**

```
A = { 1 2 3 }
A contains 3
A does not contain 4

```

* * *