# C++ 中的 Const 关键字

> 原文：<https://www.javatpoint.com/const-keyword-in-cpp>

本节将讨论 C++ 编程语言中的 const 关键字。它是常量关键字，用于定义在程序执行过程中不能改变的常量值。这意味着一旦我们在程序中将一个变量声明为常数，该变量的值将是固定的，永远不会改变。如果我们试图更改 const 类型变量的值，它会在程序中显示一条错误消息。

![Const keyword in C++](img/3a60196deb4744cde51a2db00151db22.png)

**使用不同参数的 const 关键字:**

*   使用常量变量
*   对指针使用常量
*   对变量使用常量指针
*   将常量与函数参数一起使用
*   对类成员函数使用 const
*   对类数据成员使用 const
*   对类对象使用常量

### 1.常量变量

它是一个常量变量，用于定义在程序执行过程中永不改变的变量值。如果我们试图修改这个值，它会抛出一个错误。

**语法**

```

const data_type variable_name; 

```

**示例:C++ 中使用 const 关键字的程序**

让我们创建一个程序来演示 C++ 编程语言中 const 关键字的使用。

```

#include #include <conio.h>using namespace std;
int main ()
{
// declare the value of the const
const int num = 25;
num = num + 10;
return 0;
}</conio.h> 
```

**输出**

它显示了编译时错误，因为我们将 num 25 的赋值更新了 10。

**示例:让我们创建一个简单的程序来演示 C++ 编程语言中 const 关键字的使用。**

```

/* create a program to use the const keyword with different data types in the C++. */
#include #include <conio.h>using namespace std;
int main ()
{
// declare variables
const int x = 20;
const int y = 25;
int z;
// add the value of x and y
z = x + y;
cout << " The sum of the x and y is: " << z << endl;
return 0;
}</conio.h> 
```

**输出**

```
 The sum of the x and y is: 42

```

在上面的程序中，我们在开始时声明并分配了常量变量 x 和 y。然后，将两个常量变量的结果存储到“z”变量中，以打印总和。

#### 注意:在 C++ 编程中声明常量变量时，我们需要同时赋值已定义变量的值；否则，它会显示编译时错误。

### 2.常数指针

要创建一个常量指针，我们需要在指针名称前使用 const 关键字。我们不能在常量指针初始化后改变它的地址，这意味着一旦指针被初始化为常量指针，指针将总是指向同一个地址。

**示例:使用 const 关键字**演示常量指针的程序

让我们考虑一个在 C++ 编程语言中使用 const 关键字和常量指针的例子。

```

#include using namespace std;
int main ()
{
// declaration of the integer variables
int x = 10, y = 20;

// use const keyword to make constant pointer
int* const ptr = &x; //  const integer ptr variable point address to the variable x

// ptr = &y; // now ptr cannot changed their address
*ptr = 15; // ptr can only change the value
cout << " The value of x: " << x << endl;
cout << " The value of ptr: " << *ptr << endl;
return 0;
} 
```

**输出**

```
The value of x: 15
The value of ptr: 15

```

在上面的程序中，指针 ptr 指向 int 变量' x '的地址，ptr 变量一旦初始化就不能改变它们的地址，但是指针 ptr 可以改变 x 的值。

### 3.指向常量变量的指针

这意味着指针指向不能改变的常量变量的值。

**常量变量指针的声明:**

```

const int* x; 

```

这里，x 是指向常量整数类型变量的指针，我们也可以将指向常量变量的指针声明为，

```

char const* y;

```

在这种情况下，y 是指向字符类型常量变量的指针。

**示例:程序使用 const 关键字，指针指向常量变量**

```

#include 
using namespace std;
int main ()
{
// declare integer variable
int x = 7, y = 10;

const int *ptr = &x; // here x become constant variable
cout << " \n The initial value of ptr:" << *ptr;
cout << " \n The value of x: " <
```

**输出**

```
The initial value of ptr: 7
The value of x: 7
The value of y: 10
The value of ptr: 10

```

在上面的程序中，指针 ptr 指向 const int (x)变量，int (x)变量的值永远不会改变。

### 4.常量函数参数

我们可以使用 const 关键字将函数参数声明为常量参数。如果函数参数的值声明为 const，则不允许更改其值。

**语法**

```

return_type fun_name (const int x)
{
} 

```

在上面的语法中，return_type 表示函数是否返回值。fun_name()函数包含一个常量参数，一旦它在程序中定义，其值就永远不能更改。

**示例:让我们考虑一个在 C++ 编程语言中将 const 关键字与函数参数一起使用的示例。**

```

#include using namespace std;
// create an integer Test() function contains an argument num
int Test (const int num)
{
// if we change the value of the const argument, it thwrows an error.
// num = num + 10;
cout << " The value of num: " << num << endl;
return 0;
}
int main ()
{
// call function
Test(5);
} 
```

**输出**

```
The value of num: 5

```

在上面的程序中，num 是一个常量参数，我们不能更新 num 值。如果我们更新 num 变量的值，它会返回编译时错误。

### 5.类的常量成员函数

1.  const 是一个类的常量成员函数，它从不改变任何类数据成员，也不调用任何非常量函数。
2.  它也被称为只读函数。
3.  我们可以通过在成员函数的名称后面添加 const 关键字来创建一个类的常量成员函数。

**语法**

```

return_type mem_fun() const
{
} 

```

在上面的语法中，mem_fun()是一个类的成员函数，在成员函数的名字后面使用 const 关键字使其成为常量。

**示例:将 const 关键字与类的成员函数一起使用的程序**

让我们考虑一个用类的成员函数定义 const 关键字的例子。

```

class ABC
{
// define the access specifier
public:

// declare int variables
int A;
// declare member function as constant using const keyword
void fun () const
{
 A = 0; // it shows compile time error
}
};

int main ()
{
	ABC obj;
	obj.fun();
	return 0;
}

```

**输出**

上面的代码抛出了一个编译错误，因为 fun()函数是类 ABC 的一个常量成员函数，我们试图为它的数据成员“x”赋值，结果返回了一个错误。

### 6.类的常量数据成员

数据成员就像在类中声明的变量，但是一旦数据成员被初始化，它就永远不会改变，甚至在构造函数或析构函数中也不会。常量数据成员在类中的数据类型之前使用 const 关键字初始化。在声明期间，不能为 const 数据成员分配值；但是，他们可以分配构造函数值。

**示例:对类的数据成员使用 const 关键字的程序**

```

/* create a program to demonstrate the data member using the const keyword in C++. */
#include using namespace std;
// create a class ABC
class ABC
{

public:
 // use const keyword to declare const data member
const int A;
// create class constructor
ABC ( int y) : A(y)
{
cout << " The value of y: " << y << endl;
}
};
int main ()
{
ABC obj( 10); // here 'obj' is the object of class ABC
cout << " The value of constant data member 'A' is: " << obj.A << endl;
// obj.A = 5; // it shows an error.
// cout << obj.A << endl;
return 0;
} 
```

**输出**

```
The value of y: 10
The value of constant data member 'A' is: 10

```

在上面的程序中，ABC 类的对象 obj 调用 ABC 构造函数打印 y 的值，然后打印 const data 成员‘A’的值为 10。但是当物体。“A”分配了“A”数据成员的新值，它显示编译时错误，因为 A 的值是常量，不能更改。

### 7.常量对象

当我们使用 const 关键字创建一个对象时，数据成员的值永远不会改变，直到对象在程序中的生命期。const 对象也称为只读对象。

**语法**

```

const class_name obj_name;

```

在上面的语法中，const 是一个用在类的对象名之前的关键字，用来使它成为一个常量对象。

**示例:让我们创建一个程序来使用 C++ 编程语言中的常量对象。**

```

#include using namespace std;
class ABC
{
public:
// define data member
int A;
// create constructor of the class ABC
ABC ()
{
A = 10; // define a value to A
}
};
int main ()
{
// declare a constant object
const ABC obj;
cout << " The value of A: " << obj.A << endl;
// obj.A = 20; // It returns a compile time error
return 0;
} 
```

**输出**

```
The value of A: 10

```

在上面的程序中，我们赋值 A 的值是 10，编译器打印“A 的值:10”，当我们赋值 A 为 20 时，类的对象返回程序中的编译时错误。

### 程序使用 const 关键字查找圆的面积

让我们考虑一个在 C++ 编程语言中使用 const 关键字打印圆的面积的例子。

```

#include using namespace std;
int main ()
{
// declare variables
int r;
const double PI = 3.14;
double result;
cout << " Input the radius of a circle: " << endl;
cin >> r;
result = PI * r * r;
cout << " The area of a circle is: " << result;
} 
```

**输出**

```
Input the radius of a circle: 
5
The area of a circle is: 78.5

```

* * *