# perl 标量

> 原文：<https://www.javatpoint.com/perl-scalars>

标量包含单个数据单元。它前面有一个($)符号，后面是字母、数字和下划线。

标量可以包含任何东西，如数字、浮点数、字符或字符串。

我们可以用两种方式定义标量。首先，我们可以一起声明和赋值。其次，我们将首先声明，然后给标量赋值。

在下面的例子中，我们将展示定义标量的两种方法。

**示例:**

```

use strict;
use warnings;
use 5.010;
#Declairing and assigning value together
my $color = "Red";
say $color;
#Declairing the variable first and then assigning value
my $city;
$city = "Delhi";
say $city;

```

输出:

```
Red
Delhi

```

## Perl 标量操作

在这个例子中，我们将使用两个标量变量 **$x** 和 **$y** 执行不同的操作。在 Perl 中，运算符告诉操作数如何操作。

**示例:**

```

use strict;
use warnings;
use 5.010;
my $x = 5;
say $x;             
my $y = 3;
say $y;            
say $x + $y;        
say $x . $y;        
say $x x $y;

```

输出:

```
5
3
8
53
555

```

第一个和第二个输出分别是$x 和$y 的值。

**(+)** 运算符简单地将 5 和 3 相加，输出为 8。

**(。)**是一个连接运算符，它连接输出 5 和 3，输出为 53。

**(x)** 是一个重复运算符，其左侧变量的重复次数与其右侧的数字相同。

## Perl 特殊文字

在 Perl 中有三种特殊的文字:

__FILE__:表示当前文件名。

__LINE__:表示当前行号。

__PACKAGE__:它代表程序中该点的包名。

**示例:**

```

use strict;
use warnings;
use 5.010;
#!/usr/bin/perl
print "File name ". __FILE__ . "\n";
print "Line Number " . __LINE__ ."\n";
print "Package " . __PACKAGE__ ."\n";
# they can?t be interpolated
print "__FILE__ __LINE__ __PACKAGE__\n";

```

输出:

```
File name hw.pl
Line Number 6
Package main
__FILE__ __LINE __ __PACKAGE

```

## Perl 字符串上下文

Perl 根据需求自动将字符串转换为数字，将数字转换为字符串。

比如 5 等于“5”，5.123 等于“5.123”。

但是如果一个字符串有一些字符而不是数字，它们在算术运算中会有什么表现。让我们通过一个例子来看看。

**示例:**

```

use strict;
use warnings;
use 5.010;
my $x = "5";
my $y = "2cm";
say $x + $y;       
say $x . $y;      
say $x x $y;

```

输出:

```
7
52cm
55

```

在数字上下文中，Perl 查看字符串的左侧，并将其转换为数字。字符成为变量的数值。在数字环境(+)中，给定的字符串“2cm”被视为数字 2。

但是，它会生成警告

```

Argument "2cm" isn't numeric in addition (+) at hw.pl line 9.

```

这里发生的是，Perl 没有将$y 转换成数值。它只是使用了它的数字部分，即；2.

* * *

## Perl undef

如果你不在变量中定义任何东西，它被认为是**不定义**。在数字环境中，它充当 **0** 。在字符串上下文中，它充当**空**字符串。

```

use strict;
use warnings;
use 5.010;
my $x = "5";
my $y;
say $x + $y;       
say $x . $y;      
say $x x $y;
if (defined $y) {
  say "defined";
} else {
  say "NOT";         
}

```

输出:

```
Use of uninitialized value $y in addition (+) at hw.pl line 9.
5
Use of uninitialized value $y in concatenation (.) or string at hw.pl line 10.
5
Use of uninitialized value $y in repeat (x) at hw.pl line 11.
NOT

```