# Perl 数组

> 原文：<https://www.javatpoint.com/perl-array>

Perl 数组变量存储标量值的有序列表。

要引用 Perl 数组中的单个元素，变量名前面将带有美元符号($)，后面是方括号中的元素索引。

**语法:**

```

@arrayName = (element1, element2, element3..);

```

* * *

## Perl 简单数组示例

这是一个使用 Perl 数组的简单例子。

```

#!/usr/bin/perl

@num = (2015, 2016, 2017);             
@string = ("One", "Two", "Three");
print "$num[0]\n";
print "$num[1]\n";
print "$num[2]\n";
print "$string[0]\n";
print "$string[1]\n";
print "$string[2]\n";

```

输出:

```
2015
2016
2017
One
Two
Three

```

在上面的例子中，我们定义了两个数组，一个带有 number 元素，另一个带有 string 元素。两个数组都打印有索引元素。

* * *

## Perl 数组访问

若要访问 Perl 数组的单个元素，请在变量名前使用($)符号。您可以假设$符号代表单数，而@符号代表复数。

变量名后面有方括号，里面有索引号。索引将从左侧的 0 开始，从右侧的-1 开始。

```

@months = qw/Jan Feb Mar Apr May Jun Jul Aug Sept Oct Nov Dec/;
print "$months[0]\n";
print "$months[1]\n";
print "$months[7]\n";
print "$months[9]\n";
print "$months[6]\n";
print "$months[-3]\n";

```

输出:

```
Jan
Feb
Aug
Oct
Jul
Oct

```

* * *

## Perl 数组大小或长度

数组的大小由数组上的标量上下文决定。返回值将总是比最大索引大一。简而言之，数组的大小将是($#array + 1)。这里，$#array 是数组的最大索引。

```

@array = (you, me, us);
$array[5] = 4;
$size = @array;
$index_max = $#array;
print "Size:  $size\n";
print "Maximum Index: $index_max\n";

```

输出:

```
Size: 6
Maximum Index: 5

```

在输出中，只有三个元素包含信息，但是给定数组总共有 5 个元素。

* * *

# Perl 数组函数

您可以使用一些数组函数在数组中添加或移除元素。

我们将讨论以下数组 Perl 函数:

*   推
*   流行音乐
*   变化
*   松开打字机或键盘的字型变换键

* * *

### 1)推进阵列

push 数组函数在数组末尾追加一个新元素。

```

@array = ("pink", "red", "blue");
push @array, "orange";
print "@array\n";

```

输出:

```
pink red blue orange

```

在上面的程序中，“橙色”元素被添加到数组的末尾。

* * *

### 2)阵列弹出

pop 数组函数从数组中移除最后一个元素。

```

@array = ("pink", "red", "blue");
pop @array;
print "@array\n";

```

输出:

```
pink red 

```

在上面的程序中，“蓝色”元素从数组的末尾移除。

* * *

### 3)阵列移位

移位数组函数移除数组中最左边的元素，从而将数组缩短 1。

```

@array = ("pink", "red", "blue");
shift @array;
print "@array\n";

```

输出:

```
red blue

```

在上面的程序中，“粉色”从数组中移除。

* * *

### 4)阵列上的非偏移

unshift 数组函数在数组的开头添加一个新元素。

```

@array = ("pink", "red", "blue");
unshift @array, "orange";
print "@array\n";

```

输出:

```
orange pink red blue 

```

在上面的程序中，“橙色”被添加在数组的开头。

* * *

## 替换数组元素，拼接()

拼接数组函数删除定义的元素，并用给定的列表替换它们。

```

@alpha = (A..Z);
print "Before - @alpha\n";
splice(@alpha, 8, 8, U..Z); 
print "After - @alpha\n";

```

输出:

```
Before - A B C D E F G H I J K L M N O P Q R S T U V W X Y Z
After -    A B C D E F G H U V W X Y Z Q R S T U V W X Y Z

```

在上面的程序中，替换从第 9 个位置(I)开始计数到 8 个元素，即 p。

* * *

## Perl 字符串到数组，拆分()

借助 split()函数，我们可以将字符串拆分成字符串数组并返回。

```

# original string
$string = "Where-There-Is-A-Will-There-Is-A-Way";
# transforming strings into arrays.
@string = split('-', $string);
print "$string[4]\n"; 

```

输出:

```
Will

```

在上面的程序中，我们已经将$string 转换为连字符(-)值处的数组。现在从这个数组，我们已经打印了数组的第四个元素。

* * *

## 字符串的 Perl 数组，连接()

join()函数用于将数组组合成字符串。它将单独的数组组合成一个字符串并返回。

```

# original string
$string = "Where-There-Is-A-Will-There-Is-A-Way";
# transforming arrays into strings.
@string = split('-', $string);
$string_full = join( '-', @string );
print "$string_full\n";

```

输出:

```
Where-There-Is-A-Will-There-Is-A-Way

```

在上面的程序中，字符串以连字符(-)分隔。我们在$string_full 中使用了 join()并打印了它。

* * *

## 合并两个数组，合并()

可以使用 merged()函数将两个数组合并为一个字符串，去掉它们之间的所有逗号。

```

#two arrays
@array1 = ("Girl", "in", "front", "of", "me");
@array2 = ("is", "very", "beautiful");
#merging both the arrays
@merged = (@array1, @array2);
print "@merged\n";

```

输出:

```
Girl in front of me is very beautiful

```

在上面的程序中，数组 1 和数组 2 被合并成一个字符串，然后打印出来。

* * *

## Perl 排序数组，排序()

要对数组进行排序，可以使用 sort()数组函数。sort()函数根据 ASCII 标准对数组的所有元素进行排序。

```

# defining array
@days = ("sun", "mon", "tue", "wed", "thu", "fri", "sat");
print "Original array: @days\n";
# sorting array
@days = sort(@days);
print "Sorted array: @days\n";

```

输出:

```
Original array: sun mon tue wed thu fri sat 
Sorted array: fri mon sat sun thu tue wed

```

在上面的程序中，我们打印了原始数组和排序数组。该数组按字母顺序排序。