# Perl 字符串

> 原文：<https://www.javatpoint.com/perl-string>

字符串是 Perl 语言的重要组成部分。它们是标量变量，所以以($)符号开头。字符串可以在单引号(')或双引号(")中定义。

* * *

## Perl 字符串运算符

运算符使以不同方式操作字符串变得容易。有两种类型的字符串运算符:

*   串联(。)
*   重复(x)

* * *

## Perl 连接运算符

Perl 字符串用一个(.)连接在一起。)符号而不是(+)符号。

```

$firstName = "Christian";
$lastName = "Grey";
$fullName = $firstName . " " . $lastName;
print "$fullName\n";

```

输出:

```
Christian Grey

```

* * *

## perl 重复运算符

Perl 字符串可以用(x)变量重复多次。

```

$text = "Thank You ";
$output = $text x 3;
print "$output\n";

```

输出:

```
Thank You Thank You Thank You

```

* * *

# 初始化和声明字符串

在 Perl 中，要声明一个字符串，在变量名前使用 **my** 关键字。

可以使用以下语法初始化和声明字符串:

```

my $variableName = "";

```

在这个例子中，我们展示了如何初始化和声明一个字符串。我们通过以下方式将几个字符串打印在一起:

*   使用点(.)连接字符串。)运算符。
*   提供字符串作为单独的参数。
*   将字符串嵌入到更大的字符串中。

我们已经展示了打印输出的所有三种方法。

```

 use strict;
use warnings;
# Declaring and initializing a string.
my $msg1 = "Welcome at JavaTpoint.";
my $msg2 = "This is our Perl Tutorial.";
#printing using . operator.
print $msg1 . "" . $msg2\. "\n";
#print as separate arguments.
print $msg1, "",$msg2, "\n";
#embedd string in a bigger string.
print "$msg1$msg2\n";

```

输出:

```
Welcome at JavaTpoint. This is our Perl Tutorial.
Welcome at JavaTpoint. This is our Perl Tutorial.
Welcome at JavaTpoint. This is our Perl Tutorial.

```

* * *

# 字符串中字符的 Perl 格式

| 性格；角色；字母 | 描述 |
| \a | 铃 |
| \b | 给出退格 |
| \cX | 控制人物。x 是一个字符。 |
| \e | 转义下一个字符 |
| \E | 它结束了\u，\l 和\q 函数 |
| \f | 为字符串提供 formfeed |
| \l | 仅将下一个字母转换为小写字母。 |
| \L | 将所有字母转换成小写。 |
| \n | 从新行开始下一行 |
| \ 0nn | 创建八进制格式的数字 |
| \Q | 不符合模式 |
| \r | 回车 |
| \t | 给字符串一个制表符 |
| \u | 仅将下一个字母转换为小写字母。 |
| \U | 字母转换成大写。 |
| \xnn | 十六进制格式的数字被创建 |

* * *

# Perl 单引号与双引号字符串

字符串可以放在单引号(')或双引号(")内，但它们的行为没有什么不同。

```

my $user = 'Ana';
print 'Hello $user, welcome at our site.\n';
print "\n";
my $user = 'Ana';
my $day  = "today";
print "Hello $user, welcome at our site $day.\n";

```

输出:

```
Hello $user, welcome at our site.\n
Hello Ana, welcome at our site today.

```

在单引号中，所有字符都按原样解释。

双引号提供插值。意味着字符串中的其他变量将表示它们的值。转义字符将被替换为它们的值，如' \n '将显示一个新行。

* * *

## Perl 子字符串()示例

substr()函数用于截断字符串。我们需要提供一个偏移字符串。字符串将被截断，直到提供的偏移值。

用偏移量提及长度将打印偏移量值之后直到提及长度的字符串。

如果您提供一个带有偏移量和长度的新字符串，它将替换偏移量后的字符串，直到长度值。

```

use strict;
use warnings;
# Original string
my $originalstring = "Our site javaTpoint provides all type of tutorials";
print "$originalstring\n";
# Offset of 4
my $offset = substr($originalstring, 4);
print "$offset\n";
# Offset of 4, length 15
my $offsetlength = substr($originalstring, 4, 15);
print "$offsetlength\n";
# Replacing length with the new string
my $replacing = substr($originalstring, 4, 15, "one and only site");
print "$originalstring\n";

```

输出:

```
Our site javaTpoint provides all type of tutorials
site "javaTpoint" provides all type of tutorials
site javaTpoint
Our one and only site provides all type of tutorials

```

* * *

## Perl 字符串比较示例

Perl 字符串总是与 **eq** 而不是(==)进行比较。它检查两个字符串是否相等。

```

my $string1 = "Ana";
my $string2 = "Ana";
if($string1 eq $string2) {
    print "Match!\n";
}
my $string3 = "Ana";
my $string4 = "Christian";
if($string3 eq $string4) {
    print "Match\n!";
}else{
    print "Missmatch!\n";
}

```

输出:

```
Match!
Missmatch!

```

* * *

## 确定字符串长度，长度()

Perl 字符串长度可以通过 length()函数来确定。

```

my $msg = "Our site javaTpoint provides all type of tutorials";
print "String Length : ", length($msg), "\n";

```

输出:

```
String Length : 50

```

* * *

## 用另一个字符串替换一个字符串

一个字符串可以用另一个字符串以两种方式替换。

在第一个例子中，我们用**狮子**代替了**老虎**，后者在字符串中出现一次 **s///。**

第二个，我们用**花**取代了**玫瑰**，用 **s///g.** 取代了全球

```

my $var1 = "Tigers are big and frightening.";
$var1 =~ s/Tigers/Lions/;
print "$var1\n";
my $var2 = "Red roses are very popular. Yellow roses are less seen.";
$var2 =~ s/roses/flowers/g;
print "$var2\n";

```

输出:

```
Lions are big and frightening.
Red flowers are very popular. Yellow flowers are less seen.

```

* * *

## Perl 在字符串中找到匹配项，=~

Perl 提供了一个匹配运算符(=~)来从字符串中查找子字符串。

```

my $var = "Tigers are big and frightening.";
if($var =~ /frightening/)
{
	print "Matched\n";
}else{
	print "Match not Found\n";
}
if($var =~ /biggest/)
{
	print "Matched\n";
}else{
	print "Match not Found\n";
}

```

输出:

```
Matched
Match not Found

```

* * *

## 串联两个字符串(。=)

可以使用()将两个字符串连接在一起。=)运算符。

```

my $str1 = "Where there is a will,";
my $str2 = "there is a way.\n";
my $joining = '';
$joining = $str1 . ' ';
$joining .= $str2;
print $joining;

```

输出:

```
Where there is a will, there is a way.

```