# Perl 模块和名称空间

> 原文：<https://www.javatpoint.com/perl-modules-and-namespaces>

模块是一个容器，它包含一组可以在程序中使用的变量和子程序。每个模块都有一个公共接口，一组函数和变量。

要在程序中使用模块，可以使用**要求**或**使用**语句，尽管它们的语义略有不同。

“require”语句在运行时加载模块，以避免模块的冗余加载。“use”语句类似于 require，增加了两个属性:编译时加载和自动导入。

名称空间是一组不同标识符(变量、函数)的容器。命名空间应该像**名称::变量**。

每段 Perl 代码都在一个名称空间中。

在下面的代码中，

```

use strict;
use warnings;
my $x = "Hello";
$main::x = "Bye";
print "$main::x\n";  # Bye
print "$x\n";        # Hello

```

这里有两个不同的变量定义为 **x** 。 **$main::x** 是一个包变量， **$x** 是一个词法变量。大多数情况下，我们使用用 my 关键字声明的词法变量，并使用名称空间来分隔函数。

在上面的代码中，如果我们不使用**使用严格的**，我们将得到一条警告消息如下

```

Name 	"main::x" used only once: possible typo at line..

```

主**主**是当前脚本和当前变量的名称空间。我们还没有写任何东西，但我们已经在“主”名称空间。

通过添加“使用严格”，现在我们得到了以下错误，

```

Global symbol "$x" requires explicit package name

```

在这个错误中，我们得到了一个新词“package”。它表明我们在声明变量之前忘记使用' my '关键字，但实际上它表明我们应该提供变量所在的包的名称。

* * *

## 使用包关键字切换命名空间

请看下面的代码，

```

use strict;
use warnings;
use 5.010;
sub hii {
    return "main";
}
package two;
sub hii {
    return "two";
} 
say main::hii();   # main
say two::hii();    # two
say hii();         # two
package main;
say main::hii();   # main
say two::hii();    # two
say hii();         # main

```

这里我们使用 **package** 关键字从‘main’命名空间切换到‘two’命名空间。

用名称空间调用 **hii()** 会返回各自的名称空间。像，**说 main::hii()；**返回‘main’和**说出两个::hii()；**返回‘二’。

调用没有名称空间前缀的 **hii()** ，返回当前名称空间本地的函数。第一次，我们在“二”命名空间。因此它返回“二”。第二次，我们使用**包 main 切换了名称空间。**因此它返回“主”。