# Perl 哈希

> 原文：<https://www.javatpoint.com/perl-hashes>

哈希是 perl 语言中最重要和最有影响力的部分。哈希是一组键值对。键是唯一的字符串，值是标量值。

散列是用 my 关键字声明的。变量名以(%)符号开头。

哈希就像数组，但是它们之间有两个区别。第一个数组是有序的，但是散列是无序的。其次，散列元素使用其值来访问，而数组元素使用其索引值来访问。

哈希中不允许重复键，这使得键值在哈希中是唯一的。每个键都有其唯一的值。

**语法:**

```

my %hashName = (
	"key" => "value";
)

```

* * *

## Perl 哈希访问

要访问散列的单个元素，在变量名前使用($)符号。然后在{}个大括号内写入 key 元素。

```

my %capitals = (
    "India"  => "New Delhi",
    "South Korea" => "Seoul",
    "USA"  => "Washington, D.C.",
    "Australia"  => "Canberra"
);
print"$capitals{'India'}\n";
print"$capitals{'South Korea'}\n";
print"$capitals{'USA'}\n";
print"$capitals{'Australia'}\n";

```

输出:

```
New Delhi
Seoul
Washington, D.C.
Canberra

```

* * *

## Perl 哈希索引

散列使用$key 和$value 变量进行索引。所有哈希值都将使用 while 循环打印。当 while 循环运行时，将打印这些变量的值。

```

my %capitals = (
    "India"  => "New Delhi",
    "South Korea" => "Seoul",
    "USA"  => "Washington, D.C.",
    "Australia"  => "Canberra"
);
# LOOP THROUGH IT
while (($key, $value) = each(%capitals)){
     print $key.", ".$value."\n";
}

```

输出:

```
Australia, Canberra
India, New Delhi
USA, Washington, D.C.
South Korea, Seoul

```

* * *

## Perl 按键排序哈希

您可以使用散列的键元素或值元素对散列进行排序。Perl 为此提供了一个 sort()函数。在本例中，我们将根据散列的关键元素对其进行排序。

```

my %capitals = (
    "India"  => "New Delhi",
    "South Korea" => "Seoul",
    "USA"  => "Washington, D.C.",
    "Australia"  => "Canberra"
);
# Foreach loop
foreach $key (sort keys %capitals) {
     print "$key: $capitals{$key}\n";
}

```

输出:

```
Australia: Canberra
India: New Delhi
South Korea: Seoul
USA: Washington: D.C.

```

看看输出，所有的关键元素都是按字母顺序排序的。

* * *

## Perl 根据哈希值对哈希值进行排序

这里我们将根据散列的值元素对散列进行排序。

```

my %capitals = (
    "India"  => "New Delhi",
    "South Korea" => "Seoul",
    "USA"  => "Washington, D.C.",
    "UK"  => "London"
);
# Foreach loop
foreach $value (sort {$capitals{$a} cmp $capitals{$b} }
           keys %capitals)
{
     print "$value $capitals{$value}\n";
}

```

输出:

```
UK London
India New Delhi
South Korea Seoul
USA Washington D.C.

```

看看输出，所有的值元素都是按字母顺序排序的。

* * *

## Perl 哈希键的存在

从不存在的哈希中访问键值对将返回错误或警告。为了防止这种情况，您可以使用 **exists()** 函数检查散列中是否存在密钥。如果密钥存在，则返回 true。

```

my %capitals = (
    "India"  => "New Delhi",
    "South Korea" => "Seoul",
    "USA"  => "Washington, D.C.",
    "Australia"  => "Canberra"
);
if (exists($capitals{'India'}))
{
  print "found the key\n";
}

```

输出:

```
found the key

```

上面的输出显示“茵迪丝”键存在于“大写”哈希中。

* * *

## Perl 哈希切片

如果您只想从哈希中获得一些值，可以提取它们并显示为值列表。

为此，您必须将它们存储在带@前缀的数组变量中，因为它们将返回一个值列表，然后打印它们。

```

my %capitals = (
    "India"  => "New Delhi",
    "South Korea" => "Seoul",
    "USA"  => "Washington, D.C.",
    "Australia"  => "Canberra"
);
@array = @capitals{India, USA, Australia};
print "@array\n";

```

输出:

```
New Delhi Washington, D.C. Canberra

```

* * *

## 创建空散列

空哈希的大小始终为 0。

在这个例子中，首先我们创建了一个大小为 3 的散列。然后我们创建了一个大小为 0 的空散列。

```

my %first = ('john'=>9853147320, 'jose'=>7823654028, 'janie',=>'8850279610');  
print 'hash size: ', scalar keys %first;  
print "\n";  
#creating emptyempty hash  
my %empty=();  
print 'hash size: ', scalar keys %empty;

```

输出:

```
hash size: 3
hash size: 0

```

* * *

## 添加散列元素

通过在散列变量中将新的键值对声明为单个元素，可以将它们添加到散列中。

在这里，我们添加了两个键值对，[德国-柏林]和[英国-伦敦]。

```

my %capitals = (
    "India"  => "New Delhi",
    "South Korea" => "Seoul",
    "USA"  => "Washington, D.C.",
    "Australia"  => "Canberra"
);
while (($key, $value) = each(%capitals)){
     print $key.", ".$value."\n";
}
#adding new element
$capitals{Germany} = Berlin;
$capitals{UK} = London;
# Printing new hash
print "\n";
while (($key, $value) = each(%capitals)){
     print $key.", ".$value."\n";
}

```

输出:

```
UK, London
Australia, Canberra
Germany, Berlin
India, New Delhi
USA, Washington D.C.
South Korea, Seoul

```

* * *

## 删除哈希元素

要删除散列元素，请使用 **delete()** 函数。

在这里，我们删除了上一个示例中添加的键-值对。

```

my %capitals = (
    "India"  => "New Delhi",
    "South Korea" => "Seoul",
    "USA"  => "Washington, D.C.",
    "Australia"  => "Canberra"
    "Germany "  => " Berlin"
    " UK "  => "London"
);
while (($key, $value) = each(%apitals)){
     print $key.", ".$value."\n";
}
#removing element
delete($capitals{Germany});
delete($capitals{UK});
# Printing new hash
print "\n";
while (($key, $value) = each(%capitals)){
     print $key.", ".$value."\n";
}

```

输出:

```
Australia, Canberra
India, New Delhi
USA, Washington D.C.
South Korea, Seoul

```

* * *

## Perl 删除与不定义哈希元素

**删除:**删除时，键值对会从哈希中删除。

**语法:**

```

delete($hash{$key});

```

**未定义:**在未定义中，该值将未定义，但密钥将保留在哈希中。

**语法:**

```

Undef $hash{$key};

```

在下面的示例中，我们创建了一个哈希“rank”。我们将一个接一个地取消定义并移除散列中的所有键值。不定义密钥时，将只显示其值，删除密钥时，它将与其值一起从哈希中完全删除。

像这样，最后所有的散列元素都会被删除。

```

# creating hash
$rank{'John'} = '5 ';
$rank{'Ana'} = '7 ';
$rank{'Jiyaa'} = '3 ';
$rank{'Jassi'} = '1 ';
# printing all elements in the hash
print "before:\n";
print %rank;
print"\n";
# undefining John in the hash
print "\nundefine John\n";
undef$rank{'John'};
print %rank;
print"\n";
# deleting the 'John' key the in hash element
print "\nremove John\n";
delete($rank{'John'});
print %rank;
print"\n";
# undefining Ana in the hash
print "\nundefine Ana\n";
undef$rank{'Ana'};
print %rank;
print"\n";
# deleting the 'Ana' key the in hash element
print "\nremove Ana\n";
delete($rank{'Ana'});
print %rank;
print"\n";
# undefining Jiyaa in the hash
print "\nundefine Jiyaa\n";
undef$rank{'Jiyaa'};
print %rank;
print"\n";
# deleting the 'Jiyaa' key the in hash element
print "\nremove Jiyaa\n";
delete($rank{'Jiyaa'});
print %rank;
print"\n";
# undefining Jassi in the hash
print "\nundefine Jassi\n";
undef$rank{'Jassi'};
print %rank;
print"\n";
# deleting the 'Jassi' key the in hash element
print "\nremove Jassi\n";
delete($rank{'Jassi'});
print %rank;

```

输出:

```
before:
John5 Jassi1 Jiyaa3 Ana7
undefine John
JohnJassi1 Jiyaa3 Ana7
remove John
Jassi1 Jiyaa3 Ana7
undefine Ana
Jassi1 Jiyaa3 Ana
remove Ana
Jassi1 Jiyaa3
undefine Jiyaa
Jassi1 Jiyaa
remove Jiyaa
Jassi1
undefine Jassi 
Jassi
remove Jassi

```