# Perl 正则表达式

> 原文：<https://www.javatpoint.com/perl-regular-expression>

正则表达式是定义特定模式的字符串。perl 正则表达式语法与 awk、grep 和 sed 非常相似。

perl 中有三个正则表达式运算符:

*   匹配正则表达式运算符
*   替换正则表达式运算符
*   音译正则表达式运算符

* * *

## Perl 匹配运算符

Perl 匹配运算符有各种修饰符。它主要用于将字符串或语句与正则表达式进行匹配。

* * *

## 匹配运算符修饰符

| 经营者 | 描述 |
| 厘克 | 即使全局匹配失败，也继续搜索 |
| g | 全局搜索所有匹配项 |
| 我 | 搜索不区分大小写的匹配项 |
| m | 如果字符串有新的行字符，则$和^将匹配新的行边界，而不是字符串边界 |
| o | 只允许表达式求值一次 |
| s | 使用。匹配新的行字符 |
| x | 在表达式中使用空格 |

* * *

## Perl 匹配运算符=~

匹配运算符=~用于匹配给定字符串中的单词。它区分大小写，意味着如果字符串有一个小写字母，而您正在搜索一个大写字母，那么它将不匹配。

```
$line = "This is javaTpoint.";
if ($line =~ /java/){
   print "Matching\n";
}else{
   print "Not Matching\n";
}
if ($line =~ /Java/){
   print "Matching\n";
}else{
   print "Not Matching\n";
}

```

输出:

```
Matching
Not Matching

```

* * *

## Perl 匹配运算符！~

它与前一个相反(=~)。如果字母匹配，则输出不匹配，反之亦然。

```
$ line = "This is javaTpoint.";
if ($line!~ /java/){
   print "Matching\n";
}else{
   print "Not Matching\n";
}
if ($line!~ /Java/){
   print "Matching\n";
}else{
   print "Not Matching\n";
}

```

输出:

```
Not Matching
Matching

```

* * *

## 带$_ 的 Perl 匹配运算符

您也可以将它与一个特殊的默认变量$_。

```
$_ = "This is javaTpoint.";
    if (/java/) {
        print "Matching\n";
    }
    else {
        print "Not Matching\n";
    }
if (/Java/) {
        print "Matching\n";
    }
    else {
        print "Not Matching\n";
    }

```

输出:

```
Matching
Not Matching

```

* * *

## 带 m 的 Perl 匹配运算符

匹配运算符 m 也用于匹配给定字符串中的单词。

```
$ line = "This is javaTpoint.";
if ($line=~ m[java]){
   print "Matching\n";
}else{
   print "Not Matching\n";
}
if ($line=~ m{Java}){
   print "Matching\n";
}else{
   print "Not Matching\n";
}

```

输出:

```
Matching
Not Matching

```

* * *

## 带有$1，$2 的 Perl 匹配运算符...

$1，$2 将根据指定的括号打印单词。

```
my $word = "CuNaHg";
    $word =~ /(((Cu)(Na))(Hg))/;
    print "1: $1 2: $2 3: $3 4: $4 5: $5 6: $6\n";

```

输出:

```
1: CuNaHg 2: CuNa 3: Cu 4: Na 5: Hg 6: 

```

* * *

## Perl 匹配运算符？

它打印给定字符串中括号内的匹配字符。

```
my $word = "CuNaHg";
    $word =~ /(?:(Cu)NaHg)/;
    print "$1\n"; # prints "Cu"
     $word =~ /(?:Cu(Na)Hg)/;
    print "$1\n"; # prints "Na"
     $word =~ /(?:CuNa(Hg))/;
    print "$1\n"; # prints "Hg?

```

输出:

```
Cu
Na
Hg 

```

* * *

## Perl 替换运算符

替换运算符只是匹配运算符的扩展。它允许用一些新的文本替换匹配的文本。

它的基本语法是:

```
s/oldPattern/newPattern /;

```

* * *

## 带有 s///的 Perl 替换运算符

在这里，我们将第一部分中的液体替换为固体。

在第二部分中，用 s///g 将“液体”替换为“固体”。

```
$line = "liquid will remain liquid until it is evaporated";
$line =~ s/liquid/solid/;
print "$line\n";
print"\n";
$line = "liquid will remain liquid until it is solidified";
$line =~ s/liquid/solid/g;
print "$line\n";

```

输出:

```
solid will remain liquid until it is evaporated
solid will remain solid until it is evaporated

```

* * *

## Perl 翻译运算符

翻译运算符类似于替换运算符。但是翻译不使用正则表达式来搜索替换值。

它的基本语法是:

```
tr/oldLetter/newLetter /;

```

* * *

## 替换一个字母的 Perl 翻译运算符

在这里，所有的“l”字母将被翻译操作符替换为“z”字母。

```
$line = "liquid will remain liquid until it is evaporated";
$line =~ tr/l/z/;
print "$line\n";

```

输出:

```
ziquid wizz remain ziquid untiz it is evaporated

```

* * *

## 替换多个字母的 Perl 翻译运算符

在这里，所有的“l”和“I”字母将被翻译操作符替换为“z”和“x”字母。

```
$line = "liquid will remain liquid until it is evaporated";
$line =~ tr/li/zx/;
print "$line\n";

```

输出:

```
zxquxd wxzz remaxn zxquxd untxz xt xs evaporated

```