# Perl 拆分函数

> 原文：<https://www.javatpoint.com/perl-split-function>

函数的作用是:将一个字符串分割成一个数组。字符串根据模式指定的分隔符进行拆分。默认情况下，空格被认为是分隔符。

拆分语法是:

```

Split /pattern/, variableName

```

* * *

## Perl 拆分示例

在本例中，split 返回一个字符串列表。分隔符是(-)。这意味着字符串在(-)处被拆分。

```

my $str = "Cu-K-Na-Hg-Pb-Li";  
my @break = split /-/, $str;  
print "@break\n";

```

输出:

```

Cu K Na Hg Pb Li

```

* * *

## 限制零件数量

我们可以限制一个字符串要拆分的部分的数量。

在本例中，字符串分为 3 部分。

```

my $str = "Cu-K-Na-Hg-Pb-Li";  
my @break = split(/-/, $str, 3);  
print "@break\n";

```

输出:

Cu K Na-Hg-Pb-Li

* * *

## 多个字符上的 Perl 拆分

我们可以在多个分隔符处拆分一个字符。在下面的示例中，我们在(=)和(，)处拆分了字符串。

```

my $str = 'Vishal=18Sept,Anu=11May,Juhi=5Jul';  
my @words = split /[=,]/, $str;  
print "@words\n";  

```

输出:

```
Vishal 18Sept Anu 11May Juhi 5Jul

```

由于它们是键值对，我们可以将结果分配到一个散列中，而不是数组中。

```

use Data::Dumper qw(Dumper);
my $str = 'Vishal=18th Sept,Anu=11th May,Juhi=5th Jul';
my %words = split /[=,]/, $str;
print Dumper \%words;

```

输出:

```
$VAR1 = (
		'Anu', => '11th May',
		'Vishal', => '18th Sept',
		'Juhi', => '5th Jul', 
);

```

* * *

## 空字符串上的 Perl 拆分

对空字符串进行拆分意味着该字符串将在找到空字符串的每个地方进行拆分。每两个字符之间有一个空字符串。这意味着它将返回分割成单个字符的原始字符串。

```

my $str = "JAVATPOINT";  
my @break = split //, $str;  
print "@break\n";

```

输出:

```
J A V A P O I N T

```

* * *

## Perl 连接函数

Perl 连接字符，使用分隔符模式将元素连接成单个字符串来分隔每个元素。它与分裂相反。

连接语法是:

```

join 'pattern', variableName

```

* * *

## Perl 连接示例

在下面的例子中，我们以三种不同的方式加入。

首先，我们在数组的每个元素之间连接(:)。

其次，我们将(-元音)与第一个的输出连接起来。

第三，我们在原始数组中增加了两个字符。

```

my @vowels = ('A', 'E', 'I');
my $str = join ':', @vowels;
print "$str\n";                    
my $data = join "-", $str, "vowels";
print "$data\n";                     
$str = join '', @vowels, 'OU';
print "$str\n";                  

```

输出:

```
A:E:I
A:E:I -vowels
AEIOU

```