# Perl 文件处理

> 原文：<https://www.javatpoint.com/perl-file-handling>

文件处理是任何编程语言中最重要的部分。文件句柄是一个与文件名相关联的内部 Perl 结构。

Perl 文件处理很重要，因为它有助于访问文本文件、日志文件或配置文件等文件。

Perl 文件句柄能够创建、读取、打开和关闭文件。

* * *

## 创建文件

我们正在借助 open()函数创建一个文件， **file1.txt** 。

$fh(文件句柄)是一个标量变量，我们可以在 open()函数内部或之前定义它。这里我们已经在函数内部定义了它。“>”符号表示我们正在打开该文件进行写入。**$文件名**表示路径或文件位置。

文件打开后，在打印语句中使用$fh。print()函数将打印文件中的上述文本。

现在我们要关闭$fh。在 perl 中不需要关闭文件。当变量超出范围时，您的文件将自动关闭。

```

my $filename = 'file1.txt';
open(my $fh, '>', $filename) or die "Could not open file '$filename' $!";
print $fh "Hello!! We have created this file as an example\n";
close $fh;
print "done\n";

```

输出:

```
done.

```

A file file1.txt will be created in our system.

* * *

## 打开文件

我们可以通过以下方式打开文件:

**( <)语法**

```

open FILE, "<", "fileName.txt" or die $!

```

**( >)语法**

如果文件不存在，则>号用于打开和创建文件。它以写模式打开文件。

```

open FILE, ">", "fileName.txt" or die $!

```

The "<" sign will empty the file before opening it. It will clear all your data of that file. To prevent this use (+) sign before ">" or "<" characters.

**(+ > + <)语法**

```

open FILE, "+<", "fileName.txt" or die $!
open FILE, "+>", "fileName.txt" or die $!

```

**( > >)语法**

>>符号用于读取和追加文件内容。它将文件指针放在文件的末尾，您可以在那里添加信息。此外，要读取该文件，您需要在“> >”符号前放置(+)符号。

```

open FILE, "<", "fileName.txt" or die $!

```

* * *

## Perl 读取文件

您可以一次读取一个完整的文件，也可以一次读取一行。我们将为两者展示一个例子。打开文件进行读取类似于打开文件进行写入。只有一个区别，即“>”用于写入，而“

我们创建了一个文件 **file1.txt** ，内容如下:

```

This is the First Line.
This is the Second Line.
This is the Third Line.
This is the Fourth Line.

```

* * *

## 一次读取一行

将显示 file1.txt 的第一行。$row 的内容将被打印为“完成”，以表明我们已经到达了程序的末尾。

```

use strict;
use warnings;
my $filename = 'file1.txt';
open(my $fh, '<:encoding(UTF-8)', $filename)
  or die "Could not open file '$filename' $!";
my $row = <$fh>;
print "$row\n";
print "done\n";

```

输出:

```
This is the First Line.
Done.

```

* * *

## 一次读取多行

现在我们知道如何从文件中读取单行。要读取多行，请在 while 循环中放入$row。

每次，当 while 循环达到其条件时，它将执行 **my $row =** 。它将读取文件的下一行。在最后一行，$fh 将返回 undef，这是假的，循环将终止。

```

use strict;
use warnings;
my $filename = 'file1.txt';
open(my $fh, '<:encoding(UTF-8)', $filename)
  or die "Could not open file '$filename' $!";
while (my $row = <$fh>) {
  chomp $row;
  print "$row\n";
}
print "done\n";

```

输出:

```
This is the First Line.
This is the Second Line.
This is the Third Line.
This is the Fourth Line.
Done.

```

* * *

## Perl 写文件

通过文件写入，我们将在 file1.txt 中追加行。如前所述，将在文件的最后添加新行。

```

open (FILE, ">> file1.txt") || die "problem opening $file1.txt\n";
print FILE "This line is added in the file1.txt\n";
# FILE array of lines is written here
print FILE @lines1;
# Another FILE array of lines is written here
print FILE "A complete new file is created";
# write a second array of lines to the file
print FILE @lines2;

```

输出:

```
This line is added in the file1.txt
A complete new file is created

```

* * *

## 关闭文件

Perl close file 用于使用 close()函数关闭文件句柄。在 perl 中文件关闭不是强制性的。一旦变量超出范围，Perl 就会自动关闭文件。

```

open FILE1, "file1.txt" or die $!;
...
close FILE1;

```

* * *

## Perl 文件句柄操作符，<filehandl></filehandl>

文件句柄操作符是从文件中读取信息的主要方法。它用于获取用户的输入。在标量上下文中，它从文件句柄返回一行，在行上下文中，它从文件句柄返回一列行。

```

print "What is your age?\n";
$age = <STDIN>;
if($age >= 18)
{
   print "You are eligible to vote.\n";
} else {
   print "You are not eligible to vote.\n";
    }

```

输出:

```
1\. What is your age?
      18
      You are eligible to vote

```

```
2.	What is your age?
      16
       You are not eligible to vote.

```

* * *

## Perl 文件句柄打印()函数

print()函数打印回通过 filehandle 运算符给出的信息。

```

print "Welcome to my site\n";

```

输出:

```

Welcome to my site	

```

* * *

## 复制文件

我们可以将一个文件的内容原样复制到另一个文件中。首先打开文件 1，然后打开文件 2。通过 while 循环读取文件 1 的行，将文件 1 的内容复制到文件 2。

```

# Opening file1 to read
open(File1Data, "<file1.txt");
# Opening new file to copy content of file1
open(File2Data, ">file2.txt");
# Copying data from file1 to file2.
while(<File1Data>)
{
   print File2Data $_;
}
close( File1Data );
close( File2Data );

```

输出:

```

done

```

将在 file1.pl 所在的位置创建一个新文件 file2.pl。

* * *

## Perl 文件测试运算符

有不同的测试操作符来检查文件的不同信息。一些测试操作员如下:

| 测试操作员 | 描述 |
| ［构成动植物的古名或拉丁化的现代名］ | 返回程序启动后文件的总访问时间。 |
| -b | 检查文件是否是块设备。 |
| -乙 | 检查它是否是二进制文件。 |
| -c | 检查文件是否是字符设备。 |
| -丙 | 返回程序启动后文件的信息节点更改时间。 |
| -d | 检查文件是否是目录。 |
| -e | 检查文件是否存在。 |
| -f | 检查文件类型，是常规、符号链接还是其他类型的文件。 |
| g | 检查文件是否设置了 setgid 位。 |
| k | 检查文件是否设置了粘性位。 |
| -我 | 检查文件是否是符号链接。在 dos 下，它总是返回 false。 |
| -男 | 返回程序启动后的文件修改时间(以天为单位)。 |
| 表示“具有…性质的” | 检查文件是否属于有效的 uid，在 dos 下，它总是返回 true。 |
| 表示“具有…性质的” | 检查文件是否属于真实的 uid，在 dos 下，它总是返回 true。 |
| -p | 检查文件是否是命名管道。 |
| -r | 检查文件是否可读。 |
| -右 | 检查文件是否可以被真实的 uid 读取。在 dos 中，它与-r 相同。 |
| 构成名词复数 | 以字节为单位返回文件大小。 |
| 构成名词复数 | 检查文件是否是套接字。 |
| 相当于-ED | 检查文件是否在 tty(终端)上打开 |
| 相当于-ED | 检查文件是否为文本文件。 |
| -你 | 检查文件是否设置了 setuid 位。 |
| -w | 检查文件是否可写。 |
| -W | 检查文件是否可由真实 uid/gid 写入。 |
| ［加在以-u 结尾的法语词源的名词之后构成复数］ | 检查文件是否可以执行。 |
| ［加在以-u 结尾的法语词源的名词之后构成复数］ | 检查文件是否可以由真实 uid/gid 执行。 |
| z | 检查文件大小是否为零。 |

* * *

## 使用文件测试操作符的 Perl

为了测试 Perl 中的不同特性，有一系列测试操作符。在给定的例子中，我们测试了 file1.txt 的不同特性。

```

my $a = "/Users/javatpoint/Desktop/file1.txt";
my (@description, $size);
if (-e $a)
{
   push @description, 'binary' if (-B _);
   push @description, 'a socket' if (-S _);
   push @description, 'a text file' if (-T _);
   push @description, 'a block special file' if (-b _);
   push @description, 'a character special file' if (-c _);
   push @description, 'a directory' if (-d _);
   push @description, 'executable' if (-x _);
   push @description, (($size = -s _)) ? "$size bytes" : 'empty';
   print "file1.txt is ", join(', ',@description),"\n";
}

```

输出:

```

file1.txt is a text file, 67 bytes

```