# Perl 错误处理

> 原文：<https://www.javatpoint.com/perl-error-handling>

在程序执行时，错误也会随着程序一起运行。如果这些错误得不到正确处理，程序可能无法顺利运行。

错误处理让我们通过采取适当的措施来处理这些错误，并平稳地运行程序。错误处理可以处理各种类型的错误。

您需要捕捉错误，并通过纠正错误来平稳运行程序。Perl 提供了许多这样做的方法，如下所示。

* * *

## 没有死函数的 Perl 脚本

die()函数会给你一个正确的错误信息。遇到错误时，它会立即终止脚本。如果您不在脚本中使用 die()函数，您的脚本将继续运行。

```

use strict;
use warnings;
open(my $fh, '>', 'sssit/javatpoint/file1.txt');
print $fh "Example to show Error Handling\n";
close $fh;
print "done\n";

```

输出:

```
Print() on closed filehandle $fh at script.pl 
done

```

看看上面的输出，当遇到打印错误“完成”时，脚本会继续运行。

* * *

## 要么打开要么死去

open()函数只会像往常一样打开您的文件。die()函数抛出一个异常并退出脚本。

在'打开或死亡'功能中，在左侧我们有 open()功能。在右边我们有 die()函数。

如果 open()函数返回 true，那么脚本进入下一行，die()函数不执行。

如果 open()函数返回 false，则脚本继续执行 die()函数，该函数抛出异常并退出脚本。

这里，在这个例子中，我们给出了错误的文件路径，由于这个错误，die()函数将执行并退出脚本。

```

use strict;
use warnings;
open(my $fh, '>', 'sssit/javatpoint/file1.txt') or die;
print $fh "Example to show Error Handling\n";
close $fh;
print "done\n";

```

输出:

```
Died at script.pl

```

在输出中，当我们使用 die()函数时，脚本会在遇到错误时退出。因此，不会打印“完成”。

* * *

## 在 Die 中添加解释

如果想添加一些关于错误的解释，可以在 die()函数中添加。如果您的脚本死亡，这个解释将打印为错误消息。

```

use strict;
use warnings;
open(my $fh, '>', 'sssit/javatpoint/report.txt')
  or die "Could not open file due to 'sssit/javatpoint/report.txt'";
close $fh;
print "done\n";

```

输出:

```
Could not open file due to 'sssit/javatpoint/report.txt'at script.pl
看看上面的输出，我们得到了关于脚本中错误的解释。 

```

* * *

## 使用$！

$！变量是 Perl 语言中的内置变量。通过在 die()函数中添加解释，我们知道了错误消息，但仍然不知道背后的原因。要知道错误的确切原因，请使用 **$！**变量。它将打印操作系统告知的关于该文件的消息。

```

use strict;
use warnings;
my $filename = 'sssit/javatpoint/file1.txt';
open(my $fh, '>', $filename) or die "Could not open file '$filename' $!"; 
close $fh;
print "done\n";

```

输出:

```
Could not open file 'sssit/javatpoint/file1.txt' No such file or directory

```

## Perl 警告功能

warn 函数给出警告消息，但不退出脚本。脚本将继续运行。因此，当您只想打印警告消息并继续执行程序的其余部分时，它非常有用。

```

use strict;  
use warnings;  
my $filename = 'sssit/javatpoint/file1.txt';  
open(my $fh, '>', $filename) or warn "Can't open file";   
print "done\n";

```

输出:

```
Can't open file at hw.pl at line 4.
done

```

看上面的输出，我们已经打印了‘done ’,以显示即使在打印警告消息后执行仍在继续。

## 使用坦白函数的 Perl 错误报告

错误处理的现代方法是使用鲤鱼标准库。Carp 库中使用了 reclave()函数。我们已经通过了$！作为它的论据。

```

use strict;  
use warnings;
use Carp;
my $filename = 'sssit/javatpoint/file1.txt';  
open(my $fh, '>', $filename) or confess($!);   
print "done\n";

```

输出:

```
No such file or directory.
done

```

## Perl 评估函数

eval()函数是 Perl 中的内置函数，用于检测正常的致命错误。eval()函数提供了一个代码块，而不是传入字符串。

如果有语法错误，eval 块将失败。但是如果出现运行时错误，脚本将继续运行。

在下面的程序中，没有语法错误。

use strict; use warnings; my $result = eval { my $x = 10; my $y = 0; my $result2 = $x/$y; print "$result2"; }; print "Script is still running!\n"; unless($result) { print [[email protected]](/cdn-cgi/l/email-protection); }

输出:

```
Script is still running!
Illegal division by zero

```

看上面的输出，脚本继续运行，因为它们没有语法错误。

## 死()和坦白()的区别

当脚本由十行组成时，使用 die()函数。die()函数也可以不用$！。

reclave()函数在鲤鱼包中使用。对于较大的脚本，最好使用坦白功能。