# Perl DBI

> 原文：<https://www.javatpoint.com/perl-dbi>

在本教程中，我们将在 Perl 脚本中看到数据库访问。从 Perl 5 开始，数据库应用程序使用 DBI 模块来访问数据库。

使用 DBI 模块在一个 Perl 脚本中访问数据库。 **DBI** (数据库独立接口)，提供了 Perl 代码和数据库之间的抽象层。

DBI 是一个数据库访问模块，它为一致的数据库接口提供变量和一组方法，独立于正在使用的实际数据库。

* * *

## 佩尔·DBI 建筑

![Perl Database access 1](img/bd5c4244e9c5131b7356a740f703eaf6.png)

DBI 独立于数据库，可以和 Oracle、MySQL 等一起使用。DBI 通过 API(应用程序编程接口)获取所有的 SQL 命令，并将它们转发给适当的驱动程序来执行。

* * *

## Perl DBI 连接

我们正在使用 MySQL 数据库。启动你的 MySQL 服务器。现在完成以下步骤:

*   创建数据库。我们的数据库名为“佩尔”。
*   在这个数据库中创建一个表。我们创建了一个“用户”表，其中包含“姓名”、“课程”和“费用”字段。
*   Perl 模块 DBI 应该安装正确。

成功创建数据库后，使用以下脚本将此数据库与 Perl 文件连接。

```

#!/usr/bin/perl
use strict;
use warnings;
use DBI;
my $driver = "mysql";
my $database = "perll";
my $dsn      = "dbi:$driver:database=$database";
my $user     = "root";
my $password = "";
my $dbh = DBI->connect($dsn, $user, $password, {
   PrintError       => 0,
   RaiseError       => 1,
   AutoCommit       => 1,
   FetchHashKeyName => 'NAME_lc',
});
$dbh->disconnect;

```

看上面的脚本，

**dsn** - >数据库来源名称

**dbh** - >数据库句柄对象

dsn 包含正在加载的数据库。用户是“root ”,我们没有为数据库设置任何密码。

dbh 存储数据库句柄对象调用返回。

Database disconnect 命令是可选的，当$dbh 超出范围时会自动调用。

* * *

## 将 Perl 插入数据库

通过 INSERT 操作，我们将记录传递到我们的数据库表“用户”中。以下脚本允许在数据库中插入一条记录。您可以使用相同的脚本插入多个记录。

请遵循以下步骤:

*   使用 API **prepare()** 函数配合 SQL insert 语句。
*   使用 API **执行()**功能从数据库中选择所有结果。
*   使用 API **finish()** 函数关闭代码。

```

my $sth=$dbh->prepare("insert into users(name, course, fee) values('john', 'PHP', '9000')"); 
$sth->execute();
$sth->finish();

```

* * *

## 插入绑定值

当需要的值将在运行时获取时，使用绑定值。为了插入数据，我们调用 **$dbh- >做**方法。我们通过了(？)作为实际数据的占位符。接下来是**undf**，后面是包含数据的值，这些数据将替换占位符。

```

my $name = 'nisha';
my $course = 'java',
my $fee = '10000';
$dbh->do('INSERT INTO users (name, course, fee) VALUES (?, ?, ?)',
  undef,
  $name, $course, $fee);

```

输出:

```
Name = John, Course = PHP, Fee = 9000 
Name = nisha, Course = Java, Fee = 10000

```

* * *

## Perl 读取数据库

READ 记录用于从数据库中获取信息。一旦我们在数据库中插入了一些记录，我们就可以使用 READ 查询获取这些记录。

请遵循以下步骤:

*   使用 API **准备()**函数配合 SQL SELECT 语句。
*   使用 API **执行()**功能从数据库中选择所有结果。
*   使用 API **fetchrow_array()** 函数，逐个获取并打印所有结果。
*   使用 API **finish()** 函数关闭代码。

```

# Fetching records from database
my $sth = $dbh->prepare("SELECT * FROM users");
$sth->execute() or die $DBI::errstr;
while (my @row = $sth->fetchrow_array()) {
   my ($name, $course, $fee) = @row;
   print "Name = $name, Course = $course, Fee = $fee\n";
}
$sth->finish();

```

#### 注意:我们在表中插入了更多的值来执行操作。

输出:

```
Name = John, Course = PHP, Fee = 9000 
Name = nisha, Course = Java, Fee = 10000
Name = Jia, Course = C++, Fee = 8000
Name = Anuj, Course = Java, Fee = 5000
Name = Vishal, Course = PHP, Fee = 8000
Name = Rash, Course = Hadoop, Fee = 4000

```

* * *

## 更新数据库

在 UPDATE 操作的帮助下，您可以编辑数据库表中的信息。

在这里，我们将把“课程”列更新为 PHP，适用于所有课程中有“Java”的学生。

请遵循以下步骤:

*   将 API **prepare()** 函数与带有所需条件的 SQL UPDATE 语句一起使用。
*   使用 API **执行()**功能从数据库中选择所有结果。
*   使用 API **finish()** 函数关闭代码。

```

my $sth = $dbh->prepare("UPDATE users SET course = 'PHP' WHERE course = 'Java'");
$sth->execute() or die $DBI::errstr;
$sth->finish();

```

输出:

```
Name = John, Course = PHP, Fee = 9000 
Name = nisha, Course = PHP, Fee = 10000
Name = Jia, Course = C++, Fee = 8000
Name = Anuj, Course = PHP, Fee = 5000
Name = Vishal, Course = PHP, Fee = 8000
Name = Rash, Course = Hdoop, Fee = 4000

```

看输出，所有的 Java 课程都更新为 PHP 了。

* * *

## Perl 删除数据库

执行删除操作，从数据库中删除一些记录。我们将从费用为 9000 英镑的表格中删除所有记录。

请遵循以下步骤:

*   使用 API **prepare()** 函数配合带有所需条件的 SQL DELETE 语句。
*   使用 API **执行()**功能从数据库中选择所有结果。
*   使用 API **finish()** 函数关闭代码。

```

my $fee = 9000;
my $sth = $dbh->prepare("DELETE FROM users
                        WHERE fee = ?");
$sth->execute( $fee ) or die $DBI::errstr;
$sth->finish();

```

输出:

```
Name = nisha, Course = PHP, Fee = 10000
Name = Jia, Course = C++, Fee = 8000
Name = Anuj, Course = PHP, Fee = 5000
Name = Vishal, Course = PHP, Fee = 8000
Name = Rash, Course = Hdoop, Fee = 4000

```

看看输出，所有费用为 9000 的行都从 SQL 表中删除了。

* * *

## DBI 函数

### 使用 do 语句

do 语句是在数据库中执行 **CRUD** 操作的快捷方式。如果 do 语句成功，则返回真；如果失败，则返回假。下面是显示 do 语句脚本的示例。

```

To INSERT Record,
$dbh->do('INSERT INTO users (name, course, fee) VALUES (?, ?, ?)', 
undef,
$name, $course, $fee);
To UPDATE Record,
$dbh->do('UPDATE users SET course = "PHP" WHERE course = "Java"'
  undef,
  $course,
  $course);
To DELETE Record,
$dbh->do('DELETE FROM users WHERE fee =9000');

```

### 使用提交操作

一旦给出了提交命令，就不能取回所做的更改。您可以通过以下方式调用 commit 命令，

```

$dbh->commit or die $dbh->errstr;

```

### 使用回滚操作

如果您想恢复操作过程中所做的更改，可以调用回滚应用编程接口。

```

$dbh->commit or die $dbh->errstr;

```

### 使用自动错误处理

通过指定 RaiseError 选项，您的错误将由 DBI 自动处理。遇到错误时，您的程序将被中止，而不是运行故障代码。RaiseError 的值可以是 1 或 0。

```

my $dbh = DBI->connect($dsn, $user, $password,
{ RaiseError       => 1 })
or die $DBI::errstr;

```

## 所有句柄的 Perl 通用方法

### 犯罪

```

$rv = $h->err;

```

它从调用的最后一个驱动程序方法返回本机数据库引擎错误代码，该方法通常是一个整数。

DBI 在所有 DBI 方法调用之前将$h->err 重置为 undef，因此该值的使用寿命很短。

### 错误 str

```

$str = $h->errstr;

```

它从上次调用的 DBI 方法返回本机数据库引擎错误消息。这是一种非常有效的方法。返回值可能包含用新行字符分隔的多条消息。

为了测试错误，应该使用 err 方法。因为 errstr 方法可能会为未失败的方法返回成功或警告消息。

### 微量

```

$h->trace($trace_settings);

```

DBI 跟踪方法生成运行时跟踪信息，该信息可用于跟踪您的 DBI 程序中的问题。可以将不同的值设置为跟踪级别。

### 行

```

$rv = $h->rows;

```

rows 方法返回受前一条 SQL 语句影响的行数。