# Perl 对象概念

> 原文：<https://www.javatpoint.com/perl-object-oriented>

Perl 为我们提供了一些构建面向对象系统的工具。Perl 面向对象的概念基于引用、匿名数组和散列。

## Perl 基本对象

一个**对象**只是一个数据结构，它知道它所属的类名。它作为一个引用存储在标量变量中。同一个标量变量可以在不同的类中保存不同的对象，因为它只保存对对象的引用。

A **类**简单来说就是一个包。它包含对对象进行操作(创建和操作)的方法。

**方法**是一个子程序，它需要一个对象引用或一个包名作为第一个参数。

* * *

## Perl 类声明

要创建一个类，我们需要在 Perl 中创建一个包。包包含可以重用的变量和子程序。

因为每个类都是一个包，所以它有自己的由符号名组成的命名空间。类是使用 package 关键字创建的命名空间。它通常在与类同名的模块中实现。例如， **My:: File** 将在文件 **File.pm** 中实现，位置为目录 **My** ，内容如下。

```
package My::File;
use strict;
use warnings;
1;

```

此处末尾的 1 表示文件加载成功。

包的范围扩展到文件末尾，或者直到遇到另一个包关键字。

* * *

## Perl 构造函数

代码需要一个全功能类的构造函数。

通常，构造函数被实现为**新的**方法。

```
sub new {
    my ($class, %args) = @_;
    return bless \%args, $class;
}

```

* * *

## Perl 实例/对象

一个实例或对象是一个受祝福的引用，主要是散列。祝福某事意味着我们在祝福变量所指的事物。

```
use Scalar::Util 'blessed';
  my $Ana = {};
  my $Christian = $Ana;
  bless $Ana, 'Happiness';
  print blessed( $Christian ) // 'not blessed';    # Class
  print "\n";
  $Christian = "some other value";
  print blessed( $Christian ) // 'not blessed';    # not blessed
  print "\n";  

```

输出:

```
Class
not blessed

```

在上面的程序中，当我们对一个变量调用‘祝福’时，我们是在祝福这个变量所指的数据结构。参考不是得到祝福。因此，当我们第二次称祝福($Christian)时，它返回错误。因为$Christian 不存储对对象的引用。

* * *

## Perl 破坏者

Perl 析构函数用于清理不再需要时分配给对象的内存。当一个对象超出范围时，它会在 Perl 中自动完成。所以它通常不会在 Perl 中实现。

为了实现析构函数，这里有一个函数叫做 DESTROY。就在对象被销毁和 Perl 回收内存之前调用它。

```
package MyExample;
sub DESTROY {
   my ($self) = @_;
   print "MyExample::DESTROY called\n";
}

```

* * *

## 定义方法

在 Perl 中没有定义方法的特殊语法。它只是一个用' sub '关键字声明的常规子程序。

方法需要一个对象或类名作为它的第一个参数。

要调用一个方法，需要使用 **- >** 运算符。

要将方法作为对象调用，请使用以下语法:

```
$object -> method

```

左手边是对象名，右手边是方法名。

调用方法时，左侧对象作为第一个参数传递到右侧。

**示例:**

在这个例子中，我们将设置一个助手方法和一个助手函数来设置学生的姓名和级别。

**第 1 步**在 **hw.pl** 文件中，定义一个辅助方法**学生姓名**获取学生姓名。

定义一个辅助函数 **studentRank** 来获取学生的等级。

```
sub studentName {
    return $self->{_name};
}
sub studentRank {
    my ( $self, $name ) = @_;
    $self->{_name} = $name if defined($name);
    return $self->{_name};
}

```

**第二步**在 **student.pm** 文件中，编写 student 包和 helper 函数。

```
#!/usr/bin/perl 
package Student;
sub new	
{
    my $class = shift;
    my $self = {
        _name => shift,
        _rank  => shift,   
    };
    # Print all the values just for clarification.
    print "Student's name is $self->{_name}\n";
    print "Student's rank is $self->{_rank}\n";

    bless $self, $class;
    return $self;
}
sub studentRank {
    my ( $self, $name ) = @_;
    $self->{_name} = $name if defined($name);
    return $self->{_name};
}
sub studentName {
    my( $self ) = @_;
    return $self->{_name};
}
1;

```

**第三步**在 **person.pl** 文件中，我们将使用 Student 对象来获取输出。

```
#!/usr/bin/perl
use Student;
$object = new Student( "Ana", "9th");
# name which is set using constructor.
$name = $object->studentName();
print "Name set using constructor is : $name\n";
# name set using helper function.
$object->studentRank( "Anastasia" );

# getting name set by helper function.
$name = $object->studentName();
print "Name set using helper is : $name\n";

```

输出:

```
Student's name is Ana
Student's rank is 9th
Name set using constructor is : Ana
Name set using helper is : Anastasia

```

* * *

## Perl 继承

继承意味着子类将继承父类的属性和方法。因此，要重用代码，您可以简单地继承它。在 Perl 中@ISA 数组定义了继承。

使用继承时，应考虑以下几点:

*   它将搜索给定方法的对象类，即；变量。
*   它搜索在对象类的@ISA 数组中定义的类。
*   如果在上述步骤中没有找到方法，它将使用自动加载子程序。
*   如果仍然找不到方法，它将使用作为标准 Perl 库一部分的 UNIVERSAL 类进行搜索。
*   如果仍然找不到，则发生运行时异常。

继承也可以使用**父**指令来声明，该指令替换了旧的基本指令。

**示例:**

我们的脚本加载一个模块，调用它的构造函数，然后调用两个方法。

使用以下脚本创建 **hw.pl** 文件。这里，模块本身使用**父指令**声明其继承。

```
#!/usr/bin/perl
use strict;
use warnings;
use Module1;
my $myObj = Module1->new;
$myObj->setHello;
$myObj->setBye;

```

输出:

```
This is Hello message from Module1
This is Bye message from Module2

```

使用以下脚本创建 **Module1.pm** 文件。它声明了我们继承构造函数和另一个方法的模块。

```
package Module1;
use strict;
use warnings;
use parent 'Module2';
sub setHello {
    print "This is Hello message from Module1\n";
}
1;

```

使用以下脚本创建 **Module2.pm** 文件。

```
package Module2;
use strict;
use warnings;
sub new {
    my ($class) = @_;
    return bless {}, $class;
} 
sub setBye {
    my ($self) = @_;
    print "This is Bye message from Module2\n";
    return;
}
1;

```

从模块 1 调用**新的**方法时，Perl 在模块 1 中找不到它。它将在继承链中的下一个模块 Module2 中寻找它。因此，将从模块 2 调用**新的**方法。

* * *

## Perl 多态性

多态性意味着基类中定义的方法将覆盖父类中定义的方法。

它附加了现有类的功能，而不需要重新编程整个类。

**示例:**

```
package A;
    sub A1 {
        print("Inside A::A1\n");
    }
package B;
    @ISA = (A);
    sub A1 {
        print("Inside B::B1\n");
    }
package main;
    B->A1();

```

输出:

```
Inside B::B1

```

在类 B 中定义的子类 A1 覆盖了从类 A 继承的子类