# Perl 日期和时间

> 原文：<https://www.javatpoint.com/perl-date-time>

在 Perl 中处理日期和时间最合适的方法是使用 DateTime 模块。

在每次操作日期和时间之前，我们需要通过脚本将日期时间加载到内存中。

```

use DateTime;

```

* * *

## Perl localtime()

localtime()函数如果在没有任何参数的情况下使用，将根据系统返回当前日期和时间。

```

#!/usr/local/bin/perl
$datetime = localtime();
print "Current date and time according to the system : $datetime\n";

```

输出:

```
Current date and time according to the system : Fri Jan 6 11:52:04 2017

```

## 创建时间戳

通过调用**现在的**构造函数，可以创建一个显示当前日期和时间的 DateTime 对象。

**示例:**

```

use DateTime;
my $datetime = DateTime->now;
print "$datetime\n";

```

输出:

```
2017-01-06T06:29:38

```

我们还可以通过提供日期、分钟、秒等详细信息来创建一个日期时间对象。perl 将假设数据为“0 ”,其中不会传递任何细节。

**示例:**

```

use DateTime;
$datetime = DateTime->new(
    day        => 18,
    month      => 7,
    year       => 2003,
    hour       => 12,
);
print"$datetime\n";

```

输出:

```
2003-07-18T12:00:00

```

在上面的输出中，我们没有传递分钟和第二部分的任何细节。因此，Perl 假定它为零。

* * *

## Perl GMT 时间，gmtime()

此函数的工作方式类似于 localtime()函数，唯一的区别是 gmtime()返回值是标准格林威治时区的本地化值。

```

#!/usr/local/bin/perl
$gmt = gmtime();
print "$gmt\n";
$local = localtime();
print "$local\n";

```

输出:

```
Fri Jan 6 08:43:31 2017
Fri Jan 6 14:13:31 2017

```

## Perl 纪元时间

纪元时间是指特定日期和时间之后的秒数。不同的操作系统有不同的具体日期和时间。例如，对于 Unix，它是 1970 年 1 月 1 日。由于所有的操作系统都有不同的纪元时间，您不能假设一个系统的纪元时间不同于另一个系统。

```

#!/usr/local/bin/perl
$epoch = time();
print "$epoch\n";

```

输出:

```
1483686914

```

## Perl POSIX Function strftime（）

Perl POSIX strftime()函数用于格式化日期和时间，说明符前面带有(%)符号。有两种类型的说明符，一种是本地时间，另一种是 gmt 时区。

### 本地说明符

| 分类符 | 用于 | 例子 |
| %a | 简而言之代表工作日名称 | 太阳 |
| %A | 表示完整的工作日名称 | 在星期日 |
| %b | 简而言之代表月份名称 | 七月 |
| %B | 表示完整的月份名称 | 七月 |
| %c | 表示日期和时间 | 周五 1 月 6 日 12：34：07 2017 |
| %h | 简而言之，表示月份名称，与%b 相同 | 七月 |
| %r | 12 小时制时钟时间 | 下午 6:15:30 |
| %x | 代表日期 | 12/28/12 |
| %X | 代表时间 | 15:34:06 |
| %Z | 代表时区 |  |

### 格林威治时间说明符

| 说明符 | 用于 | 例子 |
| %C | 年份除以 100，用整数(00-99)表示 | Thirty-four |
| %d | 一个月中的某一天，零填充(01-31) | Thirty-three |
| %D | 代表月/日/YY | 07/18/17 |
| %e | 每月的某一天，空格填充(1-31) | Thirty-three |
| %F | 代表年-月-日 | 2017/07/18 |
| %g | 基于周的年份，最后两位数(00-99) | 05 |
| %g | 基于周的年份 | Two thousand and fifteen |
| %H | 24 小时格式的小时 | Seventeen |
| %I | 12 小时格式的小时 | 05 |
| %J | 一年中的某一天(001-366) | Three hundred and sixty-five |
| %m | 十进制数字中的月份(01-12) | 07 |
| %M | 分钟(00-59) | Thirty-five |
| %n | 新行字符 |  |
| %p | 上午或下午 | 是 |
| %R | HH:MM 时间，采用 24 小时制 | five to six p.m. |
| %S | 干球(00-59) | Forty-five |
| % t | 水平制表符 |  |
| %T | ISO 8601 时间格式(时:分:秒) | fifteen to ten p.m./a quarter to ten p.m. |
| %u | 从星期一(1-7)开始的 ISO 8601 工作日 |  |
| %U | 第一周第一天为第一个星期日的周数(00-53) |  |
| %V | 国际标准化组织 8601 周数(00-53) |  |
| %w | 以周日(0-6)开始的十进制数字形式的工作日 |  |
| % W | 以第一个星期一作为第一周第一天的周数(00-53) | Seventeen |
| %y | 一年的最后两位数(00-99) | Two thousand and seventeen |
| % Y | 全年 |  |
| %z | 时区中与世界协调时的 ISO 8601 偏移(1 分钟=1，1 小时= 100) | +100 |
| %% | 百分号 | % |

## 显示日期和时间

有时我们需要以不同的格式显示日期或时间。为此，我们可以在 Perl 中更改格式，如下所示。

**示例:**

```

#!/usr/bin/env perl
use strict;
use warnings;
use 5.010;
use DateTime;
my $datetime = DateTime->new(
    day        => 18,
    month      => 7,
    year       => 2003,
    hour       => 12,
    minute     => 00,
    second     => 00,
);
say $datetime;
say $datetime->ymd;
say $datetime->ymd('_');
say $datetime->hms;
say $datetime->epoch;
say $datetime->year;
say $datetime->month;
say $datetime->day;
say $datetime->strftime( '%Y-%m-%d-%H-%M-%S' );

```

输出:

```
2003-07-18T12:00:00
2003-07-18
18-07-2003
12:00:00
1058529600
2003
7
18
2003-07-18-12-00-00

```