# Perl 套接字编程

> 原文：<https://www.javatpoint.com/perl-socket-programming>

* * *

## 什么是套接字编程？

套接字是有助于在网络上不同进程之间建立虚拟连接的过程。

计算机通过其上运行的各种应用程序接收和发送信息。该信息由分配给它的唯一 IP 地址路由到系统。通信期间发送的数据采用“协议”格式。这些协议是所有通信伙伴都接受的规则。套接字通信中有许多具有不同目标的协议格式。最常用的协议是 **TCP/IP** 协议。

对于一个服务器-客户端程序，我们需要创建两个 Perl 脚本。一个用于服务器，另一个用于客户端。这两个控制台将通过彼此进行通信。您可以在客户端输入数据，这些数据将显示在服务器端控制台上。

* * *

## 创建服务器

按照以下步骤创建套接字服务器。

*   使用**套接字**调用创建套接字。
*   使用**绑定套接字将**调用绑定到一个端口地址。
*   监听插座使用**在端口地址监听**呼叫。
*   使用**接受客户端连接接受**呼叫。

## 创建客户端

按照以下步骤创建客户端套接字。

*   使用**套接字**调用创建套接字。
*   连接插座使用**将**呼叫连接到服务器。

## Perl 套接字编程示例

在这个程序中我们已经显示了客户端数据**你好世界！**在服务器端控制台。

服务器端脚本 **server.pl**

```
#!/usr/bin/perl -w
use IO::Socket; 
use strict; 
use warnings; 
my $socket = new IO::Socket::INET ( 
LocalHost => 'localhost', 
LocalPort => '1234', 
Proto => 'tcp', 
Listen => 1, 
Reuse => 1, 
); 
die "Could not create socket: $!n" unless $socket; 
print "Waiting for the client to send data\n"; 
my $new_socket = $socket->accept(); 
while(<$new_socket>) { 
print $_; 
} 
close($socket);

```

客户端脚本 **client.pl**

```
use strict; 
use warnings; 
use IO::Socket; 
my $socket = new IO::Socket::INET ( 
PeerAddr => 'localhost', 
PeerPort => '1234', 
Proto => 'tcp', 
); 
die "Could not create socket: $!n" unless $socket;
print $socket "Hello World!!\n";
close($socket);

```

输出:

![Perl Socket programming 1](img/25fd063a9d44f922c6cfe9b20feab903.png)

* * *

## Perl 套接字读写程序

在这个客户端-服务器程序中，我们将从客户端控制台上的用户那里获取输入。该输入将通过客户端-服务器通信显示在服务器的控制台上。

在这里，服务器端脚本将保持与前面的脚本相同。

服务器端脚本 **server.pl**

```
#!/usr/bin/perl -w
use IO::Socket; 
use strict; 
use warnings; 
my $socket = new IO::Socket::INET ( 
LocalHost => 'localhost', 
LocalPort => '1234', 
Proto => 'tcp', 
Listen => 1, 
Reuse => 1, 
); 
die "Could not create socket: $!n" unless $socket; 
print "Waiting for the client to send data\n"; 
my $new_socket = $socket->accept(); 
while(<$new_socket>) { 
print $_; 
} 
close($socket);

```

客户端脚本 **client.pl**

```
use strict; 
use warnings; 
use IO::Socket; 
my $socket = new IO::Socket::INET ( 
PeerAddr => 'localhost', 
PeerPort => '1234', 
Proto => 'tcp', 
); 
die "Could not create socket: $!n" unless $socket;
print "Enter the data:\n";
my $data = <STDIN>;
chomp $data;
print $socket "This is the data entered by user '$data'\n";
close($socket);

```

输出:

![Perl Socket programming 2](img/1bd0436fcf76e0aa026e74d6c1ddc923.png)