# 循环的 Scala

> 原文：<https://www.javatpoint.com/scala-for-loop>

在 scala 中，for 循环被称为 for 理解。它可用于迭代、过滤和返回迭代集合。强制理解看起来有点像命令式语言中的强制循环，只是它构建了所有迭代结果的列表。

**语法**

```
for( i <- range){
	// statements to be executed
}

```

在上面的语法中，范围是具有*开始*和*结束*点的值。您可以通过使用**到**或**直到**关键字来传递范围。

* * *

## 使用*到*关键字的 Scala for-loop 示例

```
object MainObject {
   def main(args: Array[String]) {
        for( a <- 1 to 10 ){
         println(a);
      }
   }
}

```

输出:

```
1
2
3
4
5
6
7
8
9
10

```

* * *

在下面的例子中，使用*直到*代替*到*。*至*和*至*的主要区别在于，*至*包括范围内给定的起始值和结束值，而*至*不包括范围内的最后一个值。所以，下面的例子将只打印 1 到 9。

## 使用*直到*关键字进行循环的 Scala 示例

```
object MainObject {
   def main(args: Array[String]) {
        for( a <- 1 until 10 ){
         println(a);
      }
   }
}

```

输出:

```
1
2
3
4
5
6
7
8
9

```

迭代字符串或数组时应用*直到*关键字是有帮助的，因为数组范围是 0 到 n-1。*直到*不超过到 n-1。所以，你的代码不会抱怨上限。

* * *

## 环路滤波示例

您可以使用*代替*来过滤您的数据。在下面的例子中，我们通过传递一个条件表达式来过滤数据。该程序只打印给定范围内的偶数值。

```
object MainObject {
   def main(args: Array[String]) {
        for( a <- 1 to 10 if a%2==0 ){
         println(a);
      }
   }
}

```

输出:

```
2
4
6
8
10

```

* * *

## 使用*产生*关键字的循环示例的 Scala

在上面的例子中，我们使用了 *yield* 关键字，该关键字在循环迭代完成后返回一个结果。for use 缓冲区在内部存储迭代结果，并在完成所有迭代后从该缓冲区生成最终结果。它不像命令式循环那样工作。

```
object MainObject {
   def main(args: Array[String]) {
        var result = for( a <- 1 to 10) yield a
        for(i<-result){
            println(i)
        }
   }
}

```

输出:

```
1
2
3
4
5
6
7
8
9
10

```

* * *

## 集合中循环的 Scala

在 scala 中，您可以迭代像 list、sequence 等集合，或者通过对每个循环使用，或者通过 for-understanding。

我们来看一个例子。

## 迭代集合的循环示例

```
object MainObject {
   def main(args: Array[String]) {
        var list = List(1,2,3,4,5,6,7,8,9)			// Creating a list
        for( i <- list){							// Iterating the list
            println(i)
        }

   }
}

```

输出:

```
1
2
3
4
5
6
7
8
9
10

```

* * *

## 迭代集合的每个循环的 Scala 示例

在下面的代码中，我们为每个循环使用了三种方法。您可以根据需要实现其中的任何一个。

```
object MainObject {
   def main(args: Array[String]) {
        var list = List(1,2,3,4,5,6,7,8,9)	// Creating a list
        list.foreach{
            println		// Print each element
        }
        list.foreach(print)
        println
        list.foreach((element:Int)=>print(element+" "))		// Explicitly mentioning type of elements
   }
}

```

输出:

```
1
2
3
4
5
6
7
8
9
123456789
1 2 3 4 5 6 7 8 9

```

* * *

## 通过关键字使用*的循环 Scala 示例*

在上面的例子中，我们已经通过关键字使用了*。通过*关键字的*用于跳过迭代。当你像这样编码时:2 意味着，这个循环将跳过循环的所有偶数迭代。*

```
object MainObject {
   def main(args: Array[String]) {
        for(i<-1 to 10 by 2){
            println(i)
        }
   }
}

```

输出:

```
1
3
5
7
9

```