# 标量函数

> 原文：<https://www.javatpoint.com/scala-functions>

Scala 支持函数式编程方法。它提供了丰富的内置函数集，并允许您创建用户定义的函数。

在 scala 中，函数是一级值。您可以存储函数值，将函数作为参数传递，并将函数作为其他函数的值返回。可以使用 **def** 关键字创建函数。定义函数时必须提到参数的返回类型，函数的返回类型是可选的。如果不指定函数的返回类型，默认返回类型是单位。

* * *

## Scala 函数声明语法

```
def functionName(parameters : typeofparameters) : returntypeoffunction = {
// statements to be executed
}

```

在上面的语法中，= (equal)运算符看起来很奇怪，但不用担心 scala 将其定义为:

您可以使用或不使用=(等号)运算符来创建函数。如果使用它，函数将返回值。如果你不使用它，你的函数将不会返回任何东西，并且会像子程序一样工作。

Scala 函数不？不要使用 return 语句。编译器根据函数中的最后一个表达式或语句推断返回类型。

* * *

## 不使用=运算符的 Scala 函数示例

下面定义的函数也称为非参数化函数。

```
object MainObject {
   def main(args: Array[String]) {
        functionExample() 			// Calling function
    }
    def functionExample()  {		// Defining a function
          println("This is a simple function")
    }
}

```

输出:

```
This is a simple function

```

* * *

## 带有=运算符的 Scala 函数示例

```
object MainObject {
   def main(args: Array[String]) {
        var result = functionExample() 			// Calling function
        println(result)
    }
    def functionExample() = {		// Defining a function
          var a = 10
          a
    }
}

```

输出:

```
10

```

* * *

## Scala 参数化函数示例

使用参数化函数时，必须明确提到参数的类型，否则编译器会抛出错误，代码无法编译。

```
object MainObject {
   def main(args: Array[String]) = {
        functionExample(10,20) 
    }
    def functionExample(a:Int, b:Int) = {
          var c = a+b
          println(c)
    }
}

```

输出:

```
30

```

* * *

## Scala递归函数

在下面给出的程序中，我们使用递归函数将两个数字相乘。

在 scala 中，你也可以创建递归函数。使用递归函数时要小心。安全终止程序必须有一个基本条件。

```
object MainObject {
   def main(args: Array[String]) = {
        var result = functionExample(15,2) 
        println(result)
    }
    def functionExample(a:Int, b:Int):Int = {
        if(b == 0)			// Base condition
         0
        else
         a+functionExample(a,b-1)
    }
}

```

输出:

```
30

```

* * *

## 带默认值的函数参数

Scala 提供了一个为函数参数分配默认值的特性。在函数调用期间不传递值的情况下，这很有帮助。它使用参数的默认值。

我们来看一个例子。

* * *

## 带默认值的 Scala 函数参数示例

```
object MainObject {
   def main(args: Array[String]) = {
        var result1 = functionExample(15,2) 	// Calling with two values
        var result2 = functionExample(15)	// Calling with one value
        var result3 = functionExample()		// Calling without any value
        println(result1+"\n"+result2+"\n"+result3)
    }
    def functionExample(a:Int = 0, b:Int = 0):Int = {	// Parameters with default values as 0
        a+b
    }
}

```

输出:

```
17
15
0

```

* * *

## Scala 函数命名参数示例

在 scala 函数中，可以在调用函数的过程中指定参数的名称。在给定的示例中，您可以注意到参数名在调用过程中传递。您可以以任何顺序传递命名参数，也可以只传递值。

我们来看一个例子。

```
object MainObject {
   def main(args: Array[String]) = {
        var result1 = functionExample(a = 15, b = 2)    // Parameters names are passed during call
        var result2 = functionExample(b = 15, a = 2)    // Parameters order have changed during call
        var result3 = functionExample(15,2)             // Only values are passed during call
        println(result1+"\n"+result2+"\n"+result3)
    }
    def functionExample(a:Int, b:Int):Int = {
        a+b
    }
}

```

输出:

```
17
17
17

```