# 高阶函数

> 原文：<https://www.javatpoint.com/scala-higher-order-functions>

高阶函数是以函数为参数或返回函数的函数。换句话说，我们可以说一个与函数一起工作的函数叫做高阶函数。

高阶函数允许您创建函数组合、lambda 函数或匿名函数等。

我们来看一个例子。

* * *

## Scala 示例:将函数作为参数传递给函数

```
object MainObject {
   def main(args: Array[String]) = {
     functionExample(25, multiplyBy2) 	 				// Passing a function as parameter
    }
    def functionExample(a:Int, f:Int=>AnyVal):Unit = {
        println(f(a))   								// Calling that function 
    }
    def multiplyBy2(a:Int):Int = {
        a*2
    }
}

```

输出:

```
60

```

* * *

## Scala 示例:函数组合

在 scala 中，函数可以由其他函数组成。这是一个组合过程，其中一个函数代表两个组合函数的应用。

我们来看一个例子。

```
object MainObject {
   def main(args: Array[String]) = {
     var result = multiplyBy2(add2(10))      // Function composition
     println(result)
    }
    def add2(a:Int):Int = {
        a+2
    }

    def multiplyBy2(a:Int):Int = {
        a*2
    }
}

```

输出:

```
24

```

* * *

## Scala 匿名(λ)函数

匿名函数是一个没有名字但作为函数工作的函数。当你不想重用匿名函数时，创建一个匿名函数是很好的。

您可以通过在 scala 中使用=> (rocket)或 _(下划线)通配符来创建匿名函数。

我们来看一个例子。

* * *

## Scala 匿名函数示例

```
object MainObject {
   def main(args: Array[String]) = {
     var result1 = (a:Int, b:Int) => a+b        // Anonymous function by using => (rocket)
     var result2 = (_:Int)+(_:Int)              // Anonymous function by using _ (underscore) wild card
     println(result1(10,10))
     println(result2(10,10))
    }
}

```

输出:

```
20
20

```

* * *

## Scala 多行表达式

用多行写的表达式称为多行表达式。在 scala 中，使用多行表达式时要小心。

下面的程序解释了如果我们将一个表达式分解成多行，scala 编译器会抛出一条警告消息。

* * *

## Scala 多行表达式示例

```
def add1(a:Int, b:Int) = {
        a
        +b
    }

```

上面的程序不计算完整的表达式，只在这里返回 b。因此，在使用多行表达式时要小心。

输出:

```
MainObject.scala:3: warning: a pure expression does nothing in statement 
position; you may be omitting necessary parentheses
        a
        ^
one warning found

10

```

您可以采用以下方法来避免上述问题。

* * *

## Scala 示例多行表达式

```
object MainObject {
    def add2(a:Int, b:Int) = {
        a+
        b
    }
    def add3(a:Int, b:Int) = {
        (a
        +b)
    }
    def main(args: Array[String]) = {
        var result2 = add2(10,10)
        var result3 = add3(10,10)
        println(result2+"\n"+result3)
    }
}

```

输出:

```
20
20

```

* * *

## 标量函数曲线

在 scala 中，方法可能有多个参数列表。当用较少数量的参数列表调用一个方法时，这将产生一个以缺少的参数列表为参数的函数。

换句话说，它是一种将一个接受多个参数的函数转换成一个接受单个参数的函数的技术。

* * *

## 标量函数曲线示例

```
object MainObject {
    def add(a:Int)(b:Int) = {
        a+b
    }
    def main(args: Array[String]) = {
        var result = add(10)(10)
        println("10 + 10 = "+result)
        var addIt = add(10)_
        var result2 = addIt(3)
        println("10 + 3 = "+result2)
    }
}

```

输出:

```
20

```

* * *

## Scala 嵌套函数

Scala 是第一类函数语言，这意味着它允许你传递函数、返回函数、组合函数、嵌套函数等。下面的例子解释了如何定义和调用嵌套函数。

* * *

## Scala 嵌套函数示例

```
object MainObject {
    def add(a:Int, b:Int, c:Int) = {
        def add2(x:Int,y:Int) = {
            x+y
        }
        add2(a,add2(b,c))
    }
    def main(args: Array[String]) = {
        var result = add(10,10,10)
        println(result)
    }
}

```

输出:

```
30

```

* * *

## 可变长度参数的标量函数

在 scala 中，你可以定义可变长度参数的函数。它允许您在调用函数时传递任意数量的参数。

我们来看一个例子。

* * *

## Scala 示例:具有可变长度参数的函数

```
def add(args: Int*) = {
    var sum = 0;
    for(a <- args) sum+=a
    sum
}
var sum = add(1,2,3,4,5,6,7,8,9);
println(sum);

```

输出:

```
45

```