# Scala决赛

> 原文：<https://www.javatpoint.com/scala-final>

Final 是一个关键字，用于防止超级类成员继承到派生类中。您还可以声明最终变量、方法和类。

* * *

## Scala 最终变量示例

您不能覆盖子类中的最终变量。我们来看一个例子。

```

class Vehicle{
     final val speed:Int = 60
}
class Bike extends Vehicle{
   override val speed:Int = 100
    def show(){
        println(speed)
    }
}

object MainObject{
    def main(args:Array[String]){
        var b = new Bike()
        b.show()
    }
}

```

输出:

```
Error - value speed cannot override final member 

```

* * *

## Scala 最终方法

父类中的 Final 方法声明不能被重写。如果你不想让任何方法被覆盖，你可以把它变成 final。试图重写最终方法将导致编译时错误。

## Scala 最终方法示例

```

class Vehicle{
     final def show(){
         println("vehicle is running")
     }
}
class Bike extends Vehicle{
   //override val speed:Int = 100
    override def show(){
        println("bike is running")
    }
}
object MainObject{
    def main(args:Array[String]){
        var b = new Bike()
        b.show()
    }
}

```

输出:

```
method show cannot override final member
    override def show(){
                 ^
one error found

```

* * *

## Scala 最终类示例

你也可以上最后一节课。最终类不能被继承。如果你期末考了，就不能再延长了。

```

final class Vehicle{
     def show(){
         println("vehicle is running")
     }

}

class Bike extends Vehicle{
       override def show(){
        println("bike is running")
    }
}

object MainObject{
    def main(args:Array[String]){
        var b = new Bike()
        b.show()
    }
}

```

输出:

```
error: illegal inheritance from final class Vehicle
class Bike extends Vehicle{
                   ^
one error found

```