# Scala特质融合蛋白

> 原文：<https://www.javatpoint.com/scala-trait-mixins>

在 scala 中，特性混合意味着你可以用一个类或抽象类扩展任意数量的特性。你只能扩展特征或者特征和类的组合或者特征和抽象类。

有必要保持混合的顺序，否则编译器会抛出一个错误。

您可以像这样在 scala 中使用 mixins:

* * *

## Scala 特性示例:混搭顺序未保持

在这个例子中，我们扩展了一个特性和一个抽象类。让我们看看会发生什么。

```

trait Print{
    def print()
}

abstract class PrintA4{
    def printA4()
}

class A6 extends Print with PrintA4{
    def print(){                // Trait print
        println("print sheet")
    }
    def printA4(){              // Abstract class printA4
        println("Print A4 Sheet")
    }
}

object MainObject{
    def main(args:Array[String]){
        var a = new A6()
        a.print()
        a.printA4()
    }
}

```

输出:

```
error: class PrintA4 needs to be a trait to be mixed in
class A6 extends Print with PrintA4{
                            ^
one error found

```

上面的程序抛出了一个编译时错误，因为我们没有维护 mixins 的顺序。

* * *

## Scala混合顺序

特性的正确混合顺序是，任何你想要扩展的类或抽象类，首先扩展它。所有的特征都会在这个类或者抽象类之后得到扩展。

## Scala 特性示例:保持混合顺序

```

trait Print{
    def print()
}

abstract class PrintA4{
    def printA4()
}

class A6 extends PrintA4 with Print{			// First one is abstract class second one is trait
    def print(){                						// Trait print
        println("print sheet")
    }
    def printA4(){              						// Abstract class printA4
        println("Print A4 Sheet")
    }
}

object MainObject{
    def main(args:Array[String]){
        var a = new A6()
        a.print()
        a.printA4()
    }
}

```

输出:

```
print sheet
Print A4 Sheet

```

* * *

## Scala特质的另一个例子

在这里，我们使用了另一种方法来扩展我们程序中的特性。在这种方法中，我们在对象创建过程中扩展了特征。我们来看一个例子。

```

trait Print{
    def print()
}

abstract class PrintA4{
    def printA4()
}

class A6 extends PrintA4 {
    def print(){               				 // Trait print
        println("print sheet")
    }
    def printA4(){              				// Abstract class printA4
        println("Print A4 Sheet")
    }
}

object MainObject{
    def main(args:Array[String]){
        var a = new A6() with Print				// You can also extend trait during object creation
        a.print()
        a.printA4()
    }
}

```

输出:

```
print sheet
Print A4 Sheet

```