# 修改访问比例

> 原文：<https://www.javatpoint.com/scala-access-modifier>

Access 修饰符用于定义数据和代码对外部世界的可访问性。您可以将可访问性应用于类、特征、数据成员、成员方法和构造函数等。Scala 为所有人提供了最少的可访问性。您可以根据您的应用程序需求对代码应用任何访问修饰符。

Scala 只提供了三种类型的访问修饰符，如下所示:

1.  不要修改
2.  保护
3.  私人的

在 scala 中，如果您没有提到任何访问修饰符，它将被视为没有修饰符。

下表包含有关访问修饰符的可访问性的信息。

| 修饰语 | 外包装 | 包裹 | 班级 | 亚纲 | 同伴 |
| 没有访问修饰符 | 是 | 是 | 是 | 是 | 是 |
| 保护 | 不 | 不 | 是 | 是 | 是 |
| 私人的 | 不 | 不 | 是 | 不 | 是 |

* * *

## Scala 示例:私有访问修饰符

在 scala 中，私有访问修饰符用于使数据只能在声明它的类中访问。它是最受限制的，并且将您的数据保持在有限的范围内。私有数据成员不会继承到子类中。

```

class AccessExample{
     private var a:Int = 10
     def show(){
         println(a)
     }
}
object MainObject{
    def main(args:Array[String]){
        var p = new AccessExample()
        p.a = 12
        p.show()
    }
}

```

输出:

```
error: variable a in class AccessExample cannot be accessed in AccessExample
        p.a = 12
          ^
one error found

```

* * *

## Scala 示例:受保护的访问修饰符

受保护的访问修饰符只能在类、子类和伴随对象中访问。声明为受保护的数据成员在子类中继承。我们来看一个例子。

```

class AccessExample{
     protected var a:Int = 10
}
class SubClass extends AccessExample{
    def display(){
        println("a = "+a)
    }
}
object MainObject{
    def main(args:Array[String]){
        var s = new SubClass()
        s.display()
    }
}

```

输出:

```
a = 10 

```

* * *

## Scala 示例:无访问修饰符

在 scala 中，当您没有提到任何访问修饰符时，它被视为无访问修饰符。它与 java 中的 public 相同。它限制最少，从包装内部或外部的任何地方都很容易接近。

```

class AccessExample{
     var a:Int = 10
     def show(){
         println(" a = "+a)
     }
}

object MainObject{
    def main(args:Array[String]){
        var a = new AccessExample()
        a.show()
    }
}

```

输出:

```
a = 10

```