# 标量字符串插值

> 原文：<https://www.javatpoint.com/scala-string-interpolation>

从 Scala 2.10.0 开始，Scala 提供了一种从数据创建字符串的新机制。这叫做字符串插值。字符串插值允许用户将变量引用直接嵌入到已处理的字符串中。Scala 提供了三种字符串插值方法:s、f 和 raw。

* * *

## Scala 程序示例:不使用 s 方法

这是一个简单的例子，它没有在字符串中使用 s 方法。

```

class StringExample{
    var pi = 3.14
    def show(){
        println("value of pi = "+pi)		
    }
}
object MainObject{
    def main(args:Array[String]){
        var s = new StringExample()
        s.show()
    }
}

```

输出:

```
value of pi = 3.14

```

* * *

## 标量字符串插值示例

本程序在打印功能中使用字符串插值。你可以看到插值的优势。这里，我们没有使用+运算符来连接字符串对象。

```

class StringExample{
    var pi = 3.14
    def show(){
        println(s"value of pi = $pi")
    }
}

object MainObject{
    def main(args:Array[String]){
        var s = new StringExample()
        s.show()
    }
}

```

输出:

```
value of pi = 3.14

```

* * *

## 用 s 方法进行标量字符串插值的例子

字符串插值的 s 方法允许我们在字符串对象中传递变量。您不需要使用+运算符来格式化输出字符串。在下面的示例中，一个字符串变量被传递给打印函数中的 string。该变量由编译器计算，变量由值代替。

```

class StringExample{
    var s1 = "Scala string example"
    def show(){
        println(s"This is $s1")
    }
}

object MainObject{
    def main(args:Array[String]){
        var s = new StringExample()
        s.show()
    }
}

```

输出:

```
This is Scala string example

```

* * *

## 用 f 方法进行标量字符串插值的例子

f 方法用于格式化字符串输出。它就像 c 语言的 printf 函数，用来产生格式化的输出。您可以在打印函数中传递任何类型的变量。

```

class StringExample{
    var s1 = "Scala string example"
    var version = 2.12
    def show(){
        println(f"This is $s1%s, scala version is $version%2.2f")
    }
}

object MainObject{
    def main(args:Array[String]){
        var s = new StringExample()
        s.show()
    }
}

```

输出:

```
This is Scala string example, scala version is 2.12

```

* * *

## 使用原始方法的标量字符串插值示例

字符串插值的原始方法用于生成原始字符串。它不解释字符串中存在的特殊字符。我们来看一个例子。

```

class StringExample{
    var s1 = "Scala \tstring \nexample"    
    var s2 = raw"Scala \tstring \nexample"    
    def show(){
        println(s1)
        println(s2)
    }
}

object MainObject{
    def main(args:Array[String]){
        var s = new StringExample()
        s.show()
    }
}

```

输出:

```
Scala	string 
example
Scala \nstring \nexample

```