# Scala集

> 原文：<https://www.javatpoint.com/scala-set>

它用于存储集合中的唯一元素。它不维护任何存储元素的顺序。您可以对它们应用各种操作。它是在 Scala . collection . imbible 包中定义的。

* * *

### 标量集语法

```
val variableName:Set[Type] = Set(element1, element2,... elementN) or
val variableName = Set(element1, element2,... elementN)

```

### Scala集示例

在这个例子中，我们已经创建了一个集合。您也可以创建一个空集合。让我们看看如何创建一个集合。

```
import scala.collection.immutable._
object MainObject{
    def main(args:Array[String]){
        val set1 = Set()    						// An empty set
        val games = Set("Cricket","Football","Hocky","Golf") 	// Creating a set with elements
        println(set1)
        println(games)
    }
}

```

输出:

```
Set()	// an empty set
Set(Cricket,Football,Hocky,Golf)

```

* * *

### Scala 集示例 2

在 Scala 中，set 提供了一些预定义的属性来获取关于 Set 的信息。您可以获得集合的第一个或最后一个元素以及更多。我们来看一个例子。

```
import scala.collection.immutable._
object MainObject{
        def main(args:Array[String]){
            val games = Set("Cricket","Football","Hocky","Golf")
            println(games.head)				// Returns first element present in the set
            println(games.tail)			// Returns all elements except first element.
            println(games.isEmpty)			// Returns either true or false
        }
    }

```

输出:

```
Cricket
Set(Football, Hocky, Golf)
false

```

* * *

### Scala 集合示例:合并两个集合

您可以将两个集合合并为一个集合。Scala 提供了一个预定义的方法来合并集合。在这个例子中，++ 方法被用来合并两个集合。

```
import scala.collection.immutable._
object MainObject{
        def main(args:Array[String]){
            val games = Set("Cricket","Football","Hocky","Golf")
            val alphabet = Set("A","B","C","D","E") 
            val mergeSet = games ++ alphabet			// Merging two sets
            println("Elements in games set: "+games.size)	// Return size of collection
            println("Elements in alphabet set: "+alphabet.size)	
            println("Elements in mergeSet: "+mergeSet.size)
            println(mergeSet)
        }
    }

```

输出:

```
Elements in games set: 4
Elements in alphabet set: 5
Elements in mergeSet: 9
Set(E, Football, Golf, Hocky, A, B, C, Cricket, D)

```

这个例子也证明了合并集不维护存储元素的顺序。

* * *

### Scala 集示例 2

您可以检查元素是否存在于集合中。以下示例描述了 contains()方法的使用。

```
import scala.collection.immutable._
object MainObject{
        def main(args:Array[String]){
            val games = Set("Cricket","Football","Hocky","Golf")
            println(games)
            println("Elements in set: "+games.size)
            println("Golf exists in the set : "+games.contains("Golf"))
            println("Racing exists in the set : "+games.contains("Racing"))

        }
    }

```

输出:

```
Set(Cricket, Football, Hocky, Golf)
Elements in set: 4
Golf exists in the set : true
Racing exists in the set : false

```

* * *

### Scala 集合示例:添加和移除元素

您可以在集合中添加或移除元素。您只能在代码可变时添加。在这个例子中，我们添加和移除集合的元素。

```
import scala.collection.immutable._
object MainObject{
        def main(args:Array[String]){
            var games = Set("Cricket","Football","Hocky","Golf")
            println(games)
            games += "Racing"       		// Adding new element
            println(games)
            games += "Cricket"           	// Adding new element, it does not allow duplicacy.
            println(games)
            games -= "Golf"     		// Removing element
            println(games)
        }
    }

```

输出:

```
Set(Cricket, Football, Hocky, Golf)
Set(Football, Golf, Hocky, Cricket, Racing)
Set(Football, Golf, Hocky, Cricket, Racing)
Set(Football, Hocky, Cricket, Racing)

```

* * *

### Scala 集合示例:使用 for 循环迭代集合元素

可以通过使用 for 循环或 foreach 循环来迭代集合元素。您也可以在迭代过程中过滤元素。在这个例子中，我们使用 for 循环来迭代集合元素。

```
import scala.collection.immutable._
object MainObject{
        def main(args:Array[String]){
            var games = Set("Cricket","Football","Hocky","Golf")
            for(game <- games){
                println(game)
            }
        }
    }

```

输出:

```
Cricket
Football
Hocky
Golf

```

* * *

### Scala 集合示例使用 foreach 循环迭代元素

在这个例子中，我们使用 foreach 循环来迭代集合元素。

```
import scala.collection.immutable._
    object MainObject{
        def main(args:Array[String]){
            var games = Set("Cricket","Football","Hocky","Golf")
            games.foreach((element:String)=> println(element))
        }   
}

```

输出:

```
Cricket
Football
Hocky
Golf

```

* * *

### Scala 集合示例:集合运算

在 scala Set 中，您还可以使用典型的数学运算，如:交集和并集。在下面的示例中，我们使用了预定义的方法来执行集合操作。

```
import scala.collection.immutable._
object MainObject{
    def main(args:Array[String]){
        var games = Set("Cricket","Football","Hocky","Golf","C")
        var alphabet = Set("A","B","C","D","E","Golf")
        var setIntersection = games.intersect(alphabet)
        println("Intersection by using intersect method: "+setIntersection)
        println("Intersection by using & operator: "+(games & alphabet))
        var setUnion = games.union(alphabet)
        println(setUnion)
    }
}

```

输出:

```
Intersection by using intersect method: Set(Golf, C)
Intersection by using & operator: Set(Golf, C)
Set(E, Football, Golf, Hocky, A, B, C, Cricket, D)

```

* * *

### sortedset 比例

在 scala 中，SortedSet 扩展了 Set 特性，并提供了排序的集合元素。当您需要集合集合中已排序的元素时，它非常有用。您也可以对整数值和字符串进行排序。

这是一个特性，你可以应用所有在可遍历特性和集合特性中定义的方法。

### Scala 排序集示例

在下面的例子中，我们使用了 SortedSet 来存储整数元素。它在对元素排序后返回一个集合。

```
import scala.collection.immutable.SortedSet            
object MainObject{
    def main(args:Array[String]){
        var numbers: SortedSet[Int] = SortedSet(5,8,1,2,9,6,4,7,2)
        numbers.foreach((element:Int)=> println(element))
    }   
}

```

输出:

```
1
2
4
5
6
7
8
9

```