# Scala 线程方法

> 原文：<https://www.javatpoint.com/scala-thread-methods>

线程类提供了各种方法来处理线程的状态。您可以使用这些方法来控制线程流。

下表包含线程类的常用方法。

| 方法 | 描述 |
| 公共最终字符串 getName() | 它返回线程的名称。 |
| public final int getPriority() | 它返回线程的优先级。 |
| 公共线程。State getState() | 它返回这个线程的状态。这种方法设计用于监控系统状态，而不是用于同步控制。 |
| public final boolean isalive() | 它测试这个线程是否是活动的。如果一个线程已经启动，并且还没有死亡，那么它就是活动的。 |
| 公共最终 void join()引发中断异常 | 它等待线程死亡。 |
| 公共无效运行() | 如果这个线程是用一个单独的 Runnable run 对象构造的，那么调用该 Runnable 对象的 run 方法；否则，此方法不执行任何操作并返回。 |
| 公共最终无效集合名称(字符串名称) | 用于设置线程名称。 |
| 公共最终无效设置优先级(int newPriority) | 它用于设置线程的优先级。 |
| 公共静态无效睡眠(长毫秒)引发中断异常 | 它用于使执行线程休眠指定的毫秒数。 |
| 公共静态无效收益率() | 它导致当前正在执行的线程对象暂时暂停，并允许其他线程执行。 |

## Scala 线程睡眠()方法

sleep()方法用于让线程休眠指定的时间。作为一个参数需要几毫秒的时间。

```
class ThreadExample extends Thread{
override def run(){
for(i<- 0 to 5){
println(i)
Thread.sleep(500)
}
}

}

object MainObject{
def main(args:Array[String]){
var t1 = new ThreadExample()
var t2 = new ThreadExample()
t1.start()
t2.start()
}
}

```

输出:

```
0
0
1
1
2
2
3
3
4
4
5
5

```

* * *

## Scala 线程连接()方法示例

join()方法等待线程死亡。换句话说，join()方法用于保持当前正在运行的线程的执行，直到指定的线程完成它的执行。

```
class ThreadExample extends Thread{
override def run(){
for(i<- 0 to 5){
println(i)
Thread.sleep(500)
}
}

}
object MainObject{
def main(args:Array[String]){
var t1 = new ThreadExample()
var t2 = new ThreadExample()
var t3 = new ThreadExample()
t1.start()
t1.join()
t2.start()
t3.start()
}
}

```

输出:

```
0
1
2
3
4
5
0
0
1
1
2
2
3
3
4
4
5
5

```

* * *

## Scala setName()方法示例

在下面的示例中，我们正在设置和获取线程的名称。

```
class ThreadExample() extends Thread{
override def run(){
for(i<- 0 to 5){
println(this.getName()+" - "+i)
Thread.sleep(500)
}
}
}

object MainObject{
def main(args:Array[String]){
var t1 = new ThreadExample()
var t2 = new ThreadExample()
var t3 = new ThreadExample()
t1.setName("First Thread")
t2.setName("Second Thread")
t1.start()
t2.start()
}
}

```

输出:

```
First Thread - 0
Second Thread - 0
Second Thread - 1
First Thread - 1
Second Thread - 2
First Thread - 2
Second Thread - 3
First Thread - 3
Second Thread - 4
First Thread - 4
Second Thread - 5
First Thread - 5

```

* * *

## Scala 线程优先级示例

您可以使用它的预定义方法来设置线程优先级。以下示例设置线程的优先级。

```
class ThreadExample() extends Thread{
override def run(){
for(i<- 0 to 5){
println(this.getName())
println(this.getPriority())
Thread.sleep(500)
}
}
}
object MainObject{
def main(args:Array[String]){
var t1 = new ThreadExample()
var t2 = new ThreadExample()
t1.setName("First Thread")
t2.setName("Second Thread")
t1.setPriority(Thread.MIN_PRIORITY)
t2.setPriority(Thread.MAX_PRIORITY)
t1.start()
t2.start()
}
}

```

输出:

```
First Thread
Second Thread
10
1
Second Thread
10
First Thread
1
Second Thread
10
First Thread
1
Second Thread
10
First Thread
1
Second Thread
10
First Thread
1
Second Thread
10
First Thread
1

```

* * *

## Scala 线程多任务示例

下面的示例使用多线程运行多个任务。这个例子解释了我们如何在 Scala 中实现多任务处理。

```
class ThreadExample() extends Thread{
override def run(){
for(i<- 0 to 5){
println(i)            
Thread.sleep(500)
}
}
def task(){
for(i<- 0 to 5){
println(i)
Thread.sleep(200)
}
}
}

object MainObject{
def main(args:Array[String]){
var t1 = new ThreadExample()
t1.start()
t1.task()         
}
}

```

输出:

```
0
0
1
2
1
3
4
2
5
3
4
5

```