# Ruby模块

> 原文：<https://www.javatpoint.com/ruby-modules>

Ruby 模块是方法和常量的集合。模块方法可以是实例方法或模块方法。

实例方法是包含模块时类中的方法。

可以在不创建封装对象的情况下调用模块方法，而实例方法则不可以。

它们类似于类，因为它们包含方法、类定义、常数和其他模块的集合。它们被定义为类。不能使用模块创建对象或子类。没有继承的模块层次结构。

模块主要有两个目的:

*   它们充当命名空间。他们防止名称冲突。
*   它们允许 mixin 工具在类之间共享功能。

**语法:**

```

module ModuleName
   statement1
   statement2
   ...........
end

```

模块名称应以大写字母开头。

* * *

## 模块命名空间

在编写较大的文件时，会生成大量可重用的代码。这些代码被组织成类，这些类可以被插入到文件中。

例如，如果两个人在不同的文件中有相同的方法名。这两个文件都需要包含在第三个文件中。那么它可能会产生一个问题，因为两个包含的文件中的方法名称是相同的。

在这里，模块机制开始发挥作用。模块定义了一个命名空间，在这个命名空间中，您可以定义自己的方法和常量，而不会被其他方法和常量超越。

**示例:**

假设，在 file1.rb 中，我们定义了许多不同类型的图书馆书籍，如小说、恐怖等。

在 file2.rb 中，我们定义了阅读和剩余阅读的小说数量，包括小说。

在 file3.rb 中，我们需要加载文件 file1 和 file2。这里我们将使用模块机制。

**文件 1.rb**

```

#!/usr/bin/ruby 

# Module defined in file1.rb file 

module Library 
   num_of_books = 300 
   def Library.fiction(120) 
   # .. 
   end 
   def Library.horror(180) 
   # .. 
   end 
end

```

**文件 2.rb**

```

#!/usr/bin/ruby 

# Module defined in file2.rb file 

module Novel 
   total = 123 
   read = 25 
   def Novel.fiction(left) 
   # ... 
   end 
end

```

**文件 3.rb**

```
require "Library" 
require "Novel" 

x = Library.fiction(Library::num_of_books) 
y = Novel.fiction(Novel::total)

```

模块方法是通过在它的名称前面加上模块名称和句点来调用的，并且您使用模块名称和两个冒号来引用一个常量。

* * *

## 模块混合

Ruby 不支持多重继承。使用 Ruby 中的 mixin，模块消除了多重继承的需要。

模块没有实例，因为它不是类。但是，模块可以包含在类中。

当您在类中包含一个模块时，该类将有权访问该模块的方法。

**示例:**

```

module Name 
   def bella 
   end 
   def ana 
   end 
end 
module Job 
   def editor 
   end 
   def writer 
   end 
end 

class Combo 
include Name 
include Job 
   def f 
   end 
end 

final=Combo.new 
final.bella 
final.ana 
final.editor 
final.writer 
final.f

```

这里，模块名由方法 bella 和 ana 组成。模块作业由方法编辑器和编写器组成。类组合包括两个模块，因为哪个类组合可以访问所有四个方法。因此，类组合作为**混合工作。**

混合到类中的模块方法可以是实例方法，也可以是类方法。这取决于如何将 mixin 添加到类中。