# Ruby琴弦

> 原文：<https://www.javatpoint.com/ruby-strings>

Ruby string 对象保存并操作一个任意的字节序列，通常代表字符。它们是使用**字符串::new** 或作为文字创建的。

* * *

## 引用

Ruby 字符串文字用单引号和双引号括起来。

**示例:**

```

#!/usr/bin/ruby 

puts 'Hello everyone' 
puts "Hello everyone"

```

输出:

![Ruby string 1](img/2d64c3651bb9e1dc7de9e23646ac3b0e.png)

* * *

## 访问字符串元素

您可以在方括号[]的帮助下访问不同部分的 Ruby 字符串元素。在方括号内写索引或字符串。

**示例:**

```

#!/usr/bin/ruby 

msg = "This tutorial is from JavaTpoint." 

puts msg["JavaTpoint"] 
puts msg["tutorial"] 

puts msg[0] 

puts msg[0, 2] 
puts msg[0..19] 
puts msg[0, msg.length] 
puts msg[-3]

```

输出:

![Ruby string 2](img/cb1096e4bdcf8ce1bf55247ec28a7d2e.png)

* * *

## 多行字符串

在 Ruby 语言中，编写多行字符串非常简单。我们将展示打印多行字符串的三种方法。

*   字符串可以用双引号括起来。
*   使用了%字符，字符串包含在/字符中。
*   在 heredoc 语法中，我们使用<

**示例:**

```

puts " 
A 
AB 
ABC 
ABCD" 

puts %/ 
A 
AB 
ABC 
ABCD/ 

puts <<STRING 
A 
AB 
ABC 
ABCD 
STRING 

```

输出:

![Ruby string 3](img/6b3cc1ff7bf0262b0e63fa742a478fb1.png)

* * *

## 可变插值

Ruby 变量插值是用字符串内的值替换变量。变量名放在字符串文本中的#{和}个字符之间。

**示例:**

```

#!/usr/bin/ruby 

country = "India" 
capital = "New Delhi" 

puts "#{capital} is the capital of #{country}."

```

输出:

![Ruby string 4](img/25f52dbdad221f5ce9d588df5d1ee423.png)

* * *

## 串联字符串

Ruby 串联字符串意味着从多个字符串中创建一个字符串。您可以通过连接多个字符串来将它们连接成一个字符串。

有四种方法可以将 Ruby 字符串连接成单个字符串:

*   在字符串之间使用加号。
*   在字符串之间使用单个空格。
*   在字符串之间使用<
*   在字符串之间使用 concat 方法。

**示例:**

```

#!/usr/bin/ruby 

string = "This is Ruby Tutorial" + " from JavaTpoint." + " Wish you all good luck." 
puts string 

string = "This is Ruby Tutorial" " from JavaTpoint." " Wish you all good luck." 
puts string 

string = "This is Ruby Tutorial" << " from JavaTpoint." << " Wish you all good luck." 
puts string 

string = "This is Ruby Tutorial".concat(" from JavaTpoint.").concat(" Wish you all good luck.") 
puts string

```

输出:

![Ruby string 5](img/861bb8825a8716d07c2608bf3db38ebe.png)

* * *

## 冻结字符串

在大多数编程语言中，字符串是不可变的。这意味着不能修改现有的字符串，只能在它们的基础上创建新的字符串。

在 Ruby 中，默认情况下字符串不是不可变的。为了使它们不变，可以使用冻结方法。

**示例:**

```

#!/usr/bin/ruby 

str = "Original string" 
str << " is modified " 
str << "is again modified" 

puts str 

str.freeze 

#str << "And here modification will be failed after using freeze method"

```

输出:

![Ruby string 6](img/c477349a0a773a6b4cefe0337012f899.png)

在上面的输出中，我们使用冻结方法使字符串不可变。最后一行是注释，因为没有字符串不能再修改了。

通过取消最后一行的注释，我们将得到如下输出所示的错误。

输出:

![Ruby string 7](img/512b22e6bf34ea636582abff5d8a7300.png)

* * *

## 比较字符串

Ruby 字符串可以与三个运算符进行比较:

*   With ==运算符:返回真或假
*   用 eql？运算符:返回真或假
*   使用 casecmp 方法:如果匹配则返回 0，如果不匹配则返回 1

**示例:**

```

#!/usr/bin/ruby 

puts "abc" == "abc" 
puts "as ab" == "ab ab" 
puts "23" == "32" 

puts "ttt".eql? "ttt" 
puts "12".eql? "12" 

puts "Java".casecmp "Java" 
puts "Java".casecmp "java" 
puts "Java".casecmp "ja"

```

输出:

![Ruby string 8](img/06576bb115faefeff21699f19a26e9ba.png)

* * *