# Ruby文件输入输出

> 原文：<https://www.javatpoint.com/ruby-file-io>

Ruby 输入/输出是一种与系统交互的方式。数据以字节/字符的形式发送。IO 类是 Ruby 中所有输入输出的基础。它可能是双重的，因此可能使用多个本机操作系统流。

IO 有一个子类 **File** 类，允许在 Ruby 中读写文件。这两个类别密切相关。IO 对象表示键盘和屏幕可读/可写交互。

* * *

## 输入输出端口的常见模式

*   **“r”:**只读模式是从文件开头开始的默认模式。
*   **“r+”:**读写模式，从文件开头开始。
*   **“w”:**只写模式，要么创建新文件，要么截断现有文件进行写入。
*   **“w+”:**读写模式，要么创建新文件，要么截断现有文件进行读写。
*   **“a”:**只写模式，如果文件存在，它将追加文件，否则将创建一个只写的新文件。
*   **“a+”:**读写模式，如果文件存在，它会追加文件，否则会创建一个新文件进行读写。

* * *

## 输入输出控制台

IO 控制台提供了与控制台交互的不同方法。IO 类提供了以下基本方法:

*   IO::控制台
*   IO#原始#原始！
*   IO #已烹饪
*   IO #熟了！
*   我#getch
*   IO#回声=
*   IO#echo？
*   我是 io#noecho
*   我 io#winsize
*   我 io#winsize=
*   IO#iflush
*   我#ioflush
*   输入输出# oflush

* * *

## Ruby 打开文件

一个 Ruby 文件可以用不同的方法来创建，比如读、写或者两者都有。

在 Ruby 中打开文件有两种方法:

*   **File.new 方法:**使用这种方法可以创建一个新文件，用于读取、写入或两者。
*   **File.open 方法:**使用该方法创建一个新的文件对象。该文件对象被分配给一个文件。

这两种方法的区别在于，File.open 方法可以与块相关联，而 File.new 方法不能。

**语法:**

```
f = File.new("fileName.rb")

```

或者，

```
File.open("fileName.rb", "mode") do |f|

```

**创建文件示例**

让我们使用 File.open 方法在 Ruby 中创建一个文件，从文件中读取或写入数据。

**步骤 1)** 在文件 hello.rb 中，编写代码创建一个新文件，如下图所示。

```
#!/usr/bin/ruby 
File.open('about', 'w') do |f| 
    f.puts "This is JavaTpoint" 
    f.write "You are reading Ruby tutorial.\n" 
    f << "Please visit our website.\n" 
end 

```

**步骤 2)** 在控制台中键入以下两个命令查看创建的文件。

```
ruby hello.rb
cat about

```

![Ruby file io 1](img/63e83f3dcb2575e015b81c7c23a6bcb3.png)

如上所示，新文件被创建，内容被显示在终端中。

* * *

## Ruby 读取文件

读取文件有三种不同的方法。

要返回一行，请使用以下语法。

**语法:**

```
f.gets
 code...

```

要在当前位置后返回整个文件，请使用以下语法。

**语法:**

```
f.read
 code...

```

要将文件作为行数组返回，请使用以下语法。

**语法:**

```
f.readlines
 [code...]

```

* * *

## 读取文件的示例

让我们使用 File.open 方法在 Ruby 中创建一个文件，从文件中读取或写入数据。

**步骤 1)** 在文件 hello.rb 中，编写代码读取一个已经存在的文件，如下所示。

```
#!/usr/bin/ruby 
while line = gets 
	puts line 
end 

```

**步骤 2)** 在控制台中键入以下命令读取文件。

```
ruby hello.rb about

```

![Ruby file io 2](img/df9c10e4bc09a890155d88b049cbc5d3.png)

控制台中显示关于文件的内容。

### 系统读取方法

sysread 方法也用于读取文件的内容。借助这种方法，你可以在任何模式下打开一个文件。

**示例:**

在文件 hello.rb 中，编写代码来读取一个已经存在的文件，如下所示。

```
#!/usr/bin/ruby 

aFile = File.new("about.txt", "r") 
if aFile 
   content = aFile.sysread(40) 
   puts content 
else 
   puts "Unable to open file!" 
end

```

输出:

![Ruby file io 3](img/cf909aad86d48eba313864de282443ff.png)

参数 40 将打印到文件中的 40 个字符。

* * *

## Ruby 写文件

借助 syswrite 方法，您可以将内容写入文件。对于此方法，文件需要以写模式打开。

新内容将覆盖现有文件中的旧内容。

**示例:**

```
#!/usr/bin/ruby 

aFile = File.new("about.txt", "r+") 
if aFile 
   aFile.syswrite("New content is written in this file.\n") 
end

```

输出:

![Ruby file io 4](img/abc2798dbe379e547d0947bb1e720cf4.png)

* * *

## Ruby 重命名和删除文件

Ruby 文件使用重命名方法重命名，使用删除方法删除。

要将文件**重命名为**，请使用以下语法。

**语法:**

```
File.rename("olderName.txt", "newName.txt")

```

**示例:**

```
#!/usr/bin/ruby 

File.rename("about.txt", "new.txt") 

```

输出:

![Ruby file io 5](img/a44795020d4573747dfcf279ee0e8eb9.png)

在上面的输出中，about.txt 文件不再存在，因为它的名称已更改为 new.txt 文件。

要删除文件，请使用以下语法。

**语法:**

```
File.delete("filename.txt")

```

**示例:**

```
#!/usr/bin/ruby 

File.delete("new.txt")

```

输出:

![Ruby file io 6](img/e07acd8f9f16158e9100fe0637db79e3.png)

在上面的输出中，new.txt 文件不再存在，因为它已被删除。

* * *