# Ruby 套接字编程

> 原文：<https://www.javatpoint.com/ruby-socket-programming>

套接字是网络通信通道的端点，客户端和服务器在这里相互通信。它们既可以在同一台机器上通信，也可以在不同的机器上通信。

**插座类型:**

*   TCP 套接字
*   UDP 套接字
*   UNIX 套接字

插座有高低两级。低级访问允许您使用系统支持的套接字。它允许实现无连接和面向连接的协议。高级访问允许您使用像 HTTP 和 FTP 这样的网络协议。

### 示例 1

**server1.rb**

```
#!/usr/bin/ruby 
require 'socket' 

server = TCPServer.open(2017) 
loop { 
	client = server.accept 
	client.puts "Hello. This is socket programming" 
	client.close 
} 

```

在上面的代码中，需要包含预安装的插座模块。我们正在系统上使用 2017 端口。你可以使用任何端口。

开始一个循环，接受到端口 2017 的所有连接，并通过套接字网络向客户端发送数据。

最后，关闭插座。

**client1.rb**

```
#!/usr/bin/ruby 
require 'socket' 

hostname = 'localhost' 
port = 2017 

s = TCPSocket.open(hostname, port) 

while line = s.gets 
	puts line.chomp 
end 
s.close 

```

在上面的代码中，需要包含预安装的插座模块。创建一个套接字并将其连接到端口 2017。

创建一个 while 循环来获取通过套接字发送的所有信息。

最后，关闭插座。

**输出:**

转到终端，转到保存上述两个文件的目录。我们已将其保存在桌面目录中。

现在要执行这些文件，我们需要获得所需的权限。在终端中运行以下命令，

```
chmod a+x *.rb

```

这个命令将使这个目录中的所有 Ruby 文件都是可执行的。

![Ruby Socket programming 1](img/f5fbc975c5649f358b0ca80a080b8d3b.png)

现在打开两个终端。在第一终端中执行服务器脚本，在第二终端中使用以下命令执行客户端脚本。

```
ruby filename.rb

```

![Ruby Socket programming 2](img/4beca1a5aaa9e2ae71a975976cc4275d.png)

* * *

## 多客户端套接字编程

对于套接字编程上的多个客户端，需要一个循环和一些线程来接受和响应多个客户端。

### 示例 2

**server3.rb**

```
#!/usr/bin/env ruby -w 
require "socket" 
class Server 
  def initialize( port, ip ) 
    @server = TCPServer.open( ip, port ) 
    @connections = Hash.new 
    @rooms = Hash.new 
    @clients = Hash.new 
    @connections[:server] = @server 
    @connections[:rooms] = @rooms 
    @connections[:clients] = @clients 
    run 
  end 

  def run 
    loop { 
      Thread.start(@server.accept) do | client | 
        nick_name = client.gets.chomp.to_sym 
        @connections[:clients].each do |other_name, other_client| 
          if nick_name == other_name || client == other_client 
            client.puts "This username already exist" 
            Thread.kill self 
          end 
        end 
        puts "#{nick_name} #{client}" 
        @connections[:clients][nick_name] = client 
        client.puts "Connection established..." 
        listen_user_messages( nick_name, client ) 
      end 
    }.join 
  end 

  def listen_user_messages( username, client ) 
    loop { 
      msg = client.gets.chomp 
      @connections[:clients].each do |other_name, other_client| 
        unless other_name == username 
          other_client.puts "#{username.to_s}: #{msg}" 
        end 
      end 
    } 
  end 
end 

Server.new( 2019, "localhost" )

```

在上面的代码中，服务器将与客户端具有相同的端口来建立连接。这里我们需要每个连接的用户有一个线程来处理所有可能的用户。

运行方法验证输入的名称是否唯一。如果用户名已经存在，连接将被终止，否则连接将被建立。

**listen_user_messages** 方法监听用户消息并发送给所有用户。

**client3.rb**

```
#!/usr/bin/env ruby -w 
require "socket" 
class Client 
  def initialize( server ) 
    @server = server 
    @request = nil 
    @response = nil 
    listen 
    send 
    @request.join 
    @response.join 
  end 

  def listen 
    @response = Thread.new do 
      loop { 
        msg = @server.gets.chomp 
        puts "#{msg}" 
      } 
    end 
  end 

  def send 
    puts "Enter your name:" 
    @request = Thread.new do 
      loop { 
        msg = $stdin.gets.chomp 
        @server.puts( msg ) 
      } 
    end 
  end 
end 

server = TCPSocket.open( "localhost", 2019 ) 
Client.new( server )

```

在上面的代码中，创建了类**客户端**来处理用户。

在**发送**和**监听**方法中创建两个线程，这样我们就可以同时读/写消息。

输出:

下面的快照显示了两个客户之间的聊天。

![Ruby Socket programming 3](img/1220225ed3c2ca73003157c3b522081a.png)

服务器终端上的输出如下所示。

![Ruby Socket programming 4](img/b43ecd1e7a5063113a852b040e4834b4.png)

* * *