# Ruby LDAP

> 原文：<https://www.javatpoint.com/ruby-ldap>

Ruby 的 Net::LDAP 也写成了 net::ldap。它代表轻量级目录访问协议。这是一个互联网标准协议，用于访问目录服务器。它的基本搜索单位是实体，对应于一个人或其他特定领域的对象。支持 LDAP 协议的目录通常存储关于许多实体的信息。

## Ruby LDAP 主体

LDAP 服务器通常用于访问有关人员的信息，但有时也用于计算机、打印机和其他资源等项目。

* * *

## Ruby LDAP 可分辨名称

在 LDAP 服务器中，一个实体由一个名为“可分辨名称”的全局唯一文本字符串唯一标识。它就像一个域名系统主机名，一个域名是一串树节点的“扁平”文本表示。

如果您知道一个人或其他实体的域名，您可以在启用了 LDAP 的目录中查询该实体的信息。否则，您还可以看到与您提供的一组标准相匹配的域名列表。

* * *

## Ruby LDAP 属性

在 LDAP 中，关于实体的信息存储为一组属性。属性是与零个或多个值相关联的文本字符串。大多数支持 LDAP 的目录都包含一系列标准化的属性，并根据标准值约束它们的值。

属性的一个例子是 **sn** 。它代表“姓”。这个属性一般用来存储一个人的姓氏。大多数目录都遵循标准惯例，即实体 **sn** 属性只有一个值。

* * *

## Ruby LDAP 树库

就像 DNs 一样，LDAP 假设每个目录服务器包含一组对应于全局目录树特定子树的 DNS 的权威属性数据。该子树在创建时被配置到目录服务器中。您不能在大多数服务器中进行查询，因为它们不允许，除非您指定了正确的树库。

* * *

## Ruby LDAP 版本

Ruby LDAP 版本是存根，讨论 v2 和 v3。

* * *

## Ruby LDAP 操作

Ruby LDAP 操作有:

*   **#bind :** 该#bind 操作向服务器提供用户的身份验证凭证。它们可以提供不同的身份验证凭据，但大多数目录只要求用户名和密码。
*   **# add:**# add 操作指定一个新的 DN 和一组初始属性值。操作成功后，会向目录中添加一个具有相应 DN 和属性的新实体。
*   **#删除:**#删除操作指定一个实体 DN。操作成功后，该实体及其所有属性将从目录中删除。
*   **#重命名:**该#重命名操作也称为#modify_rdn。在早期的 LDAP 版本中，更改实体的 DN 的唯一方法是删除整个实体，并用不同的 DN 再次添加它。但是随着版本 3 中#rename 操作的引入，您可以在不丢弃其属性值的情况下更改 DN。
*   **#search :** 调用#search 操作，通过指定树库、搜索过滤器和属性值列表来识别目录。可以用“非”、“与”和“或”运算符将多个筛选器连接在一起。
*   **# modify:**# modify 操作指定实体 DN 和属性操作列表。它用于更改存储在特定实体目录中的属性值。它可以通过添加或删除属性的值来添加或删除属性或更改属性。有三种方法可以修改属性值:#add_attribute、#delete_attribute 和#replace_attreibute。

* * *

## 安装网络::LDAP

net::LDAP 是一个纯 Ruby 库。它不需要任何外部库。RubyGems 版本的 Net::LDAP 可以从通常的来源安装。

**要求**

Net::LDAP 需要 Ruby 2.0.0 解释器或更好的解释器。

要安装 RubyGems 版本的网络::LDAP，请编写以下命令:

```
gem install net-ldap

```

* * *

## 使用 Ruby 网::LDAP

Net::LDAP 功能首先需要库。

```
require 'net/ldap'

```

如果你已经安装了 Gem 版本，那么你需要以下库。

```
require 'rubygems'
require 'net/ldap'

```

* * *

## 用于 LDAP 连接的凭据

网络::LDAP 连接是一个两步的过程。

**步骤 1 :** 实例化网络:LDAP 对象

大多数网络:LDAP 操作都是从实例化网络:LDAP 对象开始的。构造函数接受指定 LDAP 服务器地址和端口的参数。

**语法:**

```
LDAP::Conn.new(host='localhost', port=LDAP_PORT)

```

**步骤 1 :** 认证(绑定)

在这里，我们需要指定用户名和密码，我们将在会话的其余部分使用。

**语法:**

```
conn.bind(dn=nil, password=nil, method=LDAP::LDAP_AUTH_SIMPLE)do
....
end

```

现在，我们可以通过适当的权限在 bind 方法的块内执行不同的操作，如搜索、修改或删除。

* * *

## 添加新的 LDAP 条目

以下方法向远程 LDAP 服务器添加一个新条目。

```
add(args) => object

```

**步骤 1:** 创建 LDAP::Mod 对象

需要将 LDAP::Mod 对象传递给 conn.add 方法来创建条目。

**语法:**

```
Mod.new(mod_type, attr, vals)

```

**mod_type :** 您可以在这里添加一个或多个选项，如 LDAP_MOD_ADD、LDAP_MOD_DELETE、LDAP_MOD_REPLACE。

**attr :** 是属性的名称。

**val:**它是一组值。

**第二步:**调用 conn.add 方法

创建 LDAP::Mod 对象后，我们需要调用 conn.add 方法。

**语法:**

```
conn.add(dn, attrs)

```

**示例:**

```
#/usr/bin/ruby -w 

require 'rubygems' 
require 'net/ldap' 

$HOST =    'localhost' 
$PORT =    LDAP::LDAP_PORT 
$SSLPORT = LDAP::LDAPS_PORT 

conn = LDAP::Conn.new($HOST, $PORT) 
conn.bind('cn=root, dc=localhost, dc=localdomain','secret') 

conn.perror("bind") 
entry1 = [ 
  LDAP.mod(LDAP::LDAP_MOD_REPLACE, 'sn', ['Steele']), 
] 

begin 
  conn.modify("cn=Anna williams, dc=localhost, dc=localdomain", entry1) 
rescue LDAP::ResultError 
  conn.perror("modify") 
  exit 
end 
conn.perror("modify") 
conn.unbind

```

上例将修改上例中的姓氏。

* * *

## 删除 LDAP 条目

delete 方法将删除一个条目。

**语法:**

```
conn.delete(dn)

```

```
#/usr/bin/ruby -w 

require 'rubygems' 
require 'net/ldap' 

$HOST =   'localhost' 
$PORT =   LDAP::LDAP_PORT 
$SSLPORT = LDAP::LDAPS_PORT 

conn = LDAP::Conn.new($HOST, $PORT) 
conn.bind('cn=root, dc=localhost, dc=localdomain','secret') 

conn.perror("bind") 
begin 
  conn.delete("cn=Anna Steele, dc=localhost, dc=localdomain") 
rescue LDAP::ResultError 
  conn.perror("delete") 
  exit 
end 
conn.perror("delete") 
conn.unbind

```

* * *

## 在 LDAP 中搜索

使用搜索方法执行搜索有三种不同的模式。

*   **LDAP_SCORE_BASEM :** 它将只搜索基本模式。
*   **LDAP_SCOPE_ONLEVEL :** 它将搜索基本模式的所有子模式。
*   **LDAP_SCOPE_SUBTREE :** 将搜索包括基节点在内的整个子树。

**示例:**

```
#/usr/bin/ruby -w 

require 'rubygems' 
require 'net/ldap' 

$HOST =    'localhost' 
$PORT =    LDAP::LDAP_PORT 
$SSLPORT = LDAP::LDAPS_PORT 

base = 'dc=localhost,dc=localdomain' 
scope = LDAP::LDAP_SCOPE_SUBTREE 
filter = '(objectclass=java)' 
attrs = ['sn', 'cn'] 

conn = LDAP::Conn.new($HOST, $PORT) 
conn.bind('cn=root, dc=localhost, dc=localdomain','secret') 

conn.perror("bind") 
begin 
  conn.search(base, scope, filter, attrs) { |entry| 
     # print distinguished name 
     p entry.dn 
     # print all attribute names 
     p entry.attrs 
     # print values of attribute 'sn' 
     p entry.vals('sn') 
     # print entry as Hash 
     p entry.to_hash 
  } 
rescue LDAP::ResultError 
  conn.perror("search") 
  exit 
end 
conn.perror("search") 
conn.unbind 

```

在这个例子中，我们将搜索条目的整个子树。

在搜索的最后一个参数中，您可以指定任何属性。如果传递了 nil，那么所有属性的返回都与关系数据库中的“SELECT”相同。

* * *