# Ruby XML (REXML)

> 原文：<https://www.javatpoint.com/ruby-xml>

XML 是像超文本标记语言一样的可扩展标记语言。它允许程序员开发可以被其他应用程序读取的应用程序，而不考虑所使用的操作系统和开发语言。

它在后端没有任何基于 SQL 的技术的情况下跟踪小到中等数量的数据。

REXML 是一个纯 Ruby XML 处理器。它代表一个完整的 XML 文档，包括 PIs、doctype 等。一个 XML 文档只有一个可以由 root()访问的子文档。如果您想为创建的文档创建一个 XML 声明，您必须添加一个。REXML 文档不会为您编写默认声明。

REXML 的灵感来自于 Java 的电子 XML 库。它的应用编程接口易于使用，体积小，并且在方法命名和代码流方面遵循了 Ruby 方法。

它支持树和流文档解析。Steam 解析比树解析快 1.5 倍。然而，在流解析中，您无法访问像 XPath 这样的特性。

* * *

## REXML 特性:

*   它是 100%用 Ruby 写的。
*   它包含不到 2000 行代码，因此重量更轻。
*   它的方法和类很容易理解。
*   它随 Ruby 安装一起提供。不需要单独安装。
*   它用于 DOM 和 SAX 解析。

## 解析 XML 和访问元素

让我们从解析一个 XML 文档开始:

```
require "rexml/document"
file = File.new( "trial.xml" )
doc = REXML::Document.new file

```

在上面的代码中，第 3 行解析提供的文件。

**示例:**

```
require 'rexml/document' 

include REXML 

file = File.new("trial.xml") 
doc = Document.new(file) 
puts docs

```

在上面的代码中， **require** 语句加载 REXML 库。然后包含 REXML 表明我们不必使用像 REXML::Document 这样的名称。我们已经创建了 trial.xml 文件。文档显示在屏幕上。

输出:

![Ruby XML 1](img/18e2f2c31d454074b25a33a7a4fd0a2d.png)

方法以输入输出、字符串对象或文档为参数。此参数指定必须从中读取 XML 文档的源。

如果文档构造函数将文档作为参数，则其所有元素节点都将克隆到新的文档对象中。如果构造函数采用字符串参数，字符串应该包含一个 XML 文档。

* * *

## 带有“此处文档”的 XML

此处文档是指定文本块的一种方式，保留换行符、空格或文本标识。

此处的文档是使用后跟“<

在 Ruby 中，“<

**示例:**

```
#!/usr/bin/env ruby 

require 'rexml/document' 
include REXML 

info = < <name>Caroline</name> 
 <street>9820 St.</street> 
 <city>Seattle</city> 
 <contact>9854126575</contact> 
 <country>USA</country> 

XML 

document = Document.new( info ) 
puts document 
```

这里，我们在这里使用文档信息。包括<

对于 XML 解析示例，我们将使用以下 XML 文件代码作为输入:

**文件 trial.xml**

```
#!/usr/bin/ruby -w 

require 'rexml/document' 
include REXML 
xmlfile = File.new("trial.xml") 
xmldoc = Document.new(xmlfile) 

# Now get the root element 
root = xmldoc.root 
puts "Root element : " + root.attributes["shelf"] 

# This will output all the cloth titles. 
xmldoc.elements.each("collection/clothing"){ 
   |e| puts "cloth Title : " + e.attributes["title"] 
} 

# This will output all the cloth types. 
xmldoc.elements.each("collection/clothing/type") { 
   |e| puts "cloth Type : " + e.text 
} 

# This will output all the cloth description. 
xmldoc.elements.each("collection/clothing/description") { 
   |e| puts "cloth Description : " + e.text 
}

```

* * *

## Ruby XML 类 DOM 解析

我们将以树的方式解析我们的 XML 数据。上述文件 trial.xml 代码作为输入。

```
#!/usr/bin/ruby -w 

require 'rexml/document' 
include REXML 

xmlfile = File.new("trial.xml") 
xmldoc = Document.new(xmlfile) 

# Now get the root element 
root = xmldoc.root 
puts "Root element : " + root.attributes["shelf"] 

# This will output all the cloth titles. 
xmldoc.elements.each("collection/clothing"){ 
   |e| puts "cloth Title : " + e.attributes["title"] 
} 

# This will output all the cloth types. 
xmldoc.elements.each("collection/clothing/type") { 
   |e| puts "cloth Type : " + e.text 
} 

# This will output all the cloth description. 
xmldoc.elements.each("collection/clothing/description") { 
   |e| puts "cloth Description : " + e.text 
}

```

输出:

![Ruby XML 2](img/55fe31b93e70d42219ea20f07590ac81.png)

* * *

## 类语法分析

我们将以流的方式解析我们的 XML 数据。上述文件 trial.xml 代码作为输入。这里，我们将定义一个侦听器类，它的方法将作为解析器回调的目标。

建议不要对小文件使用类似 SAX 的解析。

```
#!/usr/bin/ruby -w 

require 'rexml/document' 
require 'rexml/streamlistener' 
include REXML 

class MyListener 
  include REXML::StreamListener 
  def tag_start(*args) 
    puts "tag_start: #{args.map {|x| x.inspect}.join(', ')}" 
  end 

  def text(data) 
    return if data =~ /^\w*$/     # whitespace only 
    abbrev = data[0..40] + (data.length > 40 ? "..." : "") 
    puts "  text   :   #{abbrev.inspect}" 
  end 
end 

list = MyListener.new 
xmlfile = File.new("trial.xml") 
Document.parse_stream(xmlfile, list)

```

输出:

![Ruby XML 3](img/f1108d431ab56d901ef7313a3c1ffe09.png)

* * *