# 执行功能

> 原文：<https://www.javatpoint.com/go-functions>

在围棋中，函数是基本的构造块。函数用于将大问题分解成小任务。我们可以多次调用一个函数，因此函数提高了代码的可重用性。Go 中有 3 种功能:

*   带标识符的普通函数
*   匿名或 lambda 函数
*   方法(带接收器的功能)

函数参数、返回值和类型一起被称为*函数签名。*

函数不能在另一个函数中声明。如果我们想实现这一点，我们可以通过匿名函数来实现。

### Go 函数示例

```
package main
import "fmt"
type Employee struct {
   fname string
   lname string
}
func (emp Employee) fullname(){
   fmt.Println(emp.fname+" "+emp.lname)
}
func main() {
   e1 := Employee{ "John","Ponting"}
   e1.fullname()
}

```

输出:

```
John Ponting

```

### 带返回的 Go 函数

让我们看一个带有返回值的函数的例子。

```
package main
import (
   "fmt"
)
func fun() int {
   return 123456789
}
func main() {
   x := fun()
   fmt.Println(x)
}

```

输出:

```
123

```

### 多重返回的 Go 函数

让我们看一个函数的例子，它以 n 个 int 类型的数字作为参数，并返回两个 int 值。返回值在并行赋值的调用函数中填充。

**Go 功能多次返回示例**

```
package main
import (
   "fmt"
)
func main() {
   fmt.Println(addAll(10,15,20,25,30))
}
func addAll(args ... int)(int,int)  {
   finalAddValue:=0
   finalSubValue:=0
   for _,value  := range args{
      finalAddValue += value
      finalSubValue -= value
   }
   return finalAddValue,finalSubValue
}

```

输出:

```
100 -100

```