# go 字符串

> 原文：<https://www.javatpoint.com/go-string>

Go 字符串是可变宽度字符的序列。

Go 字符串和文本文件占用的内存或磁盘空间较少。因为 UTF-8 是标准，Go 不需要对字符串进行编码和解码。

Go Strings 是值类型，不可变。这意味着如果创建一个字符串，就不能修改字符串的内容。默认情况下，字符串的初始值为空“”。

### 转到字符串示例

```
package main
import ("fmt"
      "reflect"
)
func main()  {
   var x string = "Hello World"
   fmt.Println(x)
   fmt.Println(reflect.TypeOf(x))
}

```

输出:

```
Hello World
string

```

### Go 字符串透镜()示例

```
package main
import "fmt"
func main() {
   str := "I love my country"
   fmt.Println(len(str))
}

```

输出:

```
17

```

### 转到打印 ASCII 示例

```
package main
import "fmt"
func main() {
   fmt.Println("Ascii value of A is ","A"[0])
}

```

输出:

```
Ascii value of A is  65

```

### 转到字符串映射器()示例

```
package main
import "fmt"
import "strings"
func main() {
   str := "india"
   fmt.Println(strings.ToUpper(str))
}

```

输出:

```
INDIA

```

### 转到字符串下拉列表()示例

```
package main
import "fmt"
import "strings"
func main() {
   str := "INDIA"
   fmt.Println(strings.ToLower(str))
}

```

输出:

```
india

```

### 转到字符串前缀()示例

```
package main
import "fmt"
import "strings"
func main() {
   s := "INDIA"
   fmt.Println(strings.HasPrefix(s,"IN"))
}

```

输出:

```
true

```

### Go 字符串 HasSuffix()示例

```
package main
import "fmt"
import "strings"
func main() {
   s := "INDIA"
   fmt.Println(strings.HasSuffix(s,"IA"))
}

```

输出:

```
true

```

### 转到字符串连接()示例

```
package main
import "fmt"
import "strings"
func main() {
   var arr = []string{"a","b","c","d"}
   fmt.Println(strings.Join(arr,"*"))
}

```

输出:

```
a*b*c*d

```

### 转到字符串重复()示例

```
package main
import "fmt"
import "strings"
func main() {
   var str = "New "
   fmt.Println(strings.Repeat(str,4))
}

```

输出:

```
New New New New 

```

### 转到字符串包含()示例

```
package main
import "fmt"
import "strings"
func main() {
   str:= "Hi...there"
   fmt.Println(strings.Contains(str,"th"))
}

```

输出:

```
true

```

### 转到字符串索引()示例

```
package main
import "fmt"
import "strings"
func main() {
   str:= "Hi...there"
   fmt.Println(strings.Index(str,"th"))
}

```

输出:

```
5

```

### 转到字符串计数()示例

```
package main
import "fmt"
import "strings"
func main() {
   str:= "Hi...there"
   fmt.Println(strings.Count(str,"e"))
}

```

输出:

```
2

```

### 转到字符串替换()示例

```
package main
import "fmt"
import "strings"
func main() {
   str:= "Hi...there"
   fmt.Println(strings.Replace(str,"e","Z",2))
}

```

输出:

```
Hi...thZrZ  

```

### 转到字符串拆分()示例

```
package main
import "fmt"
import "strings"
func main() {
   str := "I,love,my,country"
   var arr []string = strings.Split(str, ",")
   fmt.Println(len(arr))
   for i, v := range arr {
      fmt.Println("Index : ", i, "value : ", v)
   }
}

```

输出:

```
4
Index :  0 value :  I
Index :  1 value :  love
Index :  2 value :  my
Index :  3 value :  country

```

### 转到字符串分割()示例 2

```
package main
import (
   "fmt"
   "strings"
)
func main() {
   fmt.Printf("%q\n", strings.Split("x,y,z", ","))
   fmt.Printf("%q\n", strings.Split(" John and Jack and Johnny and Jinn ", "and"))
   fmt.Printf("%q\n", strings.Split(" abc ", ""))
   fmt.Printf("%q\n", strings.Split("", "Hello"))
}

```

输出:

```
["x" "y" "z"]
[" John " " Jack " " Johnny " " Jinn"]
[" " "a" "b" "c" " "]
[""]

```

### 转到字符串比较()示例

```
package main
import (
   "fmt"
   "strings"
)
func main() {
   fmt.Println(strings.Compare("a", "b"))
   fmt.Println(strings.Compare("a", "a"))
   fmt.Println(strings.Compare("b", "a"))
}

```

输出:

```
-1
0
1

```

### 转到字符串修剪()示例

```
package main
import (
   "fmt"
   "strings"
)
func main() {
      fmt.Println(strings.TrimSpace(" \t\n I love my country  \n\t\r\n"))
}

```

输出:

```
I love my country

```

### Go 字符串包含任意()示例

```
package main
import (
   "fmt"
   "strings"
)
func main() {
   fmt.Println(strings.ContainsAny("Hello", "A"))
   fmt.Println(strings.ContainsAny("Hello", "o & e"))
   fmt.Println(strings.ContainsAny("Hello", ""))
   fmt.Println(strings.ContainsAny("", ""))
}

```

输出:

```
false
true
false
false

```