# 转到地图

> 原文：<https://www.javatpoint.com/go-map>

在围棋中，地图是一个无序的键及其相关值的集合。它们非常适合快速查找值。键类型必须具有操作==和！=已定义，如 string、int、float。

因此，数组、片和结构不能用作键类型，但指针和接口类型可以。

当我们提供 key()或 Hash()方法时，结构可以用作键，这样就可以从结构的字段中计算出唯一的数字或字符串键。

映射是一种引用类型，通常声明为:

```
var map1 map[keytype]valuetype

```

**例如**

```
var map1 map[int]string

```

## 前往地图示例

```
package main
import "fmt"
func main ()  {
   x := map[string]int{"Kate":28,"John":37, "Raj":20}
   fmt.Print(x)
   fmt.Println("\n",x["Raj"])
}

```

输出:

```
map[John:37 Raj:20 Kate:28]
 20

```

## 执行地图插入和更新操作

更新和插入操作在 go map 中类似。如果映射不包含提供的键，将进行插入操作，如果键存在于映射中，则进行更新操作。

```
package main
import "fmt"
func main() {
   m := make(map[string]int)
   fmt.Println(m)
   m["Key1"] = 10
   m["Key2"] = 20
   m["Key3"] = 30
   fmt.Println(m)
   m["Key2"] = 555
   fmt.Println(m)
}

```

输出:

```
map[]
map[Key3:30 Key1:10 Key2:20]
map[Key1:10 Key2:555 Key3:30]

```

* * *

## 执行地图删除操作

您可以使用 delete()函数删除 Go Map 中的元素。

语法:

```
delete(map, key)

```

示例:

```
package main
import "fmt"
func main() {
   m := make(map[string]int)
   m["Key1"] = 10
   m["Key2"] = 20
   m["Key3"] = 30
   fmt.Println(m)
   delete(m, "Key3")
   fmt.Println(m)
}	

```

输出:

```
map[Key1:10 Key2:20 Key3:30]
map[Key2:20 Key1:10]

```

* * *

## 转到地图检索元素

语法:

```
elem = m[key]

```

示例:

```
package main
import "fmt"
func main() {
   m := make(map[string]int)
   m["Key1"] = 10
   m["Key2"] = 20
   m["Key3"] = 30
   fmt.Println(m)
   fmt.Println("The value:", m["Key2"])
}

```

输出:

```
map[Key1:10 Key2:20 Key3:30]
The value: 20

```

我们还可以用两个值的例子来测试表中是否存在一个键

语法:

```
elem, ok = m[key]

```

如果键不存在，则 elem 的值是元素类型的默认值。

如果 elem 的类型是 int，那么 elem 的值为零。

```
package main
import "fmt"
func main() {
   m := make(map[string]int)
   m["Key1"] = 10
   m["Key2"] = 20
   m["Key3"] = 30
   fmt.Println(m)
   v, ok := m["Key2"]
   fmt.Println("The value:", v, "Present?", ok)
   i, j := m["Key4"]
   fmt.Println("The value:", i, "Present?", j)
}

```

输出:

```
map[Key1:10 Key2:20 Key3:30]
The value: 20 Present? true
The value: 0 Present? false

```

在围棋中，地图就像结构，但它需要键

## 结构的 Go 图

```
package main
import "fmt"
type Vertex struct {
   Latitude, Longitude float64
}
var m = map[string]Vertex{
   "JavaTpoint": Vertex{     40.68433, -74.39967,   },
   "SSS-IT": Vertex{     37.42202, -122.08408,  },
}
func main() {
   fmt.Println(m)
}

```

输出:

```
map[JavaTpoint:{40.68433 -74.39967} SSS-IT:{37.42202 -122.08408}]

```