# 执行错误

> 原文：<https://www.javatpoint.com/go-error>

Go 没有像 Java 中的 try/catch 那样的异常机制，我们不能在 Go 中抛出异常。

围棋采用了一种不同的机制，即*延迟-恐慌-恢复机制。*

Go 通过返回一个错误对象来处理函数和方法的简单错误。错误对象可能是唯一的或最后的返回值。如果函数中没有错误，则错误对象为零。

如果我们收到或没有收到任何错误，我们应该总是检查调用语句的错误。

我们永远不要忽视错误，它可能会导致程序崩溃。

检测和报告错误情况的方法是

*   一个可能导致错误的函数返回两个变量:一个值和一个在成功时为零的错误代码，以及！=错误情况下为零。
*   在函数调用后，检查错误。如果出错(如果出错！= nil)时，实际函数(或必要时整个程序)的执行停止。

Go 具有预定义的错误接口类型

```
type error interface {
		Error() string
}	

```

我们可以使用错误来定义错误类型。错误包中的新内容，并提供适当的错误消息，如:

```
err := errors.New("math - square root of negative number")

```

### Go 错误示例

```
package main
import "errors"
import "fmt"
import "math"
func Sqrt(value float64) (float64, error) {
   if (value < 0) {
      return 0, errors.New("Math: negative number passed to Sqrt")
   }
   return math.Sqrt(value), nil
}
func main() {
   result, err := Sqrt(-64)
   if err != nil {
      fmt.Println(err)
   } else {
      fmt.Println(result)
   }
   result, err = Sqrt(64)
   if err != nil {
      fmt.Println(err)
   } else {
      fmt.Println(result)
   }
}

```

输出:

```
Math: negative number passed to Sqrt
8

```