# 转到并发

> 原文：<https://www.javatpoint.com/go-concurrency>

大型程序被分成较小的子程序。同时运行较小组件的程序称为并发。

## 戈里普斯

并发运行的应用程序部分称为 goroutines。Goroutines 和 channels 用于构建并发程序。

进程是运行在机器中的独立执行实体，它运行在内存中自己的地址空间中。一个进程有同时执行实体的线程。线程共享同一个进程地址空间。

Goroutines 很轻，比线轻得多。Goroutines 在同一个地址空间中运行，因此对共享内存的访问必须同步；这可以通过同步包来完成，但建议使用通道来同步 goroutines。

goroutine 是作为函数或方法实现的。它是用“go”关键字调用的。当 goroutine 结束时，没有任何东西返回给调用者函数。

## Go 并发示例

```
package main
import (
   "fmt"
   "time"
   "sync"
)
var wg = sync.WaitGroup{}

func main() {
   wg.Add(2)
   go fun1()
   go fun2()
   wg.Wait()
}
func fun1(){
   for  i:=0;i<10;i++{
      fmt.Println("fun1,  ->",i)
      time.Sleep(time.Duration(5*time.Millisecond))
   }
   wg.Done()
}
func fun2(){
   for i:=0;i<10;i++{
      fmt.Println("fun2,  ->",i)
      time.Sleep(time.Duration(10*time.Millisecond))
   }
   wg.Done()
}

```

输出:

```
fun2,  -> 0
fun1,  -> 0
fun1,  -> 1
fun2,  -> 1
fun1,  -> 2
fun1,  -> 3
fun2,  -> 2
fun1,  -> 4
fun1,  -> 5
fun2,  -> 3
fun1,  -> 6
fun1,  -> 7
fun2,  -> 4
fun1,  -> 8
fun1,  -> 9
fun2,  -> 5
fun2,  -> 6
fun2,  -> 7
fun2,  -> 8
fun2,  -> 9

```