# 转到员工池

> 原文：<https://www.javatpoint.com/go-worker-pools>

工作人员池是一种设计，其中固定数量的 m 个工作人员(Go goroutines)在工作队列(Go channel)中处理 n 个任务。该工作驻留在队列中，直到工作人员完成其当前任务并拉出新任务。

让我们通过一个例子来看看

```
package main

import (
"fmt"
"time"
)

func worker(id int, jobs <-chan int, results chan<- int) {
	for j := range jobs {
		fmt.Println("worker", id, "processing job", j)
		time.Sleep(time.Second)
		results <- j * 2
	}
}

func main() {
	job := make(chan int, 10)
	result := make(chan int, 10)
	for w := 1; w <= 2; w++ {
		go worker(w, job, result)
	}
	for j := 1; j <= 9; j++ {
		job <- j
	}
	close(job)
	for a := 1; a <= 9; a++ {
		<-result
	}
}

```

输出:

```
worker 2 processing job 1
worker 1 processing job 2
worker 2 processing job 3
worker 1 processing job 4
worker 1 processing job 5
worker 2 processing job 6
worker 1 processing job 7
worker 2 processing job 8

```

在本例中，2 名工人开始工作，9 个工作项目被放到一个工作通道中。工人有一个带时间的工作循环。睡觉时，每个人都要做两份工作。所有工作都放在通道上后，通道上使用 close，它向所有 2 名工作人员发出信号，让他们退出工作循环范围。