# 去买票

> 原文：<https://www.javatpoint.com/go-tickers>

当我们想在固定的时间间隔内完成一些工作时，就使用 Go Tickers。可以使用 Stop()方法像计时器一样停止计时器。

NewTicker()方法返回一个新的 Ticker，它有一个根据持续时间参数发送时间的通道。持续时间必须大于零，否则跑马灯会死机。

Tick()是 NewTicker 的包装器，它提供对 Tick 通道的访问。Tick()方法对于不想关闭 Ticker 的客户端很有用。

### 围棋票示例

```
package main
import "time"
import "fmt"
func main() {
	tickerValue := time.NewTicker(time.Millisecond * 100)
	go func() {
		for t := range tickerValue.C {
			fmt.Println("Tick at", t)
		}
	}()
	time.Sleep(time.Millisecond * 500)
	tickerValue.Stop()
	fmt.Println("Ticker stopped")
}

```

输出:

```
Tick at 2017-10-07 17:26:35.946279716 +0530 IST m=+0.101345812
Tick at 2017-10-07 17:26:36.046371811 +0530 IST m=+0.201437907
Tick at 2017-10-07 17:26:36.146417657 +0530 IST m=+0.301483753
Tick at 2017-10-07 17:26:36.24851386 +0530 IST m=+0.403579956
Tick at 2017-10-07 17:26:36.346476978 +0530 IST m=+0.501543074
Ticker stopped

```

### Go 跑马灯示例 2

```
package main
import (
	"log"
	"time"
)
func haveFun(s string) {
	log.Printf("\tA: Let's have fun: %v", s)
}
func doPolling() {
	for _ = range time.Tick(2 * time.Second) {
		haveFun("\t B : Okay!")
	}
}
func main() {
	go doPolling()
	select {} //The select statement lets a goroutine wait on multiple communication operations.
}

```

输出:

```
2017/10/07 18:15:15 	A: Let's have fun: 	 B : Okay!
2017/10/07 18:15:17 	A: Let's have fun: 	 B : Okay!
2017/10/07 18:15:19 	A: Let's have fun: 	 B : Okay!
2017/10/07 18:15:21 	A: Let's have fun: 	 B : Okay!
2017/10/07 18:15:23 	A: Let's have fun: 	 B : Okay!
2017/10/07 18:15:25 	A: Let's have fun: 	 B : Okay!

```