# 去分类

> 原文：<https://www.javatpoint.com/go-sorting>

Go 有一个排序包，可以用来对内置的和用户定义的数据类型进行排序。

排序包有不同的方法对不同的数据类型进行排序，如 int()，Float64s()，Strings()等。

我们可以通过使用像 Float64sAreSorted()，IntsAreSorted()等方法来检查值是否排序。

### 转到排序示例

```
package main
import (
	"sort"
	"fmt"
)
func main() {

	intValue := []int{10, 20, 5, 8}
	sort.Ints(intValue)
	fmt.Println("Ints:   ", intValue)

	floatValue := []float64{10.5, 20.5, 5.5, 8.5}
	sort.Float64s(floatValue)
	fmt.Println("floatValue:   ", floatValue)

	stringValue := []string{"Raj", "Mohan", "Roy"}
	sort.Strings(stringValue)
	fmt.Println("Strings:", stringValue)

	str := sort.Float64sAreSorted(floatValue)
	fmt.Println("Sorted: ", str)
}

```

输出:

```
Ints:    [5 8 10 20]
floatValue:    [5.5 8.5 10.5 20.5]
Strings: [Mohan Raj Roy]
Sorted:  true

```

我们还可以实现自己的排序模式，假设我们想根据字符串的长度对它进行排序。为了做到这一点，我们必须实现排序接口中定义的我们自己的 Less、Len 和 Swap 方法。

然后，我们必须将数组转换为实现的类型。

```
package main
import "sort"
import "fmt"

type  OrderByLengthDesc []string
func (s OrderByLengthDesc) Len() int {
	return len(s)
}
func (str OrderByLengthDesc) Swap(i, j int) {
	str[i], str[j] = str[j], str[i]
}
func (s OrderByLengthDesc) Less(i, j int) bool {
	return len(s[i]) > len(s[j])
}
func main() {
	city := []string{"New York", "London","Washington","Delhi"}
	sort.Sort(OrderByLengthDesc(city))
	fmt.Println(city)
}

```

输出:

```
[Washington New York London Delhi]

```