# 参考文献和借用

> 原文：<https://www.javatpoint.com/rust-references-and-borrowing>

**引用**是作为参数传递给函数的地址。**借**就像我们借了一样东西，用完了再还。引用和借用是相互的，也就是说，当引用被释放时，借用也就结束了。

## 为什么借款？

使用借用概念的原因如下:

*   借用允许对单个资源有多个引用，但仍然服从“单个所有者”。
*   引用就像 c 语言中的指针。
*   引用是一个对象。引用有两种类型，即可变引用和不可变引用。可变引用被移动，而不可变引用被复制。

**我们通过一个例子来理解这一点。**

```

 fn main()
{
 let str=String::from("javaTpoint");
 let len=calculate_length(&str);
 println!("length of the string {}",len);
}
fn calculate_length(s:&String)->usize
{
  s.len()
}

```

**输出:**

```
length of the string 10

```

在上面的例子中，calculate_length()函数引用了 string str 作为参数，但没有取得它的所有权。

```

 let str=String::from("javaTpoint");
let len=calculate_length(&str);

```

在上面的场景中，&str 是对变量 str 的引用，但它并不拥有它。因此，即使引用超出范围，引用所指向的值也不会被删除。

```

 fn calculate_length(s:&String)->usize
{
  s.len()
}

```

在上面的例子中，变量“s”在控件没有返回 main()函数之前是有效的。当变量作为对函数的引用而不是实际值传递时，那么我们不需要返回值来归还所有权。

**我们试着修改借用值。**

```

 fn main()
{
 let x=1;
 value_changed(&x)
}
fn value_changed(y:&i32)
{
 *y=9;
}

```

**以下是上述程序的输出:**

![Rust References and Borrowing](img/6734bb0d350e89a244690de4f0516d14.png)

在上面的例子中，它抛出一个错误，因为&x 是一个不可变的引用。因此，我们不能改变 y 的值。

## 可变引用

我们可以通过使用可变引用来修复上述错误。可变引用是那些可变的引用。让我们通过一个例子来理解这一点。

```

 fn main()
{
 let mut x=1;
 value_changed(&mut x);
 println!("After modifying, the value of x is {}",x);
}
fn value_changed(y:&mut i32)
{
 *y=9;
}

```

**输出:**

```
After modifying, the value of x is 9

```

在上面的例子中，我们创建了一个可变引用，即&mut x，该引用由&i32 类型的变量 y 指向。现在，我们可以更改“y”变量引用的值。我们给 9 赋值，即*y=9。因此，x 值也变成了 9，因为这两个变量引用了相同的内存位置。

## 可变引用的限制

*   在特定范围内，我们只能有一个对数据的可变引用。

**例如:**

```

 let mut str=String::from("javaTpoint");
let a= &mut str;
let b= &mut str; 

```

在上面的场景中，编译器抛出一个错误，因为它包含两个在 Rust 语言中不可能的可变引用。

*   如果不可变引用存在于我们的程序中，那么我们的程序中就不能有可变引用。

**例如:**

```

 let mut str=String::from("javaTpoint");
let a= &str;
let b=&str;
let c=&mut str; 

```

在上面的场景中，编译器抛出了一个错误，因为我们不能有一个可变的引用，而我们有一个不可变的引用。

* * *