# 引用不同模块中的名称

> 原文：<https://www.javatpoint.com/rust-module-use-keyword>

当我们调用模块的函数时，我们需要指定完整的路径。

**我们通过一个例子来理解这个概念:**

```

 pub mod a
{
  pub mod b
  {
    pub mod c
    {
      pub fn nested_modules()
      {
        println!("Nested Modules");
      }
    }
  }
 }

fn main()
{
 a::b::c::nested_modules();
}

```

**输出:**

```
Nested Modules

```

在上例中，nested_modules()函数是通过指定完整路径调用的，即**a::b::c::nested _ modules()**。

## 使用关键字

在上面的场景中，我们看到函数调用非常长。Rust **“使用关键字”**缩短函数调用的长度，将函数的模块纳入范围。use 关键字只带来那些我们在作用域中指定的模块。让我们通过一个例子来理解这一点:

```

 pub mod a
{
  pub mod b
  {
    pub mod c
    {
      pub fn nested_modules()
      {
        println!("Nested Modules");
      }
    }
  }
 }

use a::b::c::nested_modules;
fn main()
{
  nested_modules();
}

```

**输出:**

```
Nested Modules

```

在上面的例子中，use 关键字包括范围内的所有模块。因此，我们可以直接调用函数，而不需要在调用函数中包含模块。

枚举也是一种类似模块的命名空间形式。因此，我们可以使用 use 关键字将枚举变量纳入范围。在**使用**语句中，我们可以在花括号中列出枚举变量，在最后一个位置列出逗号。

**我们通过一个例子来了解一下:**

```

 #[derive(Debug)]
enum Flagcolor
{
 Orange,
 White,
 Green,
}
use Flagcolor::{Orange,White,Green};
fn main()
{
  let _o= Orange;
  let _w= White;
 let _g= Green;
 println!("{:?}",_o);
println!("{:?}",_w);
println!("{:?}",_g);
}

```

**输出:**

```
orange
white
green

```

在上面的例子中，标志色是命名空间，其变体在 use 语句中指定。因此，我们可以直接使用枚举变量，而不使用枚举名称和命名空间说明符。

## 使用“*”运算符

*运算符用于将所有项目纳入范围，这也称为 glob 运算符。如果我们使用 glob 运算符，那么我们不需要单独指定枚举变量。

**我们通过一个例子来了解一下:**

```

 #[derive(Debug)]
enum Color
{
  Red,
  Yellow,
  Green,
  Orange,
}

use Color::*;
fn main()
{
  let _red=Red;
  let _yellow=Yellow;
  let _green=Green;
  let _orange=Orange;
  println!("{:?}",_red);
  println!("{:?}",_yellow); 
  println!("{:?}",_green);
  println!("{:?}",_orange);
}

```

**输出:**

```
Red
Yellow
Green
Orange

```

在上面的示例中，使用了' * '运算符来包含所有枚举变量，而没有在 use 语句中指定列表。

## 超级关键词的使用

**超级关键字**用于从当前模块访问祖父母模块。它使我们能够访问父模块的私有功能。

```

 mod a{
fn x() -> u8 {
    5
}

pub mod example {
    use super::x;

    pub fn foo() {
        println!("{}",x());
    }
}}

fn main()
{
  a::example::foo();
}

```

**输出:**

```
5

```

在上面的示例中，模块示例使用了引用其父模块的 super。由于这个原因，模块示例的 foo()函数可以访问模块 a 的私有函数。

* * *