# 什么是向量？

> 原文：<https://www.javatpoint.com/rust-vector>

向量是一种单一的数据结构，它使您能够在内存中存储多个相邻的值。当我们有一个物品列表时，比如购物车中的物品，向量是很有用的。

**要点:**

*   向量用于存储相同类型的值。
*   矢量用**Vec<T>T1 表示。**
*   **Vec < T >** 由标准库提供，标准库可以保存任何类型的数据，其中 **T** 确定向量的类型。
*   向量的数据被分配在堆上。
*   向量是一个可增长的数组，这意味着新元素可以在运行时添加。

**Vec < T >** :当一个向量包含特定的类型时，它被表示在角括号中。

## 如何创建向量？

可以使用 Vec::new()函数创建一个向量。让我们看看这个:

```

Let v : Vec<i32> = Vec::new();

```

在上面的声明中，v 是 i32 类型的向量，它是使用 Vec::new()函数创建的。

*   **还有一种方法可以创建向量:**

Rust 提供 vec！宏来创建向量并保存我们提供的值。

**例如:**

```

let v = vec![10,20,30,40,50]; 

```

在上面的声明中，向量 v 是使用向量宏创建的，即 vec！。在 vec 的情况下！，Rust 自动推断向量 v 的类型是 Vec <i32>，因为向量宏包含整数值。</i32>

#### 注意:如果我们想重复向量的初始值，那么也有另一种实现 vec 的方法！：

```

let v = vec![2 ; i];

```

在上面的声明中，向量“v”是使用向量宏创建的，它包含值 2“I”倍。

## 访问元素

使用下标运算符[]可以访问向量的特定元素。

**我们通过一个例子来了解一下:**

```

fn main()
{
let v =vec![20,30,40,50];
println!("first element of a vector is :{}",v[0]);
println!("Second element of a vector is :{}",v[1]);
println!("Third element of a vector is :{}",v[2]);
println!("Fourth element of a vector is :{}",v[3]);
}

```

**输出:**

```
first element of a vector is :20
Second element of a vector is :30
Third element of a vector is :40
Fourth element of a vector is :50

```

*   访问向量元素的第二种方式是使用 get(index)方法，将向量的索引作为参数传递，并返回类型为 Option 的值。

**我们通过一个例子来了解一下:**

```

             fn value(n:Option<&i32>)
            {
                match n
                {
                      Some(n)=>println!("Fourth element of a vector is {}",n),
                      None=>println!("None"),
                 }
}
fn main()
{
let v =vec![20,30,40,50];
let a: Option<&i32>=v.get(3);
value(a);
}

```

**输出:**

```
Fourth element of a vector is 50

```

在上面的例子中，get()方法用于访问向量的第四个元素。

## [] &get()方法之间的区别:

当我们使用[]运算符访问不存在的元素时，它会导致程序死机。因此，当我们试图访问不存在的元素时，程序会崩溃。如果我们尝试使用 get()方法访问元素，那么它会返回 None 而不会惊慌。

**我们通过一个例子来了解一下:**

*   **获取(索引)**

```

fn value(n:Option<&i32>)
{
 match n
 {
   Some(n)=>println!("Fourth element of a vector is {}",n),
   None=>println!("None"),
 }
}
fn main()
{
let v =vec![20,30,40,50];
let a: Option<&i32>=v.get(7);
value(a);
}

```

**输出:**

```
None

```

*   **[ ]操作员**

```

fn main()
{
let v =vec![20,30,40,50];
println!("{}",v[8]);
}

```

**输出:**

![Rust Vector](img/1b9dbf35300035dd58adcc6d15ab40cb.png)

## 迭代向量中的值

如果我们想要访问向量的每个元素，那么我们可以迭代向量的元素，而不是使用索引来访问向量的特定元素。

我们可以使用“for”循环来迭代可变或不可变的引用。

**我们来看一个不可变引用的简单例子:**

```

fn main()
{
let v =vec![20,30,40,50];
print!("Elements of vector are :");
for i in v
{
  print!("{} ",i);
}
            }

```

**输出:**

```
Elements of vector are :20 30 40 50

```

**让我们来看一个可变引用的简单例子:**

```

fn main()
{
let mut v =vec![20,30,40,50];
print!("Elements of vector are :");
for i in &mut v
{
*i+=20;
  print!("{} ",i);
}
}

```

**输出:**

```
Elements of vector are :20 30 40 50

```

在上面的例子中，我们改变了向量的值。因此，向量是一个可变的引用。在“I”变量之前使用取消引用(*)运算符来获取向量 v 的值。

## 更新向量

当我们创建向量时，我们使用 push()方法将元素插入到向量中。push()在向量的末尾插入新元素。

**我们来看一个简单的例子:**

```

fn main()
{
  let mut v=Vec::new();
  v.push('j');
  v.push('a');
  v.push('v');
  v.push('a');
  for i in v
  {
    print!("{}",i);
  }
}

```

**输出:**

```
java

```

在上面的例子中，push()函数用于在运行时将元素插入到向量中。向量“v”是可变的，因此我们也可以改变向量的值。

## 丢弃向量

当一个向量超出范围时，它会被自动丢弃或从内存中释放。

让我们通过一个简单的场景来理解这一点:

```

fn main()
{
   let v = !vec[30,40,50];
   } => v is freed here as it goes out of the scope.

```

在上面的场景中，当一个向量超出范围时，它将被释放，这意味着向量中存在的所有元素都将被移除。

## 使用枚举存储多种类型

向量可以存储相同类型的元素，这是向量的一大缺点。枚举是一种自定义数据类型，它包含同一枚举名称下各种类型的变体。当我们想要将元素存储在不同类型的向量中时，我们使用枚举类型。

**我们通过一个例子来了解一下:**

```

#[derive(Debug)]
enum Values {
   A(i32),
   B(f64), 
   C(String),
}

fn main() 
{
     let v = vec![Values::A(5), 
     Values::B(10.7),Values::C(String::from("javaTpoint"))];
     for i in v
    {
	   println!("{:?}",i);
     }
}

```

**输出:**

```
A(5)
B(10.7)
C(javaTpoint)

```

### 在向量中使用枚举的优点:

*   Rust 在编译时知道向量元素的类型，以确定每个元素在堆上需要多少内存。
*   当向量由一种或多种类型的元素组成时，对这些元素执行的操作将导致错误，但是使用带有匹配的**枚举将确保在运行时可以处理所有可能的情况。**

* * *