# Rust可恢复错误

> 原文：<https://www.javatpoint.com/rust-recoverable-errors>

*   可恢复错误是那些不严重到完全停止程序的错误。可以处理的错误称为可恢复错误。
*   由结果<t e="">表示。结果<t e="">是由两个变量组成的枚举，即正常<t>和错误<e>。它描述了可能的错误。</e></t></t></t>

**OK<T>**:“T”是一种在成功情况下返回 OK 变量的值。这是预料之中的结果。

**错误<E>**:“E”是一种在失败时返回错误变量的错误类型。这是一个意想不到的结果。

```

 Enum Result<T,E>
{
    OK<T>,
    Err<E>,
}

```

*   在上述情况下，Result 是枚举类型，**OK<T>&Err<E>**是枚举类型的变体，其中**“T”**和**“E”**是泛型类型参数。
*   “t”是一种将在成功情况下返回的值，“E”是一种将在失败情况下返回的错误类型。
*   **结果**包含泛型类型参数，因此我们可以在成功和失败值可能不同的许多不同情况下使用标准库中定义的结果类型和函数。

**我们来看一个返回 Result 值的简单例子:**

```

           use std::fs::File;
          fn main() 
         {
              let f:u32 = File::open("vector.txt");
         }

```

**输出:**

![Rust Recoverable Errors](img/5b4e76632fd77f74f4269e9042604c2e.png)

在上例中，Rust 编译器显示类型不匹配。“f”是 u32 类型，而文件::打开返回结果<t e="">类型。上面的输出显示成功值的类型是 std::fs:: File，错误值的类型是 std::io:: Error。</t>

### 注意:

1.  文件::打开的返回类型是成功值或失败值。如果文件::打开成功，则返回文件句柄，如果文件::打开失败，则返回错误值。结果枚举提供了此信息。
2.  **如果文件::打开成功**，那么 f 将有一个包含文件句柄的 OK 变量，**如果文件::打开失败**，那么 f 将有一个包含错误相关信息的 Err 变量。

## 匹配表达式来处理结果变量。

**我们来看一个匹配表达式的简单例子:**

```

 use std::fs::File;
fn main()
 {
    let f = File::open("vector.txt");
    match f 
    {
        Ok(file) => file,
        Err(error) => {
        panic!("There was a problem opening the file: {:?}", error)
      },
    };
}

```

**输出:**

![Rust Recoverable Errors](img/cbf11690e21edc8c30b4fb86a6d99211.png)

**节目解说**

*   在上面的例子中，我们可以直接访问枚举变量，而不使用**结果**:**确定**和**错误**变量之前。
*   如果结果是**确定**，则返回文件并存储在‘f’变量中。匹配后，我们可以执行文件中的操作，读或写。
*   匹配的第二个分支基于 Err 值。如果结果返回错误值，则死机！运行并停止程序的执行。

## 出错时死机:打开()

*   结果<t e="">有很多方法提供各种任务。其中一个方法是 unwrap()方法。unwrap()方法是匹配表达式的快捷方法。unwrap()方法和 match 表达式的工作原理是一样的。</t>
*   如果结果值是一个**确定**变量，那么 unwrap()方法返回**确定**变量的值。
*   如果结果值是**一个错误的**变量，那么 unwrap()方法调用恐慌！宏。

**我们来看一个简单的例子:**

```

 use std::fs::File;

fn main()
{
     File::open("hello.txt").unwrap();
}

```

**输出:**

![Rust Recoverable Errors](img/8b4e2fac1d01ac29fd639e4c6b8e63c4.png)

在上例中，unwrap()方法会自动调用死机宏和死机！显示错误信息。

## 出错时死机:预期()

*   expect()方法的行为方式与 unwrap()方法相同，也就是说，这两种方法都调用了死机！显示错误信息。
*   expect()和 unwrap()方法的区别在于，错误消息作为参数传递给 expect()方法，而 unwrap()方法不包含任何参数。因此，我们可以说 expect()方法跟踪了恐慌！来源更容易。

**我们来看一个 expect()** 的简单例子

```

 use std::fs::File;
fn main()
{
     File::open("hello.txt").expect("Not able to find the file hello.txt");
}

```

**输出:**

![Rust Recoverable Errors](img/a3b2932949ae6562360186b3b7373974.png)

在上面的输出中，错误消息显示在我们在程序中指定的输出屏幕上，即“**找不到文件 hello.txt** ”，这使得我们更容易找到错误来自哪里的代码。如果我们包含多个 unwrap()方法，那么就很难找到 unwrap()方法在哪里引起了恐慌！一样恐慌！显示所有错误的相同错误消息。

## 传播错误

传播错误是一种将错误从一个函数转发到另一个函数的机制。错误被传播到调用函数，在那里可以获得更多的信息，以便处理错误。**假设我们有一个名为‘a . txt’的文件，它包含文本“javaTpoint。”我们想创建一个程序来执行这个文件的读取操作。让我们来研究这个例子**。

让我们看一个简单的例子:

```

 use std::io;
use std::io::Read;
use std::fs::File;
fn main()
{
  let a = read_username_from_file();
  print!("{:?}",a);
}
fn read_username_from_file() -> Result<String, io::Error> 
{
    let f = File::open("a.txt");
    let mut f = match f {
    Ok(file) => file,
    Err(e) => return Err(e),
    };
    let mut s = String::new();
    match f.read_to_string(&mut s) {
        Ok(_) => Ok(s),
        Err(e) => Err(e),
    }
}

```

**输出:**

![Rust Recoverable Errors](img/711799dffa6b7fd7a645a8647ea3dafa.png)

**节目解说**

*   read_username_from_file()函数返回一个类型为 Result <t e="">的值，其中“T”是字符串的类型，“E”是 io:Error 的类型。</t>
*   如果函数成功，则返回一个保存字符串的 OK 值，如果函数失败，则返回一个 Err 值。
*   这个函数从调用 File:: open 函数开始。如果 File:: open 函数失败，那么匹配的第二个分支将返回 Err 值，如果 File:: open 函数成功，那么它将文件句柄的值存储在变量 f 中。
*   如果文件::打开函数成功，那么我们创建一个字符串变量。如果 read_to_string()方法成功，则返回文件的文本，否则返回错误信息。
*   假设我们有一个名为“a.text”的外部文件，其中包含文本“javaTpoint”。因此，这个程序读取文件“a.text”并显示文件的内容。

## 传播错误的快捷方式:“？”操作员

“？”的用法运算符减少代码的长度。“？”运算符是匹配表达式的替换，这意味着“？”运算符的工作方式与匹配表达式相同。**假设我们有一个名为‘a . txt’的文件，它包含文本“javaTpoint。”我们想创建一个程序来执行这个文件的读取操作。让我们来研究这个例子**。

**我们来看一个简单的例子。**

```

 use std::io;
use std::io::Read;
use std::fs::File;
fn main()
{
  let a = read_username_from_file();
  print!("{:?}",a);
}
fn read_username_from_file() -> Result<String, io::Error> 
{
   let mut f = File::open("a.txt")?;
   let mut s = String::new();
   f.read_to_string(&mut s)?;
  Ok(s)
}

```

**输出:**

![Rust Recoverable Errors](img/ac58a2e8de6eeaec8bbe023c778c5eb6.png)

在上例中，'？'运算符用在结果值类型之前。如果结果正常，则返回正常变量的值，如果结果为错误，则返回错误信息。

## 差异 b/w '？运算符和匹配表达式

*   与“？”一起使用的错误运算符通过“from”函数，而“from”函数是在标准库中的 from 特性中定义的。
*   什么时候？运算符调用“from”函数，然后该函数将错误类型转换为当前函数的返回类型中定义的错误类型。
*   如果没有出现错误，那么“？”任何函数末尾的运算符都返回 OK 的值，如果出现错误，则返回 Err 的值。
*   它使函数的实现更简单。

## “？”后面的链接方法调用操作员

我们甚至可以通过在“？”后面使用**链接方法调用来进一步缩短程序的代码操作员。**

**我们来看一个简单的例子:**

```

 use std::io;
use std::io::Read;
use std::fs::File;
fn main()
{
  let a = read_username_from_file();
  print!("{:?}",a);
}
fn read_username_from_file() -> Result<String, io::Error> 
{
    let mut s = String::new();
   File::open("a.txt")?.read_to_string(&mut s)?;
   Ok(s)
}

```

**输出:**

![Rust Recoverable Errors](img/59df9a146d874fb8581fe720888a7c88.png)

**节目解说**

在上面的例子中，我们已经将 read_to_string()的调用链接到了 File::open("a.txt ")？。我们把“？”read_to_string()调用结束时的运算符。如果函数 read_to_string()和 File::open("a.txt ")都成功，则返回 OK 值，否则返回错误值。

## “？”的限制操作员

“？”运算符只能在返回结果类型值的函数中使用。作为“？”运算符的工作方式与匹配表达式类似。匹配表达式仅适用于结果返回类型。

让我们通过一个简单的例子来理解这一点。

```

 use std::fs::File;
fn main() 
{
    let f = File::open("a.txt")?;
}

```

**输出:**

![Rust Recoverable Errors](img/fe5397e1d4e37e3ad0dd66f9618ee24a.png)

* * *