# RC〔t0〕

> 原文：<https://www.javatpoint.com/rust-rc-t>

*   Rc <t>代表参考计数智能指针。</t>
*   Rc <t>智能指针跟踪对某个值的引用次数，以确定该值是否仍在使用，如果对某个值的引用为零，则可以清除该值。</t>
*   Rc <t>智能指针是单线程引用计数指针。</t>

## 使用 Rc <t>共享数据</t>

让我们创建两个共享第三个列表所有权的列表。

![Rust Rc](img/97daae1e5ef1db3a59afe1a56db2af6c.png)

在上图中，b 和 c 是与第三个列表 a 共享所有权的两个列表。

**让我们使用 Box < T >类型实现上面的场景。**

```

 enum List 
{
  Cons(i32, Box<List>),
  Nil,
}
use List::{Cons,Nil};
fn main()
{
  let a = Cons(10, Box::new(Cons(15,Box::new(Nil))));
  let b = Cons(2, Box::new(a));
  let c = Cons(1, Box::new(a)); 
}

```

**输出:**

![rust Rc](img/84e5acf6580873609dccf2f0e520327d.png)

在上面的例子中，cons 变量由 i32 类型的数据和指向列表的 Box <t>组成。我们创建列表“b ”,并将“a”的所有权移到“b”列表中。然后，我们尝试将“a”列表移动到“c”列表，但是不能移动列表，因为“a”列表已经移动到“b”列表。</t>

## 如何克服这个问题

我们可以通过改变 cons 变量的定义来克服这个问题。现在，cons 变量由他们持有的数据和指向列表的 Rc <t>组成。</t>

**我们来看一个简单的例子:**

```

 enum List 
{
  Cons(i32, Rc),
  Nil,
}
use List::{Cons,Nil};
use std::rc::Rc;
fn main()
{
  let a = Rc::new(Cons(10, Rc::new(Cons(15,Rc::new(Nil)))));
  let b = Cons(2, Rc::clone(&a));
  let c = Cons(1, Rc::clone(&a)); 
} 
```

在上面的例子中，我们需要添加 use 语句来将 Rc <t>带入范围。我们将复制 a 持有的 Rc <t>列表，而不是获取 a 的所有权，因此，将引用的数量从一个增加到两个，就像现在一样，a 和 b 共享该 Rc <list>中的数据所有权。我们将在创建 c 列表时再次克隆 Rc <list>，因此将引用从两个增加到三个。</list></list></t></t>

## 克隆 Rc <t>会增加参考计数</t>

现在，我们将看到当列表超出范围时，Rc <t>如何增加或减少引用计数。</t>

**我们来看一个简单的例子:**

```

 enum List 
{
  Cons(i32, Rc<List>),
  Nil,
}
use List::{Cons,Nil};
use std::rc::Rc;
fn main()
{
  let a = Rc::new(Cons(10, Rc::new(Cons(15,Rc::new(Nil)))));
  println!("Reference count after creating a List : {}", Rc::strong_count(&a));
  let b = Cons(2, Rc::clone(&a));
  println!("Reference count after creating b List : {}", Rc::strong_count(&a));
  {
  let c = Cons(1, Rc::clone(&a)); 
  println!("Reference count after creating c List : {}",Rc::strong_count(&a));
  }
  println!("Reference count when c goes out of the scope : {}",Rc::strong_count(&a));
}

```

**输出:**

```
Reference count after creating a List : 1
Reference count after creating b List : 2
Reference count after creating c List : 3
Reference count when c goes out of the scope : 2

```

在上面的例子中，我们通过调用 **Rc::strong_count 函数**来打印引用计数。Rc <列表>中 a 的初始引用计数为 1，当我们调用 clone 时，引用计数增加 1。如果变量超出范围，则引用计数减少 1。因此，我们可以说当一个 **Rc < T > / **值超出范围时，**掉落特性**会自动减少参考计数。****

* * *