# RefCell

> 原文：<https://www.javatpoint.com/rust-refcell-t>

**内部可变性**模式是一种模式，如果我们有一个不可变的引用，它就用来变异引用。RefCell < T >可以用来实现内部可变性。

**需要记住的要点:**

*   RefCell <t>表示对其持有的数据的单一所有权。</t>
*   如果我们使用 RefCell <t>，那么不变量在运行时被强制执行。</t>
*   RefCell <t>主要用于单线程场景，如果我们在多线程情况下使用，会给出一个错误。</t>
*   RefCell <t>在运行时检查可变借用。因此，我们可以说，即使 RefCell <t>值是不可变的，我们也可以对该值进行变异。</t></t>

## 内部可变性

根据借用规则，如果我们有一个不可变的值，那么我们不能可变地借用。

**我们来看一个简单的例子:**

```

 fn main()
{
  let a = 15;
  let b = &mut a;
}

```

**输出:**

![rust RefCell](img/31bbdff267db1f395babe680055d43ef.png)

在上面的例子中，我们已经看到不可变的值不能被可变地借用。但是，RefCell 是实现内部可变性的一种方法。

## 使用 RefCell <t>在运行时跟踪借入</t>

RefCell <t>由两个在运行时跟踪借用的方法组成:</t>

*   **借位():**借位()方法返回类型为 Ref < T >的智能指针。
*   **借位 mut():** 借位 mut()方法返回 RefMut 类型的智能指针< < T >。

#### 注意:Ref <t>和 RefMut <t>两种类型都实现了 Deref 特性。因此，它们可以被视为常规引用。</t></t>

**一些要点:**

*   **RefCell < T >** 记录了当前有多少 Ref < T >和 Refmut < T >智能指针处于活动状态。
*   每当调用**借用()**方法时，RefCell < T >会增加活动的不可变借用的数量。当 Rc < T >超出范围时，RefCell < T >将计数减少 1。
*   **RefCell < T >** 让我们有许多不可变的借用，但一次只有一个可变的借用，就像编译时借用规则一样。如果我们违反了这个规则，那么 RefCell < T >在运行时就会死机。

### 借用()方法

借用()方法借用不可变的值。可以同时进行多个不可变的借用。

**语法:**

```

pub fn borrow(&self) -> Ref<T>

```

**我们来看一个发生多次不可变借用的简单例子:**

```

 use std::cell::RefCell;
fn main()
{
  let a = RefCell::new(15);
  let b = a.borrow();
  let c = a.borrow();
  println!("Value of b is : {}",b);
  println!("Value of c is : {}",c);
}

```

**输出:**

![rust RefCell](img/d5e86bfc765b25853c579997a0cb011b.png)

**我们来看一个恐慌状态的简单例子:**

```

 use std::cell::RefCell;
fn main()
{
  let a = RefCell::new(10);
  let b = a.borrow();
  let c = a.borrow_mut(); // cause panic.
  println!("Value of b is : {}",b);
  println!("Value of c is : {}",c);
}

```

**输出:**

![rust RefCell](img/8d51712652e9879174ff3cabd8d3f3bd.png)

在上面的例子中，程序在运行时死机，因为不可变借用和可变借用不能同时发生。

### 借用 mut()方法

借用 mut()方法借用可变值。可变借用可以发生一次。

**语法:**

```

pub fn borrow_mut(&self) -> RefMut<T>;

```

**我们来看一个简单的例子:**

```

 use std::cell::RefCell;
fn main()
{
  let a = RefCell::new(15);
  let b = a.borrow_mut();
  println!("Now, value of b is {}",b);
}

```

![rust RefCell](img/b6fdac057e26078e79c08e515b699913.png)

**我们来看一个恐慌状态的简单例子:**

```

 use std::cell::RefCell;
fn main()
{
  let a = RefCell::new(15);
  let b = a.borrow_mut();
  let c = a.borrow_mut();
}

```

**输出:**

![rust RefCell](img/b2dfe79a749b2c305e38d4c12b6554f1.png)

在上面的例子中，可变借用发生了两次。因此，程序在运行时死机，并抛出一个错误“已经被借用:BorrowMutError”。

## 通过组合 Rc <t>和 RefCell <t>获得可变数据的多个所有者</t></t>

我们可以将 Rc <t>和 RefCell <t>结合起来，这样我们就可以拥有可变数据的多个所有者。Rc <t>允许您拥有一个数据的多个所有者，但是它只提供对数据的不可改变的访问。RefCell <t>让你对数据进行变异。因此，我们可以说，Rc <t>和 RefCell <t>的结合提供了具有可变数据的多个所有者的灵活性。</t></t></t></t></t></t>

**我们来看一个简单的例子:**

```

 #[derive(Debug)]
enum List
{
 Cons(Rc<RefCell<String>>,Rc<List>),
 Nil,
}
use List:: {Cons,Nil};
use std::rc::Rc;
use std::cell::RefCell;
fn main()
{
  let val = Rc::new(RefCell::new(String::from("java")));
  let a = Rc::new(Cons(Rc::clone(&val),Rc::new(Nil)));
  let b = Cons(Rc::new(RefCell::new(String::from("C"))),Rc::clone(&a));
  let c = Cons(Rc::new(RefCell::new(String::from("C++"))),Rc::clone(&a));
  *val.borrow_mut() = String::from("C# language");
  println!("value of a is : {:?}",a);
  println!("value of b is : {:?}",b);
  println!("value of c is : {:?}",c);
}

```

**输出:**

![rust RefCell](img/642a25d6b2240e19f831f71a84ad65d6.png)

在上面的例子中，我们创建了一个变量‘val’，并将值“java”存储到变量‘val’中。然后，我们创建列表“a”，并克隆“val”变量，以便变量“a”和“val”都拥有“java”值的所有权，而不是将所有权从“val”转移到“a”变量。创建“a”列表后，我们创建“b”和“c”列表，并克隆“a”列表。创建列表后，我们使用借用 mut()方法将“val”变量的值替换为“C#”语言。

* * *