# VHDL 教程

> 原文：<https://www.javatpoint.com/vhdl>

VHDL 教程提供了 VHDL 的基本概念和高级概念。我们的 VHDL 教程是为初学者和专业人士设计的。

*   [什么是高密度脂蛋白？](#HDL)
*   [什么是 VHDL？](#VHDL)
*   [什么是 Verilog](#Verilog)
*   【VHDL 和 Verilog 的区别
*   [VHDL 的历史](#History)
*   [为什么是 VHDL？](#Why)
*   [VHDL 的优势](#Advantages)
*   [VHDL 的缺点](#Disadvantages)
*   [VHDL 的基本元素](#Basic-Elements)
*   [VHDL 中建模风格的类型](#Types-of-Modeling-styles)
*   [VHDL 对象](#objects)
*   [VHDL 中的数据类型](#Data-Types)
*   [VHDL 操作符](#Operators)
*   [安装 Xilinx IDE 工具](#Install-Xilinx)
*   [使用 Xilinx IDE 工具以 VHDL 语言创建项目](#Creating-Project)
*   [VHDL vs C 语言](#VHDL-vs-C)

* * *

## 什么是高密度脂蛋白？

HDL 代表**硬件描述语言**。这是一种**编程语言**，用于**描述、模拟、**和**创建**类似数字电路(ICS)的硬件。HDL 主要用于在硬件实现之前发现设计中的错误。

HDLs 的主要优势是提供了灵活的建模能力，可以表达大型复杂设计(> 10 <sup>7</sup> 门)。

如今，市场上有很多高密度脂蛋白，但 **VHDL** 和 **Verilog** 是最受欢迎的高密度脂蛋白。

* * *

## 什么是 VHDL？

VHDL 代表超高速集成电路 HDL(硬件描述语言)。它是一种 IEEE(电气和电子工程师协会)标准硬件描述语言，用于描述和模拟复杂数字电路的行为。

VHDL 最流行的例子是**奇偶校验发生器、脉冲发生器、优先级编码器、16 字的行为模型**、8 位 RAM 等。

VHDL 支持以下功能:

*   设计方法及其特点。
*   顺序和并发活动。
*   设计交流
*   标准化
*   文件
*   可读性
*   大规模设计
*   广泛的描述能力

* * *

## 什么是 Verilog？

Verilog 也是一种描述电子电路和系统的硬件描述语言。它用于硬件仿真和综合。

Verilog 最流行的例子是网络交换机、微处理器、存储器、简单的触发器等。

* * *

## VHDL 和 Verilog 的区别

| 极高密度脂蛋白 | 程序 |
| 它允许用户定义数据类型。 | 它不允许用户定义数据类型。 |
| 它支持多维数组。 | 它不支持多维数组。 |
| 它允许并发过程调用。 | 它不允许并发调用。 |
| 存在一个 mod 运算符。 | mod 运算符不存在。 |
| 一元约简运算符不存在。 | 存在一元约简运算符。 |
| 更难学。 | 这很容易学。 |

* * *

## VHDL 的历史

VHDL 是由国防部于 1980 年开发的。

*   **1980 年:**美国国防部想让电路设计自我记录。
*   **1983 年:**VHDL 的开发始于 IBM、Inter-metrics 和德州仪器的共同努力。
*   **1985 年(VHDL 版):**政府合同下语言的最终版本发布。
*   **1987 年:**国防部允许用于商业目的，VHDL 成为 IEEE 标准 1076-1987。
*   **1993:** VHDL 被重新标准化以增强语言
*   **1996:** 与合成工具一起使用的 VHDL 包，成为 IEEE 1076 标准的一部分。
*   **1999:** 模拟混合信号扩展(VHDL-AMS)
*   **2008:** IEEE 标准 1076-2008(新增功能)发布。

* * *

## 为什么是 VHDL？

VHDL 用于以下目的:

*   用于描述硬件
*   作为一种建模语言
*   对于硬件的模拟
*   对于系统架构的早期性能评估
*   用于硬件的合成

* * *

## VHDL 的优点

下面列出了 VHDL 的优点:

*   它支持各种设计方法，如自顶向下方法和自底向上方法。
*   它提供了一种灵活的设计语言。
*   它允许更好的设计管理。
*   它允许详细的实现。
*   它支持多层次的抽象。
*   它提供了与低层次设计的紧密耦合。
*   它支持所有的计算机辅助设计工具。
*   它强烈支持代码重用和代码共享。

* * *

## VHDL 的缺点

下面列出了 VHDL 的缺点:

*   它需要对语言的结构和语法有具体的了解。
*   可视化设计和排除设计故障更加困难。
*   有些 VHDL 程序无法合成。
*   VHDL 更难学。

* * *

## VHDL 语言的基本要素

VHDL 有以下三个基本元素:

### 1.实体

实体用于指定电路的输入和输出端口。实体通常有一个或多个端口，可以是输入(输入)、输出(输出)、输入输出(输入输出)或缓冲区。

实体还可以包括一组用于声明电路属性的通用值。

**实体声明**

您可以使用以下语法声明实体:

*   **简化语法**

```

      entity entity_name is
port (
 port_1_name : mode data_type;
port_2_name : mode data_type;
                  .......
                  Port_n_name : mode data_type
                  );
     end entity_name;

```

**示例:**

```

entiy orgate is
   port (
                a : in   std_logic;
                b : in   std_logic;
                c : out  std_logic
             );
end orgate; 

```

*   **使用通用**

如果一个实体是通用的，那么它必须在端口之前声明。泛型没有模式，因此它只能将信息传递给实体。

**语法:**

```

entity entity_name is
    generic (
                  generic_1_name : data_type;
                  generic_2_name : data_type;
                   ........
                  generic_n_name : data_type
                   );
 port (
             port_1_name : mode data_type;
              port_2_name : mode data_type;
              ........
              Port_n_name : mode data_type
               );
     end entity_name;

```

**示例:**

```

  entity Logic_Gates is
generic (Delay : Time := 10ns);
port (
       Input1 : in std_logic;
       Input2 : in std_logic;
       Output : out std_logic
       );
end Logic_Gates;

```

**端口名称书写规则:**

-端口名由字母、数字和下划线组成。
-总是以字母开头。
-端口名称不区分大小写。

**港口模式**

输入端口
输出端口
输入双向端口
缓冲输出端口

### 2.体系结构

架构是设计的实际描述，用于描述电路如何工作。它可以包含并发语句和顺序语句。

**架构声明**

可以使用以下语法声明体系结构:

```

architecture architecture_name of entity_name is
begin
   (concurrent statements )
end architecture_name;

```

**示例:**

```

architecture synthesis of andgate is
begin
          c <= a AND b;
end synthesis;

```

### 3.配置

配置定义了设计层次结构如何链接在一起。它也用于将架构与实体相关联。

**配置声明**

```

configuration configuration_name of entity_name is
--configuration declarations
for architecture_name
  for instance_label : component_name
     use entity library_name.entity_name(architecture_name);
end for;
--
end for;
end [configuration] [configuration_name];

```

**示例:**

```

configuration demo_config of even_detector_testbench is
    for tb_archi
       for uut : even_detector
          use entity work.even_detector (sop_archi);
        end for;
    end for;
end demo_config;

```

* * *

## VHDL 语言中建模风格的类型

VHDL 中有 4 种建模风格:

**1。数据流建模(设计方程)**

数据流建模可以基于布尔表达式来描述。它显示了数据如何从输入流向输出。它适用于并发执行。

**2。行为建模(解释行为)**

行为建模用于顺序执行语句。它显示了系统如何根据当前语句执行。

行为建模可能包含过程语句、顺序语句、信号分配语句和等待语句。

**3。结构建模(子模块连接)**

结构建模用于指定电路的功能和结构。

结构建模包含信号声明、组件实例和组件实例中的端口映射。

* * *

## VHDL 对象

VHDL 使用以下三种类型的对象:

**1。常数**

常量是一个只能保存单个值的对象，该值在整个代码中不能更改。

**示例:**常量 _ 字节数 _ 整数:= 8；

**2。变量**

变量也保存给定类型的单个值。通过使用变量赋值运算符，可以在模拟过程中改变变量值。

变量用在流程和子程序中。

变量由赋值运算符“:=”赋值。

**示例:**

变量索引:整数:= 0；

**3。信号**

信号可以在架构中声明，并在架构中的任何地方使用。信号由赋值运算符“**”T2“=**”赋值。

**示例:**

信号 sig1:STD _ logic；
Sig1 < = '1 '

* * *

## VHDL 语言中的数据类型

数据类型是存储数据的抽象表示。

VHDL 中有以下数据类型-

**1。标量类型**

*   **整数**
    整数数据类型是正负整数的集合。
*   **浮点**
    浮点数据类型是包含小数点的一组正数和负数。
*   **枚举**
    枚举数据类型用于增加代码的可读性。
*   **物理**
    物理数据类型根据基本单位、基本单位的倍数和指定范围来描述对象。

**2。复合类型**

*   **数组**
    数组用于在单个标识符下保存相同类型的多个值
*   **记录**
    记录用于指定一个或多个元素，每个元素有不同的名称和不同的类型。

* * *

## VHDL 运算符

VHDL 操作符用于构造表达式。

VHDL 中有以下类型的运算符:

**1。逻辑运算符**

逻辑运算符用于控制程序流。当逻辑运算符与信号或变量相结合时，它就被用来创建组合逻辑。

VHDL 支持以下逻辑运算符:

*   和
*   或者
*   “与非”
*   也不
*   异或运算
*   xnor！x or
*   不

**2。关系运算符**

在 VHDL 中，关系运算符用于比较相同数据类型的两个操作数，并且接收到的结果总是布尔类型的。

VHDL 支持以下关系运算符:

*   =等于
*   /=不等于

*   >大于
*   < =小于或等于
*   > =大于或等于

**3。算术运算符**

算术运算符用于执行算术运算。这些运算符是**数值类型**，如**整数**和**实数**。

VHDL 使用以下算术运算符:

*   +加法
*   -减法
*   *乘法
*   /部门
*   &串联
*   模数
*   rem 余数
*   绝对值
*   **幂运算

**4。轮班操作员**

在 VHDL 语言中，移位运算符用于通过向右或向左移位和旋转第一个操作数的位来对数据执行位操作。

VHDL 支持以下各种运算符:

*   Sll 逻辑左移
*   Srl 逻辑右移
*   Sla 左移算法
*   Sra 右移算术
*   向左旋转
*   向右旋转

#### 注意:运算符按照其优先级进行计算。(即最高到最低)

| 最高的 | 优先顺序 | 最低的 |
| 算术运算符 | 移位运算符关系运算符 | 逻辑算子 |

优先级相等的运算符从左到右计算。

* * *

## 安装 Xilinx ISE 工具

安装 Xilinx ISE 工具有以下步骤-

**步骤 1:** 点击下方链接下载 Xilinx ISE 工具。

[https://www . Xilinx . com/support/download/index . html/content/Xilinx/en/downloanav/design-tools/v 2012 _ 4-14 _ 7 . html](https://www.xilinx.com/support/download/index.html/content/xilinx/en/downloadNav/design-tools/v2012_4---14_7.html)

**第二步:**现在进入 **ISE 设计套件- 14.7 全产品安装**选择**Windows 7/XP 服务器全安装程序(TAR/GRIP - 6.18 GB)** 如下图截图所示。

![Install Xilinx ISE Tool](img/efc6e300d6bfde5b8132c71e0f52707c.png)

**第三步:**点击**windows 7/XP/Server 完整安装程序**，会看到页面出现 **Xilinx 标志**。如果您没有 Xilinx 的账户，那么点击**创建您的账户**。

![Install Xilinx ISE Tool](img/9c4e9fe196147d8ebe8b774f2a39fce2.png)

**第四步:**在注册页面填写信息，然后点击**创建账户**。

![Install Xilinx ISE Tool](img/113183e174fe117731edd42a874fab6c.png)

**第五步:**点击**创建账户**后，出现如下窗口。

![Install Xilinx ISE Tool](img/b815172f91a72dc0e437c89eac16d70b.png)

**第 6 步:**现在，您将在注册的电子邮件 id 上收到一封包含激活链接的邮件。点击链接激活您的帐户。

**第七步:**点击链接后，窗口中出现**登录激活账户窗口**，输入您的**用户名**和**密码**，然后点击**登录**。

![Install Xilinx ISE Tool](img/b80ca926ff40f9d0a298f0c3269aecf8.png)

**第 8 步:**现在点击下方链接进行**名称**和**地址**验证。

**第九步:**完成**验证表**后，点击**下一步**。

![Install Xilinx ISE Tool](img/6950752a22d9322ee56573e1ac57a93a.png)

**第十步:**现在可以看到 **Xilinx_ISE tar** 文件开始下载了。

![Install Xilinx ISE Tool](img/31057372caeb7de690fba22360b51eb5.png)

**第 11 步:**双击下载的文件，提取文件运行 xsetup.exe。

**步骤 12:** 运行应用程序后，屏幕上会出现以下**欢迎**窗口。

![Install Xilinx ISE Tool](img/507bbc67d6c6af9d7212aa36a9650df4.png)

**第 13 步:**在**上打勾我接受并同意以上**的条款和条件，在**上也打勾我也接受并同意以下**的条款和条件，然后点击下一步。

![Install Xilinx ISE Tool](img/8b0016fc7fc9aaed051959c06e147fd5.png)
![Install Xilinx ISE Tool](img/494bffb3f8e12d1d829e2a7a61ad94b6.png)

**步骤 14:** 现在，选择列出的产品进行安装。对于 VHDL，选择 **ISE 网络包**，这是软件的免费版本。选择 ISE 网络包后，点击**下一步**。

![Install Xilinx ISE Tool](img/d943594024c20b48b4a140efb893b191.png)

**第 15 步:**安装选项窗口出现。在该窗口中，点击**下一步**。

![Install Xilinx ISE Tool](img/983ccbf78ae9ea1d71f014d83fb59dd8.png)

**第 16 步:**选择**目的地目录**，然后点击**下一步**。

![Install Xilinx ISE Tool](img/d8dff3c7ee1c001cd71ac71ee25fd1df.png)

**第 17 步:**可以看到下面截图中的**安装总结。点击**安装**安装 Xilinx。**

![Install Xilinx ISE Tool](img/392b857bec2fbebef11ba61559ee0df0.png)

**步骤 18:** 可以看到安装正在进行中。

![Install Xilinx ISE Tool](img/f8f638448ee7c14bba571d48ae6fa2f2.png)

**步骤 19:** 安装完成后，点击**完成**。

![Install Xilinx ISE Tool](img/0b962b323cda1377b1943dad4e719cff.png)

**步骤 20:修复项目导航器、iMPACT 和许可证管理器**

修复项目导航器、iMPACT 和许可证管理器有以下步骤。

1.  转到**C:\ Xilinx \ 14.7 \ ISE _ DS \ ISE \ lib \ nt64**并将 libPortability.dll 重命名为 **lib。便携性. dll.orig** 。
2.  复制粘贴**libPortabilityNOSH.dll**在同一个目录下，重命名为**libPortability.dll**。
3.  复制**libPortabilityNOSH.dll**粘贴到**C:\ Xilinx \ 14.7 \ ISE _ DS \ common \ lib \ nt64**中
4.  在**C:\ Xilinx \ 14.7 \ ISE _ DS \ common \ lib \ nt64**中，将**libPortability.dll**重命名为 **libPortability.dll.orig** 。
5.  在**C:\ Xilinx \ 14.7 \ ISE _ DS \ common \ lib \ nt64**中将**libPortabilityNOSH.dll**更名为**libPortability.dll**。

完成上述步骤后，您可以关闭目录。

**第 21 步:**现在，可以看到 IDE 设计套件出现在屏幕上。双击 IDE 设计套件，可以看到如下弹出窗口:

![Install Xilinx ISE Tool](img/d05f51ddc9d277c1fb832a782cc980b6.png)

**第 22 步:**现在，弹出如下窗口，点击弹出窗口中的确定。

![Install Xilinx ISE Tool](img/a880ae11c75b536dc3ef17e509dbb516.png)

**步骤 23:** 当您点击许可证时，将打开以下窗口，在其中选择**获取我购买的许可证**，然后点击**下一步**。

![Install Xilinx ISE Tool](img/69db8597c51f426434e5bf4a4f49ae54.png)

**第 24 步:**要连接默认浏览器，点击**立即连接**。

![Install Xilinx ISE Tool](img/d86405cf5b27a2cc7db27d545a861ae3.png)

**第 25 步:**在浏览中打开**新 XILINX 页面**。在此页面，输入**用户名**和**密码**，然后点击**登录**。

![Install Xilinx ISE Tool](img/517f0e00efbd4573596fe2e88f263e62.png)

**步骤 26:** 点击登录后，出现如下窗口。

![Install Xilinx ISE Tool](img/6e4cf23c96317cd985dbdd240155cc0b.png)

**第 27 步:**选择文件后，会在您的注册电子邮件 id 中收到一封电子邮件，其中包含一个 **Xilinx.lic** 文件。你需要下载这个文件。

单击加载许可证上传下载的许可证文件，然后单击关闭。

![Install Xilinx ISE Tool](img/8c14dc6fdb53da979d108303abf733b2.png)

**步骤 28:** 文件上传后，弹出消息**许可证安装成功**，点击弹出窗口中的确定，然后点击关闭。

下面的截图显示许可证已上传。

![Install Xilinx ISE Tool](img/edd831057d765de525c8db08d82fba47.png)

**步骤 29:** 现在，您可以在 Xilinx 工具中创建项目。

![Install Xilinx ISE Tool](img/1a4064a02513a3ba192ccfb2a6e4ed70.png)

* * *

## 使用 Xilinx 集成开发环境工具以 VHDL 语言创建项目

在 Xilinx 中创建项目有以下步骤-

**步骤 1:创建新项目**

要创建新项目，选择**文件- >新项目**。它将在桌面上打开一个新的项目窗口。

![Creating a project in VHDL using Xilinx IDE Tool](img/e9b6968a3bd30ade4b40955a575d3d7c.png)

在新项目窗口中，给出您想要创建的**项目名称**，并**指定您想要保存项目的位置(目录路径)**，然后点击**下一步**。

![Creating a project in VHDL using Xilinx IDE Tool](img/8b2c8b5ff886fa966b9943377cea4b30.png)

#### 注意:确保选择顶级源类型作为 HDL，而不是原理图、EDIF 或其他东西。

点击**下一步**按钮后，出现如下窗口，显示项目属性。根据您的要求填写属性，然后点击**下一步**。

![Creating a project in VHDL using Xilinx IDE Tool](img/f495a16547f4917ee5d02a7c84b99a14.png)

点击**下一步**按钮后，出现如下窗口，显示**项目总结**。如果项目总结符合您的要求，则点击**完成**。否则，点击**返回**，根据您的要求填写属性。

![Creating a project in VHDL using Xilinx IDE Tool](img/696997c0fa6a4f40d323860ae6f1651e.png)

**步骤 2:创建 VHDL 源**

要在 VHDL 中添加 VHDL 源，在项目向导中点击**新源**，或者点击**项目- >新源**。

![Creating a project in VHDL using Xilinx IDE Tool](img/5fa841f35b6c0967bdb0b7414d4e185f.png)

键入文件名，指定位置，选择 **VHDL 模块**作为源类型。确保选中**添加到项目**复选框，然后点击**下一步**。

![Creating a project in VHDL using Xilinx IDE Tool](img/4bad1d3564c3d63d04e2f5308e97848d.png)

**步骤 3:为 VHDL 源分配端口**

要设计半加法器，可以将**端口名**指定为 **a、b、sum、**和 **cout** 。其中对于 **a** 和 **b** 被视为**输入端口**，因此从下拉菜单中选择进入。 **sum** 和 **cout** 被视为**输出端口**，因此从下拉菜单中选择 **out** 。

![Creating a project in VHDL using Xilinx IDE Tool](img/943b5a7471b6cdc096b17bdfb984ff2c.png)

下面的截图显示了项目的概要。

![Creating a project in VHDL using Xilinx IDE Tool](img/db1cf9adb7834df1d469a9e6a4a4bad8.png)

**第四步:输入并编辑 VHDL 代码**

下面的截图显示了自动生成的 Half_Adder 代码。

![Creating a project in VHDL using Xilinx IDE Tool](img/ab65791a6e488c4cad23fb2dc0051d40.png)

要设计半加法器，在工作区输入以下代码。

![Creating a project in VHDL using Xilinx IDE Tool](img/6ff7185c951300a7d74dc0b0fda2bac0.png)

**第五步:合成代码**

源文件完成后，您需要检查设计的语法。要检查语法，请单击合成-XST 过程来扩展层次结构。现在，双击**检查语法**。

您可以看到 ISE 编译过程已经开始。如果 ISE 过程成功完成，会出现绿色勾号。否则，会出现一个红色的 X，表示存在错误且处理失败。

![Creating a project in VHDL using Xilinx IDE Tool](img/cd0799902a2e85f37a297d325883b20d.png)

要查看半加法器的基本设计，双击**查看 RTL 原理图**。

![Creating a project in VHDL using Xilinx IDE Tool](img/5c6aa285e29c806e91b40bc784cf19bb.png)

现在你会看到如下弹出窗口，点击**确定**。

![Creating a project in VHDL using Xilinx IDE Tool](img/aea89ab7fdc4d8a49985b5639ad4b35f.png)

在创建 RTL 原理图中，从**可用列表**中选择项目，然后点击**添加**按钮将所选项目移动到**所选元素**并点击**创建原理图**。

![Creating a project in VHDL using Xilinx IDE Tool](img/77d4f29edb9533c72eb5b4270cb098fe.png)

现在，你可以在屏幕上看到半加法器的外部设计。

![Creating a project in VHDL using Xilinx IDE Tool](img/cf5076ca714442af1b64cc3ec6e030ab.png)

当您双击上面的矩形时，您可以看到使用逻辑门的内部图。

![Creating a project in VHDL using Xilinx IDE Tool](img/7d3456adc62dbefd705615d688a785ee.png)
![Creating a project in VHDL using Xilinx IDE Tool](img/a8cbaad0f3f0e1bf392180a358091ae2.png)

**第六步:模拟行为模型(ISE 模拟器)**

要检查行为模型，选择实现->半加法器-行为(半加法器. vhd)并双击模拟行为模型。

![Creating a project in VHDL using Xilinx IDE Tool](img/28e63008031bb5b63d92088b7f67adc9.png)

如果模拟成功，将打开以下窗口。

![Creating a project in VHDL using Xilinx IDE Tool](img/4f2d04cd92f548bdffd4336b91c7fea3.png)

要指定该值，右击给定值(U)，然后选择**力常数。考虑下图**:

![Creating a project in VHDL using Xilinx IDE Tool](img/e7c07bdc9717b70a31ef9474b5ed6028.png)

将出现以下弹出窗口，您可以在其中分配的值，然后单击应用和确定。

![Creating a project in VHDL using Xilinx IDE Tool](img/aee1e91f18b552a98e5f355d2a0d08c8.png)

**情况 1:** 如果输入为:

a = 0
b = 0

**输出:**

总和= 0
cout = 0

![Creating a project in VHDL using Xilinx IDE Tool](img/32b22e72d5d59d8b4347198870245b11.png)

**情况 2:** 如果输入为-

a = 0
b = 1

输出:

总和= 1
cout = 0

![Creating a project in VHDL using Xilinx IDE Tool](img/b61f26702fe8f62d2606920ab2048e72.png)

**情况 3:** 输入为-

a = 1
b = 0

**输出:**

总和= 1
cout = 0

![Creating a project in VHDL using Xilinx IDE Tool](img/b33ed772040cb0e62943b860586cfcbe.png)

**情况 4:** 输入为-

a = 1
b = 1

**输出:**

总和= 0
cout = 1

![Creating a project in VHDL using Xilinx IDE Tool](img/3494550eabae4e0e82e70b79e2b33cef.png)

* * *

## VHDL 与 C 语言

| 极高密度脂蛋白 | c 语言 |
| VHDL 是一种硬件描述语言。 | c 语言是高级语言和汇编语言的混合体。 |
| VHDL 是可合成的。 | c 是不可合成的。 |
| VHDL 处理顺序和并发指令。 | c 只处理顺序指令。 |

* * *

## 先决条件

在学习 VHDL 之前，你必须具备电子电路的基础知识。

## 观众

我们的 VHDL 教程旨在帮助初学者和专业人士。

## 问题

我们向您保证，在本 VHDL 教程中不会发现任何问题。但如果有任何错误或差错，请在联系表中注明。

* * *