# COBOL -分部

> 原文：<https://www.javatpoint.com/cobol-divisions>

COBOL 分部是 COBOL 程序最顶层的组成部分，也是最重要的一个。这通常包含一个或多个部分，这些部分后来被分成段落。它是部分、段落、句子或字符块的集合。分割线的起点是分割线名称，分割线的终点是下一个分割线的起点或节目的终点。分部是系统定义的词，所有分部都应该在 a 区

COBOL 程序可以分为以下四个部分:

*   识别部
*   环境部分
*   数据部分
*   过程部分

## 身份识别处

标识划分是每个 COBOL 程序的第一个也是强制划分。在这个部分，程序员写程序的细节，如作者姓名、执行日期、编写代码的日期等。这种划分用于标识程序，还指定了源元素的名称和类型，并且是指定类和接口的地方。

在这个部分中，我们必须在标识部分之后立即定义程序标识(一个关键字)，标识部分指定了可以包含 1 到 30 个字符的程序名称。

**语法:**

```

IDENTIFICATION DIVISION.
PROGRAM-ID. Entry
[AUTHOR. Entry].
[INSTALLATION Entry].
[DATE-WRITTEN. Entry].
[DATA-COMPILED. Entry].
[SECURITY. Entry.
[REMARKS. Entry.]

```

### 示例:

```

       IDENTIFICATION DIVISION.
       PROGRAM-ID. HELLO.
       PROCEDURE DIVISION.
            DISPLAY 'Welcome to JavaTpoint'.
       STOP RUN.

```

**输出:**

当您编译并执行上述程序时，它将显示以下输出:

![COBOL Divisions](img/f4ff54f40bf2de464e252efa22671ce9.png)

## 环境部分

环境部分用于指定程序功能，如文件和字符集，这取决于运行它的系统。在这里，我们写下关于编写和执行程序的计算机环境的细节。它也用于指定程序的输入和输出文件。环境部分由两部分组成:配置部分和输入输出部分。

*   **配置部分:**配置部分用于给出关于在其上编写和执行程序的系统的信息。它包含两个段落:编译程序的源计算机和执行程序的目标计算机。
*   **输入输出部分:**输入输出部分用于给出我们在程序中使用的文件的信息。它还包含两个段落:提供我们在程序中使用的外部数据集信息的文件控制，以及提供我们在程序中使用的文件信息的输入输出控制。

**语法:**

```

ENVIRONMENT DIVISION.
CONFIGURATION SECTION.
SOURCE-COMPUTER. Source-computer-entry.
OBJECT-COMPUTER. Object-computer-entry.
[SPECIAL NAMES. Special-computer-entry.]
INPUT-OUTPUT SECTION.
FILE CONTROL. File-control-entry.
[I-O CONTROL. Input-output-control-entry].

```

它由两部分组成:

### 1.结构节

配置部分包含关于您的系统的信息，您的程序在该系统上编写和执行。该部分必须在区域 a 中指定

它由两段组成:

*   源计算机:这将包含有关编译程序的系统的信息。
*   目标计算机:这将包含关于在其中执行程序的系统的信息。

**语法:**

```

[Optional]         [CONFIGURATION SECTION.
[Optional]         [SOURCE - COMPUTER.  {source - computer - entry}]
[Optional]		[OBJECT - COMPUTER.   {object - computer - entry}]
[Optional]		[SPECIAL - NAMES.        {special - names - entry}]]

```

### 输入输出部分

这个输入输出部分包含了所有要在 COBOL 程序中使用的文件的信息。

*   文件控制:这将显示程序中使用的外部数据集的信息。
*   输入输出控制:这将显示程序中使用的文件信息。

**语法:**

```

[Optional]          [INPUT - OUTPUT SECTION.  
[Optional]          [FILE - CONTROL.           {file - control - entry}]
[Optional]          [I-O - CONTROL.            {i-o - control - entry}]]

```

### 示例:

让我们看看环境部分的一个简单例子:

```

       IDENTIFICATION DIVISION.
       PROGRAM-ID. EXAMPLE.
       ENVIRONMENT DIVISION.
       CONFIGURATION SECTION.
           SOURCE-COMPUTER. XXX-370.
           OBJECT-COMPUTER. XXX-140.
           SPECIAL-NAMES.

       INPUT-OUTPUT SECTION.
           FILE-CONTROL.
           SELECT FILEN ASSIGN TO DDNAME
           ORGANIZATION IS SEQUENTIAL.
           I-O-CONTROL.
           DATA DIVISION.
           PROCEDURE DIVISION.
                DISPLAY 'ENVIRONMENT DIVISION WITH ALL ENTRIES..'
                STOP RUN.

```

**输出:**

![COBOL Divisions](img/0629cb706487929674f6ad472abe0ace.png)

## 数据部分

在 COBOL 中，数据划分用于声明变量和参数。这里，我们声明变量、它们的数据类型、大小、使用类型等。这是 COBOL 程序结构中最重要的部分之一。

数据划分包含四个部分:

*   **文件段:**该段用于定义文件的记录结构。
*   **工作-存储部分:**该部分用于声明程序中使用的临时变量和文件结构。
*   **本地存储部分:**该部分类似于工作存储部分。唯一不同的是，在这一部分中，变量是在程序每次开始执行时分配和初始化的。
*   **链接部分:**该部分用于描述从外部程序接收的数据名称。

**语法:**

```

DATA DIVISION.
FILE SECTION. File-section-entry.
WORKING-STORAGE SECTION. Variables.
LINKAGE SECTION.[Linkage-section-entry].
REPORT SECTION.

```

*   工作存储部分:该部分指定了程序中使用的所有临时变量和文件结构。

### 语法:

```

DATA DIVISION.
	WORKING-STORAGE SECTION.
		[Working-storage fields declaration]

```

*   本地存储部分:本地存储部分存储与工作存储部分相似的信息。唯一不同的是，在本地存储部分的情况下，变量将在每次程序开始执行时被分配和初始化。
*   链接部分:该部分描述了从外部程序接收的所有数据项。

### 语法:

```

DATA DIVISION.
LINKAGE SECTION
	[linkage section data item]

```

### 示例:

让我们看一个简单的数据部门的例子:

```

IDENTIFICATION DIVISION.
       PROGRAM-ID. HELLO.

       DATA DIVISION.
           WORKING-STORAGE SECTION.
            01 EMP-NAME1 PIC A(20).
            01 EMP-NAME2 PIC A(20).
            01 EMP-NAME3 PIC A(20).
            01 EMP-ID1 PIC 9(3) VALUE 001.
            01 EMP-ID2 PIC 9(3) VALUE 002.
            01 EMP-ID3 PIC 9(3) VALUE 003.

       PROCEDURE DIVISION.
           A000-FIRST-PARA.
              DISPLAY 'Welcome to JavaTpoint Employee List'.
              MOVE 'Sonu Jaiswal' TO EMP-NAME1.
              MOVE 'Deep Ghosh' TO EMP-NAME2.
              MOVE 'Nikita Kesharwani' TO EMP-NAME3.

              DISPLAY "1\. Founder   : "EMP-NAME1.
              DISPLAY "   Emp ID is : "EMP-ID1.

              DISPLAY "2\. Developer : "EMP-NAME2.
              DISPLAY "   Emp ID is : "EMP-ID2.

              DISPLAY "3\. Developer : "EMP-NAME3.
              DISPLAY "   Emp ID is : "EMP-ID3.

       STOP RUN.

```

**输出:**

![COBOL Divisions](img/da4e96fdc8143eebc1dac4f85842ac23.png)

## 过程部分

*   过程部分是 COBOL 程序的主要部分。像 C/C++ 程序的 main()函数。从程序上看，分部分项程序实际上将开始执行。
*   这部分是程序的逻辑部分。所有的业务逻辑都写在这里。像 C/C++ main()函数一样，所有 COBOL 程序都必须有一个过程划分。
*   过程划分包含可执行语句，可执行语句包含在数据划分中定义的变量。我们可以在过程划分中使用用户定义的名称和段落。
*   我们必须在这个部分至少指定一个语句。我们不能让它空着。
*   在这个部分，我们编写主程序代码。它提供了两种停止程序执行的方法。在调用程序的情况下，我们使用停止运行，在被调用程序的情况下，我们使用退出程序来停止程序的执行。

**语法:**

```

PROCEDURE DIVISION[USING DATA-NAME1[,DATA-NAME2,...]]. 

```

### 示例:

让我们看看程序划分的例子:

```

IDENTIFICATION DIVISION.
       PROGRAM-ID. HELLO.

       DATA DIVISION.
           WORKING-STORAGE SECTION.
            01 WS-NAME PIC A(20).
            01 WS-ID PIC 9(5) VALUE 12345.

       PROCEDURE DIVISION.
           A000-FIRST-PARA.
              DISPLAY '******** Welcome to JavaTpoint ********'.
              MOVE 'Nikita Kesharwani' TO WS-NAME.
              DISPLAY "My name is : "WS-NAME.
              DISPLAY "My ID is : "WS-ID.
       STOP RUN.

```

**输出:**

![COBOL Divisions](img/fa2294d5639204c1cc28024d78bbc47a.png)

* * *