# 数据类型

> 原文：<https://www.javatpoint.com/cobol-data-types>

在编程语言中，数据类型或简称为类型是数据的一种属性，用于向编译器或解释器解释程序员打算如何使用数据。每种编程语言都必须有数据类型。因此，数据类型用于定义程序中使用的变量类型。

在 COBOL 程序中，数据划分定义了程序中使用的变量。您必须理解以下术语来描述 COBOL 中的数据。让我们看看以下术语:

*   数据名称
*   层次编号
*   图片条款
*   价值条款

![COBOL Data Types](img/89fb7b52f1e9a3fe1563cbf156915bdd.png)

## 层次编号

一个级别号定义了在哪个位置或级别，我们可以在记录中定义一个数据。

| 层次编号 | 描述 |
| 01 | 记录描述条目 |
| 02 至 49 岁 | 组和基本项目 |
| Sixty-six | 重命名条款项目 |
| Seventy-seven | 无法细分的项目 |
| Eighty-eight | 条件名称条目 |

**基本项目**

基本项目是不可分割的项目。基本项包含级别号、图片子句、数据名称和值子句(可选)。

**组项目**

它是一个或多个基本项目的集合。组项目包含级别号、数据名称和值子句(可选)。组项目的级别编号始终为 01。

### 示例:

```

      DATA DIVISION.
           WORKING-STORAGE SECTION.
           01 WS-NAME    PIC X(25).                               ---> ELEMENTARY ITEM 
           01 WS-CLASS   PIC 9(2)  VALUE  '10'.                   ---> ELEMENTARY ITEM

        01 WS-ADDRESS.                                         ---> GROUP ITEM   
           05 WS-HOUSE-NUMBER    PIC 9(3).                     ---> ELEMENTARY ITEM
           05 WS-STREET          PIC X(15).                    ---> ELEMENTARY ITEM
           05 WS-CITY            PIC X(15).                    ---> ELEMENTARY ITEM
           05 WS-COUNTRY         PIC X(15)  VALUE 'INDIA'.     ---> ELEMENTARY ITEM

```

## 数据名称

在数据划分部分中，必须先指定数据名称，然后才能在过程划分中使用它们。

数据名称必须具有用户指定的名称；不能使用保留字。数据名称是指存储实际数据的存储位置。可以有基本项或组项。

### 示例:

```

Valid:
   WS-NAME
   TOTAL-STUDENTS
   A100
   100B

Invalid:
   MOVE               (Reserved Words)
   COMPUTE         (Reserved Words)
   100                  (No Alphabet)
   100+B              (+ is not allowed) 

```

## 图片条款

图片条款定义了以下项目:

**数据类型:**可以是任何类型，如数字、字母数字或字母。

| 数据类型 | 描述 |
| 数字的 | 0 到 9 |
| 字母的 | a 到 Z/a-z |
| 字母数字 | A-Z/a-z/0-9 |

**符号:**有数字数据，这个可以用。它可以是-或+。

**小数点位置:**有数值数据，这个可以用。假定的小数点使十进制值能够存储句点或点(。).

**长度:**长度用于描述数据项将使用的字节数。

| 标志 | 描述 |
| **9** | 数字。
数值数据类型的最大长度为 18。 |
| **A** | 字母。
字母数据类型最大长度为 255。 |
| **X** | 字母数字
字母数字数据类型的最大长度为 255。 |
| **S** | 符号 |
| **P** | 假设十进制 |

### 示例:

让我们看一个展示 PIC 条款的例子:

```

	   IDENTIFICATION DIVISION.
           PROGRAM-ID. HELLO.

       DATA DIVISION.
           WORKING-STORAGE SECTION.
           01 WS-NUM1 PIC S9(3)V9(2).
           01 WS-NUM2 PIC PPP999.
           01 WS-NUM3 PIC S9(3)V9(2) VALUE -123.45.
           01 WS-NAME PIC A(6) VALUE 'Nikita'.
           01 WS-ID PIC X(5) VALUE 'N001'.

       PROCEDURE DIVISION.
           DISPLAY "WS-NUM1 : "WS-NUM1.
           DISPLAY "WS-NUM2 : "WS-NUM2.
           DISPLAY "WS-NUM3 : "WS-NUM3.
           DISPLAY "WS-NAME : "WS-NAME.
           DISPLAY "WS-ID : "WS-ID.
       STOP RUN.

```

**输出:**

![COBOL Data Types](img/5e0f0a205fa7ec8868ce6381bf0a7b59.png)

## 价值条款

value 子句是初始化数据对象的可选子句。这些值可以是数字文字、图形常量或字母数字文字。value 子句可用于基本项和组项。

### 示例:

让我们看看 VALUE 子句的例子:

```

       IDENTIFICATION DIVISION.
           PROGRAM-ID. HELLO.

       DATA DIVISION.
           WORKING-STORAGE SECTION.
           01 WS-NUM1 PIC 99V9 VALUE IS 2.4.
           01 WS-NAME PIC A(6) VALUE 'JTP'.
           01 WS-ID PIC 99 VALUE ZERO.

       PROCEDURE DIVISION.
           DISPLAY "WS-NUM1 : "WS-NUM1.
           DISPLAY "WS-NAME : "WS-NAME.
           DISPLAY "WS-ID   : "WS-ID.
       STOP RUN.

```

**输出:**

![COBOL Data Types](img/596a669b1a02bfa333c6b0ae0f25f5e6.png)

## COBOL 的数据类型定义

在下表中，我们解释了 COBOL 的数据类型定义及其描述:

| 数据类型 | 描述 | 商用计算机编程语言 |
| INT2 | 它用于指定一个 2 字节的有符号整数。 | PIC S9(4)用法为二进制 |
| INT4 | 它用于指定 4 字节有符号整数。 | PIC S9(9)用法为二进制 |
| 浮动 4 | 它用于指定 4 字节单精度浮点数。 | COMP-1 |
| 浮动 8 | 它用于指定 8 字节双精度浮点数。 | COMP-2 |
| 浮动 16 | 它用于指定一个 16 字节的扩展精度浮点数。 | 无法使用 |
| COMPLEX8 | 它用于指定一个短的浮点复数十六进制数:一个 8 字节的复数，其实部和虚部都是 4 字节的单精度浮点数。 | 无法使用 |
| 复杂 16 | 它用于指定一个长浮点复数十六进制数:一个 16 字节的复数，其实部和虚部各为 8 字节双精度浮点数。 | 无法使用 |
| 复合物 32 | 它用于指定扩展浮点十六进制数:一个 32 字节的复数，其实部和虚部都是 16 字节的扩展精度浮点数。 | 无法使用 |
| 指针 | 它用于指定依赖于平台的地址指针。 | 用法是指针 |
| 魅力 | 它用于指定长度为 n 的字符串(字符数组)。 | PIC X(n) |

* * *