# 字符串处理

> 原文：<https://www.javatpoint.com/cobol-string-handling>

字符串处理语句在 COBOL 中用于执行字符串操作。COBOL 为字符串处理提供了三种类型的语句:

*   检查
*   线
*   解开

## 检查

Inspect 动词替换或计数字符串中的一个字符或一组字符。对于数字、字母或字母数字值，我们可以执行字符串操作。检查操作是从左到右的工作。

“检查”提供以下两个选项:

### 理货？

计数值用于计算字符串。

**语法:**

```

INSPECT input-string
TALLYING output-count FOR ALL CHARACTERS

```

这里，输入字符串和输出字符串是参数。输入字符串是要对其字符进行计数的字符串。输出字符串是保存字符数的数据项。

**示例:**

让我们看一个理货选项的例子:

```

       IDENTIFICATION DIVISION.
           PROGRAM-ID. HELLO.

       DATA DIVISION.
           WORKING-STORAGE SECTION.
           01 WS-CNT1 PIC 9(2) VALUE 0.
           01 WS-CNT2 PIC 9(2) VALUE 0.
           01 WS-STRING PIC X(15) VALUE 'ABCDACDADEAAAFF'.

       PROCEDURE DIVISION.
           INSPECT WS-STRING TALLYING WS-CNT1 FOR ALL 'F'.
             DISPLAY "WS-CNT1 : " WS-CNT1.
           INSPECT WS-STRING TALLYING WS-CNT2 FOR ALL 'A'.
             DISPLAY "WS-CNT2 : " WS-CNT2.

       STOP RUN.

```

**输出:**

![COBOL String Handling](img/4fcdee192e6b709a77982dd3042b8325.png)

### 取代

替换选项替换字符串。

**语法:**

```

INSPECT input-string REPLACING ALL char1 BY char2.

```

这里，输入字符串参数是其字符将从 char1 替换为 char2 的字符串。

**示例:**

```

       IDENTIFICATION DIVISION.
           PROGRAM-ID. HELLO.

       DATA DIVISION.
           WORKING-STORAGE SECTION.
           01 WS-STRING PIC X(15) VALUE 'ABCDBCDBDEBBBBF'.

       PROCEDURE DIVISION.
           DISPLAY "OLD STRING : "WS-STRING.
            INSPECT WS-STRING REPLACING ALL 'B' BY '$'.
             DISPLAY "NEW STRING : "WS-STRING.

       STOP RUN. 

```

**输出:**

![COBOL String Handling](img/d03a62ea11e8dd444c336c0e2edf11dc.png)

## 线

字符串动词用于将两个或多个字符串或文字的部分或全部内容连接成一个数据项。在字符串动词中，“DECLARED BY”子句是强制性的。

### 语法:

```

STRING ws-string1 DELIMITED BY SPACE
   ws-string2 DELIMITED BY SIZE
   INTO ws-destination-string
   WITH POINTER ws-count
   ON OVERFLOW DISPLAY message1
   NOT ON OVERFLOW DISPLAY message2
END-STRING.

```

这里，使用的参数详细信息有:

*   ws-string1 和 ws-string2:这些是要连接的输入字符串。
*   这是一个输出字符串。
*   ws-count:这用于计算新连接字符串的长度。
*   分隔:用于指定字符串的结尾。
*   指针和溢出:这些是可选的。

### 示例:

让我们看一个字符串动词的例子:

```

      IDENTIFICATION DIVISION.
           PROGRAM-ID. HELLO.

       DATA DIVISION.
           WORKING-STORAGE SECTION.
           01 WS-STRING PIC A(30).
           01 WS-STR1 PIC A(15) VALUE 'WorldJavaTpoint'.
           01 WS-STR2 PIC A(7) VALUE 'Welcome'.
           01 WS-STR3 PIC A(7) VALUE 'To AND'.
           01 WS-COUNT PIC 99 VALUE 1.

       PROCEDURE DIVISION.
           STRING WS-STR2 DELIMITED BY SIZE
              WS-STR3 DELIMITED BY SPACE
              WS-STR1 DELIMITED BY SIZE
              INTO WS-STRING 
              WITH POINTER WS-COUNT
              ON OVERFLOW DISPLAY 'OVERFLOW!' 
           END-STRING.

             DISPLAY 'WS-STRING : 'WS-STRING.
             DISPLAY 'WS-COUNT : 'WS-COUNT.

       STOP RUN.

```

**输出:**

![COBOL String Handling](img/bfe807ea0ae58ecfcc212bc3f666e908.png)

## 解开

非重读动词将一个字符串分成几个子字符串。“DECLARED BY”子句在非重读动词中是强制性的。

### 语法:

```

UNSTRING ws-string DELIMITED BY SPACE
INTO ws-str1, ws-str2
WITH POINTER ws-count
ON OVERFLOW DISPLAY message
NOT ON OVERFLOW DISPLAY message
END-UNSTRING.

```

### 示例:

让我们来看一个动词非重读的例子:

```

       IDENTIFICATION DIVISION.
       PROGRAM-ID. HELLO.

       DATA DIVISION.
       WORKING-STORAGE SECTION.
       01 WS-STRING PIC A(30) VALUE 'WELCOME TO JAVATPOINT'.
       01 WS-STR1 PIC A(7).
       01 WS-STR2 PIC A(2).
       01 WS-STR3 PIC A(15).
       01 WS-COUNT PIC 99 VALUE 1.

       PROCEDURE DIVISION.
           UNSTRING WS-STRING DELIMITED BY SPACE
             INTO WS-STR1, WS-STR2, WS-STR3
           END-UNSTRING.

           DISPLAY 'WS-STR1 : 'WS-STR1.
           DISPLAY 'WS-STR2 : 'WS-STR2.
           DISPLAY 'WS-STR3 : 'WS-STR3.

       STOP RUN.

```

**输出:**

![COBOL String Handling](img/81f2ad65dc53b6fb0e7e3f11c81dbae2.png)

* * *