# 文件访问模式

> 原文：<https://www.javatpoint.com/cobol-file-access-mode>

每个文件组织(在我们的上一节中，我们讨论了许多文件组织)都有不同的访问模式。

访问模式用于根据程序中的要求定义文件的访问方式。简而言之，我们可以说，访问模式定义了从文件中读写数据的方式。

主要有三种访问模式:

*   顺序存取
*   随机存取
*   动态访问

## 顺序存取

顾名思义，文件中的记录可以顺序读取，以便进行顺序访问，即从开始一个接一个地读取。

检索记录的方法因所选的文件组织而异。

在**顺序文件**中，记录的检索方式与插入时相同。

对于**索引文件**，从文件位置指示器的当前位置开始，按照所选关键字段的顺序访问记录。

对于**相对文件**，按照相对记录号的顺序访问记录。

### 语法:

```

ENVIRONMENT DIVISION.
INPUT-OUTPUT SECTION.
FILE-CONTROL.
   SELECT file-name ASSIGN TO dd-name
   ORGANIZATION IS SEQUENTIAL
   ACCESS MODE IS SEQUENTIAL

ENVIRONMENT DIVISION.
INPUT-OUTPUT SECTION.
   FILE-CONTROL.
   SELECT file-name ASSIGN TO dd-name
   ORGANIZATION IS INDEXED
   ACCESS MODE IS SEQUENTIAL
   RECORD KEY IS rec-key1
   ALTERNATE RECORD KEY IS rec-key2

ENVIRONMENT DIVISION.
INPUT-OUTPUT SECTION.
   FILE-CONTROL.
   SELECT file-name ASSIGN TO dd-name
   ORGANIZATION IS RELATIVE
   ACCESS MODE IS SEQUENTIAL
   RELATIVE KEY IS rec-key1

```

### 顺序访问模式的缺点

当文件记录较少时，顺序访问模式非常有效，但是当文件记录数量巨大时，从文件中读取特定记录将花费太多时间。

## 随机存取

在随机访问模式下，我们可以随机访问记录，即直接提供密钥。

这种访问模式通常只用于索引文件和相对文件。

对于**索引文件**，根据您在关键字段中放置的值检索记录。值可以是主要的、可选的或相对的。可以有一个或多个备用索引。

根据您在相对键中输入的值，为**相对文件**检索记录。

### 语法:

```

ENVIRONMENT DIVISION.
INPUT-OUTPUT SECTION.
   FILE-CONTROL.
   SELECT file-name ASSIGN TO dd-name
   ORGANIZATION IS INDEXED
   ACCESS MODE IS RANDOM
   RECORD KEY IS rec-key1
   ALTERNATE RECORD KEY IS rec-key2

ENVIRONMENT DIVISION.
INPUT-OUTPUT SECTION.
   FILE-CONTROL.
   SELECT file-name ASSIGN TO dd-name
   ORGANIZATION IS RELATIVE
   ACCESS MODE IS RANDOM
   RELATIVE KEY IS rec-key1

```

## 动态访问

在同一个程序中，动态访问允许顺序访问和随机访问。在动态访问模式下，我们可以对两种类型的处理(即随机和顺序处理)使用文件描述，例如在键的帮助下检索一些记录，并按顺序检索一些记录。

对于相对文件和索引文件，动态访问模式允许您在读取文件时，使用 READ 语句中的 NEXT 短语在随机访问模式和顺序访问模式之间切换。

### 语法:

```

ENVIRONMENT DIVISION.
INPUT-OUTPUT SECTION.
   FILE-CONTROL.
   SELECT file-name ASSIGN TO dd-name
   ORGANIZATION IS SEQUENTIAL
   ACCESS MODE IS DYNAMIC
   RECORD KEY IS rec-key1
   ALTERNATE RECORD KEY IS rec-key2

ENVIRONMENT DIVISION.
INPUT-OUTPUT SECTION.
   FILE-CONTROL.
   SELECT file-name ASSIGN TO dd-name
   ORGANIZATION IS RELATIVE
   ACCESS MODE IS DYNAMIC
   RELATIVE KEY IS rec-key1

```

* * *