# 数据库接口

> 原文：<https://www.javatpoint.com/cobol-database-interface>

在 COBOL 中，程序与 DB2 数据库交互。DB2 是由 IBM 开发的数据库 2。这是一个关系数据库。以表的形式存储的关系数据，包含元组(行)和属性(列)。

DB2 类似于 SQL，但具有一些高级功能，主要用于存储大量大型机应用程序数据。

在数据库接口的上下文中，COBOL 包括以下术语:

*   嵌入式 SQL
*   DB2 应用程序编程
*   主机变量
*   的组成
*   SQL 查询
*   光标

## 嵌入式 SQL

COBOL 使用嵌入式 SQL 语句来执行标准的 SQL 操作。在编译应用程序之前，这些语句由 SQL 处理器进行预处理。

COBOL 是宿主的语言。COBOL-DB2 应用程序包括 DB2 和 COBOL。

嵌入式 SQL 语句的工作方式类似于普通的 SQL(结构化查询语言)语句，只是做了一些小的改动。例如，查询的输出指向一组预定义的变量，这些变量被称为主机变量。SELECT 语句中有一个额外的 INTO 子句。

## DB2 应用程序编程

下面是编写 COBOL-DB2 程序时要遵循的规则:

*   所有的 SQL 语句都必须包含在 EXEC SQL 和 ENDEXEC 之间。
*   SQL 语句必须在区域 b 中编码。
*   程序的所有表都必须在工作存储部分由 INCLUDE 语句定义。
*   除了 INCLUDE 和 DECLARE TABLE 之外的所有 SQL 语句都必须显示在过程部分。

## 主机变量

COBOL 程序中指定的数据项是主机变量。宿主变量接受表的数据或将数据插入表中。这些变量用于从数据库传输值和检索值。

您可以在 COBOL 程序的文件部分、本地存储部分、链接部分或工作存储部分分配主机变量，并且可以有 1 到 48 之间的任何级别号。级别 49 是为 VARCHAR 数据项保留的。

主机变量不能是组项目，但是在主机结构中，它们可以被分组。它们不能被重新定义或重命名。

如果在嵌入式 SQL 语句中使用宿主变量，则必须用冒号(:)指定数据项名称前缀。冒号(:)用于使编译器能够理解主机变量和同名列/表之间的区别。

主机变量有两种使用方式:

*   输入主机变量:用于定义将从 COBOL 程序传输到数据库的数据。
*   输出主机变量:用于保存从数据库返回给 COBOL 程序的数据。

### 语法:

```

DATA DIVISION.
   WORKING-STORAGE SECTION.

   EXEC SQL
   INCLUDE table-name
   END-EXEC.

   EXEC SQL BEGIN DECLARE SECTION
   END-EXEC.

   01 STUDENT-REC.
      05 STUDENT-ID PIC 9(4).
      05 STUDENT-NAME PIC X(25).
      05 STUDENT-ADDRESS X(50).
   EXEC SQL END DECLARE SECTION
   END-EXEC.

```

## 的组成

SQLCA 是一个 SQL 通信区域，DB2 在这里将 SQL 执行反馈传递给程序。SQLCA 是一组变量，将在每个 SQL 语句执行结束时更新。具有可执行的 SQL 语句的程序可以提供一个，但不能超过一个。

它只是告诉程序执行是否成功。SQLCA 下有几个预定义的变量，比如 SQLCODE，其中包含错误代码。SQLCODE 中的值“000”指定成功执行。

### 语法:

以下是在工作存储部分声明 SQLCA 的语法:

```

DATA DIVISION.
WORKING-STORAGE SECTION.
	EXEC SQL
	INCLUDE SQLCA
	END-EXEC.

```

## 光标

DB2 支持一种称为游标的机制。游标用于逐个处理表中的一组行。它一次处理多行选择。游标是保存查询所有结果的数据结构。

我们可以在工作存储区或程序分区中定义光标。以下是与光标相关的操作:

*   删除
*   打开
*   关闭
*   取得

### 声明光标

游标声明可以在工作存储部分或过程部分进行。第一条语句是 DECLARE 语句，它是一条不可执行的语句。

**语法:**

```

EXEC SQL
   DECLARE STUDCUR CURSOR FOR
   SELECT STUDENT-ID, STUDENT-NAME, STUDENT-ADDRESS FROM STUDENT
   WHERE STUDENT-ID >:WS-STUDENT-ID
END-EXEC.

```

### 打开

在使用游标之前，应该执行 Open 语句。Open 语句为执行 SELECT 做准备。

**语法:**

```

EXEC SQL
   OPEN STUDCUR
END-EXEC.

```

### 关闭

close 语句用于释放游标占用的所有内存。结束一个程序之前应该关闭光标。

**语法:**

```

EXEC SQL
   CLOSE STUDCUR
END-EXEC.

```

### 取得

Fetch 语句用于标识游标并将值放入 INTO 子句中。Fetch 语句在循环中编码，因为我们一次只能得到一行。

**语法:**

```

EXEC SQL
   FETCH STUDCUR
   INTO :WS-STUDENT-ID, :WS-STUDENT-NAME, WS-STUDENT-ADDRESS
END-EXEC.

```

* * *