# 词汇标记

> 原文：<https://www.javatpoint.com/verilog-lexical-tokens>

Verilog 中的词法约定类似于 C 编程语言。Verilog 语言源文本文件是一个词汇标记流。

一个词法标记可以由一个或多个字符组成，每个字符正好在一个标记中。

标记可以是关键字、注释、数字、空格或字符串。所有行都应以分号(；).

*   Verilog HDL 是一种区分大小写的语言。
*   并且所有的关键字都是小写的。

### 空格

空白可以包含制表符、空格、换行符和换行符。这些字符被忽略，除非它们用于分隔其他标记。但是，空格和制表符在字符串中很重要。

### 评论

有两种类型来表示注释，例如:

1.  单行注释以标记//开始，以回车结束。
    例如//这是单行语法。
2.  多行注释以标记/*开头，以标记*/
    结尾。例如，/*这是多行语法*/

### 民数记

我们可以用二进制、十进制、十六进制或八进制格式指定常数。负数以 2 的补码形式表示。问号(？)字符在数字中使用时，是 z 字符的 Verilog 替代字符。下划线(_)在数字中的任何位置都是合法的，但作为第一个字符会被忽略。

**1。整数**

[Verilog](verilog) HDL 允许整数指定为:

*   有大小或无大小的数字(无大小是 32 位)。
*   十进制、十六进制、二进制或八进制的基数。
*   基数和十六进制数字(a、b、c、d)不区分大小写。
*   基数、大小和值之间允许有空格。

**语法**

语法如下:

```

<size>'<radix><value>

```

**2。实数**

*   Verilog 支持实数常量和变量。
*   Verilog 通过舍入将实数转换为整数。
*   实数不能包含“A”和“X”。
*   实数可以用十进制或科学符号表示。
*   < value >。< value >
*   < mantissa > E < exponent >
*   分配给整数时，实数四舍五入为最接近的整数。

**3。有符号和无符号数字**

Verilog 支持这两种类型的数字，但有一定的限制。在 [C 语言](https://www.javatpoint.com/c-programming-language-tutorial)中，我们没有 int 和 unint 类型来表示一个数是有符号整数还是无符号整数。

任何没有负号前缀的数字都是正数。或者间接方式是“未签名”。

负数可以通过在常数的大小前加一个减号来指定，这样就变成了有符号数。Verilog 内部以 2 的补码格式表示负数。可以为有符号算术添加可选的有符号说明符。

**4。负数**

负数是通过在数字的大小前放置减号(-)来指定的。base_format 和 number 之间有减号是非法的。

### 标识符

标识符是用于定义对象的名称，如函数、模块或寄存器。标识符应以字母字符或下划线字符开头。

例如，A_Z 和 a_z。

标识符是字母、数字、下划线和$字符的组合。它们最长可达 1024 个字符。

*   标识符必须以字母字符或下划线字符( **a-z A-Z_** )开头。
*   标识符可以包含字母字符、数字字符、下划线和美元符号( **a-z A-Z 0-9 _ $** )。
*   标识符最长可达 1024 个字符。

**1。转义标识符**

Verilog HDL 允许通过转义标识符在标识符中使用任何字符。

转义标识符包括标识符中任何可打印的 ASCII 字符。

*   十进制值 33 到 126，或者十六进制值 21 到 7E。
*   转义标识符以反斜杠(\)开头。反斜杠转义整个标识符。
*   转义标识符以空格字符结束，如逗号、圆括号，分号成为转义标识符的一部分，除非前面有空格。
*   用空格终止转义标识符。否则，标识符后面的字符将被视为标识符的一部分。

### 经营者

运算符是用于放置条件或操作变量的特殊字符。有一个、两个、有时三个字符用于对变量执行操作。

**1。算术运算符**

这些运算符执行算术运算。+和-用作一元(x)或二元(z-y)运算符。

算术运算中包含的运算符有加法、减法、乘法、除法和模数。

**2。关系运算符**

这些运算符比较两个操作数，并在单个位(1 或 0)中返回结果。关系操作中包含的运算符有:

*   ==(等于)
*   ！=(不等于)
*   (大于)
*   > =(大于或等于)

*   < =(小于或等于)

**3。逐位运算符**

逐位运算符对两个操作数进行逐位比较。逐位操作中包括的运算符有:

*   &(逐位与)
*   |(位 wiseor)
*   ~(按位不)
*   ^(逐位异或)
*   ~^或^~(Bit-wise XNOR)

**4。逻辑运算符**

逻辑运算符是逐位运算符，仅用于单位操作数。它们返回一个位值，0 或 1。它们可以处理整数或位组、表达式，并将所有非零值视为 1。

逻辑运算符通常用于条件语句，因为它们使用表达式。逻辑运算中包含的运算符有:

*   ！(逻辑非)
*   &&(逻辑与)
*   ||(逻辑或)

**5。还原操作员**

约简运算符是按位运算符的一元形式，对操作数向量的所有位进行运算。这些也返回一个单比特值。还原操作中包括的运算符有:

*   &(减与)
*   |(减少或)
*   ~&(还原与非门)
*   ~|(还原或非)
*   ^(约简异或)
*   ~^或^~(reduction XNOR)

**6。轮班操作员**

移位运算符将第一个操作数移位语法中第二个操作数指定的位数。

对于两个方向，左移位和右移位，空缺位置都用零填充(没有使用符号扩展)。轮班操作中包括的操作员有:

*   <
*   > >(右移)

**7。串联运算符**

串联运算符组合两个或多个操作数以形成一个更大的向量。串联操作中包含的运算符是:

*   { }(串联)

**8。复制操作员**

复制操作员正在制作一个项目的多个副本。复制操作中使用的运算符是:

*   {n{item}}(项目的 n 个文件夹复制)

**9。条件运算符**

条件运算符合成一个多路复用器。它与 C/C++ 中使用的类型相同，并根据条件计算两个表达式之一。条件运算中使用的运算符是:

*   (条件)？

### 操作数

*操作数*是 ***操作符*** 操作或工作的表达式或值。所有表达式都至少有一个操作数。

**1。文字**

文字是在 Verilog 表达式中使用的常值操作数。两种常用的 Verilog 文本是:

*   **字符串**:文字字符串操作数是用双引号(" ")括起来的一维字符数组。
*   **数字**:操作数的常数以二进制、八进制、十进制或十六进制数指定。

**2。焊线、注册表和参数**

线、正则和参数是在 Verilog 表达式中用作操作数的数据类型。位选择“x[2]”和零件选择“x[4:2]”

**位选择**和**部分选择**分别用于使用方括号“[ ]”从焊线、注册表或参数向量中选择一位和多位。

**3。函数调用**

在函数调用中，函数的返回值直接在表达式中使用，而无需先将其分配给寄存器或线路。

它只是将函数调用作为操作数类型之一。知道函数调用返回值的位宽很有用。

* * *