# 专用集成电路设计流程

> 原文：<https://www.javatpoint.com/verilog-asic-design-flow>

典型的设计流程遵循以下结构，并可分为多个步骤。这些阶段有些是并行发生的，有些是顺序发生的。

![ASIC Design Flow](img/f1c5c3a7ffbe0998372bb977b4316b9e.png)

### 要求

半导体公司的客户通常是计划在其系统或终端产品中使用芯片的其他公司。因此，客户的要求在决定芯片应该如何设计时也起着重要作用。

第一步是收集需求，估计最终产品的市场价值，并评估完成项目所需的资源数量。

### 规范

下一步是收集规范，抽象地描述功能、接口以及要设计的芯片的所有架构。这可以是大致如下的内容:

1.  需要计算能力来运行成像算法以支持虚拟现实。
2.  需要两个互连一致的 ARM A53 处理器，并且应该以 600 兆赫运行。
3.  需要 USB 3.0、蓝牙和***【PCIe】***第二代接口。
4.  它应该支持 1920x1080 像素显示器，并配有适当的控制器。

### 体系结构

现在，架构师给出了芯片应该如何运行的系统级视图。他们将决定需要什么样的其他组件，应该运行什么样的时钟频率，以及如何确定功率和性能要求。

他们还决定数据应该如何在芯片内部流动。一个例子是当处理器从系统 ram 获取成像数据并执行时的数据流。同时，图形引擎将执行前一批转储到另一部分内存的后处理数据，以此类推。

![ASIC Design Flow](img/9855bee166c2a37bcdf65d30b00cbe43.png)

### 数字设计

由于现代芯片的复杂性，不可能从零开始构建一些东西，在许多情况下，许多组件将被重用。

例如，A 公司需要一个 ***FlexCAN*** 模块来与汽车中的其他模块进行交互。他们可以从另一家公司购买**T5【flex can】T6**设计，以节省时间和精力，或者花费资源来建造一个。

用触发器和 ***CMOS*** 晶体管等基本构件来设计这样的系统是不切实际的。

相反，使用硬件描述语言(如 [Verilog](verilog) 或 [VHDL](https://www.javatpoint.com/vhdl) )开发行为描述，从功能、性能和其他高级问题方面分析设计。

这通常由数字设计师完成，类似于配备数字电子技能的高级计算机程序员。

### 确认

一旦 RTL 设计就绪，就需要验证其功能正确性。

例如，一个数字信号处理器预计会发出总线事务，从内存中获取指令，并知道这将按预期发生。

此时需要进行功能验证，这是通过***【EDA】***模拟器的帮助来完成的，模拟器可以对设计进行建模，并对设计施加不同的刺激。这是预硅验证工程师的工作。

![ASIC Design Flow](img/d62778906be8d4323e60767d201e3b28.png)

为了节省时间和达到功能闭合，设计和验证团队并行运行，设计人员发布一个***【RTL】***版本。验证团队开发了一个 ***测试平台*** 环境和测试用例来测试那个 RTL 版本的功能。

如果这些测试中的任何一个失败了，它可能表明设计有问题，并且在那个设计元素上会出现一个“bug”。这个 bug 必须在设计团队发布的下一个 RTL 版本中修复。

这个过程一直持续到对设计的功能正确性有足够的信心。

### 逻辑综合

现在，我们将把这种设计转换成带有诸如组合门和触发器等实际元件的硬件原理图。这一步叫做合成。

逻辑合成工具能够将高密度脂蛋白中的 RTL 描述转换成门级网表。这个网表是根据门和门之间的连接来描述电路的。

逻辑综合工具确保网表符合时序、面积和功率规格。通常，他们可以访问不同的技术节点流程和数字元素库，并可以进行智能计算来满足所有这些不同的标准。

这些库是从半导体工厂获得的，这些工厂为不同的组件提供数据特性，例如触发器的上升或下降时间、组合门的输入输出时间等。

### 逻辑等价

检查门级网表是否与 RTL 逻辑等价。有时，执行门级验证，其中某些元素的验证再次完成，不同之处在于这一次是在门级和较低的抽象级别。

模拟时间往往更慢，因为设计中涉及大量元素，并且会返回带注释的延迟信息。

### 放置和布线

然后，将网表输入到物理设计流程中，在 EDA 工具的帮助下完成自动布局和布线。 ***Cadence 偶遇*** 和***Synopsys IC Compiler***就是这类工具的好例子。

这将选择标准单元格并将其放入行中，为输入和输出定义球图，创建不同的金属层，并放置缓冲区以满足时序要求。

一旦这个过程完成，布局就会生成，通常会发送到制造。这个阶段通常由物理设计团队处理，他们非常熟悉技术节点和物理实现细节。

### 确认

样品芯片将由同一家半导体公司制造，或者发送给第三方，如***【TSMC】***或 ***全球铸造厂*** 。

这个例子现在经历了一个后硅验证过程，其中另一个工程师团队运行不同的测试模式。硅后验证比硅前验证更难调试，因为芯片内部节点的可见性大大降低。

一百万个时钟周期将在一秒钟内完成，追溯到错误的确切时间将是耗时的。

如果在此阶段发现任何实际问题或设计缺陷，必须在 RTL 进行修复和重新验证，并且必须执行所有后续步骤。

尽管设计流程中有多个步骤，但许多设计活动通常集中在电路 RTL 描述的优化和验证上。

需要注意的是，尽管 EDA 工具可用于自动化流程，但使用不当会导致设计效率低下。因此，设计师必须在设计过程中做出有意识的选择。

* * *