# 行为建模和时机

> 原文：<https://www.javatpoint.com/verilog-behavioral-modelling-and-timing>

在 Verilog 中，行为模型包含程序语句，这些语句控制数据类型的模拟和操作变量。

这些语句包含在过程中。每个过程都有一个相关的活动流程。

在行为模型模拟期间，所有由 ***定义的流总是*** 和 ***初始*** 语句一起在模拟时间 ***零点*** 开始。

***初始*** 语句执行一次， ***始终*** 语句重复执行。

**例**

寄存器变量 **a** 和 **b** 在模拟时间 0 分别初始化为二进制 1 和 0。

初始语句完成，在模拟运行期间不再执行。这个初始语句包含一个语句的开始-结束块。在这个开始-结束类型块中，首先初始化 **a** ，然后初始化 **b** 。

```

module behave; 
reg [1:0]a,b; 

initial 
begin 
   a = 'b1; 
   b = 'b0; 
end 

always 
begin 
   #50 a = ~a; 
end 

always 
begin 
   #100 b = ~b; 
end 
End module 

```

### 程序性作业

程序分配用于更新**整数、reg、时间、**和**记忆**变量。程序性分配和连续分配之间有很大的区别，例如:

**1。**每当输入操作数改变值时，连续赋值驱动净变量、求值和更新。

过程赋值在围绕它们的过程流结构的控制下更新寄存器变量的值。

**2。**过程赋值的右侧可以是任何计算值的表达式。但是，右侧的部分选择必须有常数索引。左侧表示从右侧接收赋值的变量。程序性作业的左侧可以采用以下形式之一:

*   寄存器、整数、实数或时间变量:对这些数据类型之一的名称引用的赋值。
*   寄存器、整数、实数或时间变量的位选择:对单个位的赋值，其他位保持不变。
*   寄存器、整数、实数或时间变量的部分选择:两个或多个连续位的部分选择，其余位保持不变。对于部分选择表单，只有常量表达式是合法的。
*   记忆元素:记忆的一个单词。位选择和部分选择在内存元素引用中是非法的。
*   以上任意形式的连接:可以指定前面四种形式中任意一种的连接，这将有效地对右侧表达式的结果进行分区，然后按顺序将分区部分分配给连接的各个部分。

### 分配延迟

在延迟赋值中，**δt**时间单位在语句执行之前经过，左侧赋值完成。有了分配内延迟，右侧立即被评估，但是在结果被放入左侧分配之前有一个**δt**的延迟。

如果另一个程序在δt 期间改变了右侧信号，它不会影响输出。合成工具不支持延迟。

**语法**

赋值具有以下语法，例如:

```

Procedural Assignmentvariable = expression
Delayed assignment#Δt variable = expression;
Intra-assignment delayvariable = #Δt expression;

```

### 阻止分配

阻塞过程赋值语句必须在顺序块中执行其后的语句之前执行。

该语句不阻止并行块中跟随它的语句的执行。

**语法**

以下语法适用于阻塞过程赋值，例如:

```

<lvalue> = <timing_control> <expression>

```

*   左值是对过程赋值语句有效的数据类型。
*   =是赋值运算符，时序控制是可选的赋值内延迟。定时控制延迟可以是延迟控制或事件控制。表达式是模拟器分配给左侧的右侧值。
    连续程序赋值和连续赋值也使用阻塞程序赋值所使用的=赋值运算符。

### 非阻塞(RTL)任务

非阻塞过程分配用于在不阻塞过程流的情况下调度分配。

每当我们想要在同一时间步内进行多个寄存器分配时，我们可以使用非阻塞过程语句，而不考虑顺序或相互依赖。

**语法**

以下语法适用于非阻塞过程赋值:

```

<lvalue> <= <timing_control> <expression>

```

*   左值是对过程赋值语句有效的数据类型。
*   <= is the non-blocking assignment operator, and timing control is the optional intra-assignment timing control.
    定时控制延迟可以是延迟控制，也可以是事件控制。表达式是模拟器分配给左侧的右侧值。非阻塞赋值运算符与模拟器用于小于或等于关系运算符的运算符相同。
*   当我们在表达式中使用< =运算符时，模拟器将其解释为关系运算符；当您在非阻塞过程赋值构造中使用< =运算符时，模拟器将其解释为赋值运算符。

当模拟器遇到非阻塞程序分配时，模拟器分两步评估和执行非阻塞程序分配:

**步骤 1:** 模拟器评估右侧，并在程序时序控制指定的时间安排新的值分配。

**第 2 步:**在时间步结束时，当给定的延迟已经到期，或者适当的事件已经发生时，模拟器通过将值分配到左侧来执行分配。

### 情况

条件语句或 if-else 语句用于决定是否执行语句。

**语法**

语法如下:

```

<statement> 
::= if ( <expression> ) <statement_or_null> 
||= if ( <expression> ) <statement_or_null> 
   else <statement_or_null> 
<statement_or_null> 

::= <statement> 
||= ; 

```

*   对<expression>进行评估。如果为真(非零已知值)，则执行第一条语句。如果为 false(零值或值为 x 或 z)，则不执行第一条语句。</expression>
*   如果有 else 语句<expression>为假，则 else 语句执行。</expression>
*   由于的数值，如果表达式被测试为零，则特定的快捷方式是可能的。

### 选择语句

case 语句是一个独特的多路决策语句，它测试一个表达式是否与其他几个表达式匹配，并相应地进行分支。

例如，case 语句对于描述微处理器指令的解码非常有用。

**语法**

case 语句具有以下语法:

```

<statement> 
::= case ( <expression> ) <case_item>+ endcase 
||= casez ( <expression> ) <case_item>+ endcase 
||= casex ( <expression> ) <case_item>+ endcase 
<case_item> 
::= <expression> <,<expression>>* : <statement_or_null> 
||= default : <statement_or_null> 
||= default <statement_or_null> 

```

*   案例表达式按照给出的确切顺序进行计算和比较。
*   在线性搜索期间，如果一个案例项表达式与括号中的表达式匹配，则执行与该案例项相关联的语句。
*   如果所有比较都失败，并且给出了默认项，则执行默认项语句。
*   如果没有给出默认语句，并且所有比较都失败，则不会执行任何 case item 语句。

case 语句在两个基本方面不同于多路 if-else-if 结构，例如:

**1。**if-else-if 结构中的条件表达式比比较一个表达式和其他几个表达式更通用，如 case 语句。

**2。**当表达式中有 x 和 z 值时，case 语句会提供一个确定的结果。

### 循环语句

循环语句有四种类型。它们用于控制一条语句执行零次、一次或多次。

**1。**永远持续执行一条语句。

**2。**重复执行一条语句固定次数。

**3。** While 执行一条语句，直到表达式变为 false，如果表达式开始为 false，则根本不执行该语句。

**4。**对于控制，通过三步过程执行其相关语句是:

**步骤 1:** 执行一个赋值，该赋值通常用于初始化一个变量，该变量控制执行的循环数。

**步骤 2:** 计算表达式。假设结果为零，则 for 循环退出。如果不为零，for 循环执行其相关语句，然后执行步骤 3。

**步骤 3:** 执行通常用于修改循环控制变量值的赋值，然后重复步骤 2。

**语法**

以下是循环语句的语法规则，例如:

```

<statement> 
::= forever <statement> 
||=forever 
begin 
   <statement>+ 
end  

<Statement> 
::= repeat ( <expression> ) <statement> 
||=repeat ( <expression> ) 
begin
   <statement>+ 
end  

<statement> 
::= while ( <expression> ) <statement> 
||=while ( <expression> ) 
begin 
   <statement>+ 
end  

<statement> 
::= for ( <assignment> ; <expression> ; <assignment> ) 
<statement> 
||=for ( <assignment> ; <expression> ; <assignment> ) 
begin 
   <statement>+ 
end

```

### 延迟控制

Verilog 以下列方式处理延迟控制，例如:

**1。延迟控制**

通过使用以下语法，可以延迟控制过程语句的执行:

```

<statement> 
::= <delay_control> <statement_or_null> 
<delay_control> 
::= # <NUMBER> 
||= # <identifier> 
||= # ( <mintypmax_expression> )

```

以下示例将分配的执行延迟了 10 个时间单位。

```

#10 rega = regb;

```

赋值的执行延迟了表达式值指定的模拟时间。

**2。事件控制**

通过使用以下事件控制语法，过程语句的执行可以与网络或寄存器上的值更改或声明事件的发生同步:

```

<statement> 
::= <event_control> <statement_or_null> 

<event_control> 
::= @ <identifier> 
||= @ ( <event_expression> ) 

<event_expression> 
::= <expression> 
||= posedge <SCALAR_EVENT_EXPRESSION> 
||= negedge <SCALAR_EVENT_EXPRESSION> 
||= <event_expression> <or <event_expression>> 

```

* <scalar_event_expression>是解析为一位值的表达式。</scalar_event_expression>

网络和寄存器上的值变化可以用作触发语句执行的事件。这就是所谓的检测隐含事件。

Verilog 语法还用于根据变化的方向来检测变化，即朝着值 1(pose edge)或值 0 (negedge)的方向。

未知表达式值的 posedge 和 negedge 行为如下:

*   从 1 到未知和从未知到 0 的转换检测到负边沿。
*   并且在从 0 到未知和从未知到 1 的转变中检测到 posedge。

### 程序

Verilog 中的所有程序都在以下四个模块中指定。

1.  初始块
2.  总是阻塞
3.  工作
4.  功能

**初始块**

*和 ***始终*** 语句在模拟开始时启用。初始块只执行一次，当语句完成时，它的活动就停止了。*

 ***语法**

以下语法适用于初始语句:

```

<initial_statement> 
::= initial <statement>

```

**例**

下面的例子说明了在模拟开始时初始化变量的初始语句的用法。

```

Initial 
Begin 
   Areg = 0; // initialize a register 
   For (index = 0; index < size; index = index + 1) 
   Memory [index] = 0; //initialize a memory 
   Word 
End

```

初始模块的另一个用途是指定波形描述，该波形描述执行一次，为被模拟电路的中心部分提供激励。

```

Initial 
Begin 
   Inputs = 'b000000; 
   // initialize at time zero 
   #10 inputs = 'b011001; // first pattern 
   #10 inputs = 'b011011; // second pattern 
   #10 inputs = 'b011000; // third pattern 
   #10 inputs = 'b001000; // last pattern 
End 

```

**始终阻止**

总是重复执行块。只有当模拟终止时，它的活动才会终止。模块中定义的初始块和始终块的数量没有限制。

**语法**

在整个模拟运行过程中，始终语句不断重复。“总是”语句的语法如下

```

<always_statement> 
::= always <statement> 

```

由于其循环特性，总是语句仅在与某种形式的定时控制结合使用时有用。

**任务和功能**

任务和功能是由其他过程中的一个或多个位置启用的过程。

* * **