# RTL Verilog

> 哎哎哎:# t0]https://www . javatppoint . com/RTL-verilog

在数字电路设计中，**寄存器传输级(RTL)** 是一种设计抽象，它根据硬件寄存器之间的数据流以及对这些信号执行的逻辑操作来模拟同步数字电路。

寄存器传输级抽象在 HDL 中用于创建电路的高级表示，从中可以导出低级表示和最终的实际布线。RTL 设计是现代数字设计的典型实践。

![RTL Verilog](img/f8b1ccb29ab6eafe86ca071b5b909f1d.png)

同步电路由两个元件组成，例如:

*   **寄存器(时序逻辑):**寄存器使电路的操作与时钟信号的边沿同步，并且是电路中唯一具有存储器属性的元件。并且它们通常被实现为 D 触发器。
*   **组合逻辑:**组合逻辑执行电路中的所有逻辑功能。它由逻辑门组成。

例如，下图显示了一个简单的同步电路。反相器从输出端 Q 连接到寄存器的输入端 D，形成一个电路。它在 CLK 的每一个上升沿都会改变它的状态。在该电路中，组合逻辑由反相器组成。

![RTL Verilog](img/001ce195271c42d6821803f6067c3105.png)

在用硬件描述语言设计数字集成电路时，设计通常安排在比晶体管级或逻辑门级更高的抽象级别。

在 HDLs 中，设计者声明寄存器，这些寄存器大致对应于编程语言中的变量，并通过使用 if-then-else 和算术运算等构造来描述组合逻辑。

这个等级叫做 ***注册-转移等级*** 或者 ***RTL*** 。术语“RTL”着重描述寄存器之间的信号流。

这种描述通常可以使用 EDA 工具直接翻译成等效的硬件实现文件进行合成。合成工具还执行逻辑优化。

在寄存器传输级别，可以识别某些类型的电路。如果从一个寄存器的输出到它的输入有一个循环的逻辑路径，那么这个电路被称为 ***状态机*** 或时序逻辑。

如果从一个寄存器到另一个寄存器存在无周期的逻辑路径，则称之为 ***流水线*** 。

### RTL 电路设计周期

RTL 用于集成电路设计周期的逻辑设计阶段。逻辑综合工具将 RTL 描述转换为电路的门级描述。

然后，布局和布线工具使用合成结果来创建物理布局。逻辑模拟工具可以使用设计的 RTL 描述来验证其正确性。

### 功率估计技术

最精确的功率分析工具可用于电路级，但即使使用开关而不是器件级建模，电路级工具也有缺点。它们要么太慢，要么需要太多内存。

其中大多数是类似 SPICE 的模拟器，被设计者用作性能分析工具多年

由于这些缺点，门级功率估计工具已经开始获得一些认可，更快的概率技术已经开始站稳脚跟。

但它也有其权衡，因为加速是以精度为代价实现的，尤其是在存在相关信号的情况下。

多年来，人们已经认识到低功耗设计不能来自电路和门级优化。相比之下，系统、架构和算法优化往往对功耗影响最大。因此，工具开发人员倾向于高级分析和优化工具。

### 门等效技术

这是一种基于等效门概念的技术。芯片架构的复杂性可以近似地用门等效来描述，其中等效门计数指定了实现特定功能所需的参考门的平均数量。

特定功能所需的总功率通过将近似门当量乘以每个门消耗的平均功率来估算。参考门可以是任何门，例如 2 输入与非门。这种技术分布在以下类型中，例如:

**1。类独立功率建模:**这是一种尝试根据栅极等效物方面的设计复杂性信息来估计芯片面积、速度和功耗的技术。

功能被划分在不同的块中，但是块的功能没有区别。

它是阶级独立的。这种技术被 ***芯片评估系统*** (CES)使用。这项技术完成了以下步骤:

**第一步:**识别 ***计数器、解码器、乘法器、存储器*** 等功能块。

**步骤 2:** 根据门等效物分配复杂度。每种单位类型的通用电气公司的数量或者直接作为用户的输入，或者从库中输入。

**2。类相关功率建模:**这种方法比以前的方法稍好，因为它考虑了针对不同类型功能块的定制估计技术。

因此，它试图提高建模精度，而以前的技术如 ***逻辑、内存、互连*** 和 ***时钟*** 则没有。

功率估计以非常类似于独立情况的方式完成。基本开关能量基于三输入与门，由技术参数计算得出，例如门宽、tox 和用户提供的金属宽度。

**缺点**

这种方法也有以下缺点，例如:

1.  电路活动没有被精确地建模，因为整个芯片的总活动因子是假定的，这也是用户提供的不可信的。
2.  整个芯片中的活动因子会有所不同；因此，这不是很准确，容易出错。这导致的问题是，即使模型给出了芯片总功耗的正确估计，模块式功率分配也相对不准确。
3.  所选的活动因子给出了正确的总功率，但是功率被分解成逻辑、时钟、存储器等。不太准确。
4.  与 CES 相比，这个工具没有太大的不同或改进。

### 预表征细胞库技术

该技术通过为逻辑、存储器和互连设置单独的功率模型，进一步定制各种功能块的功率估计。这些建议了一种*(PFA)功率因数近似方法，用于单独表征整个功能块库，例如乘法器、加法器等。而不是“逻辑”块的单一门等效模型。*

 ***优势**

预表征细胞库技术具有以下优点:

*   根据适合该块的任何复杂度参数，定制都是可能的。对于乘数来说，字长的平方是合适的。
*   存储容量以位为单位用于存储，仅字长就足以满足输入/输出驱动程序。

* * **