# Verilog 阵列

> 原文：<https://www.javatpoint.com/verilog-arrays>

Verilog 数组用于将元素分组到多维对象中，以便更容易操作。Verilog 没有用户定义的类型，我们仅限于内置 Verilog 类型的数组，如 ***网、regs、*** 和其他 Verilog 变量类型。

数组是相同类型变量的集合，使用相同的名称加上一个或多个索引进行访问。

每个数组维度通过方括号内的 ***min*** 和 ***max*** 索引来声明。数组索引可以在任一方向上写入:

```

array_name[least_significant_index:most_significant_index]
array_name[most_significant_index:least_significant_index]

```

多维数组可以通过在数组声明后有多个维度来声明。

数组标识符前的任何方括号都是数组中复制的数据类型的一部分。

Verilog 阵列是可合成的，因此我们可以在可合成的 RTL 代码中使用它们。

在 C 语言中，数组由整数从 0 开始索引，或者转换成指针。但是整个数组是可以初始化的，每个元素都必须在过程语句中读取或单独写入。

在 Verilog-2001 中，数组是从左到右索引的。如果它们是向量，它们可以被指定为单个单位，但如果它们是数组，则不能。Verilog-2001 允许多维度。

在 Verilog-2001 中，所有数据类型都可以声明为数组。导线、reg 和所有其他网络类型也可以声明向量宽度。在对象名称之前声明的尺寸称为 ***向量宽度*** 尺寸。

Verilog-2005 规范还将具有类型 ***reg*** 元素的一维数组称为内存。它有利于对只读存储器和随机存取存储器等存储元件进行建模。

对象名后声明的维度称为 ***数组*** 维度。数组保存固定数量的大小相等的数据元素。

使用连续的整数范围通过索引来访问单个元素。有些数组允许使用任何数据类型的非连续值来访问单个元素。

数组可以分为固定大小的数组，也称为静态数组，一旦声明，静态数组的大小就不能改变，或者动态数组可以调整大小。

Verilog 只有一种类型的数组。Verilog 数组可以是*或 ***未包装*** 。压缩数组是指在类型之后和数据标识符名称之前声明的维度。解包数组是指在数据标识符名称后声明的维度。*

 *### 打包或固定阵列

在 [Verilog](https://www.javatpoint.com/verilog) 中，术语打包数组是指在对象名称之前声明的维度。

一维压缩数组也称为向量。压缩数组将向量分成子字段，这些子字段可以作为数组元素访问。在模拟和合成中，打包数组保证表示为一组连续的位。

打包数组只能由单比特数据类型 ***比特、逻辑、reg*** 、枚举类型以及其他打包数组和打包结构组成。这也意味着我们不能使用预定义宽度的整型数组。

压缩数组的最大大小可以限制，但至少应为 65536 (216)位。

打包的数组保证表示为一组*连续的位。*

 *### 未打包的数组

在 Verilog 中，术语“解包数组”用于指在对象名称后声明的维度。

未打包的数组可以由任何数据类型组成。每个固定大小的维度由一个地址范围表示，如[0:1023]。

或一个正数来指定固定大小的解包数组的大小，如[1024]。符号大小相当于[0:size-1]。

未打包的数组可以表示为一组相邻的位，也可以不表示为一组相邻的位。

### 多维数组

多维数组可以用包装维度和未包装维度来声明。创建多维压缩数组类似于将一个连续向量分割成多个维度。

当一个数组有多个可以逻辑分组的维度时，使用***【typedef】***来分阶段定义多维数组以增强可读性是很有用的。

### Verilog 数组索引和切片

Verilog 数组一次只能访问一个元素。在 Verilog 数组中，我们还可以选择一个数组的一个或多个连续元素。这叫一个 ***切片*** 。

数组切片只能应用于一维；其他维度在表达式中必须有单个索引值。

### Verilog 阵列操作

Verilog 阵列比传统的 Verilog 阵列支持更多的操作。

*   **+:和-:符号**

当访问一个 Verilog 数组切片的范围时，我们可以使用[start+:递增宽度]和[start-:递减宽度]符号来指定一个变量切片。

它们比选择可变切片时需要计算精确的开始和结束索引更简单。递增或递减宽度必须是常数。

```

bit signed [31:0] car A [7:0];                          // unpacked array of 8 32-bit vectors
int car B [1:0];                                                // unpacked array of 2 integers
car B = car A [7:6];                                        // select a 2-vector slice from car A
car B = car A [6+:2];                                     // equivalent to car A[7:6]

```

*   **分配和复制操作**

Verilog 阵列支持更多的操作。以下操作可以在打包和未打包的阵列上执行。

```

A = B;                              // reading and writing the array
A[i:j]  = B[i:j];                 // reading and writing a slice of the array
A[x+:c] = B[y+:d];          // reading and writing a variable slice of the array
A[i] = B[i];                      // accessing an element of the array
A == B;                           // equality operations on the array
A[i:j]  != B[i:j];               // equality operations on slice of the array

```

*   **打包阵列分配**

Verilog 打包数组可以一次分配，例如多位向量、单个元素或片等等。

```

logic [1:0][1:0][7:0] packed_3d_array;

always_ff @(posedge clk, negedge rst_n)
  if (!rst_n) begin
    packed_3d_array <= '0;                             // assign 0 to all elements of array
  end

  else begin
    packed_3d_array[0][0][0]   <= 1'b0;                    // assign one bit
    packed_3d_array[0][0]      <= A0a;                    // assign one element
    packed_3d_array[0][0][3:0] <= 4'ha;                   // assign part select
    packed_3d_array[0]         <= 16'habcd;                // assign slice
    packed_3d_array            <= 32'h01234567;         // assign entire array as vector
  end

```

*   **解包数组分配**

Verilog 解包数组的所有或多个元素都可以分配给一个值列表。

该列表可以包含单个数组元素的值，也可以包含整个数组的默认值。

```

logic [7:0] a, b, c;
logic [7:0] d_array[0:3];
logic [7:0] e_array[3:0];                // note index of unpacked dimension is reversed

logic [7:0] mult_array_a[3:0][3:0];
logic [7:0] mult_array_b[3:0][3:0];

always_ff @(posedge clk, negedge rst_n)
  if (!rst_n) begin
    d_array <= '{default:0};                                  // assign 0 to all elements of array
  end

  else begin
    d_array        <= '{A00, c, b, a};                    // d_array[0]=A00, d_array[1]=c,    
                                                                             d_array[2]=b, d_array[3]=a

    e_array        <= '{A00, c, b, a};                    // e_array[3]=A00, e_array[2]=c,   
                                                                             e_array[1]=b, d_array[0]=a

    mult_array_a   <= '{'{A00, A01, A02, A03}, '{A04, A05, A06, A07},
                                    '{A08, A09, A0a, A0b},
                                    '{A0c, A0d, A0e, A0f}};               // assign to full array
    mult_array_b[3] <= '{A00, A01, A02, A03};        // assign to slice of array
  end

```

* * ***