# Verilog端口

> 原文：<https://www.javatpoint.com/verilog-ports>

端口是 Verilog 模块的重要组成部分。端口用于模块通过输入和输出与外部世界进行通信。

它通过引脚与芯片通信，因为模块是放置在印刷电路板上的预制芯片。

端口列表中的每个端口必须声明为 ***输入、输出*** 或 ***输入*** 。默认情况下，声明为其中一个端口的所有端口都被认为是有线的，否则需要再次声明。

端口，也称为引脚或端子，用于将模块连接到其他模块。

*   如果模块不与环境交换任何信号，则列表中没有端口。
*   考虑一个在顶层模块中实例化的 4 位全加器。
*   模块 fulladd4 在端口 a、b 和 c_in 接收输入，并在端口 sum 和 c_out 产生输出。

![Verilog Ports](img/1aac4e23b49cea47cf6b28343a1b27f1.png)

### 港口声明

端口列表中的每个端口根据端口信号的方向定义为输入、输出或输入输出。

如果端口声明包括网络或变量类型，则该端口被认为是完全声明的。在网络或变量类型声明中声明相同的端口是非法的。

如果端口声明不包含网络或变量类型，那么端口可以在网络或变量类型声明中再次声明。

例如，考虑上图所示的顶部和全加器端口。

```

module fulladd4(sum, c_out, a, b, c_in); //Begin port declarations section 
output [3 : 0] sum; 
output c_out; 
input [3:0] a, b; 
input c_in; 
//End port declarations section 
<module internals>
endmodule 

```

#### 注意:按照惯例，模块的输出总是在端口列表中的第一位。这个约定也用于 Verilog 中的预定义模块。

**焊线和区域**

在 [Verilog](https://www.javatpoint.com/verilog) 中，所有端口声明都隐式声明为 ***线*** 。如果一个端口是一条线，那么将它声明为输出、输入或输入输出就足够了。

输入和输入端口通常被声明为线。但是，如果输出端口保持它们的值，它们必须声明为 ***reg*** ，如下所示:

```

module DFF(q, d, clk, reset); 
output q; 
reg q; // Output port q holds value; so it is declared as reg input d, clk, reset;
endmodule

```

#### 注意:输入 和 ***类型的端口不能声明为 reg。***

### 端口连接规则

在模块实例化中指定的信号和模块定义中的端口之间建立连接有两种方法。

**1。按顺序列表连接:**是初学者最简单的方法。要连接的信号必须以与模块定义中的端口相同的顺序出现在模块实例中。

**2。按名称连接端口:**适用于模块具有大约 50 个或更多端口的大型设计。在这种情况下，记住模块定义中端口的顺序既复杂又不切实际。

Verilog 提供了通过端口名称而不是位置将外部信号连接到端口的功能。

按名称连接端口的另一个主要原因是，只要不更改端口名称，就可以重新排列模块端口列表中的端口顺序，而无需更改模块实例中的端口连接。

### 端口变化

*   Verilog 进行了一些研究，最初的 IEEE 版本在 ***1995 年*** 进行港口申报时采用了以下方式。

这里，模块声明必须首先列出括号内的端口名称。然后是稍后在模块主体中定义的那些端口的方向。

```

module test (a, b, c);

	input 	[3:0] a;            // inputs "a" and "b" are wires
	input 	[3:0] b;
	output 	[3:0] c; 			// output "c" by default is a wire

	// Still, we declare them again as wires 
	wire 	[3:0] a;
	wire 	[3:0] b;
	wire 	[3:0] c;
endmodule
module test (a, b, c);

              input  [3:0] a, b;
              output [3:0] c;           // By default c is of type wire

             // port "c" is changed to a reg type

             reg    [3:0] c;

endmodule

```

*   ANSI-C 风格的端口命名是在 ***2001*** 中引入的。它允许在端口列表中指定类型。

* * *