# Verilog 运算符

> 原文：<https://www.javatpoint.com/verilog-operators>

运算符对表达式中的一个或多个操作数执行运算。表达式将操作数与适当的运算符相结合，以生成所需的函数表达式。

### 1.算术运算符

对于现场可编程门阵列来说，除法和乘法非常昂贵，有时我们无法合成除法。如果我们使用 Z 或 X 作为值，结果是未知的。这些操作将这些值视为无符号的。

| 性格；角色；字母 | 已执行的操作 | 例子 |
| + | 增加 | b + c = 11 |
| - | 减去 | b - c = 9，-b=-10 |
| / | 划分 | b / a = 2 |
| * | 乘；成倍增加；（使）繁殖 | a * b = 50 |
| % | 系数 | b % a = 0 |

### 2.按位运算符

对每个位进行操作，结果是最大操作数的大小，较小的操作数用零扩展到较大操作数的大小。

| 性格；角色；字母 | 已执行的操作 | 例子 |
| ~ | 反转每个位 | ~a = 3'b010 |
| & | 每一位 | b & c = 3'b010 |
| &#124; | 或者每一位 | a &#124; b = 3'b111 |
| ^ | 异或每一位 | a ^ b = 3'b011 |
| ^~还是~^ | Xnor 每个位 | a ^~ b = 3'b100 |

### 3.约简算子

这些运算符将向量减少到只有一位。如果有字符 z 和 x，结果可以是一个已知的值。

| 性格；角色；字母 | 已执行的操作 | 例子 |
| & | 和所有位 | &a = 1'b0，&d = 1'b0 |
| ~& | Nand 所有位 | ~&a = 1'b1 |
| &#124; | 或所有位 | &#124; a = 1’B1，&#124; c = 1’bx |
| ~&#124; | 也不是所有的位 | ~&#124;a= 1'b0 |
| ^ | 异或所有位 | ^a = 1'b1 |
| ^~还是~^ | Xnor 所有位 | ~^a = 1'b0 |

### 4.关系运算符

这些运算符比较操作数，得出一个 1 位标量布尔值。大小写等式和不等式运算符可用于未知或高阻抗值(z 或 x)，如果两个操作数未知，结果为 1。

| 性格；角色；字母 | 已执行的操作 | 例子 |
| > | 大于 | a > b = 1'b0 |
| < | 小于 | a < b = 1'b1 |
| >= | 大于或等于 | a >= d = 1'bX |
| <= | 小于或等于 | a <= e = 1'bX |
| == | 平等 | a == b = 1'b0 |
| ！= | 不平等 | a！= b = 1'b1 |
| === | 案例平等 | e === e = 1'b1 |
| ！=== | 案例不等式 | a！== d = 1'b1 |

### 5.逻辑运算符

这些运算符比较操作数，得出一个 1 位标量布尔值。

| 性格；角色；字母 | 已执行的操作 | 例子 |
| ！ | 不正确 | ！(a && b) = 1'b1 |
| && | 这两种表达都是正确的 | a && b = 1'b0 |
| &#124;&#124; | 一个或两个表达都是真的 | a &#124;&#124; b = 1'b1 |

### 6.移位运算符

这些运算符将操作数向右或向左移动，大小保持不变，移动的位丢失，向量用零填充。

| 性格；角色；字母 | 已执行的操作 | 例子 |
| >> | 右移 | b >> 1 结果 4？b010X |
| << | 左移位 | a << 2 结果 4？b1000 |

### 7.赋值运算符

有三个赋值运算符，每个运算符执行不同的任务，并用于不同的数据类型:

*   分配(连续分配)
*   < =(非阻塞分配)
*   =(阻塞分配)

### 8.其他操作员

这些是用于条件测试和创建向量的运算符。

| 性格；角色；字母 | 已执行的操作 | 例子 |
| ？： | 条件测试 | 测试条件。？如果是真的，就这样做；如果不是真的，就这样做 |
| {} | 连锁的 | c = {a，b} = 8'101010x0 |
| {{}} | 复制的 | {3{2'b10}}= 6'b101010 |

### 9.运算符优先级

表的顺序告诉我们首先进行什么操作。第一个优先级最高。()可用于覆盖默认值。

| 运算符优先 |
| +, -, !，~(一元) |
| +，-(二进制) |
| <> |
| ，<=,> = |
| ==, != |
| & |
| ^、^~或~^ |
| &#124; |
| && |
| &#124;&#124; |
| ？： |

* * *