# Verilog分配

> 原文：<https://www.javatpoint.com/verilog-assignments>

将值放在变量和网络上称为赋值。有三种必要的形式:

1.  程序的
2.  连续的
3.  过程连续的

### 合法的 LHS 价值观

赋值有两部分，右手边(RHS)和左手边(LHS)，中间有一个等号(=)或小于等于的符号(< =)。

| 分配类型 | 左侧 |
| 程序的 | 

*   Variable (vector or scalar)
*   Bit selection or partial selection of integer, vector register or time variable.
*   Memory words.
*   Series connection of any of the above items.

 |
| 连续的 | 

*   Net (vector or scalar)
*   Bit selection or partial selection of vector network.
*   The concatenation of bit selection and partial selection.

 |
| 程序连续 | 

*   [Variable or network (scalar/vector)]
*   Partial selection or bit selection of vector network.

 |

RHS 可以包含评估为最终值的任何表达式，而 LHS 表示 RHS 值被分配到的变量或净值。

### 程序分配

过程赋值发生在过程中，如 ***【初始】【始终】【任务】*** 和 ***函数*** 用于将值放置到变量上。该变量将保持该值，直到对同一变量的下一次赋值。

当模拟在模拟期间执行该语句时，该值将被放入变量中。这可以通过使用控制流语句(如***【if-else-if】、循环*** 、 ***案例语句*** 机制)按照我们想要的方式进行修改和控制。

```

reg [7:0]  data;
integer    count;
real       period;

initial begin
	data = 8'h3e;
	period = 4.23;
	count = 0;
end

always @ (posedge clk)
              count++;

```

**变量声明分配**

初始值可以在声明时放在变量上。赋值没有持续时间，并保持该值，直到对同一变量的下一次赋值发生。

#### 注意:不允许对数组进行变量声明赋值。

```

module my_book;
	reg [31:0] data = 32'hdead_cafe;
	initial begin
 #20  data = 32'h1234_5678;    // data will have dead_cafe from time 0 to 20 
	end
endmodule
reg [3:0] a = 4'b4;
reg [3:0] a;
initial a = 4'b4;

```

如果变量在声明过程中被初始化，并且在如下所示的初始块中被初始化 0 次，则评估的顺序不能保证，因此可以是 8'h05 或 8'hee。

```

module my_book;
reg [7:0]  addr = 8'h05;
	initial
		addr = 8'hee;
endmodule
reg [3:0] array [3:0] = 0;              // illegal
integer i = 0, j;                             // declares two integers i,j and 0 is assigned to i
real r2 = 4.5, r3 = 8;          // declares two real numbers r2,r3 and are assigned 4.5, 8 resp.
time startTime = 40;                   // declares time variable with initial value 40

```

### 连续分配

这是用来给标量网和矢量网赋值的。每当 RHS 发生变化时，就会发生这种情况。

它提供了一种在不指定门的互连的情况下对组合逻辑建模的方法，并使用逻辑表达式驱动网络变得更加容易。

```

// Example model of an AND gate
wire  a, b, c;
assign a = b & c;

```

每当 b 或 c 改变它的值时，RHS 中的整个表达式将被求值并用新值更新。

**净申报分配**

这允许我们在声明 net 的同一个语句上放置一个连续的赋值。

#### 注意:只能有一个声明赋值，因为一个网只能声明一次。

```

wire  penable = 1;

```

### 程序性连续赋值

这些是过程语句，允许表达式被连续赋值给变量或网。这是两种类型。

**1。分配取消标记:**它将覆盖变量的所有程序分配，并使用与 ***取消标记*** 相同的信号将其停用。

变量的值将保持不变，直到变量通过过程性或过程性连续赋值获得新值。

赋值 语句的 LHS 不能是部分选择、位选择或数组引用，但可以是变量或变量的组合。

```

reg q;
initial begin
    assign q = 0;
    #10 deassign q;
   end

```

**2。强制释放:**这些类似于 ***赋值取消符号*** 语句，但也可以应用于网络和变量。

LHS 可以是网的位选择、网的部分选择、变量或网，但不能是数组的引用和变量的位或部分选择。

***force*** 语句将覆盖对变量的所有其他赋值，直到使用 ***release*** 关键字将其释放。

```

reg o, a, b;
initial begin
           force o = a & b;
           ……….
            release o;
end

```

* * *