# Verilog 函数

> 原文：<https://www.javatpoint.com/verilog-functions>

函数的目的是返回要在表达式中使用的值。函数定义总是以 ***函数*** 关键字开始，后跟返回类型、名称和括在括号中的端口列表。它以 ***endfunction*** 关键字结束。

函数应该至少有一个输入声明和一个语句，该语句将一个与函数同名的值赋给寄存器。如果函数不返回任何内容，返回类型可以是*。*

 *函数只能在模块声明中声明，并且可以通过始终块、连续赋值或其他函数调用。在连续赋值中，当任何声明的输入发生变化时，就会对它们进行求值。在过程中，它们在被调用时被求值。

函数描述组合逻辑。函数是重用过程代码的好方法，因为模块不能从过程中调用。

返回的类型或范围声明后跟函数标识符和分号应该出现在函数关键字之后。函数可以包含返回类型、参数、范围、寄存器、事件和输入参数的声明。这些声明类似于模块项声明。

Net 声明是非法的。不需要声明寄存器、参数、事件、范围和返回类型。没有范围或返回类型声明的函数返回一位值。

任何表达式都可以用作函数调用参数。函数不能包含任何时间控制的语句，也不能启用任务。函数只能返回一个值。

当我们发现特定的代码片段在 RTL 内被重复调用多次时，它们大多不会消耗模拟时间。它们可能涉及复杂的计算，需要用不同的数据值来完成。

在这种情况下，我们可以声明一个函数，并将重复的代码放在函数中，并允许它返回结果。

这将减少 RTL 的线路数量。现在我们需要做一个函数调用，传递需要执行计算的数据。

**语法**

以下是在 [Verilog](https://www.javatpoint.com/verilog) 中使用函数的语法:

```

function [automatic] [return_type] name ([port_list]);
	[statements]

endfunction

```

关键字 automatic 将使*可重入任务中声明的动态分配而不是在任务的不同调用之间共享的函数和项目。这对于递归函数以及同一函数由 N 个进程并发执行时非常有用。*

 *### 函数声明

函数声明指定函数的名称、函数输入参数、函数中使用的变量(reg)、函数返回值的宽度以及函数局部参数和整数。

**语法**

以下是在 Verilog 中声明函数的指定语法:

```

function [msb: lsb] function_name;
    input [msb: lsb] input_arguments;
    reg [msb: lsb] reg_variable_list;
    parameter [msb: lsb] parameter_list;
    integer [msb: lsb] integer_list;
             [statements]
Endfunction 

```

**例**

```

function [7:0] sum;
	input [7:0] a, b;
	begin
		sum = a + b;
	end

```

### 函数返回值

函数定义将隐式创建一个与函数同名的内部变量。

因此，在函数范围内声明另一个同名变量是非法的。返回值通过将函数结果赋给内部变量来初始化。

```

sum = a + b;

```

### 调用函数

函数调用是带有表达式的操作数。函数调用必须在其终端列表中指定所有输入参数。

**例**

```

reg [7:0] result;
reg [7:0] a, b;
initial begin
	a = 4;
	b = 5;
	#10 result = sum (a, b);
end

```

### 规则

以下是 Verilog 函数的一些一般规则:

*   一个函数不能包含任何时间控制语句，如 ***#、@、等待、*** 和 ***否定*** 。
*   函数无法启动任务，因为它可能会消耗模拟时间，但可以调用其他函数。
*   函数应该至少有一个输入参数。
*   一个函数不能有非阻塞赋值、强制释放或赋值取消符号。
*   函数不能有任何触发器。
*   一个函数不能有 ***inout*** 或 ***output*** 声明。
*   函数必须包含将返回值赋给隐式函数名寄存器的语句。

* * ***