# Verilog任务

> 原文：<https://www.javatpoint.com/verilog-task>

函数意味着对输入进行一些处理并返回一个值。相比之下，一个任务更通用，可以使用 ***输出*** 和 ***inout*** 类型参数计算多个结果值并返回。

任务可以包含耗时的模拟元素，如 **@、posedge** 等。所有编程语言都使用任务，通常称为过程或子程序。

数据被传递给任务，处理完成，结果返回。它们必须通过数据的输入和输出被专门调用，而不是仅仅连接到一般的网表中。

包含在代码主体中，可以多次调用，减少代码重复。

*   任务在使用它们的模块中定义。可以在单独的文件中定义一个任务，并使用编译后的指令，包括文件中的任务，该指令实例化该任务。
*   任务可以包括定时延迟，例如 ***posedge，negedge，# delay*** ，以及 ***wait*** 。
*   任务可以有任意数量的输入和输出。
*   任务中声明的变量是该任务的本地变量。任务中的声明顺序定义了如何使用调用者传递给任务的变量。
*   当不使用局部变量时，任务可以获取、驱动和获取全局变量。当使用局部变量时，仅在任务执行结束时分配输出。
*   任务可以调用另一个任务或函数。
*   任务可以用于组合逻辑和时序逻辑的建模。

必须使用语句专门调用任务。它不能像函数一样在表达式中使用。

**语法**

任务以关键字 task 开始，以关键字 endtask 结束。输入和输出在关键字任务之后声明。

局部变量在输入和输出声明之后声明。

```

// Style 1

task [name];
	input  [port_list];
	inout  [port_list];
	output [port_list];
	begin
		[statements]
	end
endtask

// Style 2

task [name] (input [port_list], inout [port_list], output [port_list]);
	begin
		[statements]
	end
endtask

```

关键字 ***【自动】*** 将使 ***重新进入*** 任务。否则，默认情况下它将是静态的。如果一个任务是静态的，那么它的所有成员变量将在同一任务的不同调用之间共享，该任务已经并发启动。

#### 注意:分层引用不能访问自动任务项。

### 调用任务

如果任务不需要任何参数，那么可以避免参数列表。如果任务需要参数，可以在调用时在同一个语句中提供它们。

```

//Style 1
task sum (input [7:0] a, b, output [7:0] c);
		begin
			c = a + b;
		end
	endtask

// Style 2
	task sum;
		input  [7:0] a, b;
		output [7:0] c;
		begin
			c = a + b;
		end
	endtask
           initial begin
		reg [7:0] x, y , z;
		sum (x, y, z);
	end

```

任务使能参数(x，y，z)对应于任务定义的参数(a，b，c)。

由于 **a** 和 **b** 为输入，因此 **x** 和 **y** 的值将分别置于 **a** 和 **b** 中。由于 **c** 在调用时被声明输出并与 **z** 连接，所以总和会自动从 **c** 传递给变量 **z** 。

### 全局任务

在所有模块之外声明的任务称为全局任务，因为它们具有全局范围，可以在任何模块内调用。

```

// This task is outside all modules
task display();
  $display("Hello");
endtask
module des;
  initial begin
    display();
  end
endmodule

```

执行上述代码后，它会产生以下输出。

```

xcelium> run
Hello 
xmsim: *W,RNQUIE: Simulation is complete.

```

### 功能和任务的区别

| 功能 | 工作 |
| 它不能有时间控制语句/延迟，因此在相同的模拟时间单位中执行。 | 它可以包含时间控制语句/延迟，并且只能在其他时间完成。 |
| 它无法启用任务。 | 它可以启用其他任务和功能。 |
| 该函数应该至少有一个输入参数，不能有输出或 inout 参数。 | 任务可以有零个或多个任何类型的参数。 |
| 一个函数只能返回一个值。 | 它不能返回值，但可以使用输出参数达到同样的效果。 |

* * *