# Verilog帧间和帧内延迟

> 原文：<https://www.javatpoint.com/verilog-inter-and-intra-delay>

Verilog 延迟语句可以在赋值运算符右侧的左侧指定延迟。

### 任务间延迟

赋值间延迟语句在赋值运算符的左侧有延迟值。

内部分配是那些延迟语句，其中整个语句或分配的执行被延迟。

在 [Verilog](https://www.javatpoint.com/verilog) 中，内部分配延迟通常对应于惯性延迟或 [VHDL](https://www.javatpoint.com/vhdl) 的常规延迟语句。

```

// Delay is specified on the left side
#<delay> <LHS> = <RHS>

```

表示语句本身是在 延迟到期后 ***执行的，是最常用的延迟控制形式。***

**例**

```

module vd;
  reg  a, b, c, q;

  initial begin
    $monitor("[%0t] a=%0b b=%0b c=%0b q=%0b", $time, a, b, c, q);

    // Now initialize all signals to 0 at time 0 
    a <= 0;
    b <= 0;
    c <= 0;
    q <= 0;

    // Inter-assignment delay. Wait for #5 time units
    // and then assign a and c to 1\. Note that 'a' and 'c'
    // gets updated at the end of current timestep
    #5  a <= 1;
    	c <= 1;

    // Inter-assignment delay. Wait for #5 time units
  // and then assign 'q' with whatever value RHS gets
    // evaluated to
    #5 q <= a & b | c;
    #20;
  end
endmodule

```

这里，q 在 10 个时间单位时变成 1，因为语句在 10 个时间单位时被求值，而由 a、b 和 c 组成的 RHS 的求值结果为 1。执行完成后，它给出以下输出。

```
xcelium> run
[0] a=0 b=0 c=0 q=0
[5] a=1 b=0 c=1 q=0
[10] a=1 b=0 c=1 q=1
xmsim: *W,RNQUIE: Simulation is complete.

```

### 内部分配延迟

内部赋值延迟表示语句本身在 延迟到期后 ***执行，是最常用的延迟控制形式。***

它们可以用于阻塞和非阻塞分配。如果在模拟过程中遇到带有内部赋值定时控制的语句，那么表达式将被求值，其值将被存储。

然后，语句的执行将被暂停，直到延迟控件指定的时间到期。事件发生前表达式值的变化将被忽略。

```

// Delay is specified on the right side
<LHS> = #<delay> <RHS>

```

赋值运算符右侧声明了赋值内延迟。这表示语句被求值，并且首先捕获 RHS 上所有信号的值。

**例**

```

module vd;
  reg  a, b, c, q;
  initial begin
    $monitor("[%0t] a=%0b b=%0b c=%0b q=%0b", $time, a, b, c, q);
	// Initialize all signals to 0 at time 0
    a <= 0;
    b <= 0;
    c <= 0;
    q <= 0;
    // Inter-assignment delay: Wait for #5 time units
    // and then assign a and c to 1\. Note that 'a' and 'c'
    // gets updated at the end of current timestep
    #5  a <= 1;
    	c <= 1;
    // Intra-assignment delay: First execute the statement
    // then wait for 5 time units and then assign the evaluated
    // value to q
    q <= #5 a & b | c;
    #20;
  end
endmodule

```

上面的代码给出了下面的输出:

```
xcelium> run
[0] a=0 b=0 c=0 q=0
[5] a=1 b=0 c=1 q=0
xmsim: *W,RNQUIE: Simulation is complete.

```

在 5 个时间单位中，a 和 c 使用非阻塞语句分配。并且非阻塞语句的行为被评估，但是仅在时间步结束时才被分配给变量。

因此，a 和 c 的值被计算为 1，但在执行下一个非阻塞语句 q 时不会赋值。因此，当对 q 的 RHS 进行求值时，a 和 c 仍然具有旧值 0，因此$monitor 不会检测到显示语句的变化。

为了观察变化，让我们将赋值语句 a 和 c 从非阻塞改为阻塞。

```

// Non-blocking changed to blocking 
// rest of the code remains the same
         #5  a = 1;
	c = 1;
    q <= #5 a & b | c;

```

输出如下所示:

```
xcelium> run
[0] a=0 b=0 c=0 q=0
[5] a=1 b=0 c=1 q=0
[10] a=1 b=0 c=1 q=1
xmsim: *W,RNQUIE: Simulation is complete.

```

* * *