# 数据流建模

> 原文：<https://www.javatpoint.com/verilog-data-flow-modeling>

数据流建模利用定义电路工作的函数，而不是其门结构。

随着逻辑合成工具变得复杂，数据流建模已经成为一种流行的设计方法。这种方法允许设计人员专注于根据数据流优化电路。

数据流建模使用几个操作符，这些操作符作用于操作数以产生期望的结果。 [Verilog](https://www.javatpoint.com/verilog) 提供约 30 种操作员类型。数据流建模根据从输入到输出的数据流来描述硬件。

数据流建模风格主要用于描述组合电路。使用的主要机制是连续分配。

### 连续作业

一个值被分配给一个名为*的数据类型，该数据类型用于表示连续分配中电路元件之间的物理连接。赋给网络的值由使用操作数和运算符的表达式指定。*

 *连续赋值代替了电路描述中的门，在更高的抽象层次上描述了电路。连续赋值语句以关键字 ***赋值*** 开始。

**语法**

连续赋值的语法是

```

assign [delay] LHS_net = RHS_expression; 

```

LHS 网是一个或多个比特目的网，RHS 表达式是各种运算符的表达式。

在任何源操作数值发生变化时，都会对语句进行求值，并将结果分配给延迟单元后的目标网络。

*   assign 语句的 LHS 必须始终是标量或向量网或串联。它不能是寄存器。
*   连续语句始终是活动语句，这意味着如果 RHS 上的任何值发生变化，LHS 就会自动变化。
*   寄存器或网络或函数调用可以进入赋值的 RHS。
*   每当 RHS 表达式的一个操作数发生变化时，就会对其进行求值。然后将结果分配给 LHS。
*   可以在 assign 语句中指定延迟。

**例**

```

assign out1 = in1 & in2; // perform and function on in1 and in2 and assign the result to out1 
assign out2 = not in1; 
assign #2 z[0] = ~(ABAR & BBAR & EN); // perform the desired function and assign the result after 2 units 

```

连续赋值表达式中的目标可以是下列之一:

1.  标量网络
2.  向量 nti
3.  向量的恒定位选择
4.  向量的常数部分选择
5.  以上任何一项的串联

让我们再举一组例子，其中声明并使用了标量网和矢量网

```

wire COUNT, CIN;               // scalar net declaration 
wire [3:0] SUM, A, B;           // vector nets declaration 
assign {COUT,SUM} = A + B + CIN;              // A and B vectors are added with CIN

```

#### 注意:不允许在同一个目标网上有多个连续的赋值语句。

**向量上的连续赋值**

如特征中所述，连续分配可以在向量网上执行。

```

module adder(a,b,sum);
input [2:0] a,b;
output [3:0] sum;

assign sum = a + b;
$display("a = %b, b = %b, sum=%b", a,b,sum);
endmodule

```

上面的代码描述了一个 3 位加法器。总和的 MSB 专用于上述模块中的进位。它生成以下输出:

```

a = 100, b = 111, sum = 1011                      // (a = 4, b = 7, sum = 011, carry = 1)

```

向量网和标量网的连接也是可能的。3 位加法器的相同示例通过使用串联来显示:

```

module adder(a,b,sum);
input [2:0] a,b;
output [2:0] sum; //sum is a vector
output carry; // carry is a scalar

assign {carry,sum} = a + b; //assigning result to a concatenation of scalar and vector
$display("a = %b, b = %b, sum=%b, carry = %b", a,b,sum,carry);
endmodule

```

输出结果是:

```
a = 100, b = 111, sum = 011, carry = 1 

```

**1。常规连续分配**

它遵循以下步骤，例如:

**第一步:**申报入网。

**第二步:**在网上连续写作业。

下面的代码遵循常规连续赋值:

```

wire out; // net 'out' is declared
assign out = a&b; //continuous assignment on declared net

```

**2。隐式连续赋值**

当一个连续赋值被声明时，我们也可以把它放在网上。格式如下所示:

```

wire out = a & b; // net declaration and assignment together

```

**3。隐式净申报**

在 Verilog 中，在隐式赋值过程中，如果声明了 LHS，它会将 RHS 赋值给声明的 ***网*** ，但是如果没有定义 LHS，它会自动为信号名创建一个网。

```

Wire in0, in1; 
Assign out = in0 ^ in1; 

```

在上例中， ***out*** 是未声明的，但是 Verilog 为 out 做了一个隐式的 net 声明。

### 推迟

在现实硬件中，输入的变化和相应的输出之间有一个时间间隔。

例如， ***和*** 门的延迟为 2 ns，意味着从输入改变的时间算起，2 ns 后输出将发生变化。

延迟值控制从 RHS 操作数改变到新值分配给 LHS 之间的时间。这类似于为门指定延迟。增加延迟有助于模拟简单电路中的时序行为。

它让我们更接近于模拟一个功能电路的实际情况。在连续赋值语句中有不同的方法来指定延迟，例如:

**1。常规分配延迟**

我们在连续赋值语句中赋值一个延迟值。延迟值在 ***指定*** 关键字后指定。

当已经定义了 LHS 信号时，该延迟是适用的，并且该延迟表示改变已经声明的净值的延迟。例如，

```

Assign #10 out = in0 | in1; 

```

如果 RHS 操作数有任何变化，那么 RHS 表达式将在 10 个时间单位后被求值，并且被求值的表达式将被分配给 LHS。

在时间 t，如果上述示例中的一个操作数发生变化，则表达式在 t+10 个时间单位时计算。

这意味着，如果 in0 或 in1 在 10 个时间单位之前改变了值，那么在重新计算时(t+10)考虑 in1 和 in2 的值。

**2。隐式连续分配延迟**

这里，我们使用隐式连续赋值来指定网络上的延迟和赋值。

```

wire #10 out = in0 ^ in1;               //implicit Continuous Assignment Delay.

```

与相同

```

wire out
assign #10 out = in0 ^ in1;

```

**3。净申报延迟**

在这种情况下，延迟与网络而不是分配相关联。

这里，当声明网络而不进行连续赋值时，会增加一个延迟。

```

wire #10 out;
assign out = in;

```

该代码与以下代码具有相同的效果:

```

wire out
assign #10 out = in;

```

* * **