# 开关级建模

> 原文：<https://www.javatpoint.com/verilog-switch-level-modeling>

建模的开关级别提供了逻辑和模拟晶体管抽象级别之间的抽象级别。它描述了传输门的互连，传输门是单个金属氧化物半导体和互补金属氧化物半导体晶体管的抽象。

开关级晶体管被建模为导通或截止、导通或不导通。互连携带的值从整个模拟电压或电流范围抽象为少量离散值。这些值被称为信号 ***强度*** 。

[Verilog](https://www.javatpoint.com/verilog) 也提供晶体管级建模的支持。然而，现在设计人员很少使用，因为电路的复杂性要求他们转向更高层次的抽象，而不是使用开关级建模。

通常，晶体管级建模指的是使用具有模拟输入和输出信号值的晶体管模型的硬件结构中的模型。

另一方面，门级建模是指用数字输入和输出信号值对硬件结构机翼门模型进行建模，这两种建模方案之间的关系称为开关级建模。

晶体管仅表现出数字行为和晶体管级的输入，输出信号值仅限于数字值。

Verilog 采用 4 值逻辑值系统，因此 Verilog 开关输入输出信号可以取 4 个 ***0、1、Z、*** 和 ***X*** 逻辑值中的任意一个。

### 开关级原语

开关是单向或双向的，并且对于每个组是电阻性或非电阻性的，那些用正栅极(例如***【NMOS】***晶体管)导通的原语，以及那些用负栅极(例如***【PMOS】***晶体管)导通的原语。

*   **导通:**表示逻辑值从输入晶体管流向其输入端。
*   **关断:**表示晶体管的输出处于 Z 电平，与输入值无关。
*   单向晶体管在导通时将其输入值传递到输出端。
*   双向晶体管双向导通。
*   电阻结构在将其传递到输出端时会降低其输入逻辑的强度。

### 金属氧化物半导体开关

可以用关键字***【NMOS】***和 ***pmos*** 定义两种类型的 MOS 开关。

*   nmos 关键字用于模拟 NMOS 晶体管。
*   而 pmos 关键字用来建模 PMOS 晶体管。

在 Verilog 中，nmos 和 pmos 开关如下所示:

```

nmos n1(out, data, control);                             // instantiate a nmos switch
pmos p1(out, data, control);                             // instantiate a pmos switch

```

由于开关是 Verilog 原语，如逻辑门，实例的名称是可选的。因此，在不指定实例名的情况下实例化交换机是可以接受的。

```

nmos (out, data , control);                     // instantiate nmos switch ; no instance name
pmos (out, data, control);                      // instantiate pmos switch; no instance name

```

*信号的值由数据和控制信号的值决定。*

 *数据和控制信号的某些组合会使栅极输出 1 或 0 或 z 值，而不选择任何一个值。符号 L 代表 0 或 Z；h 代表 1 或 z。

因此，当其控制信号为 1 时，nmos 开关导通。如果控制信号为 0，输出呈现高阻抗值。类似地，如果控制信号为 0，pmos 开关导通。

### 互补金属氧化物半导体开关

CMOS 开关用 **cmos** 关键字声明。cmos 器件可以用 nmos 和 pmos 器件建模。CMOS 开关实例如下所示，例如:

```

cmos cl(out, data, ncontrol, pcontrol);                               //instantiate cmos gate
  or
cmos (out, data, ncontrol, pcontrol);                                 //no instance name given

```

***控制*** 和 ***控制*** 通常是相辅相成的。当 ncontrol 信号为 1，pcontrol 信号为 0 时，开关导通。如果 ncontrol 为 0，pcontrol 为 1，则开关的输出为高阻抗值。

cmos 门本质上是两个门的组合:一个 ***nmos*** 和一个 ***pmos*** 。因此，上面显示的 cmos 实例化相当于下面的内容。

```

nmos (out, data, ncontrol); //instantiate a nmos switch
pmos (out, data, pcontrol); //instantiate a pmos switch

```

### 双向开关

NMOS、PMOS 和 CMOS 栅极从漏极到源极导通。拥有双向导电的设备非常重要。

在这种情况下，器件任一侧的信号都可以是驱动信号。为此提供了双向开关。

三个关键字用于定义双向开关，例如:

**1。tran:**tran 开关充当两个信号 ***inout1*** 和 ***inout2*** 之间的缓冲器。inout 1 或 inout2 都可以作为驱动信号。

```

module des (input io1, ctrl, output io2);

  tran (io1, io2);

endmodule

```

**2。tranif0:** 只有当 ***控制*** 信号为逻辑 0 时，tranif0 开关才连接两个信号 ***inout1*** 和 ***inout2*** 。如果控制信号为逻辑 1，则非驱动器信号获得高阻抗值 z。驱动器信号保留来自其驱动器的值。

```

module des (input io1, ctrl, output io2);

  tranif0 (io1, io2, ctrl);

endmodule

```

**3。如果 ***控制*** 信号为逻辑 1，则转换 1 开关导通。**

```

module des (input io1, ctrl, output io2);

  tranif1 (io1, io2, ctrl);

endmodule

```

当信号通过电阻开关时，电阻开关会降低信号强度。常规开关保持从输入到输出的信号强度水平。

* * **