# Verilog 时间格式

> 原文：<https://www.javatpoint.com/verilog-timeformat>

Verilog 时间刻度指令指定模拟的时间单位和精度。

verilog***$ time format***系统功能在***$ display******$ strobe***等显示语句中指定 ***%t*** 格式说明符报告样式。

### 句法

```

$timeformat(<unit_number>, <precision>, <suffix_string>, <minimum field width>);

```

*   ***unit_number*** 是源代码中使用的所有‘时间刻度指令’中时间精度最小的。
*   ***精度*** 代表当前时间刻度的小数位数。
*   ***后缀 _ 字符串*** 是一个在实时值旁边显示刻度的选项。

| 单位数 | 时间单位 |
| -3 | 1 毫秒 |
| -6 | 1us |
| -9 | 1ns |
| -12 | 1ps |
| -15 | 1fs |

### 示例 1: 1ns/1ps

以下是 ***$timeformat*** 如何影响时间单位显示格式的示例。

```

`timescale 1ns/1ps

module tb;
  bit a;

  initial begin

    // Wait for some time
    // precision is 1/1000 of
 the main scale (1ns), the 3rd position will truncate
 this delay 
    #10.512351;

    // Display current time with default timeformat parameters
    $display("[T=%0t] a=%0b", $realtime, a);

    // Change timeformat parameters and display again
    $timeformat(-9, 2, " ns");
    $display("[T=%0t] a=%0b", $realtime, a);

    // Remove the space in suffix, and extend fractional digits to 5
    $timeformat(-9, 5, "ns");
    $display("[T=%0t] a=%0b", $realtime, a);

    // Here suffix is wrong, it should not be "ns" because we are
    // setting display in "ps" (-12)
    $timeformat(-12, 3, " ns");
    $display("[T=%0t] a=%0b", $realtime, a);

    // Correct the suffix to ps
    $timeformat(-12, 2, " ps");
    $display("[T=%0t] a=%0b", $realtime, a);
  end
endmodule

```

现在执行上面的代码，它将给出如下输出，例如:

```
xcelium> run
[T=10512] a=0
[T=10.51 ns] a=0
[T=10.51200ns] a=0
[T=10512.000 ns] a=0
[T=10512.00 ps] a=0
xmsim: *W,RNQUIE: Simulation is complete.

```

### 示例 2: 1ns/100ps

我们用不同的时间尺度考虑上面的同一个例子。

```

`timescale 1ns/100ps

module tb;
  bit a;

  initial begin

    // Wait for some time 
    // precision is 1/1000 of
 the main scale (1ns), the 3rd position will truncate
 this delay 
    #10.512351;

    // Display current time with default timeformat parameters
    $display("[T=%0t] a=%0b", $realtime, a);

    // Change timeformat parameters and display again
    $timeformat(-9, 2, " ns");
    $display("[T=%0t] a=%0b", $realtime, a);

    // Remove the space in suffix, and extend fractional digits to 5
    $timeformat(-9, 5, "ns");
    $display("[T=%0t] a=%0b", $realtime, a);

    // Here suffix is wrong, it should not be "ns" because we are
    // setting display in "ps" (-12)
    $timeformat(-12, 3, " ns");
    $display("[T=%0t] a=%0b", $realtime, a);

    // Correct the suffix to ps
    $timeformat(-12, 2, " ps");
    $display("[T=%0t] a=%0b", $realtime, a);
  end
endmodule

```

上面的代码产生以下输出:

```
xcelium> run
[T=105] a=0
[T=10.50 ns] a=0
[T=10.50000ns] a=0
[T=10500.000 ns] a=0
[T=10500.00 ps] a=0
xmsim: *W,RNQUIE: Simulation is complete.

```

### 示例 3: 100ns/1ns

```

`timescale 100ns/1ns

module tb;
  bit a;

  initial begin

    // Wait for some time - note that because precision is 1/1000 of
    // the main scale (1ns), this delay will be truncated by the 3rd
    // position
    #10.512351;

    // Display current time with default timeformat parameters
    $display("[T=%0t] a=%0b", $realtime, a);

    // Change timeformat parameters and display again
    $timeformat(-9, 2, " ns");
    $display("[T=%0t] a=%0b", $realtime, a);

    // Remove the space in suffix, and extend fractional digits to 5
    $timeformat(-9, 5, "ns");
    $display("[T=%0t] a=%0b", $realtime, a);

    // Here suffix is wrong, it should not be "ns" because we are
    // setting display in "ps" (-12)
    $timeformat(-12, 3, " ns");
    $display("[T=%0t] a=%0b", $realtime, a);

    // Correct the suffix to ps
    $timeformat(-12, 2, " ps");
    $display("[T=%0t] a=%0b", $realtime, a);
  end
endmodule

```

#### 注:#1 代表 100 纳米，因此#10 产生 1000 纳米。

输出如下所示:

```
xcelium> run
[T=1051] a=0
[T=1051.00 ns] a=0
[T=1051.00000ns] a=0
[T=1051000.000 ns] a=0
[T=1051000.00 ps] a=0
xmsim: *W,RNQUIE: Simulation is complete.

```

* * *