# Verilog显示任务

> 原文：<https://www.javatpoint.com/verilog-display-tasks>

显示系统任务主要用于显示信息和调试消息，以跟踪来自日志文件的模拟流。有不同的显示任务组和打印值的格式。

通常，显示系统任务分为三类，例如:

1.  显示和写入任务
2.  Verilog 闪光灯
3.  持续监控任务

当调用其中一个任务时，它只是打印它的参数。打印参数的顺序与 x 出现在参数列表中的顺序相同。如果没有指定参数，它可以被声明为空参数，当调用显示任务时，它只打印一个空格字符。参数可以是返回值和带引号的字符串的表达式。

### 显示和写入任务

第一组显示任务非常类似于 ANSI C 语言中的打印功能。$write 和$display 任务的工作方式相同，唯一的区别是$display 任务在输出的末尾添加了一个新的行字符，而$write 任务没有。

**语法**

***$display*** 和 ***$write*** 都按照参数列表中出现的顺序显示参数。

```

$display(<list_of_arguments>);
$write(<list_of_arguments>);

```

***$write*** 并不在其字符串末尾追加换行符，而 ***$display*** 则可以从下图所示的例子中看出。

**例**

```

module tb;
  initial begin
    $display ("This ends with a new line ");
    $write ("This does not,");
    $write ("like this. To start new line, use newline char");
    $display ("This always starts on a new line!");
  end
endmodule

```

现在，执行上面的代码，我们将得到以下输出。

```
ncsim> run
This ends with a new line 
This does not, like this. To start a new line, use newline char
Hello!
ncsim: *W,RNQUIE: Simulation is complete.

```

### verilog 闪光灯

$strobe 在当前增量时间步长结束时打印变量的最终值，格式类似 ***$display*** 。文本中会自动添加一个换行符。

**例**

```

module tb;
  initial begin
    reg [7:0] a;
    reg [7:0] b;

    a = 8'h2D;
    b = 8'h2D;

    #10;                  // Wait till simulation reaches 10ns
    b <= a + 1;           // Assign a+1 value to b

    $display ("[$display] time=%0t a=0x%0h b=0x%0h", $time, a, b);
    $strobe  ("[$strobe]  time=%0t a=0x%0h b=0x%0h", $time, a, b);

    #1;
    $display ("[$display] time=%0t a=0x%0h b=0x%0h", $time, a, b);
    $strobe  ("[$strobe]  time=%0t a=0x%0h b=0x%0h", $time, a, b);

  end
endmodule

```

#### 注:$strobe 在时间 10ns、0x2E 显示变量 b 的最终更新值，$display 仅在 11ns 的下一次模拟增量中拾取该值。

输出如下所示:

```
ncsim> run
[$display] time=10 a=0x2d b=0x2d
[$strobe]  time=10 a=0x2d b=0x2e
[$display] time=11 a=0x2d b=0x2e
[$strobe]  time=11 a=0x2d b=0x2e
ncsim: *W,RNQUIE: Simulation is complete.
ncsim> exit

```

### Verilog 连续监视器

$monitor 有助于在变量或表达式的参数列表发生变化时自动打印出变量或表达式的值。

每次它的任何参数更新后，它都会调用$display，达到类似的效果。文本中会自动添加一个换行符。

**例**

```

module tb;  
initial begin
    reg [7:0] a;
    reg [7:0] b;

    a = 8'h2D;
    b = 8'h2D;

    #10;                  // Wait till simulation reaches 10ns
    b <= a + 1;           // Assign a+1 value to b

    $monitor ("[$monitor] time=%0t a=0x%0h b=0x%0h", $time, a, b);

    #1 b <= 8'hA4;
    #5 b <= a - 8'h33;
    #10 b <= 8'h1;

  end
endmodule

```

$monitor 就像一个在主线程后台运行的任务，它监视并显示其参数变量的值变化。在模拟过程中，新的$monitor 任务可以发布任意次。

```

ncsim> run
[$monitor] time=10 a=0x2d b=0x2e
[$monitor] time=11 a=0x2d b=0xa4
[$monitor] time=16 a=0x2d b=0xfa
[$monitor] time=26 a=0x2d b=0x1
ncsim: *W,RNQUIE: Simulation is complete.

```

### Verilog格式说明符

要在显示函数中打印变量，必须为每个变量指定适当的 ***格式说明符*** 。

这些任务有一个特殊字符(%)，表示需要关于信号值的信息。使用字符串时，编译器会识别%字符，并知道下一个字符是格式规范。

如果使用了格式规范符号，则应始终遵循相应的参数(例外情况是%m 参数)。

| 争吵 | 描述 |
| %h，%H | 以十六进制格式显示 |
| %d，%D | 以十进制格式显示 |
| %b，%B | 以二进制格式显示 |
| %o 或%O | 显示八进制格式 |
| %m，%M | 显示分层名称 |
| %s，%S | 显示为字符串 |
| %t，%T | 以时间格式显示 |
| %f，%F | 以十进制格式显示“实数” |
| %e，%E | 以指数格式显示“真实” |

这些系统任务可以用“o”、“h”和“b”扩展来调用。例如 ***$writeb，$writeo*** ，以及 ***$displayh*** 。当被调用时，它们通知模拟器有一些参数没有相应的格式规范，默认的显示格式应该被改变。默认情况下，$display 和$write 系统任务使用十进制格式来更改显示格式。

显示数据的大小至关重要。一般取决于格式规范。如果我们使用十六进制格式，数据将显示为四个字符，每个字符代表值的四位(单个十六进制值可以表示为四位)。

同样，八进制值将显示为代表三位的一组字符。表达式的结果会自动调整大小。但是，我们可以通过在%字符后添加 0(零)来更改默认设置。

另一个非常有用的显示任务特性是将规则应用于具有未知或高阻抗值的表达式的结果。如果我们使用十进制格式(%d)，那么我们遵循以下规则:

*   当所有位都是未知值时，将显示单个小写“x”字符。
*   当某些位的值未知时，将显示单个大写“X”字符。
*   当所有位都是高阻抗值时，将显示单个小写“z”字符。
*   当某些位具有高阻抗时，将显示单个大写“Z”字符。

如果我们使用十六进制(%h)和八进制(%o)格式，我们遵循以下规则:

*   当组中的所有位都是未知值时，将显示单个小写“x”。
*   当某些组位的值未知时，将显示单个大写字母“X”。
*   当该组中的所有位都具有高阻抗值时，将显示单个小写“z”。
*   当组中的某些位具有高阻抗时，将显示单个大写的“Z”。

#### 注:在八进制格式中，一个组代表三个位，在 0 到 7 的范围内可以表示为一个数字。在十六进制格式中，四位可以表示为 0 到 9 范围内的一个字符和 a 到 f 范围内的字符。

**例**

```

module tb;
  initial begin
    reg [7:0]  a;
    reg [39:0] str = "Hello";
    time       cur_time;
    real       float_pt;

    a = 8'h0E;
    float_pt = 3.142;

    $display ("a = %h", a);
    $display ("a = %d", a);
    $display ("a = %b", a);
    $display ("str = %s", str);
    #200 cur_time = $time;
    $display ("time = %t", cur_time);
    $display ("float_pt = %f", float_pt);
    $display ("float_pt = %e", float_pt);
  end
endmodule

```

上面的代码在执行后给出了如下输出，例如:

```
ncsim> run
a = 0e
a =  14
a = 00001110
str = Hello
time =                  200
float_pt = 3.142000
float_pt = 3.142000e+00
ncsim: *W,RNQUIE: Simulation is complete.

```

### Verilog 转义序列

有些字符被认为是唯一的，因为它们代表其他显示目的，如新行、制表符和表格馈送。

要打印这些特殊字符，这些字符的每次出现都必须是 ***转义的*** 。

| 争吵 | 描述 |
| \n | 换行符 |
| \t | 制表符 |
| \\ | 反斜线符号 |
| \ddd | 八进制码 |
| %% | 百分号 |

**例**

```

module tb;
  initial begin
    $write ("Newline character
");
    $display ("Tab character 	stop");
    $display ("Escaping  " %%");

/*
    // Compilation errors
    $display ("Without escaping ");       // ERROR : Unterminated string
    $display ("Without escaping "");       // ERROR : Unterminated string
*/
  end
endmodule

```

输出如下所示:

```
ncsim> run
Newline character 

Tab character	stop
Escaping  " %
ncsim: *W,RNQUIE: Simulation is complete.

```

* * *