# Verilog 环形计数器

> 原文：<https://www.javatpoint.com/verilog-ring-counter>

环形计数器是由一系列以反馈方式连接的触发器组成的数字电路。环形计数器由移位寄存器组成。只要施加时钟脉冲，数据模式就会重新循环。

该电路是一种特殊类型的移位寄存器，其中最后一个触发器的输出反馈到第一个触发器的输入。当电路复位时，除了一个触发器输出，所有其他输出都为零。对于 n 触发器环形计数器，我们有一个 ***MOD-n*** 计数器。这意味着计数器有 n 种不同的状态。

例如，如果我们采用 4 位环形计数器，那么数据模式将每四个时钟脉冲重复一次。如果模式是 1000，它将生成 0100、0010、0001、1000 等。

![Verilog Ring Counter](img/a3476c7e368835dc30516cd8c1490e04.png)

### 例子

```

module ring_ctr  #(parameter WIDTH=4) 
  (  
	input clk,                
	input rstn,
  	output reg [WIDTH-1:0] out
  );    

  always @ (posedge clk) begin
      if (!rstn)
         out <= 1;
      else begin
        out[WIDTH-1] <= out[0];
        for (int i = 0; i < WIDTH-1; i=i+1) begin
          out[i] <= out[i+1];
        end
      end
  end
endmodule

```

**试验台**

```

module tb;
  parameter WIDTH = 4;

  reg clk;
  reg rstn;
  wire [WIDTH-1:0] out;

  ring_ctr 	u0 (.clk (clk),
                .rstn (rstn),
                .out (out));

  always #10 clk = ~clk;

  initial begin
    {clk, rstn} <= 0;

    $monitor ("T=%0t out=%b", $time, out);
    repeat (2) @(posedge clk);
    rstn <= 1;
    repeat (15) @(posedge clk);
    $finish;
  end
endmodule

```

### 环形计数器的旋转运动

由于上面的例子有四种不同的状态，它也被称为模-4 或 ***模-4*** 计数器，每个触发器输出的频率值等于主时钟频率的四分之一。

![Verilog Ring Counter](img/ca02a6c85b52bad09ee08ad366c193e6.png)

计数器的 ***模*** 或 ***模*** 是计数器在重复自身之前计数或排序通过的状态数，环形计数器可以输出任意模数。

一个 ***mod-n*** 环形计数器将需要 ***n*** 个触发器连接来循环单个数据位，从而提供 ***n*** 种不同的输出状态。

在上面的例子中，16 种可能状态中只有 4 种被使用，这使得环形计数器的输出状态使用效率非常低。

* * *