# 4 位计数器

> 原文：<https://www.javatpoint.com/verilog-4-bit-counter>

4 位计数器从 4'b0000 到 4'h1111 开始递增，然后回到 4'b0000。只要有运行时钟，它就会一直计数，复位保持高电平。

当最终加法的最高有效位被丢弃时，就会发生翻转。当计数器处于最大值 4'h1111 并获得一个计数请求时，计数器试图达到 5'b10000，但由于它只能支持 4 位，MSB 将被丢弃，导致 0。

```

	0000
	0001
	0010
	...
	1110
	1111
	       rolls over
	0000
	0001
	...

```

该设计包含两个输入，一个用于时钟，另一个用于低电平有效复位。低电平有效复位是指当复位引脚的值为 0 时，设计复位。有一个名为*的 4 位输出，本质上是提供计数器值。*

*![4-bit Counter](img/69926e838f0e0913759747aa9c643e66.png)

### 电子计数器示例

```

module counter (input clk,      // Declare input port for the clock to allow counter to count up
                  input rstn,              // Declare input port for the reset to allow the counter to be reset to 0 when required
                  output reg[3:0] out);    // Declare 4-bit output port to get the counter values

 // This always block will be triggered at the rising edge of clk (0->1)
  // Once inside this block, it checks if the reset is 0, then change out to zero 
  // If reset is 1, then the design should be allowed to count up, so increment the counter 

  always @ (posedge clk) begin
    if (! rstn)
      out <= 0;
    else
      out <= out + 1;
  end
endmodule

```

***模块*** 计数器有一个时钟和低电平有效复位(***【n】***)作为输入，计数器值作为 4 位输出。

每当时钟从 0 转换到 1 时，总是执行*块，这表示正沿或上升沿。*

 *只有当复位保持高电平或 1 时，输出才会增加，这是通过 ***【否则】*** 模块实现的。如果在时钟的正边沿复位为低电平，则输出复位为默认值 4'b0000。

**试验台**

我们可以将设计实例化到我们的 testbench 模块中，以验证计数器是否按预期计数。

![4-bit Counter](img/9bf4034e2fb06a361d78ae5e79d369b3.png)

测试平台模块名为 ***tb_counter*** ，不需要端口，因为这是仿真中的顶层模块。然而，我们需要有内部变量来生成、存储和驱动时钟和复位。

为此，我们为时钟和复位声明了两个类型为***【reg】***的变量。我们还需要一个 ***线*** 型网来连接设计的输出；否则，它将默认为 1 位标量网络。

时钟通过 ***始终*** 块生成，会给出一个 10 时间单位的周期。 ***初始*** 块用于为我们的内部变量设置初始值，并驱动设计的重置值。

设计在测试平台中被实例化，并连接到我们的内部变量，以在我们从测试平台驱动它们时获得值。

我们的测试平台中没有任何***$ display】***语句，因此我们在控制台中看不到任何消息。

```

module tb_counter;
  reg clk;                     // Declare an internal TB variable called clk to drive clock to the design
  reg rstn;                    // Declare an internal TB variable called rstn to drive active low reset to design
  wire [3:0] out;              // Declare a wire to connect to design output

  // Instantiate counter design and connect with Testbench variables
  counter   c0 ( .clk (clk),
                 .rstn (rstn),
                 .out (out));

  // Generate a clock that should be driven to design
  // This clock will flip its value every 5ns -> time period = 10ns -> freq = 100 MHz

 always #5 clk = ~clk;

  // This initial block forms the stimulus of the testbench
  initial begin
    // Initialize testbench variables to 0 at start of simulation
    clk <= 0;
    rstn <= 0;

    // Drive rest of the stimulus, reset is asserted in between
    #20   rstn <= 1;
    #80   rstn <= 0;
    #50   rstn <= 1;

    // Finish the stimulus after 200ns
    #20 $finish;
  end
endmodule

```

请注意，当低电平有效复位变为 0 时，计数器复位至 0，当复位在 150ns 左右无效时，计数器从下一次时钟正边沿开始计数。

**硬件示意图**

![4-bit Counter](img/abbe0806ee316045af08e20c7b562699.png)

* * ***