# Verilog文件操作

> 原文：<https://www.javatpoint.com/verilog-file-operations>

Verilog 具有系统任务和功能，可以打开文件，将值输出到文件中，从文件中读取值并加载到其他变量中，以及关闭文件。

该应用程序描述了 Verilog 模型或测试平台如何读取文本和二进制文件来加载内存、应用刺激和控制模拟。文件输入输出功能格式基于 C stdio 例程，如 ***fopen、fgetc、fprintf、*** 和 ***fscanf*** 。

[Verilog 语言](https://www.javatpoint.com/verilog)有一套写文件的系统函数($fdisplay，$fwrite 等。)但只读取单一固定格式的文件($readmem)。

在过去，如果我们想读取一个不是 ***$readmem*** 格式的文件，我们必须学习编程语言接口(PLI)和 C 语言，编写 C 代码来读取文件并将值传递到 Verilog 中，然后调试组合的 [C](https://www.javatpoint.com/c-programming-language-tutorial) 和 Verilog 代码。此外，Verilog 一次只能打开 32 个文件。

但是，使用新的文件输入/输出系统功能，我们可以直接从 Verilog 执行文件输入/输出。我们可以将 Verilog HDL 写入:

*   读取刺激文件，将模式应用于模型的输入。
*   阅读期望值文件，与您的模型进行比较。
*   阅读驱动模拟的命令脚本。
*   将 ASCII 或二进制文件读入 Verilog 寄存器和存储器。
*   同时打开数百个日志文件(尽管一次只能写入一个)。

该文件中所有示例的代码都包含在文件输入/输出功能的示例目录中。

#### 注意:这些系统任务的行为与等效的标准输入输出例程相同。例如，$fscanf 将跳过空白，包括空行，就像 fscanf()。我们可以用 C 语言原型化代码，然后将其转换为 Verilog。

### 打开和关闭文件

***$fopen*** 函数打开一个文件，返回一个未格式化的整数格式的多通道描述符。这对于每个文件都是唯一的。模拟器和文件之间的所有通信都是通过文件描述符进行的。用户只能指定文件名作为参数。它将在默认文件夹或完整路径描述中给出的文件夹中创建一个文件。

我们使用 ***$fclose*** 功能关闭一个打开的文件。调用此函数时没有任何参数。它只是关闭所有打开的文件。如果指定了一个参数，它将只关闭给定描述符的文件。默认情况下，在模拟器终止之前，所有打开的文件都会关闭。这意味着用户不必关闭任何文件，关闭是由模拟器自动完成的。

所有文件输出任务的工作方式与其对应的显示任务相同。唯一的区别是文件描述符作为函数参数列表中的第一个参数出现。这些函数只能向文件追加数据，不能从文件中读取数据。

```

module tb;
	// Declare a variable to store the file handler
	integer fd;

	initial begin
		// Open a new file by the name "my_file.txt"
		// with "write" permissions, and store the file
		// handler pointer in variable "fd"
		fd = $fopen("my_file.txt", "w");

		// Close the file handle pointed to by "fd"
		$fclose(fd);
	end
endmodule

```

**打开文件模式**

| 争吵 | 描述 |
| “r”或“rb” | 开放阅读。 |
| “w”或“wb” | 创建一个新文件进行写入。如果文件存在，将其截断为零长度并覆盖它。 |
| “a”或“ab” | 如果文件存在，追加(在 EOF 时打开进行写入)，否则创建一个新文件。 |
| “r+”、“r+b”或“rb+” | 开放阅读和写作。 |
| “w+”、“w+b”或“wb+” | 为更新截断或创建。 |
| “a+”、“a+b”或“ab+” | 追加，或创建一个新的文件在 EOF 更新。 |

**如何写文件**

| 功能 | 描述 |
| $fdisplay | 类似于$display，改为写入文件 |
| $fwrite | 类似于$write，改为写出到文件中 |
| $fstrobe | 类似于$strobe，改为写入文件 |
| $fmonitor | 类似于$monitor，改为写入文件 |

上述系统的每个函数都以十进制为基数打印值。它们还有另外三个版本可以打印二进制、八进制和十六进制的值。

| 功能 | 描述 |
| $fdisplay() | 默认情况下以十进制打印 |
| $fdisplayb() | 二进制打印 |
| $fdisplayo() | 八进制打印 |
| $fdisplayh() | 以十六进制打印 |

```

module tb;
	integer  	fd;
	integer 	i;
	reg [7:0] 	my_var;

	initial begin
		// Create a new file
		fd = $fopen("my_file.txt", "w");
		my_var = 0;

      $fdisplay(fd, "Value displayed with $fdisplay");
		#10 my_var = 8'h1A;
		$fdisplay(fd, my_var);      // Displays in decimal
		$fdisplayb(fd, my_var); 	// Displays in binary
		$fdisplayo(fd, my_var); 	// Displays in octal
		$fdisplayh(fd, my_var); 	// Displays in hex

	  // $fwrite does not print the newline char '\n' automatically at
	  // the end of each line; So we can predict all the values printed
	  // below to appear on the same line
      $fdisplay(fd, "Value displayed with $fwrite");
		#10 my_var = 8'h2B;
		$fwrite(fd, my_var);
		$fwriteb(fd, my_var);
		$fwriteo(fd, my_var);
		$fwriteh(fd, my_var);

      // Jump to new line with '\n', and print with strobe which takes
      // the final value of the variable after non-blocking assignments
      // are done
      $fdisplay(fd, "\nValue displayed with $fstrobe");
		#10 my_var <= 8'h3C;
		$fstrobe(fd, my_var);
		$fstrobeb(fd, my_var);
		$fstrobeo(fd, my_var);
		$fstrobeh(fd, my_var);
      #10 $fdisplay(fd, "Value displayed with $fmonitor");
	  $fmonitor(fd, my_var);
		for(i = 0; i < 5; i= i+1) begin
			#5 my_var <= i;
		end
      #10 $fclose(fd);
	end
endmodule

```

上面的代码给出了以下输出，例如:

```
Value displayed with $fdisplay
26
00011010
032
1a
The value displayed with $fwrite
43001010110532b
The value displayed with $fstrobe
60
00111100
074
3c
The value displayed with $fmonitor
60
0
1
2
3
4

```

### 读文件

要从内存文件中读取和存储数据，我们使用 ***$readmemh*** 和***$ readmem***函数。

**$ readmember**任务读取二进制数据， **$readmemh** 读取十六进制数据。数据必须存在于文本文件中。允许使用空白来提高可读性，以及单行和块中的注释。这些数字必须存储为二进制或十六进制值。内存文件的基本形式包含由加载到内存中的新行字符分隔的数字。

当一个函数在没有开始和结束地址的情况下被调用时，它从第一个单元开始将数据加载到内存中。开始和结束地址只能用于将数据加载到内存的特定部分。

地址可以是显式的，在文件中用@字符给出，后跟十六进制地址，数据用空格隔开。记住文件中给出的开始和结束地址范围是很重要的。函数调用中的参数必须相互匹配。否则，将显示一条错误消息，加载过程将终止。

**读一行**

系统函数 ***$fgets*** 将[hl]fd[/hd]指定的文件中的字符读入变量 str，直到 ***str*** 被填充，或者一个换行符被读取并转移到 str，或者遇到 EOF 条件。

如果读取过程中出现错误，它将返回代码零。否则，它返回读取的字符数。

**检测电渗流**

系统函数 ***$feof*** 在找到 eof 时返回非零值，否则对于给定的文件描述符作为参数返回零。

```

module tb;
	reg[8*45:1] str;
	integer  	fd;

	initial begin
	  fd = $fopen("my_file.txt", "r");

	  // Keep reading lines until EOF is found
      while (! $feof(fd)) begin

      	// Get current line into the variable 'str'
        $fgets(str, fd);

        // Display contents of the variable
        $display("%0s", str);
      end
      $fclose(fd);
	end
endmodule

```

**fdisplay 的多个参数**

当给 ***$fdisplay*** 多个变量时，它只是按给定的顺序一个接一个地打印所有变量，没有空格。

```

  reg [3:0] a, b, c, d;
  reg [8*30:0] str;
  integer fd;

  initial begin
    a = 4'ha;
    b = 4'hb;
    c = 4'hc;
    d = 4'hd;

    fd = $fopen("my_file.txt", "w");
    $fdisplay(fd, a, b, c, d);
    $fclose(fd);
  end
endmodule

```

### 将数据格式化为字符串

***$sformat*** 系统函数中的第一个参数是放置结果的变量名。

第二个参数是 ***format_string*** ，它告诉下面的参数应该如何格式化成字符串。

```

module tb;
	reg [8*19:0] str;
	reg [3:0] a, b;

	initial begin
		a = 4'hA;
		b = 4'hB;

		// Format 'a' and 'b' into a string given
		// by the format, and store into 'str' variable
		$sformat(str, "a=%0d b=0x%0h", a, b);
		$display("%0s", str);
	end
endmodule

```

* * *