# Verilog 多路复用器

> 原文：<https://www.javatpoint.com/verilog-multiplexer>

多路复用器是一种从多个输入中选择一个输出的器件。它也被称为数据选择器。我们用术语*和***【MPX】***来指代多路复用器。*

 *多路复用器用于通信系统中，以增加在一定时间和带宽内通过网络发送的数据量。它允许我们将多条数据线压缩成一条数据线。

它在多条输入线中的一条之间切换，并将它们逐个组合到输出端。它使用控制信号决定切换哪条输入线。

物理上，一个多路复用器有 n 个输入引脚、一个输出引脚和 m 个控制引脚。n = 2^m.由于多路复用器的工作是选择一条数据输入线并将其发送到输出端，因此它也被称为 ***数据选择器*** 。

![Verilog Multiplexer](img/8a4f70060dcb4ae499870e6d8c3daee3.png)

构建多路复用器有三种主要方式。

*   数字多路复用器由逻辑门组成。
*   模拟多路复用器由晶体管制成。
*   机械开关或旋转开关是用旋转轴制成的。

***多路复用器*** 本身就像一个数字控制的多位置开关，应用于选择输入的二进制代码控制数据输入，数据输入将切换到输出。

例如，它基于选择信号将数据从 N 个输入之一传输到输出。一个 4 位多路复用器将有 N 个输入，每个 4 位，其中每个输入可以通过使用选择信号传输到输出。

![Verilog Multiplexer](img/d3c8e933ea425a80aa69826d8d6a3170.png)

***【Sel】***是 2 位输入，可以有 4 个值。选择线上的每个值将允许一个输入发送到输出。

4x1 多路复用器可以多种方式实现，这里我们展示两种最常见的方式:

**1。使用赋值语句**

```

module mux_4to1_assign ( input [3:0] a,                 // 4-bit input called a
                         input [3:0] b,                 // 4-bit input called b
                         input [3:0] c,                 // 4-bit input called c
                         input [3:0] d,                 // 4-bit input called d
                         input [1:0] sel,               // input sel used to select between a,b,c,d
                         output [3:0] out);             // 4-bit output based on input sel

   // When sel[1] is 0, (sel[0]? b:a) is selected and sel[1] is 1, (sel[0] ? d:c) is taken
   // If sel[0] is 0, a is sent to output, else b and if sel[0] is 0, c is sent to output, else d
   assign out = sel[1] ? (sel[0] ? d : c) : (sel[0] ? b : a);

endmodule

```

名为 ***mux_4x1_assign*** 的模块有四个 4 位数据输入、一个 2 位选择输入和一个 4 位数据输出。多路复用器将使用 assign 语句根据选择信号 sel 选择 a、b、c 或 d。

**2。使用案例说明**

当我们使用 case 语句时，那么信号*被声明为 ***reg*** 类型，因为它被用在一个 ***程序*** 块中。*

 *```

module mux_4to1_case ( input [3:0] a,                 // 4-bit input called a
                       input [3:0] b,                 // 4-bit input called b
                       input [3:0] c,                 // 4-bit input called c
                       input [3:0] d,                 // 4-bit input called d
                       input [1:0] sel,               // input sel used to select between a,b,c,d
                       output reg [3:0] out);         // 4-bit output based on input sel

   // This always block gets executed whenever a/b/c/d/sel changes value
   // When it happens, output is assigned to either a/b/c/d
   always @ (a or b or c or d or sel) begin
      case (sel)
         2'b00 : out <= a;
         2'b01 : out <= b;
         2'b10 : out <= c;
         2'b11 : out <= d;
      endcase
   end
endmodule

```

名为 ***mux_4x1_case*** 的模块有四个 4 位数据输入、一个 2 位选择输入和一个 4 位数据输出。多路复用器将使用 case 语句根据选择信号 sel 选择 a、b、c 或 d。

### 多路复用器的用途

多路复用器包括以下有用的点，例如:

1.  在我们拥有通信网络的通信系统中，多路复用器通过允许音频和视频数据在单个通道上传输来提高系统的效率。
2.  在光纤通信中，多路复用器使用一种称为 ***密集波分复用*** 的技术将多根光缆合并到一根光缆上，完成同样的工作。
3.  在卫星通信中，多路复用器使用 ***GSM*** 通信将数据从卫星的计算机系统传输到地面部分。
4.  它也是一个并行到串行数据转换器。
5.  计算机减少了将内存连接到其他计算机部件所需的铜线数量。

### 如何加入多路复用器？

如果我们有小型多路复用器，但我们想增加它们的功能，我们可以加入它们来获得一个具有更多输入的多路复用器。多路复用器的级联很容易。确保我们的连接提供与目标多路复用器相同数量的输入和控制线。

让我们使用 2:1 多路复用器制作 4:1 多路复用器。我们知道 2:1 多路复用器有两个输入和一条选择线。因此，连接两个 2:1 多路复用器将为我们提供四个输入和两条选择线。

我们可以将输出减少到一个，因此我们使用另一个 2:1 多路复用器来组合两条线以获得一条线。

然而，尽管这给了我们所需要的一个输出，它给了我们一个额外的选择线。现在我们有三条选择线。

现在我们将三条选择线减少到两条选择线。我们可以通过连接两条选择线来做到这一点。这将从本质上把两条线缩减为一条线。下图显示了我们通过应用逻辑得到的结果。

![Verilog Multiplexer](img/cca31d09817156f020437d7db6c336cf.png)

### 8:1 和 16:1 多路复用器

与我们上面看到的过程类似，我们可以使用 2:1 多路复用器设计 8:1 多路复用器，使用 4:1 多路复用器设计 16:1 多路复用器，或者使用 8:1 多路复用器设计 16:1 多路复用器。

![Verilog Multiplexer](img/dba1ec0383b580d10c7217e56f93b2dc.png)

我们也可以反其道而行之，使用输入比所需更多的多路复用器作为较小的多路复用器。这里有一个 8:1 多路复用器用作 2:1 多路复用器。

![Verilog Multiplexer](img/fac0a55b5b2335743296f32aa98c1f0c.png)

### 多路解调器

多路分解器是一种组合逻辑电路，其功能与多路复用器相反。多路分解器也称为 ***多路分解器*** 。

在 ***demux*** 中，我们有 n 条输出线、一条输入线和 m 条选择线。输出线数量和选择线数量之间的关系与我们在多路复用器中看到的相同。也就是说，2^m = n。根据由选择线形成的二进制数的值，任何一条输出线连接到输入线。

此时，其余输出线进入关闭状态。也就是说，剩余行的值为 0。

这样，多路分解器将串行数据转换为并行数据，并充当串并转换器。此外，由于多路分解器将一条数据线连接到多条数据线并在它们之间切换，所以它也被称为 ***数据分配器*** 。下图显示了多路分解器的一般符号。

![Verilog Multiplexer](img/58b0c22650f79be9b07ced798996e616.png)

### 解复用器是如何工作的？

为了理解解复用器的工作原理，我们将直接设计一个。1:2 多路分解器是所有多路分解器中最简单的。我们有一个输入、两个输出和一条选择线(2^m = 2，因此 m=1)。

![Verilog Multiplexer](img/57f85d1208eec818d2ab81eae48d1e19.png)

我们可以看到，根据选择线的值，一个输出连接到输入线。当 S 为 0 时，第一条输出线连接到输入端。当 S 为 1 时，第二条输出线连接到输入端。

这样，多路分解器将数据从一条数据线分配到多条数据线。

接下来，我们将设计一个 1:4 解复用器。根据我们上面看到的选择线公式，1:4 demux 将有两条选择线。让我们为 1:4 demux 绘制真值表。

**真值表**

| I0 | S0 | S1 | Y0 | Y1 | Y2 | Y3 |
| 我 | Zero | Zero | 我 | Zero | Zero | Zero |
| 我 | Zero | one | Zero | 我 | Zero | Zero |
| 我 | one | Zero | Zero | Zero | 我 | Zero |
| 我 | one | one | Zero | Zero | Zero | 我 |

正如我们所看到的，这个真值表比 4:1 多路复用器的真值表短，因为我们没有取输入的两个可能值，而是取 I。得到的等式将是相同的。所以从真值表来看，我们得到，

y0 = S0 ' S1 '
Y1 = S0 ' S1
Y2 = s0s 1 '
Y3 = s0s 1

上述方程的合成电路如下所示。

![Verilog Multiplexer](img/7d16ff7721b5e128b1f3034938788dd2.png)

### 多路分解器的用途

下面是解复用器的一些重要用途，例如:

1.  解复用器可以从通信系统中传输端的多路复用器接收串行数据。然后 ***demux*** 将数据转换为其原始形式。
2.  我们可以使用多路分解器将算术逻辑单元的输出存储在多个存储寄存器中。
3.  多路分解器还充当串行到并行转换器。

* * ***